(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1527411,      38553]
NotebookOptionsPosition[   1265008,      35832]
NotebookOutlinePosition[   1265822,      35859]
CellTagsIndexPosition[   1265779,      35856]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This Notebook contains supplementary material related to the paper
\"Arrangement of Central Points on the Faces of a Tetrahedron\" by Stanley \
Rabinowitz,
submitted to the International Journal of Computer Discovered Mathematics 
(http : // www.journal - 1. eu/) in August 2020.
 
This Notebook is Copyright \[Copyright] August 2020 by Stanley Rabinowitz \
(stan.rabinowitz@comcast.net) and is published with open access. This \
Notebook is distributed under the terms of the Creative Commons Attribution \
License which permits any use, distribution, and reproduction in any medium, \
provided the original author and the source are credited.\
\>", "Text",
 CellChangeTimes->{{3.8056311537890673`*^9, 3.805631183666998*^9}, {
  3.805631221024912*^9, 3.8056313282165127`*^9}, {3.805643718014955*^9, 
  3.805643719078762*^9}},ExpressionUUID->"371ff2f8-f3d0-420c-b039-\
e77672a2725a"],

Cell[BoxData[
 RowBox[{"(*", "\n", "\t\t\t", 
  RowBox[{
   RowBox[{
   "If", " ", "your", " ", "input", " ", "files", " ", "are", " ", "going", 
    " ", "to", " ", "be", " ", "in", " ", "a", " ", "special", " ", 
    "directory"}], ",", "\[IndentingNewLine]", "            ", 
   RowBox[{
   "you", " ", "should", " ", "add", " ", "that", " ", "directory", " ", "to",
     " ", "the", " ", "$Path", " ", 
    RowBox[{"variable", ".", " ", "For"}], " ", 
    RowBox[{"example", ":", "\[IndentingNewLine]", "          ", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"$Path", ",", 
       RowBox[{"NotebookDirectory", "[", "]"}]}], "]"}]}]}]}], "\n", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.805631006929036*^9, 3.8056310083438387`*^9}, {
  3.805640012619944*^9, 3.8056400427391376`*^9}, {3.805640124611961*^9, 
  3.805640173227358*^9}},ExpressionUUID->"b1163c4e-79d8-4c96-b931-\
923fe0f4dfc2"],

Cell[CellGroupData[{

Cell["\<\
ReadCenters[file_,echo_]:=
Block[{expr,k,state,cname},
\tstate = OpenRead[file];
\tIf[state==$Failed,Return[0]];
\tk = 0;
\tWhile[True,
\t\tcname = Read[file,Word,WordSeparators->\",\"];
\t\tRead[file,Character];
\t\texpr = Read[file,Expression];
\t\tIf[expr==EndOfFile,Break[]];
\t\tIf[expr==$Aborted,Break[]];
\t\tIf[expr==Null,Continue[]];
\t\tk++;
\t\tIf[echo,
\t\t\tPrint[\"\"];
\t\t\tPrint[k,\") \",cname,\": \",expr];
\t\t\t];
\t\tcenterName[k] = cname;
\t\texpr=expr/.{K->(2a^2b^2+2b^2c^2+2c^2a^2-a^4-b^4-c^4)/4};
\t\tTrilinearCenter[k]=Together[expr];
\t];
\tClose[file];
\tReturn[k];
];

SetAttributes[g,Orderless];\t(* Make g commutative *)

numberOfCenters = 0;
numberOfCenters =
\tReadCenters[\"trilinearCenters.txt\",True];
Print[numberOfCenters,\" trilinear centers found.\"];

For[i=1,i<=numberOfCenters,i++,
\t(* Convert Center info into triples *)
\tcoord1 = TrilinearCenter[i];
\tcoord2 = coord1/.{a->b,b->c,c->a};
\tcoord3 = coord2/.{a->b,b->c,c->a};
\tTrilinearCoords[i]={coord1,coord2,coord3};
\t(* Convert to Areal Coordinates *)
\tArealCoords[i]={a coord1,b coord2,c coord3};
\t];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{3.805639037965542*^9},
 AspectRatioFixed->True,
 CellLabel->
  "In[186]:=",ExpressionUUID->"4234ab68-a109-4864-a278-29656578f3a7"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965054262*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"51ccb197-f6cc-4555-8c1a-6e0f71201997"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"incenter\"\>", "\[InvisibleSpace]", "\<\": \"\>",
    "\[InvisibleSpace]", "1"}],
  SequenceForm[1, ") ", "incenter", ": ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965056303*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"76ac379a-1d58-4294-bb88-66de29a0315e"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965057922*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"ee91ec92-eaea-439f-9dc5-4123c0a1f45a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "2", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\": \"\>",
    "\[InvisibleSpace]", 
   FractionBox["1", "a"]}],
  SequenceForm[2, ") ", "centroid", ": ", $CellContext`a^(-1)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965059495*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"5e85d021-a840-4b44-852d-43cadcdf930b"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965061105*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"405d1c23-165e-4030-8cdf-d0e1667e7907"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "3", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  3, ") ", "circumcenter", 
   ": ", $CellContext`a (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965062714*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"28daf1c5-1250-42c8-8971-94a3fcf917da"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965064662*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"38078b31-b19c-4f75-aa86-5d920f1e7a70"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "4", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"orthocenter\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  4, ") ", "orthocenter", 
   ": ", $CellContext`a^(-1)/(-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996506633*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"5fc19aee-aeb8-4081-8562-220f34827195"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965068025*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"5bfc5989-acaa-4c41-9605-74c0159aad6e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "5", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"nine point center\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "4"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "4"]}], "a"]}],
  SequenceForm[
  5, ") ", "nine point center", 
   ": ", $CellContext`a^(-1) ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965069951*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"4cbf2f36-0b25-4eef-b2e9-de5d8e4768b2"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965071851*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"7fdb971a-426d-4eef-94d1-48c9cd03beaf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "6", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"symmedian point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", "a"}],
  SequenceForm[6, ") ", "symmedian point", ": ", $CellContext`a],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399650736227`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"03fc96fc-877f-4642-b2da-e828604f51f6"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965075201*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a6acf05d-f4da-4fab-97a3-a761755d08e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "7", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}],
  SequenceForm[
  7, ") ", "Gergonne point", 
   ": ", $CellContext`a^(-1)/(-$CellContext`a + $CellContext`b + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965076796*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c4889aab-d6df-433b-90e8-9053ee5bdbc2"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965078375*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"3294a03e-b2b2-4672-90ac-10ee1fb11d5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "8", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "a"}], "+", "b", "+", "c"}], "a"]}],
  SequenceForm[
  8, ") ", "Nagel point", 
   ": ", $CellContext`a^(-1) (-$CellContext`a + $CellContext`b + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996508*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a7bc21b2-9c87-47d7-8c04-de889c314ca8"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399650818653`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"82012601-404e-4f94-9c99-a83ef3fa4ad7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "9", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "a"}], "+", "b", "+", "c"}]}],
  SequenceForm[
  9, ") ", "Mittenpunkt", 
   ": ", -$CellContext`a + $CellContext`b + $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996508349*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"30d62214-60aa-430d-8a4e-89a689242e87"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996508503*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"67c0ee30-5d03-4a4c-bea0-4bbab63ea4f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "10", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker center\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"b", "+", "c"}], "a"]}],
  SequenceForm[
  10, ") ", "Spieker center", 
   ": ", $CellContext`a^(-1) ($CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399650865993`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"83827553-bdc9-4a65-b70f-3754299f36e8"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965088153*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"f36d9b9f-d255-4ad0-9d57-e4476751bbf1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "11", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "b"}], "+", "c"}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], "a"]}],
  SequenceForm[
  11, ") ", "Feuerbach point", 
   ": ", $CellContext`a^(-1) (-$CellContext`b + $CellContext`c)^2 \
(-$CellContext`a + $CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965089704*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"6539b65b-0bee-476e-8d4b-cd6cf3d9b136"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399650912733`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"3ad217ac-314c-4ecc-9755-80cd5afc02ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "12", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X12\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}], "2"], 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}],
  SequenceForm[
  12, ") ", "X12", 
   ": ", $CellContext`a^(-1) ($CellContext`b + \
$CellContext`c)^2/(-$CellContext`a + $CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399650928164`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"d838eeea-d168-47a6-858c-ebefba39a062"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965094337*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"9ba04be4-0ea3-466d-8d4c-77f99b023caf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "13", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"1st isogonic center (Fermat point)\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], "-", 
     RowBox[{"4", " ", "K"}]}], 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"b", " ", "c"}], "+", 
       SuperscriptBox["c", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       RowBox[{"b", " ", "c"}], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  13, ") ", "1st isogonic center (Fermat point)", 
   ": ", $CellContext`a^(-1) (-$CellContext`a^2 + $CellContext`b^2 - \
$CellContext`b $CellContext`c + $CellContext`c^2)^(-1) (-$CellContext`a^2 + \
$CellContext`b^2 + $CellContext`b $CellContext`c + $CellContext`c^2)^(-1) (
    3^Rational[
       1, 2] (-$CellContext`a^2 + $CellContext`b^2 + $CellContext`c^2) - 4 K)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965095976*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c29c7334-659a-4aa9-99e8-8a3e5c310bf0"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965097721*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"dd834b83-9cda-424c-bcaf-04910a1acb74"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "14", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isogonic center\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], "-", 
     RowBox[{"4", " ", "K"}]}], 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"b", " ", "c"}], "+", 
       SuperscriptBox["c", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       RowBox[{"b", " ", "c"}], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  14, ") ", "2nd Isogonic center", 
   ": ", $CellContext`a^(-1) (-$CellContext`a^2 + $CellContext`b^2 - \
$CellContext`b $CellContext`c + $CellContext`c^2)^(-1) (-$CellContext`a^2 + \
$CellContext`b^2 + $CellContext`b $CellContext`c + $CellContext`c^2)^(-1) (
    3^Rational[1, 2] ($CellContext`a^2 - $CellContext`b^2 - $CellContext`c^2) - 
    4 K)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965099374*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"b95ef58c-a054-47e4-a6e3-c4f7ebfaf660"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965100913*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"dfbda8bb-6e6e-4a53-a1c1-6616d0068ac4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "15", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"1st Isodynamic point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], "+", 
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}]}], "+", 
      RowBox[{"4", " ", "K"}]}], ")"}]}]}],
  SequenceForm[
  15, ") ", "1st Isodynamic point", 
   ": ", $CellContext`a (
    3^Rational[
       1, 2] (-$CellContext`a^2 + $CellContext`b^2 + $CellContext`c^2) + 4 K)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965102373*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"83a205bc-954f-4203-9605-f01215db58d3"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651038637`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a75ca343-33c3-421c-b5e9-d16bb20bddf5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "16", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isodynamic point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}]}], "+", 
      RowBox[{"4", " ", "K"}]}], ")"}]}]}],
  SequenceForm[
  16, ") ", "2nd Isodynamic point", 
   ": ", $CellContext`a (
    3^Rational[1, 2] ($CellContext`a^2 - $CellContext`b^2 - $CellContext`c^2) + 
    4 K)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965105359*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"94433305-7375-41ef-8cfc-c06db4084cc8"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965106832*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"259ccaa3-3be7-475e-aad6-140cb05ada63"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "17", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "+", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"], "-", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", "K"}]}], 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "+", 
       SuperscriptBox["b", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["c", "2"]}], "+", 
       SuperscriptBox["c", "4"]}], ")"}]}]]}],
  SequenceForm[
  17, ") ", "1st Napoleon point", 
   ": ", $CellContext`a^(-1) ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4)^(-1) (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2 - 4 3^Rational[1, 2] K)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965108368*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2be48901-9118-492c-8884-2c90d2ab8a6f"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965109909*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"1d75df1c-8fdd-4196-959e-9fcf5199e317"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "18", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "-", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", "K"}]}], 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "+", 
       SuperscriptBox["b", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["c", "2"]}], "+", 
       SuperscriptBox["c", "4"]}], ")"}]}]]}],
  SequenceForm[
  18, ") ", "2nd Napoleon point", 
   ": ", $CellContext`a^(-1) ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4)^(-1) ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`c^2 - 4 3^Rational[1, 2] K)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965111433*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a3452c6c-ad7c-46c2-b316-5b5d983f43af"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965112966*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a12b56cd-23cd-4847-9117-41231a6c5e2d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "19", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "+", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"]}]]}],
  SequenceForm[
  19, ") ", "Crucial point", 
   ": ", (-$CellContext`a^2 + $CellContext`b^2 + $CellContext`c^2)^(-1)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965114362*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"87caa698-1893-45e1-8dda-b417a5d5e411"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651157913`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"da77f11a-191a-41fc-8643-962f6f19774a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "20", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SuperscriptBox["a", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox["b", "4"], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     SuperscriptBox["c", "4"]}], "a"]}],
  SequenceForm[
  20, ") ", "De Longchamps point", 
   ": ", $CellContext`a^(-1) ((-3) $CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
    2 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651172657`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"93164cb1-274e-413a-a632-9e745f33bd73"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965118763*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2c84754f-7736-4ea6-963b-807a5a9345b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "21", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "a"}], "+", "b", "+", "c"}], 
    RowBox[{"b", "+", "c"}]]}],
  SequenceForm[
  21, ") ", "Schiffler point", 
   ": ", ($CellContext`b + $CellContext`c)^(-1) (-$CellContext`a + \
$CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965120216*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"8a3c5239-f63f-45b6-8d6c-8b330fe03a61"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965121655*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"16f03b13-d528-4b19-8618-296563a17650"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "22", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      SuperscriptBox["c", "4"]}], ")"}]}]}],
  SequenceForm[
  22, ") ", "Exeter point", 
   ": ", $CellContext`a (-$CellContext`a^4 + $CellContext`b^4 + \
$CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965123205*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"9a6aef59-f2cf-4a6e-aa05-eed7b131d0bc"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996512466*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"d934694e-cf41-41e0-8302-83ad795fe196"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "23", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"far out point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}]}]}],
  SequenceForm[
  23, ") ", "far out point", 
   ": ", $CellContext`a (-$CellContext`a^4 + $CellContext`b^4 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651261053`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"1af41dd6-9647-4076-97d4-49e658cb17bc"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965127556*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"503dfba2-7ebf-4fb6-a4e4-da0a76b17671"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "24", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X24\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "-", 
       SuperscriptBox["b", "4"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "2"]}], "-", 
       SuperscriptBox["c", "4"]}], ")"}]}], 
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"]}]]}],
  SequenceForm[
  24, ") ", "X24", 
   ": ", $CellContext`a ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`c^2)^(-1) (-$CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + 
    2 $CellContext`a^2 $CellContext`c^2 - $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651290607`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"b8e2960e-67c6-4381-a854-314aa6fa1bfc"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651305656`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"b761960f-2d1b-495a-851f-33ec0d031e67"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "25", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X25\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["a", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "+", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"]}]]}],
  SequenceForm[
  25, ") ", "X25", 
   ": ", $CellContext`a/(-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965131978*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"3d4fe4bf-c361-4b53-97d2-3c7b6c73c800"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965133423*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"42d05af0-2716-41a9-aea2-f93a3cdf086e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "26", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "8"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      SuperscriptBox["b", "8"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      SuperscriptBox["c", "8"]}], ")"}]}]}],
  SequenceForm[
  26, ") ", "Circumcenter of tangential triangle", 
   ": ", $CellContext`a (-$CellContext`a^8 + 
    2 $CellContext`a^6 $CellContext`b^2 - 
    2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 + 
    2 $CellContext`a^6 $CellContext`c^2 - 2 $CellContext`b^6 $CellContext`c^2 + 
    2 $CellContext`b^4 $CellContext`c^4 - 2 $CellContext`a^2 $CellContext`c^6 - 
    2 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965135003*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"715e642f-7664-4e1f-ade4-bc11107bb36e"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965136676*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"853ebbd0-8b0f-40cb-b550-d374456ae021"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "27", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X27\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  27, ") ", "X27", 
   ": ", $CellContext`a^(-1) ($CellContext`b + \
$CellContext`c)^(-1)/(-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965138137*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"82741e14-875e-4168-a5e7-a2c4e418fb2b"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965139608*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a2782d39-f7a2-4f58-9874-f8d9d64ab97f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "28", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X28\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  28, ") ", "X28", 
   ": ", ($CellContext`b + $CellContext`c)^(-1)/(-$CellContext`a^2 + \
$CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965141049*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"bc4848fd-579d-4122-b051-c62a4a21b57a"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965142509*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2177ea89-50cf-4339-89c6-1f26c82387b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "29", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X29\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"a", "-", "b", "-", "c"}], 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  29, ") ", "X29", 
   ": ", $CellContext`a^(-1) ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`b + $CellContext`c)^(-1)/($CellContext`a^2 - \
$CellContext`b^2 - $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965144011*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"9ab0a8db-45b3-4756-add6-c3251644c1ae"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651454782`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"072f0f3b-0133-46b8-a664-9956acf28719"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "30", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X30\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", "a"}], "+", "b", "+", "c"}], "a"]}],
  SequenceForm[
  30, ") ", "X30", 
   ": ", $CellContext`a^(-1) (
    2 $CellContext`a + $CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965146888*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"f9bca379-59d3-4188-aa48-1b489b4c0c00"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965148315*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"77175869-ccc7-4878-b90b-a4f23fb5670c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "31", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   SuperscriptBox["a", "2"]}],
  SequenceForm[31, ") ", "2nd power point", ": ", $CellContext`a^2],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965149694*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"7888a723-7fad-4a12-af78-70504f89f5cd"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965151123*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"4476c4ad-11b4-4a2a-a271-a7d60a708583"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "32", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   SuperscriptBox["a", "3"]}],
  SequenceForm[32, ") ", "3rd power point", ": ", $CellContext`a^3],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965152564*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"5dbec48a-54c8-48c9-926e-9886004bf610"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965153996*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"63c5b55c-4089-420b-be91-fbf6b2a8489b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "33", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X33\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "a"}], "+", "b", "+", "c"}], 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "+", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"]}]]}],
  SequenceForm[
  33, ") ", "X33", 
   ": ", (-$CellContext`a + $CellContext`b + \
$CellContext`c)/(-$CellContext`a^2 + $CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965155438*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"9343b70b-968f-417e-a899-c89db675cc2c"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965157048*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"1e910ce5-aacd-4b5e-9f12-9c876b205cac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "34", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X34\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  34, ") ", "X34", 
   ": ", (-$CellContext`a + $CellContext`b + \
$CellContext`c)^(-1)/(-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996515853*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"6b9a8f07-9c32-4d49-a3ca-613138d738c8"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965160007*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"5ccedeeb-1b8b-489e-bb89-b858c3dc6a75"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "35", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X35\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  35, ") ", "X35", 
   ": ", $CellContext`a (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651614447`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"e82703f7-d208-4d2b-862a-1226e22bb27f"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651628933`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"6de262f6-da72-4278-a0bd-bad3abf0f4a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "36", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X36\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"b", " ", "c"}], "-", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  36, ") ", "X36", 
   ": ", $CellContext`a ($CellContext`a^2 - $CellContext`b^2 + $CellContext`b \
$CellContext`c - $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651643267`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"4ba353d1-366c-4bde-a55d-83272e3b9c1d"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965165771*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2fbe6791-e453-42fc-ace2-f4ac098d6beb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "37", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X37\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"b", "+", "c"}]}],
  SequenceForm[37, ") ", "X37", ": ", $CellContext`b + $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965167285*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"441203b2-dee5-48aa-9618-847560dd972b"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651687202`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"5937fed9-93af-4a3f-9868-334ebb5b1ef0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "38", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X38\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"]}]}],
  SequenceForm[38, ") ", "X38", ": ", $CellContext`b^2 + $CellContext`c^2],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965170192*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"1964eb1b-ac90-4361-a777-972f5fbab02c"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965171605*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"fd9177e1-2467-4c07-a116-074df7baddfa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "39", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  39, ") ", "Brocard midpoint", 
   ": ", $CellContext`a ($CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965173007*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"15462f16-5795-415a-bfc8-7b7883686b54"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651744623`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"beeeb58a-8aa3-4337-a9fa-e1e3657ba1dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "40", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X40\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "3"], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"]}], "-", 
    SuperscriptBox["b", "3"], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "c"}], "-", 
    RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "c"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "2"]}], "-", 
    SuperscriptBox["c", "3"]}]}],
  SequenceForm[
  40, ") ", "X40", 
   ": ", $CellContext`a^3 + $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 $CellContext`c - 
   2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965176095*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"443e3e9d-c4ab-4553-87ff-318127a9e0c9"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996517761*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"02f07f4d-083f-490f-a402-1bbaa71b1d94"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "41", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X41\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}],
  SequenceForm[
  41, ") ", "X41", 
   ": ", $CellContext`a^2 (-$CellContext`a + $CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965179051*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"9a0b4794-bb05-4692-a247-6aab9900004d"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996518047*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"0543221b-70d0-4f60-9332-bb59fa2b404e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "42", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X42\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c"}], ")"}]}]}],
  SequenceForm[
  42, ") ", "X42", ": ", $CellContext`a ($CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965181868*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"0fea522d-a925-4652-b019-2937d7a394a5"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965183267*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"64b52802-9e92-4e8b-85aa-536e42b6e363"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "43", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X43\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"a", " ", "b"}], "+", 
    RowBox[{"a", " ", "c"}], "-", 
    RowBox[{"b", " ", "c"}]}]}],
  SequenceForm[
  43, ") ", "X43", 
   ": ", $CellContext`a $CellContext`b + $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965184801*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"423b821b-b0de-4163-9f47-c059bf38cf00"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965186282*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"21f40674-62cf-42ef-a9a7-f570cc201290"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "44", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X44\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}]}],
  SequenceForm[
  44, ") ", "X44", 
   ": ", (-2) $CellContext`a + $CellContext`b + $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965187688*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"3a86ecf2-bcbf-4c18-8177-9dd9a91a2b1c"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965189093*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"1dd0e29a-48f1-4988-a9d6-27144ec6b95e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "45", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X45\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "a"}], "+", 
    RowBox[{"2", " ", "b"}], "+", 
    RowBox[{"2", " ", "c"}]}]}],
  SequenceForm[
  45, ") ", "X45", ": ", -$CellContext`a + 2 $CellContext`b + 
   2 $CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399651905003`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"7669c966-6b91-4332-98d0-bb1f77d87f9c"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965191903*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"756093f6-ecc9-47a5-93ee-b8038f734c4c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "46", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X46\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "3"], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"]}], "-", 
    SuperscriptBox["b", "3"], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "c"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "2"]}], "-", 
    SuperscriptBox["c", "3"]}]}],
  SequenceForm[
  46, ") ", "X46", 
   ": ", $CellContext`a^3 + $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 $CellContext`c + \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 - $CellContext`c^3],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965193474*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"de121f17-6986-45d9-a1b7-81827a96cda1"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965194956*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c1bfd83b-9f3d-4917-bb4c-48bae8ca1a02"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "47", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X47\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}]}]}],
  SequenceForm[
  47, ") ", "X47", 
   ": ", $CellContext`a^2 ($CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`c^2 + $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965196447*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c7d6bae5-d066-476b-8887-e9fb0ba5a0f4"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965197953*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"fef30252-0508-439d-aff7-4bdaaf37ea02"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "48", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X48\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  48, ") ", "X48", 
   ": ", $CellContext`a^2 (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996519939*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a4fd87e3-8e46-4430-b110-0b08263f2648"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965200828*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"e75c94a0-2062-4db1-9f32-d5748b725851"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "49", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X49\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ")"}]}]}],
  SequenceForm[
  49, ") ", "X49", 
   ": ", $CellContext`a^3 ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`c^2) (-$CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + 
    2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965202392*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"71ba4eda-d340-4b3c-b9c0-f434a5f2d248"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965204018*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"52415aa3-90d4-49da-9697-fc3259b816c6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "50", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"X50\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"b", " ", "c"}], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"b", " ", "c"}], "-", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  50, ") ", "X50", 
   ": ", $CellContext`a^3 ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`b $CellContext`c - $CellContext`c^2) ($CellContext`a^2 - \
$CellContext`b^2 + $CellContext`b $CellContext`c - $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965205523*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"547556e0-145c-498a-a010-4dbf4ba00106"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965207073*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"ec7d7278-cbf1-4b0c-a419-5eb211db49bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "51", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ")"}]}]}],
  SequenceForm[
  51, ") ", "Centroid of orthic triangle", 
   ": ", $CellContext`a ($CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996520857*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"256439b8-5060-4eda-91af-0f37bd97a3b9"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965210067*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"51e79423-8e7f-4dda-9a1c-5fdcb7e12406"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "52", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}]}]}],
  SequenceForm[
  52, ") ", "Orthocenter of orthic triangle", 
   ": ", $CellContext`a ($CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4) ($CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`c^2 + $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965211619*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"20b64273-2427-4cca-b52a-6371e339016b"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965213166*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"cd2131de-7dac-4002-9c99-5ae348647a56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "53", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "4"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "4"]}], 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  53, ") ", "Symmedian point of orthic triangle", 
   ": ", $CellContext`a^(-1) (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2)^(-1) ($CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965214679*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"f6f52034-359f-4965-9b39-2e3b4cb051fb"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965216217*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"b29cfa0b-c9e8-4394-8ed6-37c415fe4e6b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "54", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Nine point inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["a", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "4"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "4"]}]]}],
  SequenceForm[
  54, ") ", "Nine point inv", 
   ": ", $CellContext`a/($CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + 
   2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652177687`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a3f56cee-0813-4b1a-9078-7c59937e564a"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965219335*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"ae8b1540-06fc-4e24-a61f-9b2124c87d03"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "55", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}],
  SequenceForm[
  55, ") ", "Gergonne inv", 
   ": ", $CellContext`a (-$CellContext`a + $CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965220745*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c7dbf858-0b2e-4007-b606-1128c4b1dd29"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652221746`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"4ecacb8c-08cd-49e8-9ac7-581d4b11d48d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "56", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["a", 
    RowBox[{
     RowBox[{"-", "a"}], "+", "b", "+", "c"}]]}],
  SequenceForm[
  56, ") ", "Nagel inv", 
   ": ", $CellContext`a/(-$CellContext`a + $CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965223577*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"f0085f72-ea00-4710-9d4d-e3d017a1491a"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965225193*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"61822e1e-863c-484c-99b5-ae1ba703d0d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "57", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"-", "a"}], "+", "b", "+", "c"}]]}],
  SequenceForm[
  57, ") ", "Mittenpunkt inv", 
   ": ", (-$CellContext`a + $CellContext`b + $CellContext`c)^(-1)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965226618*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"3af666fc-9a49-44eb-a06d-6b18e8bbd4c8"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652280607`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"8de2d586-83f3-4664-b094-7c554ec2ddaa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "58", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["a", 
    RowBox[{"b", "+", "c"}]]}],
  SequenceForm[
  58, ") ", "Spieker inv", 
   ": ", $CellContext`a/($CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965229465*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"6738566e-0703-4bc1-b987-3c41d317e5eb"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965230898*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"88c3c56b-5c9f-46fe-ab03-488ad4e10f23"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "59", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["a", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "b"}], "+", "c"}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}],
  SequenceForm[
  59, ") ", "Feuerbach inv", 
   ": ", $CellContext`a (-$CellContext`b + \
$CellContext`c)^(-2)/(-$CellContext`a + $CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965232335*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"632c732a-57a1-4201-a13f-43f0a226a9b5"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652337914`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"eea6689a-f702-49e0-a104-7069c39ed328"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "60", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X12 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}], "2"]]}],
  SequenceForm[
  60, ") ", "X12 inv", 
   ": ", $CellContext`a ($CellContext`b + $CellContext`c)^(-2) \
(-$CellContext`a + $CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965235221*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"03c56ae1-02fc-45ab-98b3-e5ba2ef30876"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965236731*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"3f4d7b40-c3d3-4a6a-b86a-9c32e6a79df3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "61", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"], "+", 
      RowBox[{"4", " ", 
       SqrtBox["3"], " ", "K"}]}], ")"}]}]}],
  SequenceForm[
  61, ") ", "1st Napoleon point inv", 
   ": ", $CellContext`a (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2 + 4 3^Rational[1, 2] K)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652383842`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"70e60c5c-fc0e-4a6a-81b7-2baaed68f24c"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965239946*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"e2896ab5-d5b0-4129-9e0c-d9393fb8baec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "62", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "+", 
      RowBox[{"4", " ", 
       SqrtBox["3"], " ", "K"}]}], ")"}]}]}],
  SequenceForm[
  62, ") ", "2nd Napoleon point inv", 
   ": ", $CellContext`a ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`c^2 + 4 3^Rational[1, 2] K)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965241432*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a56dcfed-ccc5-4724-a3fb-3c5b7e43f32e"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965242936*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a7f618d4-5fb7-4502-bfd7-f7d8ee9bd8f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "63", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], "+", 
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"]}]}],
  SequenceForm[
  63, ") ", "Crucial point inv", 
   ": ", -$CellContext`a^2 + $CellContext`b^2 + $CellContext`c^2],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965244375*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"e4628727-1bbe-4811-9ca6-a9d758d29dc8"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965245832*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"0bb0720f-e8d2-4cbd-9a37-fad887ee652b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "64", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["a", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SuperscriptBox["a", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox["b", "4"], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     SuperscriptBox["c", "4"]}]]}],
  SequenceForm[
  64, ") ", "De Longchamps point inv", 
   ": ", $CellContext`a/((-3) $CellContext`a^4 + 
   2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
   2 $CellContext`a^2 $CellContext`c^2 - 
   2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965247347*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2ba6f63c-579c-4866-9bc8-a6c4cd860ce5"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965249044*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"cc75b2fd-b8a2-4d12-9ea3-64df15aaf48c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "65", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"b", "+", "c"}], 
    RowBox[{
     RowBox[{"-", "a"}], "+", "b", "+", "c"}]]}],
  SequenceForm[
  65, ") ", "Schiffler point inv", 
   ": ", ($CellContext`b + $CellContext`c)/(-$CellContext`a + $CellContext`b + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652505217`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"e57d3d06-a034-4e40-ab31-d4608daf1d72"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965252*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"604463a6-9c68-494e-9e40-93fe627c9ac1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "66", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "4"]}], "+", 
       SuperscriptBox["b", "4"], "+", 
       SuperscriptBox["c", "4"]}], ")"}]}]]}],
  SequenceForm[
  66, ") ", "Exeter point inv", 
   ": ", $CellContext`a^(-1)/(-$CellContext`a^4 + $CellContext`b^4 + \
$CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965253538*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2dfe7f3c-bf2a-4277-aaa7-23c23d7de488"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965255044*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2372cef8-fbcb-4b5e-a160-66f9a1089b69"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "67", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"far out point inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "4"]}], "+", 
       SuperscriptBox["b", "4"], "-", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["c", "2"]}], "+", 
       SuperscriptBox["c", "4"]}], ")"}]}]]}],
  SequenceForm[
  67, ") ", "far out point inv", 
   ": ", $CellContext`a^(-1)/(-$CellContext`a^4 + $CellContext`b^4 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965256527*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"bf0fb608-8a17-46c4-ab25-d99a0557af33"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965258101*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"5580697a-0a83-4801-a9c0-2b1cb43a5cb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "68", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X24 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"]}], 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "-", 
       SuperscriptBox["b", "4"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "2"]}], "-", 
       SuperscriptBox["c", "4"]}], ")"}]}]]}],
  SequenceForm[
  68, ") ", "X24 inv", 
   ": ", $CellContext`a^(-1) ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`c^2)/(-$CellContext`a^4 + 
   2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + 
   2 $CellContext`a^2 $CellContext`c^2 - $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652596607`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"809740bf-2610-4553-bf92-9ddc90addd71"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965261209*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c3652db1-79d1-4004-92c7-299d289d392e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "69", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X25 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "+", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"]}], "a"]}],
  SequenceForm[
  69, ") ", "X25 inv", 
   ": ", $CellContext`a^(-1) (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652626667`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"65b2dd76-86db-47d5-9bcb-825816ebebc9"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996526414*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2dbce668-56a1-4498-9118-e393d361f43a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "70", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "8"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "6"], " ", 
        SuperscriptBox["b", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "6"]}], "+", 
       SuperscriptBox["b", "8"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "6"], " ", 
        SuperscriptBox["c", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "6"], " ", 
        SuperscriptBox["c", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "4"], " ", 
        SuperscriptBox["c", "4"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "6"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["c", "6"]}], "+", 
       SuperscriptBox["c", "8"]}], ")"}]}]]}],
  SequenceForm[
  70, ") ", "Circumcenter of tangential triangle inv", 
   ": ", $CellContext`a^(-1)/(-$CellContext`a^8 + 
   2 $CellContext`a^6 $CellContext`b^2 - 
   2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 + 
   2 $CellContext`a^6 $CellContext`c^2 - 2 $CellContext`b^6 $CellContext`c^2 + 
   2 $CellContext`b^4 $CellContext`c^4 - 2 $CellContext`a^2 $CellContext`c^6 - 
   2 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965265843*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"ecf7352d-f8bf-4ec5-9c19-d6f196e6530e"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652674913`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"04ff3b02-e9c1-4f8b-b780-9cc679b59f39"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "71", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X27 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  71, ") ", "X27 inv", 
   ": ", $CellContext`a ($CellContext`b + $CellContext`c) (-$CellContext`a^2 + \
$CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965268997*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"653c5b24-aeea-400e-9a61-c86d3c9ded9c"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652705183`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"82bf62da-30e1-4525-ab56-eb99a996dd45"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "72", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X28 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"b", "+", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  72, ") ", "X28 inv", 
   ": ", ($CellContext`b + $CellContext`c) (-$CellContext`a^2 + \
$CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652720013`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"839c4ef0-d715-4c7e-8c4e-08980f0b48ca"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652734957`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"1fa3e877-67eb-4ae4-b60d-1a497b49d383"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "73", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X29 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}]}], 
    RowBox[{"a", "-", "b", "-", "c"}]]}],
  SequenceForm[
  73, ") ", "X29 inv", 
   ": ", $CellContext`a ($CellContext`a - $CellContext`b - \
$CellContext`c)^(-1) ($CellContext`b + $CellContext`c) ($CellContext`a^2 - \
$CellContext`b^2 - $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652749968`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a094d815-8208-40bb-a5f4-738db1308396"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965276533*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"7c324041-53d6-46ae-b403-c0731cde7da4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "74", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X30 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["a", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["a", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox["b", "4"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     SuperscriptBox["c", "4"]}]]}],
  SequenceForm[
  74, ") ", "X30 inv", 
   ": ", $CellContext`a/((-2) $CellContext`a^4 + $CellContext`a^2 \
$CellContext`b^2 + $CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 - 
   2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965278059*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"9582d9c6-44a9-4e28-bbb3-3007148d5c19"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965280036*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"d68bd58c-3090-450d-b7ec-a88a18f9b62d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "75", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    SuperscriptBox["a", "2"]]}],
  SequenceForm[75, ") ", "2nd power point inv", ": ", $CellContext`a^(-2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965281619*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"809b718f-7acf-4f7c-9eea-538029178bc6"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652831497`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"53e81a49-933d-4927-bd6f-d02085fa2199"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "76", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    SuperscriptBox["a", "3"]]}],
  SequenceForm[76, ") ", "3rd power point inv", ": ", $CellContext`a^(-3)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965284605*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"97bda6be-44d8-481f-9526-189066878b90"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996528619*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"626f52cc-42fa-4d3e-8604-235a233edd25"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "77", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X33 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "+", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"]}], 
    RowBox[{
     RowBox[{"-", "a"}], "+", "b", "+", "c"}]]}],
  SequenceForm[
  77, ") ", "X33 inv", 
   ": ", (-$CellContext`a + $CellContext`b + $CellContext`c)^(-1) \
(-$CellContext`a^2 + $CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965288268*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"fdad4d9b-2458-4cc1-85b9-36cc6b48c6e4"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965289927*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"b06a3bec-f687-4d4c-b55e-89d4c154f0ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "78", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X34 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  78, ") ", "X34 inv", 
   ": ", (-$CellContext`a + $CellContext`b + $CellContext`c) \
(-$CellContext`a^2 + $CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652914257`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"0a664050-ead7-488f-828c-1087f5bd51b8"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965292906*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"82b621e2-8d3d-4bb4-a206-244d5dc28030"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "79", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X35 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       RowBox[{"b", " ", "c"}], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  79, ") ", "X35 inv", 
   ": ", $CellContext`a^(-1)/(-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965294509*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"0b11c4c4-40f0-4157-997f-3525149c58d2"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965296094*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"7febb892-f675-4e41-8334-f2243820a908"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "80", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X36 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"], "+", 
       RowBox[{"b", " ", "c"}], "-", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  80, ") ", "X36 inv", 
   ": ", $CellContext`a^(-1)/($CellContext`a^2 - $CellContext`b^2 + \
$CellContext`b $CellContext`c - $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399652976017`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"58e801f8-d323-4f07-8ad9-9a755bc3b716"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965299115*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a42293d8-0e0d-4b29-befc-73b744513095"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "81", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X37 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"b", "+", "c"}]]}],
  SequenceForm[
  81, ") ", "X37 inv", ": ", ($CellContext`b + $CellContext`c)^(-1)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965300619*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"1b47772a-cdfa-49c8-a426-0e8cec774fd8"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996530221*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"33da6a5d-9ce8-44e0-83e8-8d1c61ba4e12"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "82", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X38 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"]}]]}],
  SequenceForm[
  82, ") ", "X38 inv", ": ", ($CellContext`b^2 + $CellContext`c^2)^(-1)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965303877*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"4a8cfad3-2e1e-42d2-8e24-281e42dbf479"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965305409*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"d9c66f93-f535-4ed3-959d-6760f5fb6593"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "83", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  83, ") ", "Brocard midpoint inv", 
   ": ", $CellContext`a^(-1)/($CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653069572`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c0baf930-f524-4e97-9627-83ea8d880c0e"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996530849*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"e771183d-a0f4-4332-8e25-8bcf33702064"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "84", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X40 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["a", "3"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b"}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "3"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "c"}], "-", 
     RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", "c"}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"b", " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "3"]}]]}],
  SequenceForm[
  84, ") ", "X40 inv", 
   ": ", ($CellContext`a^3 + $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 $CellContext`c - 
    2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3)^(-1)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965310161*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"fa4808ce-64bc-4071-863c-42976f94db35"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653117447`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c09e8795-f9da-43cf-9938-18e1a9edd4c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "85", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X41 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}],
  SequenceForm[
  85, ") ", "X41 inv", 
   ": ", $CellContext`a^(-2)/(-$CellContext`a + $CellContext`b + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965313212*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a24f411f-1d81-42f4-a0f1-62167594e3dd"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965314707*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"0cb5931b-b704-46de-b3d4-8f5d6c7a58e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "86", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X42 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}]}]]}],
  SequenceForm[
  86, ") ", "X42 inv", 
   ": ", $CellContext`a^(-1)/($CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653161592`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"de425fcf-0d08-4588-bb69-73d5a2731830"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965317634*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2bfd6c35-55d8-49dc-a391-5e63e5f4e708"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "87", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X43 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"a", " ", "b"}], "+", 
     RowBox[{"a", " ", "c"}], "-", 
     RowBox[{"b", " ", "c"}]}]]}],
  SequenceForm[
  87, ") ", "X43 inv", 
   ": ", ($CellContext`a $CellContext`b + $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c)^(-1)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965319171*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"f82c8f58-f1cd-48bf-8b05-6f2f8e10a7ac"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653211517`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"96667089-b9c0-4770-a1e3-2bb7acb6f032"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "88", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X44 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}]]}],
  SequenceForm[
  88, ") ", "X44 inv", 
   ": ", ((-2) $CellContext`a + $CellContext`b + $CellContext`c)^(-1)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965323103*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"8e5d9b34-a744-4efc-8d90-9521dba50f17"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965324684*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"f64d7967-7df0-460e-9e0a-f6316cca2256"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "89", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X45 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"-", "a"}], "+", 
     RowBox[{"2", " ", "b"}], "+", 
     RowBox[{"2", " ", "c"}]}]]}],
  SequenceForm[
  89, ") ", "X45 inv", 
   ": ", (-$CellContext`a + 2 $CellContext`b + 2 $CellContext`c)^(-1)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653261642`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"82c5cec4-26d4-406a-b97f-9ad9bbd93319"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965327677*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c61822d5-f299-41a9-804b-a52f4c618666"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "90", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X46 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["a", "3"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b"}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "3"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "c"}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", "c"}], "-", 
     RowBox[{"a", " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"b", " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "3"]}]]}],
  SequenceForm[
  90, ") ", "X46 inv", 
   ": ", ($CellContext`a^3 + $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 $CellContext`c + \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 - $CellContext`c^3)^(-1)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653292513`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"240f78b9-eed5-4725-af0f-a23440da1cf6"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965330926*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"8d939d92-73c1-4676-9828-da176a09fa11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "91", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X47 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "+", 
       SuperscriptBox["b", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "2"]}], "+", 
       SuperscriptBox["c", "4"]}], ")"}]}]]}],
  SequenceForm[
  91, ") ", "X47 inv", ": ", $CellContext`a^(-2)/($CellContext`a^4 - 
   2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
   2 $CellContext`a^2 $CellContext`c^2 + $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965332471*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"7626366c-767c-4ffa-bf6d-32dc99510d22"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965334188*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"e83ed515-b33e-48ab-9d6b-c83d7482fef6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "92", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X48 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  92, ") ", "X48 inv", 
   ": ", $CellContext`a^(-2)/(-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965335785*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c3a67ad6-b84f-44b6-9c54-ddca3db38649"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965337825*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"678a25fe-08fa-43d4-b99d-00bed7989469"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "93", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X49 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "-", 
       SuperscriptBox["b", "4"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["c", "2"]}], "-", 
       SuperscriptBox["c", "4"]}], ")"}]}]]}],
  SequenceForm[
  93, ") ", "X49 inv", 
   ": ", $CellContext`a^(-3) ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`c^2)^(-1)/(-$CellContext`a^4 + 
   2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + 
   2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653397703`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"e7769183-d41e-404e-94b3-7846f0c5f217"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965341435*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"010ba9ad-f23e-44dd-b085-8910d4d51be0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "94", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X50 inv\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"b", " ", "c"}], "-", 
       SuperscriptBox["c", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["b", "2"], "+", 
       RowBox[{"b", " ", "c"}], "-", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  94, ") ", "X50 inv", 
   ": ", $CellContext`a^(-3) ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`b $CellContext`c - $CellContext`c^2)^(-1)/($CellContext`a^2 - \
$CellContext`b^2 + $CellContext`b $CellContext`c - $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965343014*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2feafbb2-7dc3-4112-b749-aef16896fbaa"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965344583*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"cbb92654-b65d-437e-9666-f36054b6e098"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "95", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "-", 
       SuperscriptBox["b", "4"], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["c", "2"]}], "-", 
       SuperscriptBox["c", "4"]}], ")"}]}]]}],
  SequenceForm[
  95, ") ", "Centroid of orthic triangle inv", 
   ": ", $CellContext`a^(-1)/($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + 
   2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965346119*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"94995a70-19f7-4910-9fbd-2e539359b849"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653477097`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"9d6e2e37-8372-41d1-b212-814d757ee337"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "96", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "-", 
       SuperscriptBox["b", "4"], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["c", "2"]}], "-", 
       SuperscriptBox["c", "4"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "+", 
       SuperscriptBox["b", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "2"]}], "+", 
       SuperscriptBox["c", "4"]}], ")"}]}]]}],
  SequenceForm[
  96, ") ", "Orthocenter of orthic triangle inv", 
   ": ", $CellContext`a^(-1) ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4)^(-1)/($CellContext`a^4 - 
   2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
   2 $CellContext`a^2 $CellContext`c^2 + $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965349326*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"6c6c3a07-27a5-4f40-b8db-924d1f031926"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653509483`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"646871a4-857c-447a-9ee1-85455e24a313"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "97", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle inv\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}], 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "4"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "4"]}]]}],
  SequenceForm[
  97, ") ", "Symmedian point of orthic triangle inv", 
   ": ", $CellContext`a (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2)/($CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + 
   2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653525763`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c1842c61-d405-4ded-a6cd-a5dd36c3b78e"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653547087`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"b27dd74f-a4a3-4382-895a-0887a3f165a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "98", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Tarry point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], " ", 
        SuperscriptBox["b", "2"]}], "+", 
       SuperscriptBox["b", "4"], "-", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["c", "2"]}], "+", 
       SuperscriptBox["c", "4"]}], ")"}]}]]}],
  SequenceForm[
  98, ") ", "Tarry point", 
   ": ", $CellContext`a^(-1)/(-$CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 + $CellContext`c^4)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965356572*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"044a371e-3c2b-48eb-b6f4-3065b529a161"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965358191*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"283a00f0-2241-47b1-8db6-b980331be831"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "99", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"Steiner point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "c"}], ")"}]}], 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}]}]]}],
  SequenceForm[
  99, ") ", "Steiner point", 
   ": ", $CellContext`a^(-1) (-$CellContext`a + $CellContext`b) \
(-$CellContext`a + $CellContext`c)/($CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653597097`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"fdd8e7c1-859c-4b41-a056-24e0f80b2a53"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965361383*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"b1f592ef-d0d9-4829-8673-9bf1baf029e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "100", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X100\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", "c"}], ")"}]}]}],
  SequenceForm[
  100, ") ", "X100", 
   ": ", (-$CellContext`a + $CellContext`b) (-$CellContext`a + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965362936*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"f44e329a-ec7a-4741-a7b1-68e3810ba5eb"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965364439*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"f597bba7-f350-4b9e-bf90-0c8e94d54ce8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "101", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X101\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", "c"}], ")"}]}]}],
  SequenceForm[
  101, ") ", "X101", 
   ": ", $CellContext`a (-$CellContext`a + $CellContext`b) (-$CellContext`a + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965365922*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"808ab5e4-613c-4f9e-86e3-956a38906f22"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965367394*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a6ccf6e7-e957-4ffb-87a1-cea69f1d546e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "102", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X102\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], " ", "b", " ", "c"}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}]]}],
  SequenceForm[
  102, ") ", "X102", 
   ": ", (-$CellContext`a $CellContext`b $CellContext`c + $CellContext`a^2 \
($CellContext`b + $CellContext`c))^(-1)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653690166`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"4e1dcfb0-535f-415e-ae22-0c3da310f0e1"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996537101*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"684e506b-156b-4e07-bf33-a872f77a1214"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "103", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X103\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["a", 
    RowBox[{
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"]}]]}],
  SequenceForm[
  103, ") ", "X103", 
   ": ", $CellContext`a/($CellContext`b^2 - $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965372793*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"e828c4ac-444e-4ac3-a345-2b40f3131dfc"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965374436*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"b0b15a09-e337-4347-805d-7bcab0db736e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "104", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X104\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"b", "-", "c"}], 
    SuperscriptBox["a", "2"]]}],
  SequenceForm[
  104, ") ", "X104", 
   ": ", $CellContext`a^(-2) ($CellContext`b - $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653760557`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"ff137390-f66d-4812-b033-5938d9587c01"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965377604*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a7a2f863-b5c6-4379-b9b9-616c025b8d86"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "105", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X105\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["a", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "c"}], ")"}]}]]}],
  SequenceForm[
  105, ") ", "X105", 
   ": ", $CellContext`a (-$CellContext`a + \
$CellContext`b)^(-1)/(-$CellContext`a + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965379136*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a39bd450-d3f7-40b5-91d9-fdd14b4ecd80"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965380683*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"99d57015-4150-4e5c-aa7b-3962728c2bbc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "106", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X106\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c"}], ")"}]}]}],
  SequenceForm[
  106, ") ", "X106", ": ", $CellContext`a^2 ($CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965382181*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"5e6cd9b3-a35b-4dc7-92c6-5ed2b60bd86b"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965383685*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"4d3ce550-4ab3-445d-83e6-a98e94fc98d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "107", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X107\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}]}]]}],
  SequenceForm[
  107, ") ", "X107", 
   ": ", $CellContext`a^(-2)/($CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965385186*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c1a6b206-81cb-453c-abac-1ef16f598cc4"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965386983*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"8d9ade43-f274-4254-a014-f602b144e099"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "108", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X108\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["a", 
    RowBox[{
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"]}]]}],
  SequenceForm[
  108, ") ", "X108", 
   ": ", $CellContext`a/($CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653888807`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"8a2f81b4-385d-41ad-881f-9050a0615c3c"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653906403`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"aa29ba6d-fea4-4b9d-a6a7-efe6e926bc9a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "109", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X109\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  109, ") ", "X109", 
   ": ", $CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653922157`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"6c26d426-9eab-4e0b-9b1a-fb8f1bc4b356"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965393758*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"5da3e7fb-57e3-43e2-8c85-c43fedd14926"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "110", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X110\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}]]}],
  SequenceForm[
  110, ") ", "X110", 
   ": ", $CellContext`a^(-2)/($CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965395257*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"8cc76e0a-636d-47d6-84eb-c41112c37550"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399653968*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2e5f2870-d24c-48b2-97c3-0aa83a5f37f0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "111", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X111\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"]}], "a"]}],
  SequenceForm[
  111, ") ", "X111", 
   ": ", $CellContext`a^(-1) ($CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996539828*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"1807ea47-c9c2-4bae-a0c2-be0b2ab3fe79"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996539979*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"b0ba2011-ebb9-4dad-a259-aa0d1f8353ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "112", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X112\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}]}],
  SequenceForm[
  112, ") ", "X112", 
   ": ", $CellContext`a ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654012747`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"836339a4-a10a-453e-b8da-3067a93c24e5"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965403133*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"6a304bbe-9498-4481-9571-d81f49a96c60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "113", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X113\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}]]}],
  SequenceForm[
  113, ") ", "X113", 
   ": ", $CellContext`a^(-1)/((-2) $CellContext`a + $CellContext`b + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654051228`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"f0d3837d-533c-4078-9b88-3f34813bc144"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965407032*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"3de7cd00-f753-4c84-a3be-83f5fd8b1a5b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "114", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X114\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["a", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}]]}],
  SequenceForm[
  114, ") ", "X114", 
   ": ", $CellContext`a/((-2) $CellContext`a + $CellContext`b + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654224873`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"ac09a20c-8d3b-4d07-bffa-b881a78edea0"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654244413`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"7845bab8-1c18-40e3-aca8-3b5bd44aca51"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "115", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X115\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}]}],
  SequenceForm[
  115, ") ", "X115", 
   ": ", $CellContext`a^2 ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965425974*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"3a24b073-1230-4934-9d12-e9cd1046dd7f"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965427556*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"73085de4-fa65-47ef-8a3f-fe9a3847fddd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "116", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X116\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}]]}],
  SequenceForm[
  116, ") ", "X116", 
   ": ", $CellContext`a^(-2)/((-2) $CellContext`a + $CellContext`b + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965429125*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"d3315c2a-cd48-49a9-9fa8-3ab22eb49cf3"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965430854*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"e6c8fa86-1878-4a4d-8aab-b259ca63e73b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "117", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"X117\"\>", "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"b", "+", "c", "-", 
    FractionBox[
     RowBox[{"b", " ", "c"}], "a"]}]}],
  SequenceForm[
  117, ") ", "X117", 
   ": ", $CellContext`b + $CellContext`c - $CellContext`a^(-1) $CellContext`b \
$CellContext`c],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965432397*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"446d802a-50ba-448b-955d-329a20912f84"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654339314`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"1c7533d7-588b-4fff-8778-d6415e38fb95"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "118", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"r-power point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   SuperscriptBox["a", "r"]}],
  SequenceForm[
  118, ") ", "r-power point", ": ", $CellContext`a^$CellContext`r],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965435451*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"b29546ba-04a1-4421-9d85-271302704d2e"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965437443*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"96d324b1-17d6-40b3-9cf9-b4fc791d354c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "119", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"r2-power point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["b", "r"], "+", 
     SuperscriptBox["c", "r"]}], "a"]}],
  SequenceForm[
  119, ") ", "r2-power point", 
   ": ", $CellContext`a^(-1) ($CellContext`b^$CellContext`r + \
$CellContext`c^$CellContext`r)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654393177`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"4cb39c81-1353-42f9-b2d4-912ea189916b"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965440981*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"222280cc-cac7-43d0-9ea1-94620d350aa5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "120", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"r3-power point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "r"]}], "+", 
     SuperscriptBox["b", "r"], "+", 
     SuperscriptBox["c", "r"]}], "a"]}],
  SequenceForm[
  120, ") ", "r3-power point", 
   ": ", $CellContext`a^(-1) (-$CellContext`a^$CellContext`r + \
$CellContext`b^$CellContext`r + $CellContext`c^$CellContext`r)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965442533*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"c9934314-f3ba-4d7d-ab1c-ee3367a3733e"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654441147`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"74fa001f-7769-4e7f-abd4-d59aa8f66db8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "121", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"Z1\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "r"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c"}], ")"}]}]}],
  SequenceForm[
  121, ") ", "Z1", 
   ": ", $CellContext`a^$CellContext`r ($CellContext`b + $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965445669*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"eda4db63-3f9e-49f5-a2c8-8bd548738b9a"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654472017`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"4624bda6-8ba3-4538-8a4e-fca7ade64782"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "122", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"Z2\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  122, ") ", "Z2", 
   ": ", $CellContext`a^$CellContext`r ($CellContext`b^2 + $CellContext`c^2)],
  
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965448807*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"5e776865-b3c4-4526-ac78-b05d2baa1294"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965450419*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a8dc2e72-12c4-4a78-a203-b945411d32fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "123", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"Z3\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}],
  SequenceForm[
  123, ") ", "Z3", 
   ": ", $CellContext`a^$CellContext`r (-$CellContext`a + $CellContext`b + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654519987`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"f65d6539-d0d1-4550-a596-91c38eab21f5"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965453825*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"9651c933-ce7f-4804-81be-081c04b427d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "124", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"Z4\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}]}],
  SequenceForm[
  124, ") ", "Z4", 
   ": ", $CellContext`a^$CellContext`r ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965455677*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"60352cc5-3ab8-4c95-a5a0-f2d7cd94012d"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965457406*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"2267bf23-917b-4fdf-8012-953539026d07"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "125", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"Z5\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  125, ") ", "Z5", 
   ": ", $CellContext`a^$CellContext`r (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965458971*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"b89064eb-ff2c-4e0c-b895-5ee58313053c"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965460504*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"3eae4d4d-26ae-4711-aaae-384ec3c7f47a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "126", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"Z6\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "3"], "+", 
      SuperscriptBox["c", "3"]}], ")"}]}]}],
  SequenceForm[
  126, ") ", "Z6", 
   ": ", $CellContext`a^$CellContext`r ($CellContext`b^3 + $CellContext`c^3)],
  
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654620047`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"ffb128cd-4914-4982-976e-ab7f6bef5e0c"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965463624*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"7a045eeb-0945-4555-9090-67a3d5fcbf59"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "127", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"Z7\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "r"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  127, ") ", "Z7", 
   ": ", $CellContext`a^$CellContext`r ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996546593*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"adc49578-a461-4a1b-85eb-8debb33fb14b"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654677067`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"fb574810-f993-4765-8f21-8fc1f5caf2c7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "128", "\[InvisibleSpace]", "\<\") \"\>", "\[InvisibleSpace]", "\<\"Z8\"\>",
    "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "r"], " ", 
    RowBox[{"g", "[", 
     RowBox[{"b", ",", "c"}], "]"}]}]}],
  SequenceForm[
  128, ") ", "Z8", 
   ": ", $CellContext`a^$CellContext`r $CellContext`g[$CellContext`b, \
$CellContext`c]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965469564*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"dde5ca0b-c99b-4ebc-97d8-7ba86dc331e7"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965471236*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"4ac41cc4-814f-4f44-874c-631177d75cce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "129", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"r4-power point\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["a", "r"]}], "+", 
     SuperscriptBox["b", "r"], "+", 
     SuperscriptBox["c", "r"]}], "a"]}],
  SequenceForm[
  129, ") ", "r4-power point", 
   ": ", $CellContext`a^(-1) (
    2 $CellContext`a^$CellContext`r + $CellContext`b^$CellContext`r + \
$CellContext`c^$CellContext`r)],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.8056399654728193`*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"a69256f4-ba12-4507-a4f2-9441e1bb5d43"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.80563996547442*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"db1f0aa5-d042-4c0a-be9a-081ac9eb98ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "130", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"arbitrary center\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"f", "[", 
    RowBox[{"a", ",", 
     RowBox[{"g", "[", 
      RowBox[{"b", ",", "c"}], "]"}]}], "]"}]}],
  SequenceForm[130, ") ", "arbitrary center", ": ", 
   $CellContext`f[$CellContext`a, 
    $CellContext`g[$CellContext`b, $CellContext`c]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965475937*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"6c0e85e7-85e4-455a-b79d-d028acc4da62"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965477611*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"206a3129-b852-4dd9-a369-d599e84b54ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "131", "\[InvisibleSpace]", "\<\") \"\>", 
   "\[InvisibleSpace]", "\<\"areal center\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"f", "[", 
     RowBox[{"a", ",", "b", ",", "c"}], "]"}], "a"]}],
  SequenceForm[
  131, ") ", "areal center", 
   ": ", $CellContext`a^(-1) $CellContext`f[$CellContext`a, $CellContext`b, \
$CellContext`c]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965479155*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"655a9a68-690d-402b-b8cf-2f0f583d6064"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"131", "\[InvisibleSpace]", "\<\" trilinear centers found.\"\>"}],
  SequenceForm[131, " trilinear centers found."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.805639055639859*^9, 3.8056390559201736`*^9}, 
   3.805639837925405*^9, 3.805639965480794*^9},
 CellLabel->
  "During evaluation of \
In[186]:=",ExpressionUUID->"4f2a2e34-6158-4ddf-aec3-6ba636add4ad"]
}, Open  ]],

Cell["\<\
ZeroQ[exp_]:=
Block[{val,expr},
\texpr = exp;
\tIf[!FreeQ[expr,r],
\t\texpr = expr/.{x_^k_ y_^k_->(x y)^k};
\t\texpr = Together[expr];
\t\tIf[!FreeQ[expr,t/a1],
\t\t\texpr = PowerExpand[expr];
\t\t\texpr = Together[expr];
\t\t  ];
\t  ];
\tIf[Head[expr]===Real,
\t\tval = Abs[N[expr,50]];
\t\tIf[val<0.000000000001,
\t\t\tPrint[\"  --> Expression \",expr,\"=\",val];
\t\t\t];
\t\t(* Return[expr==0.0]; *)
\t\tReturn[val<0.0000001];
\t  ];
\tIf[IntegerQ[expr],Return[expr==0]];
\tIf[Head[expr]===Rational,Return[False]];
\tval = Abs[N[expr,50]];
\tIf[val<0.000000000001,
\t\tPrint[\"  ----> Expression \",expr,\"=\",val];
\t\t];
\tReturn[False];
\t];

(* Finds the plane through three given points *)
PlaneThruThreePoints[p1_,p2_,p3_]:=
Block[{xx,yy,zz,ww,cx,cy,cz,cw},
\teqn = Det[{{xx,yy,zz,ww},p1,p2,p3}]//Expand;
\tcx = Coefficient[eqn,xx];
\tcy = Coefficient[eqn,yy];
\tcz = Coefficient[eqn,zz];
\tcw = Coefficient[eqn,ww];
\tReturn[{cx,cy,cz,cw}];
\t];
\t
(* Returns True if planes are parallel *)
ArePlanesParallel[p1_,p2_]:=
Block[{x1,x2,x3,x4,y1,y2,y3,y4,cond1,cond2},
\t{x1,x2,x3,x4}=p1;
\t{y1,y2,y3,y4}=p2;
\tcond1=(x1-x2)(y2-y3)-(y1-y2)(x2-x3)//Expand;
\tcond2=(x2-x3)(y3-y4)-(y2-y3)(x3-x4)//Expand;
\tIf[!ZeroQ[cond1],Return[False]];
\tIf[!ZeroQ[cond2],Return[False]];
\tReturn[True];
\t];

Coplanar[P_]:=
Block[{determ},
\tdeterm = Det[P]//Together;
\tReturn[ZeroQ[determ]];
\t];

ExactTetrahedralCoordinates[P_]:=
(* Returns coordinates scaled so that sum is 1 *)
Block[{su},
\tsu = Apply[Plus,P];
\tIf[su==0,Return[{Infty,Infty,Infty,Infty}]]; (* avoid errmsg *)
\tReturn[P/su];
\t];

SquaredDistance[A_,B_,S_]:=
(*
\tReturns the square of the distance between
\ttwo points, A and B, given in Tetrahedral Coordinates.
\tFormula from page 69 of Frost and Wolstenholme,
\tSolid Geometry. 
\tS is the square of the lengths of the 6 edges (see figure).
*)
Block[{eA,eB,
\t\tsa1,sa2,sa3,sb1,sb2,sb3,dist,d1,d2,d3,d4},
\teA = ExactTetrahedralCoordinates[A];
\teB = ExactTetrahedralCoordinates[B];
\t{sa1,sa2,sa3,sb1,sb2,sb3} = S;
\t{d1,d2,d3,d4} = eA-eB;
\tdist=
\t-d1 d2 sa3-d1 d3 sa2-d1 d4 sb1-
\t d2 d3 sa1-d2 d4 sb2-d3 d4 sb3;
\tIf[NumberQ[dist],
\t\tIf[N[dist]<0,
\t\t\tPrint[\"  --> Distance, \",dist,\" is negative.\"];
\t\t  ];
\t  ];
\tReturn[dist];
\t];
\
\>", "Input",
 InitializationCell->True,
 AspectRatioFixed->True,
 CellLabel->
  "In[195]:=",ExpressionUUID->"ced5749c-396f-4d37-a140-5c82afc0c811"],

Cell["\<\
EquationOfLine[A_,B_]:=
(*
\tFinds equation of line through 2 points
\tin tetrahedral coordinates.
\tEquation is of form
\t(x-a)/K=(y-b)/L=(z-c)/M=(w-d)/N
\twhere K+L+M+N=0.
\tWe return {K,L,M,N} where A={a,b,c,d}.
*)
Block[{eA,eB,expr,den},
\teA = ExactTetrahedralCoordinates[A];
\teB = ExactTetrahedralCoordinates[B];
\texpr = Together[eA-eB];
(*
\texpr = LowestTerms[expr];
*)
\tden = Denominator[expr[[1]]];
\texpr = Together[den * expr];
\tReturn[expr];
\t];

EquationOfPlane[A_,B_,C_]:=
(* Plane through 3 points *)
Block[{eq,cx,cy,cz,cw,xx,yy,zz,ww,expr},
\teq = Det[{{xx,yy,zz,ww},A,B,C}];
\teq = Expand[eq];
\tcx = Coefficient[eq,xx];
\tcy = Coefficient[eq,yy];
\tcz = Coefficient[eq,zz];
\tcw = Coefficient[eq,ww];
\texpr = Together[{cx,cy,cz,cw}];
\tReturn[expr];
\t];

EquationOfPlane2[P_,A_,L_]:=
(* Plane through point P and line (A,L) *)
Block[{B},
\t(* Find another point on the line *)
\tB = A + L;
\tReturn[EquationOfPlane[P,A,B]];
\t];


IntersectionOfLineAndPlane[A_,L_,Plane_]:=
(* A is point on line, L are line divisors *)
(* Point returned is in exact coordinates *)
Block[{aa,bb,rr},
\taa = A . Plane;
\tbb = L . Plane;
\tIf[bb==0,
\t\tPrint[\"  -> Line does not meet plane.\"];
\t\tReturn[{Infty,Infty,Infty,Infty}];
\t  ];
\trr = aa/bb;
\tReturn[Together[A - rr L]];
\t];

IntersectionOfPlanes[Plane1_,Plane2_]:=
(* Returns a point on the line and the direction vector *)
Block[{A1,B1,C1,D1,A2,B2,C2,D2,K,L,M,N,x0,y0,z0,w0},
\t{A1,B1,C1,D1}=Plane1;
\t{A2,B2,C2,D2}=Plane2;
\tK = B2 C1-B1 C2-B2 D1+C2 D1+B1 D2-C1 D2;
\tL = -A2 C1+A1 C2+A2 D1-C2 D1-A1 D2+C1 D2;
\tM = A2 B1-A1 B2-A2 D1+B2 D1+A1 D2-B1 D2;
\tN = -A2 B1+A1 B2+A2 C1-B2 C1-A1 C2+B1 C2;
\tx0 = (B1 C2 - B2 C1)/N;
\ty0 = (A2 C1 - A1 C2)/N;
\tz0 = (A1 B2 - A2 B1)/N;
\tw0 = 0;
\tReturn[{{x0,y0,z0,w0},{K,L,M,N}}];
\t];

DoPointsColline[A_,B_,C_]:=
Block[{tm,eA,eB,eC,
\t\tdelba1,delba2,delba3,delba4,
\t\tdelac1,delac2,delac3,delac4},
\teA = ExactTetrahedralCoordinates[A];
\teB = ExactTetrahedralCoordinates[B];
\teC = ExactTetrahedralCoordinates[C];
\t{delba1,delba2,delba3,delba4} = eB-eA;
\t{delac1,delac2,delac3,delac4} = eC-eA;
\ttm = Together[delba1 delac2-delac1 delba2];
\tIf[!ZeroQ[tm],Return[False]];
\ttm = Together[delba1 delac3-delac1 delba3];
\tIf[!ZeroQ[tm],Return[False]];
\ttm = Together[delba1 delac4-delac1 delba4];
\tIf[!ZeroQ[tm],Return[False]];
\tReturn[True];
\t];

CanSpearThreeLines[P0_,A1_,L1_,A2_,L2_,A3_,L3_]:=
(* Decides if there is a line through P0
 that meets lines (A1,L1), (A2,L2), (A3,L3). *)
Block[{planet,P1,P2,coll,P},
\tplanet = EquationOfPlane2[P0,A3,L3];
\tP1 = IntersectionOfLineAndPlane[A1,L1,planet];
\tP2 = IntersectionOfLineAndPlane[A2,L2,planet];
\tcoll = DoPointsColline[P0,P1,P2];
\tReturn[{coll,P1,P2}];
\t(* Returns answer as well as two points on spearing line *)
\t];

SquaredAreaOfTriangleFromSides[a_,b_,c_]:=
Block[{s,K},
\ts=(a+b+c)/2;
\tK=Expand[s(s-a)(s-b)(s-c)];
\tK=Together[K];
\tReturn[K];
\t];

SquaredAreaOfTriangleFromSquaredSides[a_,b_,c_]:=
Block[{K},
\tK = (2a b+2b c+2c a-a^2-b^2-c^2)/16;
\tK=Together[K];
\tReturn[K];
\t];
\t
SquaredVolumeOfTetrahedron[S_]:=
Block[{sa1,sa2,sa3,sb1,sb2,sb3,M,V},
\t{sa1,sa2,sa3,sb1,sb2,sb3} = S;
\tM = {
\t\t\t{sb1,(sb1+sb2-sa3)/2,(sb3+sb1-sa2)/2},
\t\t\t{(sb1+sb2-sa3)/2,sb2,(sb2+sb3-sa1)/2},
\t\t\t{(sb3+sb1-sa2)/2,(sb2+sb3-sa1)/2,sb3}
\t\t};
\tV=Det[M];
\tV=Together[V/36];
\tReturn[V];
\t];

CheckValidTetrahedron[S_]:=
Block[{ss,sa1,sa2,sa3,sb1,sb2,sb3,V,sc1,sc2,sc3},
\t{sa1,sa2,sa3,sb1,sb2,sb3} = S;
\tss=SquaredAreaOfTriangleFromSquaredSides[sa1,sa2,sa3];
\tIf[ss<=0,
\t\tPrint[\"-->Face of Tetrahedron has invalid area.\"];
\t\tPrint[\"   Sides: \",Sqrt[{sa1,sa2,sa3}]];
\t  ];
\t{sc1,sc2,sc3}=Sort[Sqrt[{sa1,sa2,sa3}]];
\tIf[sc1+sc2==2sc3 || sc1+sc3==2sc2,
\t\tPrint[\"-->Special case triangle (a+b=2c).\"];
\t\tPrint[\"   Sides: \",{sc1,sc2,sc3}];
\t  ];
\tss=SquaredAreaOfTriangleFromSquaredSides[sa1,sb2,sb3];
\tIf[ss<=0,
\t\tPrint[\"-->Face of Tetrahedron has invalid area.\"];
\t\tPrint[\"   Sides: \",Sqrt[{sa1,sb2,sb3}]];
\t  ];
\t{sc1,sc2,sc3}=Sort[Sqrt[{sa1,sb2,sb3}]];
\tIf[sc1+sc2==2sc3 || sc1+sc3==2sc2,
\t\tPrint[\"-->Special case triangle (a+b=2c).\"];
\t\tPrint[\"   Sides: \",{sc1,sc2,sc3}];
\t  ];
\tss=SquaredAreaOfTriangleFromSquaredSides[sb1,sa2,sb3];
\tIf[ss<=0,
\t\tPrint[\"-->Face of Tetrahedron has invalid area.\"];
\t\tPrint[\"   Sides: \",Sqrt[{sb1,sa2,sb3}]];
\t  ];
\t{sc1,sc2,sc3}=Sort[Sqrt[{sb1,sa2,sb3}]];
\tIf[sc1+sc2==2sc3 || sc1+sc3==2sc2,
\t\tPrint[\"-->Special case triangle (a+b=2c).\"];
\t\tPrint[\"   Sides: \",{sc1,sc2,sc3}];
\t  ];
\tss=SquaredAreaOfTriangleFromSquaredSides[sb1,sb2,sa3];
\tIf[ss<=0,
\t\tPrint[\"-->Face of Tetrahedron has invalid area.\"];
\t\tPrint[\"   Sides: \",Sqrt[{sb1,sb2,sa3}]];
\t  ];
\t{sc1,sc2,sc3}=Sort[Sqrt[{sb1,sb2,sa3}]];
\tIf[sc1+sc2==2sc3 || sc1+sc3==2sc2,
\t\tPrint[\"-->Special case triangle (a+b=2c).\"];
\t\tPrint[\"   Sides: \",{sc1,sc2,sc3}];
\t  ];
\tV = SquaredVolumeOfTetrahedron[S];
\tIf[V<=0,Print[\"-->Tetrahedron has invalid volume: \",V,\".\"]];
\t];

LowestTerms[exp_]:=
Block[{de,gg,expr},
\texpr = Together[exp];
\tde=Denominator[expr];
\tgg=Apply[PolynomialLCM,de];
\texpr=Together[gg expr];
\tgg=Apply[PolynomialGCD,expr];
\texpr=Together[expr/gg];
\tReturn[expr];
\t];

RemoveCommonFactors[exp_]:=
Block[{de,gg,expr},
\texpr = Together[exp];
\tgg=Apply[PolynomialGCD,expr];
\texpr=Together[expr/gg];
\tReturn[expr];
\t];

SamePoints[P1_,P2_]:=
Block[{x1,y1,z1,w1,x2,y2,z2,w2},
\t{x1,y1,z1,w1} = P1;
\t{x2,y2,z2,w2} = P2;
\tIf[!ZeroQ[Together[x1 y2-y1 x2]],Return[False]];
\tIf[!ZeroQ[Together[y1 z2-z1 y2]],Return[False]];
\tIf[!ZeroQ[Together[z1 w2-w1 z2]],Return[False]];
\tReturn[True];
\t];

PlaneThruLineParallelToLine[A1_,L1_,A2_,L2_]:=
(* Finds equation of plane through line (A1,L1)
\tthat is parallel to line (A2,L2).
\tIt returns {A,B,C,D}. *)
Block[{eq,A,B,C,D,xx,yy,zz,ww},
\teq = Det[{{xx,yy,zz,ww},A1,L1,L2}];
\teq = Expand[eq];
\tA = Coefficient[eq,xx];
\tB = Coefficient[eq,yy];
\tC = Coefficient[eq,zz];
\tD = Coefficient[eq,ww];
\tReturn[{A,B,C,D}];
\t];

CenterOfHyperboloid[P1_,L1_,P2_,L2_,P3_,L3_]:=
Block[{PL1,PL2,X1,X2},
\tPL1 = PlaneThruLineParallelToLine[P1,L1,P2,L2];
\tX1 = IntersectionOfLineAndPlane[P3,L3,PL1];
\tPL2 = PlaneThruLineParallelToLine[P1,L1,P3,L3];
\tX2 = IntersectionOfLineAndPlane[P2,L2,PL2];
\tReturn[Together[(X1+X2)/2]];
\t];

CheckIfCenter[P_,centers_]:=
Block[{i},
\tFor[i=1,i<=numberOfTetrCenters,i++,
\t\tIf[SamePoints[P,centers[i]],
\t\t\tPrint[\"    Point coincides with \",
\t\t\t\ttetrCenterName[i],\" of tetrahedron.\"];
\t\t  ];
\t\t];
\t];

CheckIfOnEuler[name_,centers_,P_]:=
Block[{loc,OGx,OPx},
\tIf[DoPointsColline[P,centers[1],centers[2]],
\t\tOGx = ExactTetrahedralCoordinates[centers[2]][[1]]
\t\t\t\t- ExactTetrahedralCoordinates[centers[1]][[1]];
\t\tIf[OGx=!=0,
\t\t\tOPx = ExactTetrahedralCoordinates[centers[2]][[1]]
\t\t\t\t- ExactTetrahedralCoordinates[P][[1]];
\t\t\tloc = Simplify[OPx/OGx];
\t\t\tPrint[\"    \",name,\" lies on reference Euler line (at \",
\t\t\t\t(* InputForm[loc] *) loc,\").\"];
\t\t  ];
\t   ];
\t];

\
\>", "Input",
 InitializationCell->True,
 AspectRatioFixed->True,
 CellLabel->
  "In[209]:=",ExpressionUUID->"ceaca7e7-6ed5-4628-8cfd-15034dd504cd"],

Cell["\<\
(* Property 1: The Pi are coplanar. *)
CheckProperty1[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{cop},
\tcop = Coplanar[P];
\tIf[debug,
\t\tPrint[\"cop=\",cop];
\t\tPrint[\"P=\",P];
\t  ];
\tIf[!cop,Return[False]];
\tIf[!numeric,
\t\tIf[ShowEquationOfPlanes,
\t\t\t(* Output equation of plane *)
\t\t\tPrint[\"    Equation of plane is:\"];
\t\t\tPrint[\"    \",Factor[EquationOfPlane[P[[1]],P[[2]],P[[3]]]]];
\t\t  ];
\t  ];
\tReturn[True];
\t];

(* Property 2: Plane of PiPjPk || Plane of AiAjAk *)
CheckProperty2[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{par1,par2,par3,par4,par},
\tAPlane[1] = PlaneThruThreePoints[A[[2]],A[[3]],A[[4]]];
\tAPlane[2] = PlaneThruThreePoints[A[[3]],A[[4]],A[[1]]];
\tAPlane[3] = PlaneThruThreePoints[A[[4]],A[[1]],A[[2]]];
\tAPlane[4] = PlaneThruThreePoints[A[[1]],A[[2]],A[[3]]];
\tPPlane[1] = PlaneThruThreePoints[P[[2]],P[[3]],P[[4]]];
\tPPlane[2] = PlaneThruThreePoints[P[[3]],P[[4]],P[[1]]];
\tPPlane[3] = PlaneThruThreePoints[P[[4]],P[[1]],P[[2]]];
\tPPlane[4] = PlaneThruThreePoints[P[[1]],P[[2]],P[[3]]];
\tpar1 = ArePlanesParallel[APlane[1],PPlane[1]];
\tpar2 = ArePlanesParallel[APlane[2],PPlane[2]];
\tpar3 = ArePlanesParallel[APlane[3],PPlane[3]];
\tpar4 = ArePlanesParallel[APlane[4],PPlane[4]];
\tpar = par1 && par2 && par3 && par4;
\tIf[par,Return[True],
\t\tIf[par1 || par2 || par3 || par4,
\t\t\tPrint[\"  --> Some faces are parallel.\"];
\t\t  ];
\t  ];
\tReturn[False];
\t];
\t
(* Assuming lines AB and CD meet, this finds the intersection point *)
IntersectionOfLines[A_,B_,C_,D_]:=
Block[{sa1,sa2,sa3,sa4,sb1,sb2,sb3,sb4,
\t   sc1,sc2,sc3,sc4,sd1,sd2,sd3,sd4,
\t   p1,p2,p3,p4,pt,L,Plane,
\t   nu,de,gg},
\tPlane=EquationOfPlane[A,B,{10,12,13,15}];
\tL=EquationOfLine[C,D];
\tpt=IntersectionOfLineAndPlane[C,L,Plane];
\tde=Denominator[pt];
\tgg=Apply[PolynomialLCM,de];
\tpt=Together[gg pt];
\tgg=Apply[PolynomialGCD,pt];
\tpt=Together[pt/gg];
\tReturn[Factor[pt]];
\t];

(* Property 3: Cevians AiPi concur *)
CheckProperty3[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{meet12,meet23,meet34,meet41,meet,cev,i},
\tIf[debug,
\t\tPrint[\"A=\",A];
\t\tPrint[\"P=\",P];
\t  ];
\tmeet12=Coplanar[{A[[1]],P[[1]],A[[2]],P[[2]]}];
\tIf[debug,Print[\"meet12=\",meet12]];
\tmeet23=Coplanar[{A[[2]],P[[2]],A[[3]],P[[3]]}];
\tIf[debug,Print[\"meet23=\",meet23]];
\tmeet34=Coplanar[{A[[3]],P[[3]],A[[4]],P[[4]]}];
\tIf[debug,Print[\"meet34=\",meet34]];
\tmeet41=Coplanar[{A[[4]],P[[4]],A[[1]],P[[1]]}];
\tIf[debug,Print[\"meet41=\",meet41]];
\tmeet = meet12 && meet23 && meet34 && meet41;
\tIf[meet,
\t\tcev=IntersectionOfLines[A[[1]],P[[1]],A[[2]],P[[2]]];
\t\tIf[!numeric || debug,
\t\t\tPrint[\"    Coordinates of intersection point:  \",Factor[cev]];
\t\t  ];
\t\t(* See if intersection point is a tetrahedron center *)
\t\tIf[!numeric,
\t\t\tCheckIfCenter[cev,centers];
\t  \t\tCheckIfOnEuler[\"Intersection point\",centers,cev];
\t  \t  ];
\t\tReturn[True],
\t(* else *)
\t\tIf[meet12 || meet23 || meet34 || meet41,
\t\t\tPrint[\"  --> Some cevians meet.\"];
\t\t  ];
\t  ];
\tReturn[False];
\t];

(* Property 4: Cevians AiPi have same length *)
CheckProperty4[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{d1,d2,d3,d4,z1,z2,z3,z4,eq},
\td1 = SquaredDistance[A[[1]],P[[1]],S];
\td2 = SquaredDistance[A[[2]],P[[2]],S];
\td3 = SquaredDistance[A[[3]],P[[3]],S];
\td4 = SquaredDistance[A[[4]],P[[4]],S];
\tIf[debug,
\t\tPrint[\"S=\",S];
\t\tPrint[\"A1=\",A[[1]]];
\t\tPrint[\"A2=\",A[[2]]];
\t\tPrint[\"A3=\",A[[3]]];
\t\tPrint[\"A4=\",A[[4]]];
\t\tPrint[\"P1=\",P[[1]]];
\t\tPrint[\"P2=\",P[[2]]];
\t\tPrint[\"P3=\",P[[3]]];
\t\tPrint[\"P4=\",P[[4]]];
\t\tPrint[\"d1=\",d1];
\t\tPrint[\"d2=\",d2];
\t\tPrint[\"d3=\",d3];
\t\tPrint[\"d4=\",d4];
\t  ];
\tz1 = ZeroQ[Together[d1-d2]];
\tz2 = ZeroQ[Together[d2-d3]];
\tz3 = ZeroQ[Together[d3-d4]];
\tz4 = ZeroQ[Together[d4-d1]];
\teq = z1 && z2 && z3 && z4;
\tIf[eq,Return[True],
\t\tIf[z1 || z2 || z3 || z4,
\t\t\tPrint[\"  --> Some cevians have same length.\"];
\t\t  ];
\t  ];
\tReturn[False];
\t];

(* Property 5: Tetrahedron formed by Pi is isosceles *)
CheckProperty5[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{d1,d2,d3,c1,c2,c3,z1,z2,z3,eq,u1,u2},
\tIf[debug,
\t\tPrint[\"Facial points:\"];
\t\tPrint[\"  P1 = \",P[[1]]];
\t\tPrint[\"  P2 = \",P[[2]]];
\t\tPrint[\"  P3 = \",P[[3]]];
\t\tPrint[\"  P4 = \",P[[4]]];
\t\tPrint[\"Sides squared:\"];
\t\tPrint[\"  S1 = \",S[[1]]];
\t\tPrint[\"  S2 = \",S[[2]]];
\t\tPrint[\"  S3 = \",S[[3]]];
\t\tPrint[\"  S4 = \",S[[4]]];
\t\tPrint[\"  S5 = \",S[[5]]];
\t\tPrint[\"  S6 = \",S[[6]]];
\t  ];
\t{c1,c2,c3,d1,d2,d3} = SD;
\tIf[debug,
\t\tPrint[\"Squared lengths:\"];
\t\tPrint[\"c1 = \",c1];
\t\tPrint[\"c2 = \",c2];
\t\tPrint[\"c3 = \",c3];
\t\tPrint[\"d1 = \",d1];
\t\tPrint[\"d2 = \",d2];
\t\tPrint[\"d3 = \",d3];
\t\t];
\tz1 = ZeroQ[Together[d1-c1]];
\tz2 = ZeroQ[Together[d2-c2]];
\tz3 = ZeroQ[Together[d3-c3]];
\teq = z1 && z2 && z3;
\tIf[eq,
\t\t(* See if regular *)
\t\tu1 = ZeroQ[Together[c2-c1]];
\t\tu2 = ZeroQ[Together[c3-c1]];
\t\tIf[u1 && u2,
\t\t\tPrint[\"  Tetrahedron is regular.\"],
\t\t(* else *)
\t\t\tIf[u1 || u2,
\t\t\t\tPrint[\"  --> 4 of 6 edges have same length.\"];
\t\t\t  ];
\t\t  ];
\t\tReturn[True],
\t(* else *)
\t\tIf[z1 || z2 || z3,
\t\t\tPrint[\"  --> Some pairs of edges have same length.\"];
\t\t  ];
\t  ];
\tReturn[False];
\t];

(* Property 6: Tetrahedron formed by Pi is isodynamic *)
CheckProperty6[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{d1,d2,d3,c1,c2,c3,z1,z2,eq},
\t{c1,c2,c3,d1,d2,d3} = SD;
\tz1 = ZeroQ[Together[d1 c1 - d2 c2]];
\tz2 = ZeroQ[Together[d2 c2 - d3 c3]];
\teq = z1 && z2;
\tIf[eq,Return[True],
\t\tIf[z1 || z2,
\t\t\tPrint[\"  --> Some pairs of edges have same product.\"];
\t\t  ];
\t  ];
\tReturn[False];
\t];

(*
SqCond[a_,b_,c_,d_]:=
\tTogether[(a^2+b^2+c^2+d^2-2a b-2a c-2a d-2b c-2b d-2c d)^2-
\t64 a b c d];
*)

(* Property 7: Tetrahedron formed by Pi is circumscriptible *)
CheckProperty7[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{d1,d2,d3,c1,c2,c3,z1,z2,eq},
(*
\tThe condition Sqrt[a]+Sqrt[b]==Sqrt[c]+Sqrt[d]
\tis almost equivalent to the condition:
\t64abcd==(2ab+2bc+2cd+2ac+2ad+2bd-a^2-b^2-c^2-d^2)^2.
\t[Actually, sum of some 2 = sum of other 2.]
\tSo not good enough.

\tz1 = ZeroQ[SqCond[c1,d1,c2,d2]];
\tz2 = ZeroQ[SqCond[c2,d2,c3,d3]];
*)

\t{c1,c2,c3,d1,d2,d3} = (Sqrt[SD])/.{Sqrt[x_^2]:>x};

\tz1 = ZeroQ[Together[d1 + c1 - d2 - c2]];
\tz2 = ZeroQ[Together[d2 + c2 - d3 - c3]];

\tIf[debug,
\t\tPrint[\"z1=\",z1];
\t\tPrint[\"z2=\",z2];
\t  ];
\teq = z1 && z2;
\tIf[eq,Return[True],
\t\tIf[z1 || z2,
\t\t\tPrint[\"  --> Some pairs of edges have same sum.\"];
\t\t  ];
\t  ];
\tReturn[False];
\t];
\t
(* Property 8: Tetrahedron formed by Pi is orthocentric *)
CheckProperty8[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{d1,d2,d3,c1,c2,c3,z1,z2,cond1,cond2,eq},
\t{c1,c2,c3,d1,d2,d3} = SD;
\tcond1 = Together[d1 + c1 - d2 - c2];
\tcond2 = Together[d2 + c2 - d3 - c3];
\tz1 = ZeroQ[cond1];
\tz2 = ZeroQ[cond2];
\tIf[debug,
\t\tPrint[\"c1 = \",c1];
\t\tPrint[\"c2 = \",c2];
\t\tPrint[\"c3 = \",c3];
\t\tPrint[\"d1 = \",d1];
\t\tPrint[\"d2 = \",d2];
\t\tPrint[\"d3 = \",d3];
\t\tPrint[\"cond1=\",cond1];
\t\tPrint[\"cond2=\",cond2];
\t\tPrint[\"z1 = \",z1];
\t\tPrint[\"z2 = \",z2];
\t\t];
\teq = z1 && z2;
\tIf[eq,Return[True],
\t\tIf[z1 || z2,
\t\t\tPrint[\"  --> Some pairs of edges are perpendicular.\"];
\t\t  ];
\t  ];
\tReturn[False];
\t];

(* Property 9: Cevial tetrahedron has same centroid as original tetrahedron \
*)
CheckProperty9[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{M,meet12,meet23,meet34,meet},
\tM=P[[1]]+P[[2]]+P[[3]]+P[[4]];
\tmeet12=ZeroQ[Together[M[[1]]-M[[2]]]];
\tmeet23=ZeroQ[Together[M[[2]]-M[[3]]]];
\tmeet34=ZeroQ[Together[M[[3]]-M[[4]]]];
\tmeet = meet12 && meet23 && meet34;
\tIf[meet,Return[True]];
\tReturn[False];
\t];

(* Property 10: Cevians form a hyperbolic group *)
CheckProperty10[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{P1,P2,P3,spear,wantSpears,x2,x3,y1,y3,z1,z2,cond,
\t\tHcenter,A1,A2,A3},
\twantSpears = False;
\twantHyperboloidCenters = False;
\tP1=P[[1]];
\tP2=P[[2]];
\tP3=P[[3]];
\ty1 = P1[[2]];
\tz1 = P1[[3]];
\tx2 = P2[[1]];
\tz2 = P2[[3]];
\tx3 = P3[[1]];
\ty3 = P3[[2]];
\t(* Symmetry conditions show we need only spear one set *)
\tcond = Together[z1 x2 y3 - y1 z2 x3];
\tspear = ZeroQ[cond];
\tIf[debug,
\t\tPrint[\"Condition is: \",cond];
\t  ];
\tIf[spear,
\t\tIf[!numeric && wantSpears,
\t\t\tPrint[\"  Spear line meets base at:\"];
\t\t\tPrint[\"  \",Factor[{x3 y1,y1 y3,y3 z1}]];
\t\t  ];
\t\tIf[wantHyperboloidCenters,
\t\t\tP1 = ExactTetrahedralCoordinates[P1];
\t\t\tP2 = ExactTetrahedralCoordinates[P2];
\t\t\tP3 = ExactTetrahedralCoordinates[P3];
\t\t\tA1 = A[[1]];
\t\t\tA2 = A[[2]];
\t\t\tA3 = A[[3]];
\t\t\tIf[!numeric,
\t\t\t\tPrint[\"  Center of hyperboloid:\"];
\t\t\t  ];
\t\t\tHcenter = CenterOfHyperboloid[A1,P1-A1,A2,P2-A2,A3,P3-A3];
\t\t\tHcenter = LowestTerms[Hcenter];
\t\t\tIf[!numeric,
\t\t\t\tPrint[\"  \",Factor[Hcenter]];
\t\t\t  ];
\t\t\tIf[!numeric,
\t\t\t\tCheckIfCenter[Hcenter,centers];
\t  \t\t\tCheckIfOnEuler[\"Center of hyperboloid\",centers,Hcenter];
\t  \t\t  ];
\t\t  ];
\t\tReturn[True];
\t  ];
\tReturn[False];
\t];

(* Property 11: The Pi are collinear. *)
CheckProperty11[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{coline1,coline2,P1,P2,P3,P4},
\t{P1,P2,P3,P4} = P;
\tcoline1 = DoPointsColline[P1,P2,P3];
\tcoline2 = DoPointsColline[P1,P2,P4];
\tIf[coline1 && coline2,
\t\tIf[!numeric,
\t\t\tIf[ShowEquationOfLines,
\t\t\t\t(* Print equation of line *)
\t\t\t\tPrint[\"    Equation of line is:\"];
\t\t\t\tPrint[\"    \",Factor[P[[1]]]];
\t\t\t\tPrint[\"    \",Factor[EquationOfLine[P[[1]],P[[2]]]]];
\t\t\t  ];
\t\t  ];
\t\tReturn[True],
\t(* else *)
\t\tIf[coline1 || coline2,
\t\t  Print[\"  --> 3 of 4 points colline.\"];
\t\t  ];
\t  ];
\tReturn[False];
\t];

(* Property 12: The tetrahedra are similar. *)
CheckProperty12[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{sa1,sa2,sa3,sb1,sb2,sb3,c1,c2,c3,d1,d2,d3,val},
\t{sa1,sa2,sa3,sb1,sb2,sb3} = S;
\t{c1,c2,c3,d1,d2,d3} = SD;
\tIf[debug,
\t\tPrint[\"S=\",S];
\t\tPrint[\"SD=\",SD];
\t  ];
\tval = sa1 c2 - sa2 c1;
\tIf[!ZeroQ[val],Return[False]];
\tval = sa1 c3 - sa3 c1;
\tIf[!ZeroQ[val],Return[False]];
\tval = sa1 d1 - sb1 c1;
\tIf[!ZeroQ[val],Return[False]];
\tval = sa1 d2 - sb2 c1;
\tIf[!ZeroQ[val],Return[False]];
\tval = sa1 d3 - sb3 c1;
\tIf[!ZeroQ[val],Return[False]];
\tReturn[True];
\t];

(* Property 13: Find conditions for Cevians AiPi to concur *)
CheckProperty13[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{meet12,meet23,meet34,meet41,meet},
\tIf[numeric,masterCondition={};Return[True]];
\tIf[debug,
\t\tPrint[\"A=\",A];
\t\tPrint[\"P=\",P];
\t  ];
\tmeet12=Det[{A[[1]],P[[1]],A[[2]],P[[2]]}];
\tIf[debug,Print[\"meet12=\",meet12]];
\tPrint[Factor[meet12]==0];
\tmasterCondition = Append[masterCondition,
\t\t\t\t\t\tFactor[meet12]==0];
\tmeet23=Det[{A[[2]],P[[2]],A[[3]],P[[3]]}];
\tIf[debug,Print[\"meet23=\",meet23]];
\tPrint[Factor[meet23]==0];
\tmasterCondition = Append[masterCondition,
\t\t\t\t\t\tFactor[meet23]==0];
\tmeet34=Det[{A[[3]],P[[3]],A[[4]],P[[4]]}];
\tIf[debug,Print[\"meet34=\",meet34]];
\tPrint[Factor[meet34]==0];
\tmasterCondition = Append[masterCondition,
\t\t\t\t\t\tFactor[meet34]==0];
\tmeet41=Det[{A[[4]],P[[4]],A[[1]],P[[1]]}];
\tIf[debug,Print[\"meet41=\",meet41]];
\tPrint[Factor[meet41]==0];
\tReturn[True];
\t];

(* Property 14: Find condition for Pi to be coplanar. *)
CheckProperty14[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{determ},
\tIf[numeric,Return[True]];
\tIf[debug,
\t\tPrint[\"P=\",P];
\t  ];
\tdeterm = Det[P]//Together;
\tIf[debug,
\t\tPrint[\"det=\",determ];
\t  ];
(*\tmasterCondition = (Factor[determ]==0); *)
\tmasterCondition = determ;
\tReturn[True];
\t];

(* Property 15: Find condition for Cevial tetrahedron
to have same centroid as original tetrahedron *)
CheckProperty15[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{M,meet12,meet23,meet34,meet},
\tIf[numeric,masterCondition={};Return[True]];
\tM=P[[1]]+P[[2]]+P[[3]]+P[[4]];
\tmeet12=Together[M[[1]]-M[[2]]];
\tmeet23=Together[M[[2]]-M[[3]]];
\tmeet34=Together[M[[3]]-M[[4]]];
\tmasterCondition = Append[masterCondition,
\t\t\t\t\t\tFactor[meet12]==0];
\tmasterCondition = Append[masterCondition,
\t\t\t\t\t\tFactor[meet23]==0];
\tmasterCondition = Append[masterCondition,
\t\t\t\t\t\tFactor[meet34]==0];
\tReturn[True];
\t];

(* Property 16: Find conditions for Cevians to be hyperbolic. *)
CheckProperty16[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{P1,P2,P3,x2,x3,y1,y3,z1,z2,cond},
\tIf[numeric,Return[True]];
\tP1=P[[1]];
\tP2=P[[2]];
\tP3=P[[3]];
\ty1 = P1[[2]];
\tz1 = P1[[3]];
\tx2 = P2[[1]];
\tz2 = P2[[3]];
\tx3 = P3[[1]];
\ty3 = P3[[2]];
\t(* Symmetry conditions show we need only spear one set *)
\tcond = Together[z1 x2 y3 - y1 z2 x3];
\tcond = Factor[cond];
\tmasterCondition = cond;
\tPrint[masterCondition];
\tReturn[True];
\t];

perp[V1_,V2_,S_]:=
Block[{K1,L1,M1,N1,K2,L2,M2,N2,sa1,sa2,sa3,sb1,sb2,sb3},
\t{K1,L1,M1,N1}=V1;
\t{K2,L2,M2,N2}=V2;
\t{sa1,sa2,sa3,sb1,sb2,sb3} = S;
\tReturn[
\tsa1(L1 M2+L2 M1)+sa2(K1 M2+K2 M1)+sa3(K1 L2+K2 L1)+
\tsb1(K1 N2+K2 N1)+sb2(L1 N2+L2 N1)+sb3(M1 N2+M2 N1)];
\t];

(* Property 17: Erected normals concur *)
CheckProperty17[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{q1,q2,P1,P2,P3,P4,A1,A2,A3,A4,Q,meet,u,X,Y,Z,W,ans,eP1,eP2},
\t(*
\t\tNeed (P1A4)^2+(P2A3)^2=(P1A3)^2+(P2A4)^2.
\t*)
\t{P1,P2,P3,P4} = P;
\t{A1,A2,A3,A4} = A;
\tq1 = SquaredDistance[P1,A4,S]+SquaredDistance[P2,A3,S];
\tIf[!FreeQ[q1,Infty],Return[False]];
\tq2 = SquaredDistance[P1,A3,S]+SquaredDistance[P2,A4,S];
\tIf[debug,
\t\tPrint[\"q1=\",q1];
\t\tPrint[\"q2=\",q2];
\t  ];
\tmeet = ZeroQ[Together[q1-q2]];
\tIf[meet,
\t\t(* Find point where normals at P1 and P2 meet *)
\t\tIf[!numeric || True,
\t\t\tu={X,Y,Z,W};
\t\t\teP1=ExactTetrahedralCoordinates[P1];
\t\t\teP2=ExactTetrahedralCoordinates[P2];
\t\t\teq1=perp[u-eP1,eP1-A2,S];
\t\t\teq2=perp[u-eP1,eP1-A3,S];
\t\t\teq3=perp[u-eP2,eP2-A3,S];
\teq1=Collect[eq1,{X,Y,Z,W},Simplify];
\teq2=Collect[eq2,{X,Y,Z,W},Simplify];
\teq3=Collect[eq3,{X,Y,Z,W},Simplify];
\t(* Print[\"Solving...\",eq1]; *)
\t\t\tans=Solve[{eq1==0,eq2==0,eq3==0,X+Y+Z+W==1},{X,Y,Z,W}];
\t\t\tans = First[ans];
\t\t\t{X,Y,Z,W}={X,Y,Z,W}/.ans;
\t(* Print[\"W=\",W]; *)
\t\t\t{X,Y,Z,W} = LowestTerms[{X,Y,Z,W}];
\t\t\tQ = {X,Y,Z,W};
\t\t\tIf[!numeric,
\t\t\t\tCheckIfCenter[Q,centers];
\t  \t\t\tCheckIfOnEuler[\"Intersection point\",centers,Q];
\t  \t\t  ];
\t  \t\tIf[!numeric,
\t\t\t\tPrint[\"    4th coordinate of point of intersection is:\"];
\t\t\t\tPrint[\"    \",Factor[W]];
\t\t\t  ];
\t\t  ];
\t\tReturn[True];
\t  ];
\tReturn[False];
\t];

(* Property 18: Some center of central tetrahedron
\tcoincides with a center of the reference tetrahedron. *)
CheckProperty18[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{P1,P2,P3,P4,x2,x3,y1,y3,z1,z2,cond,i,j,
\tcoinc,coincide,used,Pcenter,OGx,OPx,loc},
\tcoincide = False;
\t{P1,P2,P3,P4}=P;
\tIf[debug,Print[\"P=\",P]];
\tFor[j=1,j<=numberOfTetrCenters,j++,used[j]=False];
\tOGx = 0;
\t(* Find centers of central tetrahedron *)
\tFor[i=1,i<=numberOfTetrCenters,i++,
\t\tcoinc[i] = False;
\t\tIf[debug,Print[\"Looking at center \",i]];
\t\tPcenter[i] = centers[i] . P;
\t\tIf[debug,Print[\"  Pcenter=\",Pcenter[i]]];
\t\t(* See if any center of ref tetr is same as one of these *)
\t\tFor[j=1,j<=numberOfTetrCenters,j++,
\t\tIf[debug,Print[\"  Comparing with center \",j]];
\t\tIf[debug,Print[\"  center=\",centers[j]]];
\t\t\tIf[SamePoints[Pcenter[i],centers[j]],
\t\t\t\tIf[!numeric,
\t\t\t\t\tPrint[\"    Central \",tetrCenterName[i],
\t\t\t\t\t\t\" coincides with reference \",
\t\t\t\t\t\ttetrCenterName[j],\".\"];
\t\t\t\t  ];
\t\t\t\tcoincide = True;
\t\t\t\tcoinc[i] = True;
\t\t\t\tused[j]  = True;
\t\t\t\tBreak[];
\t\t\t  ];
\t\t\t];
\t\tIf[!coinc[i] && !numeric,
\t\t\t(* See if Pcenter lies on Euler line *)
\t  \t\tCheckIfOnEuler[\"Central \"<>tetrCenterName[i],
\t  \t\t\tcenters,Pcenter[i]];
\t\t  ];
\t\t];
\tFor[i=1,i<=numberOfTetrCenters,i++,
\t  If[!used[i] && !numeric,
\t\tIf[DoPointsColline[centers[i],Pcenter[1],Pcenter[2]],
\t\t\tOGx = ExactTetrahedralCoordinates[Pcenter[2]][[1]]
\t\t\t\t- ExactTetrahedralCoordinates[Pcenter[1]][[1]];
\t\t\tOPx = ExactTetrahedralCoordinates[Pcenter[2]][[1]]
\t\t\t\t- ExactTetrahedralCoordinates[centers[i]][[1]];
\t\t\tIf[debug,
\t\t\t\tPrint[\"i=\",i,\"  Points colline. Pcenter1=\",
\t\t\t\t\t\tPcenter[1],\" Pcenter2=\",Pcenter[2]];
\t\t\t\tPrint[\"centers[i]=\",centers[i]];
\t\t\t\tPrint[\"OGx=\",OGx,\"  OPx=\",OPx];
\t\t\t  ];
\t\t\t(* There is no Euler line for an isosceles tetrahedron *)
\t\t\tIf[Simplify[OGx]=!=0,
\t\t\t\tloc = Simplify[OPx/OGx];
\t\t\t\tPrint[\"    Reference \",tetrCenterName[i],
\t\t\t\t\t\" lies on central Euler line (at \",
\t\t\t\t\t(* InputForm[loc] *) loc,\").\"];
\t\t\t  ];
\t\t  ];
\t\t];
\t   ];
\tReturn[coincide];
\t];

(* Property 19: Find condition for Pi to be collinear. *)
CheckProperty19[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{P1,P2,P3,P4,Q},
\tIf[numeric,Return[True]];
\tIf[debug,
\t\tPrint[\"P=\",P];
\t  ];
\t{P1,P2,P3,P4}=P;
\tQ = (P2-P1)/(P3-P1);
\tQ = Q - Q[[1]];
\tQ = Drop[Q,1];
\tQ = Together[Q];
\tQ = Numerator[Q];
\tmasterCondition = Q==0;
\tPrint[masterCondition];
\tReturn[True];
\t];

(* Property 20: Find condition normals at Pi to concur. *)
CheckProperty20[A_,P_,S_,SD_,debug_,numeric_,centers_]:=
Block[{P1,P2,P3,P4,Q,q1,q2,A1,A2,A3,A4},
\tIf[numeric,Return[True]];
\t(*
\t\tCondition is (P1A4)^2+(P2A3)^2==(P1A3)^2+(P2A4)^2.
\t*)
\t{P1,P2,P3,P4} = P;
\t{A1,A2,A3,A4} = A;
\tq1 = SquaredDistance[P1,A4,S]+SquaredDistance[P2,A3,S];
\tq2 = SquaredDistance[P1,A3,S]+SquaredDistance[P2,A4,S];
\tIf[debug,
\t\tPrint[\"q1=\",q1];
\t\tPrint[\"q2=\",q2];
\t  ];
\tQ = Together[q1-q2];
\tQ = Numerator[Q];
\tmasterCondition = (Q==0);
\tPrint[masterCondition];
\tReturn[True];
\t];

\t\
\>", "Input",
 InitializationCell->True,
 AspectRatioFixed->True,
 CellLabel->
  "In[247]:=",ExpressionUUID->"c6e32e54-0604-467d-a964-2984f98c1d1e"],

Cell["\<\
CheckProperties[A_,P_,NumConditions_,GenConditions_,
\t\ttestList_,debugList_,debug_,numericCheckOnly_]:=
Block[{ok,numericOk,
\t\tcaseNames,values,S0,S1,SD0,SD1,
\t\tdoAllTests,doAllDebug,gc},
\tP1 = P/.GenConditions;
\tP0 = P1/.NumConditions;
\tP1=Simplify[P1/.{t->100}];  (* can scale tetrahedron to make t=100 *)
\tP0=Sqrt3Simp[P0];
\tgc = Apply[Plus,P0];
\tIf[IntegerQ[gc],
\t\tgc = Apply[GCD,P0];
\t\tIf[gc>1,P0=P0/gc];
\t  ];
\tS1 = {a1^2,a2^2,a3^2,b1^2,b2^2,b3^2}/.GenConditions;
\tS0 = S1/.NumConditions;
\tS1=S1/.t->100;
\tS0=Sqrt3Simp[S0];
\tSD0 = {
\t\t\tSquaredDistance[P0[[2]],P0[[3]],S0],
\t\t\tSquaredDistance[P0[[3]],P0[[1]],S0],
\t\t\tSquaredDistance[P0[[1]],P0[[2]],S0],
\t\t\tSquaredDistance[P0[[4]],P0[[1]],S0],
\t\t\tSquaredDistance[P0[[4]],P0[[2]],S0],
\t\t\tSquaredDistance[P0[[4]],P0[[3]],S0]
\t\t  };
\tIf[!numericCheckOnly,
\t  SD1 = {
\t\t\tSquaredDistance[P1[[2]],P1[[3]],S1],
\t\t\tSquaredDistance[P1[[3]],P1[[1]],S1],
\t\t\tSquaredDistance[P1[[1]],P1[[2]],S1],
\t\t\tSquaredDistance[P1[[4]],P1[[1]],S1],
\t\t\tSquaredDistance[P1[[4]],P1[[2]],S1],
\t\t\tSquaredDistance[P1[[4]],P1[[3]],S1]
\t\t    };
\t  ];
\tcaseNames = False; (* set to True to print case names *)
\tvalues = False; (* set to True to print sample values *)

\t(* Make sure that the numerical tetrahedron exists *)
\tCheckValidTetrahedron[S0];

\tIf[!skipTetrCenters,
\t\t{numCentroid,numCircumcenter,
\t\tnumMongePoint,numIncenter,numEulerPoint} =
\t\t\t{ourCentroid,ourCircumcenter,
\t\t \tourMongePoint,ourIncenter,ourEulerPoint}/.NumConditions;
\t  ];
\t
\tnumberOfTests = 20;
\t
\tdoAllDebug = debug;

\tdoAllTests = Length[testList]==0;
\tFor[test=1, test<=numberOfTests, test++,
\t\tdoTest[test] = MemberQ[testList,test];
\t\tdoDebug[test] = MemberQ[debugList,test];
\t\t];
\t
\tCheckProp[1] = CheckProperty1;
\tCheckProp[2] = CheckProperty2;
\tCheckProp[3] = CheckProperty3;
\tCheckProp[4] = CheckProperty4;
\tCheckProp[5] = CheckProperty5;
\tCheckProp[6] = CheckProperty6;
\tCheckProp[7] = CheckProperty7;
\tCheckProp[8] = CheckProperty8;
\tCheckProp[9] = CheckProperty9;
\tCheckProp[10] = CheckProperty10;
\tCheckProp[11] = CheckProperty11;
\tCheckProp[12] = CheckProperty12;
\tCheckProp[13] = CheckProperty13;
\tCheckProp[14] = CheckProperty14;
\tCheckProp[15] = CheckProperty15;
\tCheckProp[16] = CheckProperty16;
\tCheckProp[17] = CheckProperty17;
\tCheckProp[18] = CheckProperty18;
\tCheckProp[19] = CheckProperty19;
\tCheckProp[20] = CheckProperty20;
\t
\tPropMsg[1] = \"Points are coplanar.\";
\tPropMsg[2] = \"Faces are parallel.\";
\tPropMsg[3] = \"Cevians concur.\";
\tPropMsg[4] = \"Cevians have same length.\";
\tPropMsg[5] = \"Tetrahedron is isosceles.\";
\tPropMsg[6] = \"Tetrahedron is isodynamic.\";
\tPropMsg[7] = \"Tetrahedron is circumscriptible.\";
\tPropMsg[8] = \"Tetrahedron is orthocentric.\";
\tPropMsg[9] = \"Tetrahedra have same centroid.\";
\tPropMsg[10] = \"Cevians form a hyperbolic group.\";
\tPropMsg[11] = \"Points are collinear.\";
\tPropMsg[12] = \"Tetrahedra are similar.\";
\tPropMsg[13] = \"Find condition for concurrence of cevians.\";
\tPropMsg[14] = \"Find condition for points to be coplanar.\";
\tPropMsg[15] = \"Find condition for tetrahedra to have same centroid.\";
\tPropMsg[16] = \"Find condition for cevians to form a hyperbolic group.\";
\tPropMsg[17] = \"Normals concur.\";
\tPropMsg[18] = \"Tetrahedra have centers in common.\";
\tPropMsg[19] = \"Find condition for points to be collinear.\";
\tPropMsg[20] = \"Find condition for normals to concur.\";

\tTetrCenters[1] = ourCentroid;
\tTetrCenters[2] = ourCircumcenter;
\tTetrCenters[3] = ourMongePoint;
\tTetrCenters[4] = ourIncenter;
\tTetrCenters[5] = ourEulerPoint;

\tnumTetrCenters[1] = ourCentroid/.NumConditions;
\tnumTetrCenters[2] = ourCircumcenter/.NumConditions;
\tnumTetrCenters[3] = ourMongePoint/.NumConditions;
\tnumTetrCenters[4] = ourIncenter/.NumConditions;
\tnumTetrCenters[5] = ourEulerPoint/.NumConditions;
\t
\tIf[IntegerQ[numTetrCenters[1][[1]]],
\t\tgc = Apply[GCD,numTetrCenters[1]];
\t\tnumTetrCenters[1] = numTetrCenters[1]/gc;
\t  ];
\tIf[IntegerQ[numTetrCenters[2][[1]]],
\t\tgc = Apply[GCD,numTetrCenters[2]];
\t\tnumTetrCenters[2] = numTetrCenters[2]/gc;
\t  ];
\tIf[IntegerQ[numTetrCenters[3][[1]]],
\t\tgc = Apply[GCD,numTetrCenters[3]];
\t\tnumTetrCenters[3] = numTetrCenters[3]/gc;
\t  ];
\tIf[IntegerQ[numTetrCenters[4][[1]]],
\t\tgc = Apply[GCD,numTetrCenters[4]];
\t\tnumTetrCenters[4] = numTetrCenters[4]/gc;
\t  ];
\tIf[IntegerQ[numTetrCenters[5][[1]]],
\t\tgc = Apply[GCD,numTetrCenters[5]];
\t\tnumTetrCenters[5] = numTetrCenters[5]/gc;
\t  ];

\tFor[test=1, test<=numberOfTests, test++,
\t  If[doAllTests && test!=13 && test!=14 && test!=15 && test!=16
\t    && test!=19  && test!=20 || doTest[test],
\t\tIf[caseNames||doAllDebug,
\t\t\tPrint[\" Checking property \",test,\"...\"];
\t\t  ];
\t\tIf[values||doAllDebug,
\t\t\tPrint[\"P0=\",P0];
\t\t  ];
\t\tnumericOk = CheckProp[test][A,P0,S0,SD0,doDebug[test],
\t\t\t\t\t\tTrue,numTetrCenters];
\t\tIf[numericOk,
\t\t\tIf[numericCheckOnly,
\t\t\t\tok = True,
\t\t\t(* else *)
\t\t\t\tIf[values||doAllDebug,
\t\t\t\t\tPrint[\"P1=\",P1];
\t\t  \t\t  ];
\t\t\t\tok = CheckProp[test][A,P1,S1,SD1,doDebug[test],
\t\t\t\t\t\tFalse,TetrCenters];
\t\t\t  ];
\t\t\tIf[ok,Print[\"  \",PropMsg[test]],
\t\t\t\tIf[numericOk,
\t\t\t\t\tPrint[\"  Property \",test,
\t\t\t\t\t\t  \" failed in general,\",
\t\t\t\t\t\t  \" but numeric example succeeded.\"
\t\t\t\t\t\t ];
\t\t\t\t  ];
\t\t\t  ];
\t \t  ];
\t  ];
\t];

];

g0[y_,z_]:=y^3+z^3;
f0[a_,x_]:=a(x-a^2);

Sqrt3Simp[expr_]:=
Block[{temp},
\ttemp=expr/.{3^Rational[n_/;OddQ[n],2]->3^((n-1)/2)Sqrt3};
\ttemp=temp/.{Sqrt3->Sqrt[3]};
\ttemp=Together[temp];
\tReturn[temp];
\t];

(*
\tOther ideas for tests:
\t
\tratio of volumes numerical constant
\tratio of face areas numerical constant
\tcan inscribe a regular tetrahedron
\tlines to center j of inner tetrahedron concur
\tcorresponding edges are perpendicular
\tcorresponding edges are same distance apart
\terected perpendiculars are hyperbolic
\tcenter i of inner coincides with center j of outer
\t\twhere centers are:
\t\tcentroid, circumcenter, incenter, Monge point
*)
\
\>", "Input",
 InitializationCell->True,
 AspectRatioFixed->True,
 CellLabel->
  "In[333]:=",ExpressionUUID->"946e07da-c32d-4f6b-8c3f-26f83440993b"],

Cell[CellGroupData[{

Cell["\<\
(* Picture of our base tetrahedron *)
Under the transformation A1A2A3->A2A1A4->A3A4A1->A4A3A2,
we have
(a1,a2,a3)->(b2,b1,a3)->(b3,b1,a2)->(b3,b2,a1).\
\>", "Input",
 Evaluatable->False,
 AspectRatioFixed->
  True,ExpressionUUID->"823fae71-366a-4996-820b-c71d4ec979d6"],

Cell[GraphicsData["PICT", "\<\
18`0S`1H0FD1Oa41X022X@1T00YCD4iD0nP00@00X@1T00iCD4iD3=00S`1H0FD1
Oj40I00:De1>E0^h00/00:00S:40I00:De1>E0^h00<00P402P2?05P1I@5o802d
09`1CP1cX@1T00YCD4iD2kP00`02805?07<1C`5TX@1T00YCD4iD2kP00`02805>
0F@0]02MX@1T00YCD4iD2kP00`02802d09`0Y@4iX@1T00YCD4iD2kP00`02802T
0CT1C`1cX@1T00YCD4iD2kP00`02802T0CT1C`5UX@1T00YCD4iD2kP00@00X@1T
01YCD4iD32H1B@5X0F01O`0400;ooooooooooj40I00:De1>E0bD00000:40UP0<
1@00008000000000;00<01D9B6E/MVEdJF=Q0`0E3@0<:05I0Fd2@C6P09NQ06@0
2U=@CU@;^001002Q06@06U=@CU@<9P2P08<0]`2J00@00_ooooooooooX@1T00YC
D4iD39@00000X@2F00`500000P000000000X0;00R091<Z00Uj40I00:De1>E0^h
00400:40I00JDe1>E0`V0Dh0F05U06l01002oooooooooonQ06@02U=@CU@<U000
002Q09H030D000020000000002P1GP1M0T4cX02GX@1T00YCD4iD2kP00@00X@1T
01YCD4iD32H0S`4h0:H1C`0400;ooooooooooj40I00:De1>E0bD00000:40UP0<
1@00008000000000:02O0Cd2@CBP09NQ06@02U=@CU@;^001002Q06@06U=@CU@<
9P3_07411P2800@00_ooooooooooX@1T00YCD4iD39@00000X@2F00`500000P00
0000000X0?l0MP9Q<J00Uj40I00:De1>E0^h00400:40I00JDe1>E0`V0Dd0e05T
0>d01002oooooooooonQ06@02U=@CU@<U000002Q09H030D000020000000002]S
GP9Q<Z00Uj40I00:De1>E0^h00400:40I00JDe1>E0`V0@T0n`4P0AD01002oooo
oooooonQ06@02U=@CU@<U000002Q09H030D000020000000002P16@400V4cX02G
X@1T00YCD4iD2kP00@00X@1T01YCD4iD32H0i05?0?/1IP0400;ooooooooooj40
I00:De1>E0bD00000:40UP0<1@00008000000000:03d0E@2HS6P09NQ06@02U=@
CU@;^001002Q06@06U=@CU@<9P2F0=/0[@3i00@00_ooooooooooX@1T00YCD4iD
39@00000X@2F00`500000P000000000X0:H0h09R<Z00Uj40I00:De1>E0^h0040
0:40I00JDe1>E0`V0@80Y@4I0;`01002oooooooooonQ06@02U=@CU@<U000002Q
09H030D000020000000002P14P2Z0V8cX02GX@1T00YCD4iD2kP03000X02=X@1T
00ICD4iD0nVP08?o\>"], "Graphics",
 Evaluatable->False,
 AspectRatioFixed->True,
 ImageSize->{282, 287},
 ImageMargins->{{34, Inherited}, {
   Inherited, 
    Inherited}},ExpressionUUID->"84ed5b7b-3083-44e9-a997-6d5db940bf81"]
}, Open  ]],

Cell["\<\
findTetrCenters[condition_]:=
Block[{aCentroid,aCircumcenter,aMongePoint,aIncenter,aEulerPoint},
\t{aCentroid,aCircumcenter,aMongePoint,aIncenter,aEulerPoint} =
\t\t{Centroid,Circumcenter,MongePoint,
\t\t\tIncenter,EulerPoint}/.condition;
\t{aCentroid,aCircumcenter,aMongePoint,aIncenter,aEulerPoint} =
\t\tPowerExpand[{aCentroid,aCircumcenter,aMongePoint,
\t\t\t\t\taIncenter,aEulerPoint}];
(*
\taCentroid = RemoveCommonFactors[aCentroid];
*)
\tIf[NumberQ[aCentroid[[1]]] && aCentroid[[1]]<0,
\t\taCentroid = -aCentroid];
\tIf[showTetrCenters,
\t\tPrint[\"Coordinates of centroid: \",Factor[aCentroid]];
  \t  ];
(*
\taCircumcenter = RemoveCommonFactors[aCircumcenter];
*)
\tIf[NumberQ[aCircumcenter[[1]]] && aCircumcenter[[1]]<0,
\t\taCircumcenter = -aCircumcenter];
\tIf[showTetrCenters,
\t\tPrint[\"Coordinates of circumcenter: \",Factor[aCircumcenter]];
  \t  ];
(*
\taMongePoint = RemoveCommonFactors[aMongePoint];
*)
\tIf[NumberQ[aMongePoint[[1]]] && aMongePoint[[1]]<0,
\t\taMongePoint = -aMongePoint];
\tIf[showTetrCenters,
\t\tPrint[\"Coordinates of Monge point: \",Factor[aMongePoint]];
  \t  ];
(*
\taIncenter = RemoveCommonFactors[aIncenter];
*)
\tIf[NumberQ[aIncenter[[1]]] && aIncenter[[1]]<0,
\t\taIncenter = -aIncenter];
\tIf[showTetrCenters,
\t\tPrint[\"Coordinates of Incenter: \",
\t\t\t(aIncenter/.{Sqrt[x_]:>Sqrt[Factor[x]]})];
  \t  ];
(*
\taEulerPoint = RemoveCommonFactors[aEulerPoint];
*)
\tIf[NumberQ[aEulerPoint[[1]]] && aEulerPoint[[1]]<0,
\t\taEulerPoint = -aEulerPoint];
\tIf[showTetrCenters,
\t\tPrint[\"Coordinates of Euler point: \",Factor[aEulerPoint]];
  \t  ];
  \tReturn[{aCentroid,aCircumcenter,aMongePoint,
  \t\t\t\taIncenter,aEulerPoint}];
\t];

findGeneralTetrCenters[]:=
Block[{A1,A2,A3,A4,tem1,tem2,tem3,tem4},
\tIf[IntegerQ[numberOfTetrCenters],Return[]];
\tPrint[\"Finding general tetrahedron centers...\"];
\tA1 = {1,0,0,0};
\tA2 = {0,1,0,0};
\tA3 = {0,0,1,0};
\tA4 = {0,0,0,1};
\tCentroid = A1+A2+A3+A4;
\t(* Note that we have to divide Centroid by 4 to get exact coords *)
\tPrint[\"  Found centroid.\"];
\tcosf[x_,y_,z_]:=y^2+z^2-x^2;
\ttem1 = a1^2 b1^2 cosf[a1,b2,b3]+a2^2 b2^2 cosf[b2,b3,a1]+
\t\ta3^2 b3^2 cosf[b3,a1,b2]-2a1^2 b2^2 b3^2;
\ttem2 = tem1/.{b2->b1,a1->a2,a2->a1,b1->b2};
\ttem3 = tem1/.{b3->b2,b2->b1,a1->a3,a3->a2,a2->a1,b1->b3};
\ttem4 = tem1/.{b3->a1,b2->a2,a1->a3,a3->b1,a2->b2,b1->b3};
\tCircumcenter = {tem1,tem2,tem3,tem4};
\tPrint[\"  Found circumcenter.\"];
\t(* M = 2G-O *)
\tMongePoint = Centroid/2 -
\t\tExactTetrahedralCoordinates[Circumcenter];
\t(* Note that we have exact tetrahedral coords for Monge Point *)
\tPrint[\"  Found Monge point.\"];
\tF1=SquaredAreaOfTriangleFromSides[a1,b2,b3];
\tF2=SquaredAreaOfTriangleFromSides[b1,a2,b3];
\tF3=SquaredAreaOfTriangleFromSides[b1,b2,a3];
\tF4=SquaredAreaOfTriangleFromSides[a1,a2,a3];
\tIncenter = Sqrt[{F1,F2,F3,F4}];
\tPrint[\"  Found incenter.\"];
\t(* E = (2G+M)/3 *)
\tEulerPoint = Centroid/6 + MongePoint/3;
\t(* Note that we have exact tetrahedral coords for Euler Point *)
\tPrint[\"  Found Euler point.\"];
\tnumberOfTetrCenters = 5;
\ttetrCenterName[1] = \"centroid\";
\ttetrCenterName[2] = \"circumcenter\";
\ttetrCenterName[3] = \"Monge point\";
\ttetrCenterName[4] = \"incenter\";
\ttetrCenterName[5] = \"Euler point\";
\t];
\
\>", "Input",
 InitializationCell->True,
 AspectRatioFixed->True,
 CellLabel->
  "In[342]:=",ExpressionUUID->"3611b796-46ce-4baf-98f0-4ec44bfe3eea"],

Cell[CellGroupData[{

Cell["\<\
(* Set up Tetrahedral Coordinates for
\tvertices of a tetrahedron *)
A[1] = {1,0,0,0};
A[2] = {0,1,0,0};
A[3] = {0,0,1,0};
A[4] = {0,0,0,1};
typesOfTetrahedra = 6;
TetrTypeName[1] = \"General Tetrahedron\";
TetrTypeCond[1] = {};
TetrNumCond[1]  = {a1->16,a2->20,a3->22,
\t\t\t\t\tb1->14,b2->17,b3->21,r->3,f->f0,g->g0};
TetrTypeName[2] = \"Isosceles Tetrahedron\";
TetrTypeCond[2] = {b1->a1,b2->a2,b3->a3};
TetrNumCond[2]  = {a1->7,a2->8,a3->10,r->3,f->f0,g->g0};
TetrTypeName[3] = \"Circumscriptible Tetrahedron\";
TetrTypeCond[3] = {b1->t-a1,b2->t-a2,b3->t-a3};
TetrNumCond[3]  = {a1->8,a2->10,a3->13,t->32,r->3,f->f0,g->g0};
TetrTypeName[4] = \"Isodynamic Tetrahedron\";
TetrTypeCond[4] = {b1->t/a1,b2->t/a2,b3->t/a3};
TetrNumCond[4]  = {a1->35,a2->40,a3->28,t->840,r->3/2,f->f0,g->g0};
TetrTypeName[5] = \"Orthocentric Tetrahedron\";
TetrTypeCond[5] = {b1->Sqrt[t-a1^2],b2->Sqrt[t-a2^2],
\t\t\t\t\tb3->Sqrt[t-a3^2]};
TetrNumCond[5]  = {a1->4,a2->9,a3->12,t->1105,r->3,f->f0,g->g0};
TetrTypeName[6] = \"Harmonic Tetrahedron\";
TetrTypeCond[6] = {b1->a1/(a1 t-1),b2->a2/(a2 t-1),b3->a3/(a3 t-1)};
TetrNumCond[6]  = {a1->7,a2->9,a3->10,t->1/4,r->3,f->f0,g->g0};
(*
TetrTypeName[7] = \"Ecliptic Tetrahedron\";
TetrTypeCond[7] = {b1->(t-a1)/(a1+1),b2->(t-a2)/(a2+1),b3->(t-a3)/(a3+1)};
TetrNumCond[7]  = {a1->7,a2->8,a3->17/2,t->260,r->3,f->f0,g->g0};
*)
(*
\tFor each triangle center,
\tfind the 4 centers of each of the faces
\tof the tetrahedron in
\ttetrahedral (Barycentric) coordinates.
\tThe center in face i (opposite vertex Ai
\tis called Pi).
*)

skipSqrts=False;
showTetrCenters=False;
skipTetrCenters=False;
ShowEquationOfPlanes = False;
ShowEquationOfLines = False;

doAllTypes = True;
If[doAllTypes,
\tktLow=1; ktHigh=typesOfTetrahedra,
(* else *)
\tktLow=4; ktHigh=typesOfTetrahedra;
  ];
doAllCenters = True;
If[doAllCenters,
\tiLow=1; iHigh=numberOfCenters,
(* else *)
\tiLow=1; iHigh=5;
  ];

If[!skipTetrCenters,findGeneralTetrCenters[]];

For[k=ktLow,k<=ktHigh,k++,
Print[\" \"];
Print[\"CASE \",k,\": \",TetrTypeName[k]];
Print[\"------\"];
genCondition = TetrTypeCond[k];
numericalCondition = TetrNumCond[k];
(*
\tCompute various centers of the tetrahedron.
*)
If[!skipTetrCenters,
\tgenC=genCondition/.t->100;
\t{ourCentroid,ourCircumcenter,ourMongePoint,
\t\tourIncenter,ourEulerPoint} =
\t\t\tfindTetrCenters[genC];
  ];
For[i=iLow,i<=iHigh,i++,
\t{x1,x2,x3}=ArealCoords[i]/.{a->b3,b->b2,c->a1};
\tP[1]={0,x1,x2,x3};
\tIf[skipSqrts,
\t\tIf[!FreeQ[x1,3^(x_)],Continue[]]
\t  ];
\t{x1,x2,x3}=ArealCoords[i]/.{a->b3,b->b1,c->a2};
\tP[2]={x1,0,x2,x3};
\t{x1,x2,x3}=ArealCoords[i]/.{a->b2,b->b1,c->a3};
\tP[3]={x1,x2,0,x3};
\t{x1,x2,x3}=ArealCoords[i]/.{a->a1,b->a2,c->a3};
\tP[4]={x1,x2,x3,0};
\tPrint[\"i=\",i,\" \",centerName[i]];
\tCheckProperties[{A[1],A[2],A[3],A[4]},
\t\t{P[1],P[2],P[3],P[4]},
\t\tnumericalCondition,
\t\tgenCondition,{},{},False,False];
\t];
  ];\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->
  "In[346]:=",ExpressionUUID->"dbcebd92-0be6-4d67-928b-77e052207010"],

Cell[BoxData["\<\"Finding general tetrahedron centers...\"\>"], "Print",
 CellChangeTimes->{3.8056402882853937`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9c2abb94-4493-4e03-9056-27607469835e"],

Cell[BoxData["\<\"  Found centroid.\"\>"], "Print",
 CellChangeTimes->{3.805640288286786*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d3f43e2f-217c-4871-81e6-45090933691c"],

Cell[BoxData["\<\"  Found circumcenter.\"\>"], "Print",
 CellChangeTimes->{3.805640288287624*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f45b1579-321d-4979-a41a-25fa905677f7"],

Cell[BoxData["\<\"  Found Monge point.\"\>"], "Print",
 CellChangeTimes->{3.8056402882884293`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4e901449-f76f-4f7f-bfd0-22c17a8081d8"],

Cell[BoxData["\<\"  Found incenter.\"\>"], "Print",
 CellChangeTimes->{3.805640288289238*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"76ef299e-9706-4d0f-87ba-2edd05fefafa"],

Cell[BoxData["\<\"  Found Euler point.\"\>"], "Print",
 CellChangeTimes->{3.805640288290041*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6ca2af8f-ab56-4471-9699-ec170ea95b46"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.8056402882908487`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"61851c4f-79d2-4206-a53f-3b7e52d237c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CASE \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", "\<\"General Tetrahedron\"\>"}],
  SequenceForm["CASE ", 1, ": ", "General Tetrahedron"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288291683*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"852a16bc-12eb-4648-81eb-28581823c727"],

Cell[BoxData["\<\"------\"\>"], "Print",
 CellChangeTimes->{3.805640288292557*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8569086b-b2e2-42d1-970f-ff3831b69170"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>"}],
  SequenceForm["i=", 1, " ", "incenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288293401*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e2ea3737-604b-4a26-b9f0-8fe1c6326d81"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564028829429*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"19f374be-6f85-47b3-a531-0070086e6f0e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>"}],
  SequenceForm["i=", 2, " ", "centroid"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288295189*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7c2c1899-552c-4811-bc88-bac7b63aaa4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Faces are parallel.\"\>"}],
  SequenceForm["  ", "Faces are parallel."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288296082*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c6041b47-9a39-4647-bd29-fd578a0e1e59"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}],
  SequenceForm["    Coordinates of intersection point:  ", {1, 1, 1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402882969923`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ae1738d4-4331-436b-8e87-7613205c5bf0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "centroid", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402882978697`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a3535f4c-db4c-411c-b581-3421e147fadc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "1", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 1, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564028829878*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"11dcc305-3148-488f-9c17-5479163ad944"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288299857*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"36d0ec96-f7da-4991-ab9a-89ef0716d9b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288300735*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6a618272-e15d-4669-a2ac-71a7230953b0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288301608*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"337a6289-cb82-4aa8-9135-8255091390d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra are similar.\"\>"}],
  SequenceForm["  ", "Tetrahedra are similar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288302492*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"77c57d29-f94a-4c4e-b1bf-b8458a700b11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402883033733`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d5e7e192-080a-48fc-bc52-b34291619458"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "Euler point",
    "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288310062*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a7119445-1ece-457b-8ab6-9113e70817c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Central Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["2", "3"], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Central Monge point", " lies on reference Euler line (at ", 
   Rational[2, 3], ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288415225*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b93b61b4-7b9f-46da-92a0-7c6a19ba4b40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Central Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["8", "9"], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Central Euler point", " lies on reference Euler line (at ", 
   Rational[8, 9], ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288580682*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"805dcc43-1610-4c79-adda-4a6b6de07509"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Reference \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" lies on central Euler line (at \"\>", 
   "\[InvisibleSpace]", "4", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    Reference ", "circumcenter", " lies on central Euler line (at ", 4, 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402886898518`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"088e1d52-ff68-48ef-a43b-6b6a1f3280ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Reference \"\>", 
   "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on central Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    Reference ", "Monge point", " lies on central Euler line (at ", -2, 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402887454567`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"93af3f87-8d45-4973-ac42-1742f22c8fd3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564028879634*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3d3d1cb4-34e5-4daa-b9de-fe6b6f621a2f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>"}],
  SequenceForm["i=", 3, " ", "circumcenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640288797707*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"67620ae0-4593-4dff-8a95-c72e8c00250c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm[
  "    Point coincides with ", "circumcenter", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402893611937`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ad473ed5-a5c3-42e8-a4a1-c5ba5d11b247"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "0", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 0, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402894109163`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e423ef22-9992-45e9-b9b5-540aa9cd7775"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.805640289412037*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8ba90fe5-77f8-4d4a-897e-8905e2a87461"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a1", "4"], " ", 
     SuperscriptBox["b1", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["b1", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "2"], " ", 
     SuperscriptBox["b1", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["b2", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a2", "4"], " ", 
     SuperscriptBox["b2", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"], " ", 
     SuperscriptBox["b2", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "2"], " ", 
     SuperscriptBox["b3", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"], " ", 
     SuperscriptBox["b3", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a3", "4"], " ", 
     SuperscriptBox["b3", "2"]}]}]}],
  SequenceForm[
  "    ", 2 $CellContext`a1^2 $CellContext`a2^2 $CellContext`a3^2 + \
$CellContext`a1^4 $CellContext`b1^2 - $CellContext`a1^2 $CellContext`a2^2 \
$CellContext`b1^2 - $CellContext`a1^2 $CellContext`a3^2 $CellContext`b1^2 - \
$CellContext`a1^2 $CellContext`a2^2 $CellContext`b2^2 + $CellContext`a2^4 \
$CellContext`b2^2 - $CellContext`a2^2 $CellContext`a3^2 $CellContext`b2^2 - \
$CellContext`a1^2 $CellContext`a3^2 $CellContext`b3^2 - $CellContext`a2^2 \
$CellContext`a3^2 $CellContext`b3^2 + $CellContext`a3^4 $CellContext`b3^2],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289413233*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"20471d4e-ca4d-4f05-aa2c-b6c797f54a5d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289414331*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"79e0fa2f-cdda-4948-9968-834e47088181"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"orthocenter\"\>"}],
  SequenceForm["i=", 4, " ", "orthocenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289415303*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d63aa755-2c98-4a7b-9adf-6bfc738d82f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"nine point center\"\>"}],
  SequenceForm["i=", 5, " ", "nine point center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289423534*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5c967f6c-9737-4474-a3b9-7a53c6ff37f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"symmedian point\"\>"}],
  SequenceForm["i=", 6, " ", "symmedian point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289473167*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7a5d7d3e-687b-420e-b608-b64c419075fc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289475128*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"40c9ec49-054a-4469-9530-485d2cb9ef79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne point\"\>"}],
  SequenceForm["i=", 7, " ", "Gergonne point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289476613*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"78532b1b-a92b-4887-9b1d-e9e2e69ea4d0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel point\"\>"}],
  SequenceForm["i=", 8, " ", "Nagel point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289529195*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d8a5d62f-f4a8-49d5-909d-8ddfa9207ebc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt\"\>"}],
  SequenceForm["i=", 9, " ", "Mittenpunkt"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289530373*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c7ab2528-6ddb-4403-ada9-ee5c3d5835ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker center\"\>"}],
  SequenceForm["i=", 10, " ", "Spieker center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289531402*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ba0472a2-0fe9-4cc8-af1b-67892af57477"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach point\"\>"}],
  SequenceForm["i=", 11, " ", "Feuerbach point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289532583*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f1a64fe8-0c8e-4894-9a5b-f865aa155204"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12\"\>"}],
  SequenceForm["i=", 12, " ", "X12"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402895833483`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9db589b3-9647-465c-82df-938b481389ea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st isogonic center (Fermat point)\"\>"}],
  SequenceForm["i=", 13, " ", "1st isogonic center (Fermat point)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564028958457*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"faef6ddd-04dc-4946-9e71-a63f317e32b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isogonic center\"\>"}],
  SequenceForm["i=", 14, " ", "2nd Isogonic center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640289916532*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"03396519-aeb1-4b00-a722-e077aae332c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Isodynamic point\"\>"}],
  SequenceForm["i=", 15, " ", "1st Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640290184306*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"90a615a5-86da-4720-a937-b3287ddfc4b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isodynamic point\"\>"}],
  SequenceForm["i=", 16, " ", "2nd Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402903602123`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cc3b2664-496b-4fb1-9875-baacebc17da7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point\"\>"}],
  SequenceForm["i=", 17, " ", "1st Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564029054246*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"77d22860-bb01-4a30-9b77-a9442ec3e2d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "18", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point\"\>"}],
  SequenceForm["i=", 18, " ", "2nd Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402908922997`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7db3bb49-4d08-4459-9fe1-3ab70cf64eec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point\"\>"}],
  SequenceForm["i=", 19, " ", "Crucial point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402911663303`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"982b4106-a887-4978-bc0c-aeceb588147c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point\"\>"}],
  SequenceForm["i=", 20, " ", "De Longchamps point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291216346*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d68651a6-72c9-4a9f-acce-9434639084a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point\"\>"}],
  SequenceForm["i=", 21, " ", "Schiffler point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291269678*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"667e0853-6740-4802-a850-536669bcd1fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "22", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point\"\>"}],
  SequenceForm["i=", 22, " ", "Exeter point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291271123*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ca99398d-9d1f-4aea-931e-83d7f51c1894"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point\"\>"}],
  SequenceForm["i=", 23, " ", "far out point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291332068*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5a89c572-12a7-4c0e-acb3-e8eb878c8904"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "24", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24\"\>"}],
  SequenceForm["i=", 24, " ", "X24"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402913332567`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9fb0565e-155a-4daa-9691-325426559b6c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25\"\>"}],
  SequenceForm["i=", 25, " ", "X25"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291386265*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e1fba38c-dfda-4696-9705-c026e351c6c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "26", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle\"\>"}],
  SequenceForm["i=", 26, " ", "Circumcenter of tangential triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291437261*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2e4de72a-f5a2-49a2-9858-c77e5599d2d0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27\"\>"}],
  SequenceForm["i=", 27, " ", "X27"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291529298*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"df55f275-6491-4202-8d7d-d686244c0505"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28\"\>"}],
  SequenceForm["i=", 28, " ", "X28"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291579672*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"614a2ff8-4835-41c4-a70d-a15f7653ee7e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "29", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29\"\>"}],
  SequenceForm["i=", 29, " ", "X29"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291631278*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1013e40c-4c03-4b57-abe4-44f769e41297"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30\"\>"}],
  SequenceForm["i=", 30, " ", "X30"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291683201*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"838ab076-3afd-490e-a027-7b9593aed008"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291684383*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b52c6319-3700-477f-89b2-c850dd798fbd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640291685315*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"033e753b-605b-466b-93a8-b8fce5f6d6f8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640293741828*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"da7aafa6-da1b-4134-a62f-806ae50dd6d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point\"\>"}],
  SequenceForm["i=", 31, " ", "2nd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402937431393`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fecadb8d-f07f-4be0-b733-52e8873c41eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640293772252*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d842687e-c54e-4d0f-9307-13f9203d91b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point\"\>"}],
  SequenceForm["i=", 32, " ", "3rd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640293773471*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b9c9243a-7da0-489e-89ea-ee7b0b22796f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402937744513`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"560ba00e-95dc-46b7-9630-922428636267"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "33", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33\"\>"}],
  SequenceForm["i=", 33, " ", "X33"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640293781377*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0b723a03-c74b-4cc9-9634-67ec81bc871f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34\"\>"}],
  SequenceForm["i=", 34, " ", "X34"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402938286552`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5421d628-3293-43f9-9f80-73e967d6fed8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35\"\>"}],
  SequenceForm["i=", 35, " ", "X35"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640293875193*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"de39644b-c40c-48f9-90bb-4507d38ad6fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36\"\>"}],
  SequenceForm["i=", 36, " ", "X36"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640293906139*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4df2e2ff-2640-433d-80bc-37dd7827a147"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37\"\>"}],
  SequenceForm["i=", 37, " ", "X37"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402939437447`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fc905fac-f6d5-453c-b68b-5c702dcdf729"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38\"\>"}],
  SequenceForm["i=", 38, " ", "X38"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640293951232*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a00cf050-3288-42bf-a39e-8e3978745c00"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint\"\>"}],
  SequenceForm["i=", 39, " ", "Brocard midpoint"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640293981545*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4a2b5ed2-1b7c-4865-a037-df52539a0377"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40\"\>"}],
  SequenceForm["i=", 40, " ", "X40"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294013198*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"47aadfd3-703f-4d28-8ff5-08c0781b0c01"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41\"\>"}],
  SequenceForm["i=", 41, " ", "X41"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294075626*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4c204fc7-2c00-49c6-a3d8-1e257b3824c8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42\"\>"}],
  SequenceForm["i=", 42, " ", "X42"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294104649*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2076d98e-5668-4230-a450-0a73d3fd43be"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43\"\>"}],
  SequenceForm["i=", 43, " ", "X43"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294144375*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"da3b7619-50c6-45af-9b76-072df3f0269d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44\"\>"}],
  SequenceForm["i=", 44, " ", "X44"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294176853*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"119f10c6-6719-4a3c-b39c-cdfd13ee85b2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45\"\>"}],
  SequenceForm["i=", 45, " ", "X45"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402941840677`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e5955500-95b3-43d6-8fc2-c78f74b5aeb2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46\"\>"}],
  SequenceForm["i=", 46, " ", "X46"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402942133904`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ebf088b5-432f-47e6-90ed-786c1270da2a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "47", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47\"\>"}],
  SequenceForm["i=", 47, " ", "X47"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294273849*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"521c57d0-e9d2-43a5-9451-58f296f2110a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "48", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48\"\>"}],
  SequenceForm["i=", 48, " ", "X48"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294320568*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"099f273c-adb6-4e54-b125-027f10de18e8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "49", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49\"\>"}],
  SequenceForm["i=", 49, " ", "X49"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294352024*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f8d227e7-9c0d-4c52-9e38-4d734b8b1dfe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "50", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50\"\>"}],
  SequenceForm["i=", 50, " ", "X50"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294414586*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6b62d5fc-2508-485f-8c54-17e95864df28"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle\"\>"}],
  SequenceForm["i=", 51, " ", "Centroid of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294474605*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"89a8c6ea-1969-4694-9c0d-b405e4843dbd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle\"\>"}],
  SequenceForm["i=", 52, " ", "Orthocenter of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294542076*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7922cc65-9fc2-4b4a-8dc7-b18f654e3d1b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle\"\>"}],
  SequenceForm["i=", 53, " ", "Symmedian point of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564029460917*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cdf4b289-434a-4edd-a5a1-f2e4ba53442e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "54", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nine point inv\"\>"}],
  SequenceForm["i=", 54, " ", "Nine point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402946483173`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dab80396-84c0-466a-a858-e3b60517bbad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne inv\"\>"}],
  SequenceForm["i=", 55, " ", "Gergonne inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402947314863`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"786b6e23-a700-4070-a7fe-e174f23d728f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel inv\"\>"}],
  SequenceForm["i=", 56, " ", "Nagel inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294761503*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6ecc383b-2d92-436b-b7a8-8a772208eae6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt inv\"\>"}],
  SequenceForm["i=", 57, " ", "Mittenpunkt inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294794046*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"29291453-cc84-482c-acd2-67ed79f091a7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker inv\"\>"}],
  SequenceForm["i=", 58, " ", "Spieker inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402948260813`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6142d65d-f914-4f83-ac9b-7e62e5986f85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach inv\"\>"}],
  SequenceForm["i=", 59, " ", "Feuerbach inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564029483276*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"afdec6cf-8d8b-4c81-9348-9d1520de76bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12 inv\"\>"}],
  
  SequenceForm["i=", 60, " ", "X12 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294890935*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"06b3c2ca-b38e-42ce-b710-1c34ac51f73a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "61", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point inv\"\>"}],
  SequenceForm["i=", 61, " ", "1st Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640294926674*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"95fec1a0-0ab0-4fd7-8bfb-6114fb14fdfe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "62", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point inv\"\>"}],
  SequenceForm["i=", 62, " ", "2nd Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402951631823`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ae0e7d8e-71ed-4ef7-86d7-139d918eac29"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point inv\"\>"}],
  SequenceForm["i=", 63, " ", "Crucial point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640295387528*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a0016b32-f688-4976-b718-040f120561f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "64", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point inv\"\>"}],
  SequenceForm["i=", 64, " ", "De Longchamps point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640295415966*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d880af38-02d6-4e07-a9e2-ca915960ff05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point inv\"\>"}],
  SequenceForm["i=", 65, " ", "Schiffler point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640295491495*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f4844b27-2b8b-4c2e-be0b-1ecd914a943f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "66", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point inv\"\>"}],
  SequenceForm["i=", 66, " ", "Exeter point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640295519959*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0c7cbfc1-17a1-49c5-99ce-e3559983e251"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point inv\"\>"}],
  SequenceForm["i=", 67, " ", "far out point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640295558823*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"39691d46-c68b-48e7-8ae8-f53e5097b654"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "68", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24 inv\"\>"}],
  
  SequenceForm["i=", 68, " ", "X24 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640295594221*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"09556604-b6fe-4ae2-aa8f-2f99b2e17734"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25 inv\"\>"}],
  
  SequenceForm["i=", 69, " ", "X25 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640295646324*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"97d98980-9b35-4a09-b289-cf29baf1641d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "70", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle inv\"\>"}],
  SequenceForm["i=", 70, " ", "Circumcenter of tangential triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640295675188*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"875a96a9-0394-4853-99e2-8220485032b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27 inv\"\>"}],
  
  SequenceForm["i=", 71, " ", "X27 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402957774563`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"85be37a4-8a76-4edc-9cac-b3249bac63d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28 inv\"\>"}],
  
  SequenceForm["i=", 72, " ", "X28 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564029580797*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2ff2bdcb-bc3f-440d-a419-a5cba62bf3f0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "73", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29 inv\"\>"}],
  
  SequenceForm["i=", 73, " ", "X29 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640295844596*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"85e4b186-dec9-4b07-835a-7f0b264336d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30 inv\"\>"}],
  
  SequenceForm["i=", 74, " ", "X30 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640295878207*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6fd42880-f0cd-4d27-a7d7-d5b2c24bb51f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point inv\"\>"}],
  SequenceForm["i=", 75, " ", "2nd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402959746037`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"507ef26e-865d-4f63-af3d-6d9bb27da8f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564029600412*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d0cb0cc5-19ae-4fc7-949e-1cd14a9a6e66"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point inv\"\>"}],
  SequenceForm["i=", 76, " ", "3rd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296005588*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"863bb3aa-3bc7-40b0-b163-6a86861bcb54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402960067043`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eb947ff0-4b51-4f1e-8543-0be86a2cc339"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "77", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33 inv\"\>"}],
  
  SequenceForm["i=", 77, " ", "X33 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296014361*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4ee0f0d0-9f50-4b33-b934-9437c206e008"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34 inv\"\>"}],
  
  SequenceForm["i=", 78, " ", "X34 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296076853*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"df4f1454-aefa-4dd3-87f7-b95042432070"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35 inv\"\>"}],
  
  SequenceForm["i=", 79, " ", "X35 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296108897*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1a6c82ff-adfe-49c9-b4ad-f57c894483b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36 inv\"\>"}],
  
  SequenceForm["i=", 80, " ", "X36 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402961409893`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"240644e2-3d4f-47bf-9a70-1bf70cb096c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37 inv\"\>"}],
  
  SequenceForm["i=", 81, " ", "X37 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296172102*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"afb791c5-3057-450b-a697-c3c836feea80"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38 inv\"\>"}],
  
  SequenceForm["i=", 82, " ", "X38 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402961798983`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b430b451-5235-4637-ac37-ce95b6e5f5ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint inv\"\>"}],
  SequenceForm["i=", 83, " ", "Brocard midpoint inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296209771*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1112cb2b-7093-45a7-a3ee-a89371ec7891"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "84", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40 inv\"\>"}],
  
  SequenceForm["i=", 84, " ", "X40 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296243784*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3290574d-4e2d-434c-9f2f-07ad77c37ab3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41 inv\"\>"}],
  
  SequenceForm["i=", 85, " ", "X41 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296341263*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0f667cba-f1f3-48a0-ac6e-e9f328df1e46"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42 inv\"\>"}],
  
  SequenceForm["i=", 86, " ", "X42 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296388029*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1c0fd936-dbb0-4598-b664-0b935c3e7ba9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "87", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43 inv\"\>"}],
  
  SequenceForm["i=", 87, " ", "X43 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296418735*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4ee94d49-8152-44d7-aaaf-c1939b9763b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44 inv\"\>"}],
  
  SequenceForm["i=", 88, " ", "X44 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296461491*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"15b20e51-737a-4c14-a37f-15fb5fed8da5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45 inv\"\>"}],
  
  SequenceForm["i=", 89, " ", "X45 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296493181*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2397d759-4946-42ff-8e10-0aeb732f18c2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "90", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46 inv\"\>"}],
  
  SequenceForm["i=", 90, " ", "X46 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296527224*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"48bb5c38-2754-4feb-ba53-ad8c7ac3a686"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "91", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47 inv\"\>"}],
  
  SequenceForm["i=", 91, " ", "X47 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402966164303`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"90a813bb-f18a-40c1-ac89-b2b5066504b0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "92", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48 inv\"\>"}],
  
  SequenceForm["i=", 92, " ", "X48 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296683681*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"da693dba-ce6e-480e-9635-bd92114ae62f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "93", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49 inv\"\>"}],
  
  SequenceForm["i=", 93, " ", "X49 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296732603*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9a01959c-a30e-4599-93d7-8bac92e5dc45"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50 inv\"\>"}],
  
  SequenceForm["i=", 94, " ", "X50 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296828474*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"53f7df52-1c47-484b-b8e0-8bf2f9920be8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle inv\"\>"}],
  SequenceForm["i=", 95, " ", "Centroid of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296918071*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"38fc67af-6513-4b22-a4e7-9c473d2ce889"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "96", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle inv\"\>"}],
  SequenceForm["i=", 96, " ", "Orthocenter of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640296984991*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7e495f59-2841-49f6-9e89-161bbb8dd16d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "97", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle inv\"\>"}],
  SequenceForm["i=", 97, " ", "Symmedian point of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297086473*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5370a7f3-bf14-482e-89d3-b248c678daa7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Tarry point\"\>"}],
  SequenceForm["i=", 98, " ", "Tarry point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297151082*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d3d7006a-387b-4aff-a1e1-7e228e24c1a4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Steiner point\"\>"}],
  SequenceForm["i=", 99, " ", "Steiner point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402971904097`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"afd9490a-c072-4402-8feb-a34691d6608a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X100\"\>"}],
  SequenceForm["i=", 100, " ", "X100"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297219401*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"410af620-0e50-4266-b623-23c05901e94a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "101", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X101\"\>"}],
  SequenceForm["i=", 101, " ", "X101"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297249189*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ea5b51f6-79ac-4b3d-ae5e-0fc4bd6896da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "102", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X102\"\>"}],
  SequenceForm["i=", 102, " ", "X102"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297279396*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2b0553c9-8308-400d-9d0e-1ff0b18b5a8a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "103", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X103\"\>"}],
  SequenceForm["i=", 103, " ", "X103"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297310246*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"872667b2-dd5b-4072-b904-ac844638326a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "104", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X104\"\>"}],
  SequenceForm["i=", 104, " ", "X104"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402973447323`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2a8e9bb2-2c33-40c1-9502-736ac7e6f707"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "105", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X105\"\>"}],
  SequenceForm["i=", 105, " ", "X105"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297346018*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"864d1feb-53c7-4110-b964-740d24c73ddd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "106", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X106\"\>"}],
  SequenceForm["i=", 106, " ", "X106"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402973773813`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0285236e-5290-4307-8054-2e3249aa6037"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "107", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X107\"\>"}],
  SequenceForm["i=", 107, " ", "X107"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402974108047`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"974c5321-0b36-4033-ab9f-20132281b064"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "108", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X108\"\>"}],
  SequenceForm["i=", 108, " ", "X108"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297443317*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b2104916-1273-4a49-a2a8-3419a88facc8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "109", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X109\"\>"}],
  SequenceForm["i=", 109, " ", "X109"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297476807*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"906e8a7c-cd7a-4292-9d02-9819f9862fd3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "110", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X110\"\>"}],
  SequenceForm["i=", 110, " ", "X110"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297510385*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"02c2637d-9da1-4191-8fc0-a4ed39708264"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "111", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X111\"\>"}],
  SequenceForm["i=", 111, " ", "X111"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402975431757`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4ae733eb-b0f7-4eb6-aa03-abdccf1cdd1d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "112", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X112\"\>"}],
  SequenceForm["i=", 112, " ", "X112"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297577352*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e4c28837-f900-418d-bcfd-9bf843ddb36d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "113", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X113\"\>"}],
  SequenceForm["i=", 113, " ", "X113"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297578648*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b6d8e765-9a9c-4579-9c4b-7f7172a5f8d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "114", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X114\"\>"}],
  SequenceForm["i=", 114, " ", "X114"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402976104317`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1f247bcb-a16c-45cd-ad64-c734f0f0f8c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "115", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X115\"\>"}],
  SequenceForm["i=", 115, " ", "X115"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402976441517`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b426517e-4512-436e-b245-dbb21ac9e9a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "116", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X116\"\>"}],
  SequenceForm["i=", 116, " ", "X116"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402976511917`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dd56925f-9048-43dc-81e3-05ace3ebed90"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "117", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X117\"\>"}],
  SequenceForm["i=", 117, " ", "X117"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297696891*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a436f191-60d1-49fb-8337-9c3ebdc3c6d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "118", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r-power point\"\>"}],
  SequenceForm["i=", 118, " ", "r-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297725699*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d422ddd7-7f05-4e98-99dd-18130da8d198"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297735314*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c7ea991c-ffbb-4ac3-84cc-0e3c46b571ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "119", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r2-power point\"\>"}],
  SequenceForm["i=", 119, " ", "r2-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402977651*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a5f0afce-61f1-4fb2-90bc-110eec999199"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "120", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r3-power point\"\>"}],
  SequenceForm["i=", 120, " ", "r3-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564029776667*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e8653cda-114d-415a-b8f8-c009279c3e57"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "121", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z1\"\>"}],
  SequenceForm["i=", 121, " ", "Z1"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297796578*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b7fffb14-9b85-40f1-a80d-31f285927997"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "122", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z2\"\>"}],
  SequenceForm["i=", 122, " ", "Z2"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402978307343`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e79fbc14-bc8e-46c5-bcc1-25aa19092f8e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "123", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z3\"\>"}],
  SequenceForm["i=", 123, " ", "Z3"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297867634*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eafb03d3-0323-4c31-8f1c-12df60bd93d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "124", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z4\"\>"}],
  SequenceForm["i=", 124, " ", "Z4"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402979058228`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5bf87cef-d8c5-4a2e-aba3-0595968e162e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "125", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z5\"\>"}],
  SequenceForm["i=", 125, " ", "Z5"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640297947194*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a07eeb8d-b602-4983-87b2-8b872b24dd3e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "126", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z6\"\>"}],
  SequenceForm["i=", 126, " ", "Z6"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564029798946*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c0be2871-bd40-4d3a-8a77-f4259b62f03b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "127", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z7\"\>"}],
  SequenceForm["i=", 127, " ", "Z7"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640298031706*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cd46855e-61b7-4255-a709-b4f5d24ca7d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "128", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z8\"\>"}],
  SequenceForm["i=", 128, " ", "Z8"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640298072398*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bc8daebf-b43a-4ea9-9eb1-710de84ba1f0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "129", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r4-power point\"\>"}],
  SequenceForm["i=", 129, " ", "r4-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640298107225*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d57f52f7-0989-48ce-af38-9807c4387d0e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056402981353416`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1860ef45-6d7a-4c32-b8e7-a3691f882b92"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640298143173*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f3f39d84-eb6b-48df-9ca6-5c4a5e2de933"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640303723339*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c0d3acf8-670e-4a73-bf5c-3f3484859b84"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "130", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"arbitrary center\"\>"}],
  SequenceForm["i=", 130, " ", "arbitrary center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640303725037*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d96b3595-4f85-4d3c-9c9d-14a3da595535"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "131", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"areal center\"\>"}],
  SequenceForm["i=", 131, " ", "areal center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640303753126*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"06dd7cf6-186e-4231-93b2-1a23bdf348be"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.805640304395855*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bcc903b0-d751-4ec1-8516-5cc55c3f9573"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CASE \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", "\<\"Isosceles Tetrahedron\"\>"}],
  SequenceForm["CASE ", 2, ": ", "Isosceles Tetrahedron"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403043970537`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"592ebb34-ccbb-4503-96cd-d327ff6e6285"],

Cell[BoxData["\<\"------\"\>"], "Print",
 CellChangeTimes->{3.805640304398025*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"81d0dc1f-5a65-4ae9-9a4d-1abcfd5583b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>"}],
  SequenceForm["i=", 1, " ", "incenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044049177`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"15517421-6a45-4fe3-9561-8024996e2861"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044061604`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"77e69562-687a-48cf-aaea-e22bcfcd90a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044351873`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0b198c8c-9fd4-4943-82db-fa9a28f158f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304436489*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b8ef1d4-1f96-4ad8-891a-a787cfaa1aa3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044375763`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dda277ac-a316-461a-bc76-054c606c7b63"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304438838*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f3a49b3a-bfa2-4416-a1ec-297b8c2f179f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304439912*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"006cf50d-60f9-4e68-bc27-3684c5a2c509"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044411592`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"519f1139-4eb1-4a32-8dff-7c55baea1337"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044425793`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b622efa2-a101-46c6-b439-ce51281774fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044437733`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e54c8a72-3f34-4fec-a734-c64adb44d0f1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044448233`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f79354e1-e162-4334-980b-52f84e241acc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>"}],
  SequenceForm["i=", 2, " ", "centroid"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304445836*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"57fa2a91-22b1-4bab-b52c-54f3556c9f5a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Faces are parallel.\"\>"}],
  SequenceForm["  ", "Faces are parallel."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304446847*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aaca4b46-ffeb-469a-bfdc-22ed82652d31"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}],
  SequenceForm["    Coordinates of intersection point:  ", {1, 1, 1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304447996*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"088b0835-7885-44d0-adee-488c0e5ed228"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "centroid", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304448997*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f8197239-2e98-406e-b5ac-826ad51789c1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm[
  "    Point coincides with ", "circumcenter", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044500923`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8306fa51-eee9-465c-b93f-84386bcaa050"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "Monge point", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304451296*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"73462778-00cd-42ea-80b2-c4795eeeeb3e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "incenter", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304452298*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3e6c1b17-549a-49bf-aef7-ed72c65287a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "Euler point", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304453413*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a7e60955-d35a-4a9c-b7df-d315ddc89b33"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "1", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 1, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030445442*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"80a29330-31a6-462e-baf7-c1ff7d4ecd0b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304455428*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"385371b6-8d61-46cb-a775-517cf02c00a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304456402*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1d82838d-ec1f-4401-a1e3-53550475c8d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304457468*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0101d518-c0e3-4fe7-a35a-a013e46957ae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304458756*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7466cdde-d6e2-4fa2-934b-e41419b4b8cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044597673`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"58abb50e-d03c-484b-b5b2-7d2425018e5e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra are similar.\"\>"}],
  SequenceForm["  ", "Tetrahedra are similar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304460738*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"efab5d81-8966-4ad0-b194-8bc25a32cd30"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304461708*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ee6670cd-79f3-465d-b0dc-34354aeff9bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304462779*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ef2f50a1-c66e-4413-a645-b4cd575d8041"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044642467`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"69c1ed6e-9125-4184-9b27-e46e1d705e43"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304465456*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dcad4262-c985-4d0f-9176-93387129f054"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304466818*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"41bb4a92-5034-4f2f-871b-b22e0b7b157f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030446824*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c7bc8b46-10da-45d7-bca1-12019dc57cc4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>"}],
  SequenceForm["i=", 3, " ", "circumcenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403044692707`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d45beffc-cdab-411c-8246-04e69620e0aa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304470293*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ffecfd32-4eef-4eeb-9190-8aa56531e703"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304471285*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1b022d58-c298-43d0-b9b9-b128aa30d7ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304472268*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d14e2278-3572-4548-a377-2ff953f620d0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304473343*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c1da1928-7465-4a52-86b2-2ec6bee28b9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "centroid", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304593389*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"285a575a-6aac-4821-b6a9-94d39e980e2b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm[
  "    Point coincides with ", "circumcenter", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403045951233`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"018b0eba-278c-47b2-b077-8d743f11cdc8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "Monge point", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403045962467`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"00f510bc-13da-4f8c-b9fb-93ec92edd99e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "incenter", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304597541*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e1551546-33fd-4484-bbbf-244b4ea67075"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "Euler point", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304598588*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34c27977-0d3e-47c3-8112-36b4bab3ddb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "1", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 1, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403045996103`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0f491ae0-5973-4daf-b9bc-175ee1d0634c"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.805640304600634*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"59b1b0c0-3a5a-4bb7-9922-08f415cc709d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["    ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304601636*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e819d094-b190-40bd-bba8-4d3a92ed261d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304602902*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8d2d9479-30d6-4438-98ac-945177438941"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304603998*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0a0ec2f0-b6bb-4676-846a-8ef67e19e187"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304605364*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"09f6e77f-f064-4427-8648-e934cdf12efd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403046064243`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"72f26f05-70b9-471f-b9ff-5124470ae963"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304607465*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ebdb69e5-e4b6-4f82-87d1-5c065f9ac4d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304608494*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"27ade93e-4d2f-46cd-bdf5-2e52b67b18d1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403046095667`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fd984479-b08c-43e2-8d17-7a5a3fb0cff8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"orthocenter\"\>"}],
  SequenceForm["i=", 4, " ", "orthocenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403046108294`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0d363715-8e08-4eea-86f2-e74006e12bf7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304611949*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fc60175a-c2e4-4db4-bc0b-5b3f0566feec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403046416273`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f2e10c4a-21e1-4abe-8b22-86e551aa708e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304643373*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f0eaf316-0011-45a4-b31c-af6315ac940b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403046443768`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"72c0a2b5-0d35-444b-9435-32677009a167"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304645361*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0d5ce6b1-d2c5-4fbc-970d-e1087460cba3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304646411*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8bf15219-94b1-4245-b2aa-9a1c631b8042"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403046474867`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5d6689b8-a928-436f-864b-ea134591105d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304648546*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"73a084f8-dd7d-405c-8212-b997b82883e8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304649596*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b2bbff70-3a3c-405f-8e53-fe60d6567598"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304650926*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ec40667c-453a-461d-938f-5190386fba2d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"nine point center\"\>"}],
  SequenceForm["i=", 5, " ", "nine point center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304651967*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e5bcf21d-e649-40c2-b6eb-c8a06ca0bea2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403046531878`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8cd78f7a-d022-4080-8dc5-040690544925"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403046848383`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b7d8077e-5546-4cab-85f3-7291205282b0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304686151*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3a4818fe-fd40-4c7b-bf28-84dd4d5f315f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304687166*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4cbd9497-c5ce-41a5-9df1-03e00a26bd1e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304688169*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bfcbdce1-aa60-42d2-b22c-90d685485894"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403046892347`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"42eb4795-17a7-43cb-9a17-1f62bef44171"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304690539*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f36e44e4-321e-4ab2-bdcf-7032aca007cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304692238*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fd9149b3-1d5a-47d7-8ac0-2c165da9fbd0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304693514*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1d9a685e-d185-4790-ac6f-7d5d70e1df35"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304694705*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1c5bf385-c603-4dd6-a265-63c87f859537"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"symmedian point\"\>"}],
  SequenceForm["i=", 6, " ", "symmedian point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304695836*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"924082fc-512b-485a-9811-517e97a63130"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304696968*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7581baea-ecdc-4e6f-a49f-9e3cf8354f03"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403046981087`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7ac73288-9c00-42ec-8d00-6c9c87c34a51"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304699473*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"06b82576-91c9-4568-aa03-a058d34e6e27"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047005053`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e3d86004-7985-40dc-a27d-27c76633a546"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304701518*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"724cad43-6575-478e-8196-2a9a56e5a8d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304702573*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"12eeccb0-9224-4a28-a475-01a54ed5f226"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030470366*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f0416fa3-735f-4704-a880-71f2f4a20f2d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047047367`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4e56c23a-0f45-4c6e-b98b-eb419a2e2013"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304705791*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9623f492-4e92-43bc-8d20-c58d12a7854a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304707259*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c9b97b02-eafc-4c7a-ada8-aea504f09eed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne point\"\>"}],
  SequenceForm["i=", 7, " ", "Gergonne point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304708308*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"26134890-d336-4eac-b33e-1347cdd7f22d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304709301*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"47953207-96dd-4d1a-9e9d-ce4b2f5f5a79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304738407*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2e0a3249-73e7-48a0-9598-6b88d4e5de04"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047398157`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bb208f4d-cd6a-48e7-99ee-2cd0f197956c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047411203`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"24ef2105-addb-4376-848e-1477d3bb762c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304742714*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"60f16928-87fe-4c8e-bbe2-d2f064c2b681"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304743904*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"53570a8e-3dd4-498a-93a4-51421c9772fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304745245*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a6bd3ad1-a92f-4f9f-91ce-bfb32127c375"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047464323`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b3835a59-19c6-4f2e-940f-1b3f8899fe17"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304747651*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"31f72b85-93d0-4195-8b3f-3406f22a07df"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304748869*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"af8c4656-7271-4821-ab4f-729f5b70ef1a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel point\"\>"}],
  SequenceForm["i=", 8, " ", "Nagel point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304749887*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8f312120-459c-4ddb-9996-c2e12611a447"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304750875*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"46619af1-8092-41b4-8222-4f9a16da5f1e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304751873*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c3f0306a-5cc1-4b61-96d4-5f6022797114"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304752873*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ee6bae4d-e8ff-4599-b280-d4d5425c2287"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304753881*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"35018b0f-5a88-4e03-8127-d1a57fbd3113"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304754903*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3821bd6e-0940-4432-9695-de3174b405e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304756043*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"663c620a-46ae-4374-962c-fc4bc0c120c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304757214*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fee80596-f405-48a9-954a-b0674a4313af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304758292*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e7a19f5c-9129-4d67-8932-150b1fbe525d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047593946`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"28b09bf6-aace-4e38-bde2-296d25fa1b6f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304760456*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"61e973b0-74c3-4ceb-827a-d48feebbdc72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt\"\>"}],
  SequenceForm["i=", 9, " ", "Mittenpunkt"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047615137`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d73cf4fa-e4e1-4e93-8a5a-674f8b9bf6cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047625113`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"782d4e6b-6ad0-4dc2-b141-c4d27664b084"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304769929*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"106e551a-c13b-42db-a428-6a615d5af780"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304771283*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fdcad515-afd5-4afd-be09-3add38ede6f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047723103`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a1805b4c-de53-496e-bea4-593c2d5ad32c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047734003`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f94a6327-4a38-44d6-b839-7b709501c75d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047745943`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1abcf482-2c52-4219-a329-2b97d4f01f80"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047756577`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a4a1b138-3007-40d8-9b5d-a6e80deb7626"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304776805*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b91d7d06-6806-4fea-ae8b-6f30ef173e07"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304777884*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"900e1dc5-3dd1-4f5c-ab55-b598da0e051a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304778962*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"67017ae7-c1f0-479c-94c7-21108d8f550d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker center\"\>"}],
  SequenceForm["i=", 10, " ", "Spieker center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304779969*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"57fa5069-5933-4f11-870e-adec70e46d49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304780979*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a1efbea4-cfc9-4535-ac04-7417424f9337"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047820044`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9dc08a99-59f4-4776-960c-78342903c969"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304783024*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ae30d9fe-bbce-46cd-803f-fa4eb51779f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304784114*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"76f01dd2-7ac7-4353-8056-a6a20a25dfe1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304785337*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"154dbbc9-a8f9-4a51-b1fb-615105d58b93"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304786667*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d3b400e8-e24c-4362-9295-aa040a2bce79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047880497`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8677cdd4-ba8b-499c-87cb-f3fcf747833a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047894*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dd84995d-bf59-4e5c-86e3-2965c73fd620"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403047906513`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bd27b767-fb43-4544-b1b9-6d9b8a19bfa9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304791741*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aff9f76b-f02e-4e0b-8e91-d8eb96cb1263"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach point\"\>"}],
  SequenceForm["i=", 11, " ", "Feuerbach point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304792816*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"db42b7f2-007e-4bdd-a1a9-914bdcf9f319"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304820943*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"73d0dfd1-103d-4858-92ac-92b5cbbc62a7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304829154*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"28c59beb-728d-4e14-9718-463b66305577"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403048306303`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"29ccfad2-d7d1-4a31-bdea-fd37e9ae150b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304831821*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"88b8033b-f283-4444-93b2-10019b98992d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304832877*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c4edc251-8cdc-43d6-8404-8e0dee4a66b2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304834207*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1ea2195b-2ad2-4016-930d-2318fa5f4dec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304835772*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"622bceee-cff4-49e9-8fbf-d48858d7f518"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304836882*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"57a70b13-05f3-46b6-81ec-daae5be7e06b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304837994*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bd566519-6648-437d-838b-fa17c131783b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304839135*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f1938957-bdee-4a23-9e5d-eae0a5f46b9c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12\"\>"}],
  SequenceForm["i=", 12, " ", "X12"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403048404016`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f8f03509-ecde-4224-8f80-1689dc0888e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304841441*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8ee7906d-65d1-4940-a13a-d35c64795b3b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304892962*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3d6c44ec-b8a1-45cc-a6e8-5bb4e9f11148"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403048943157`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2fde76e0-c89f-4fd2-a2b3-671ee4610749"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403048953657`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d41ed009-4e8e-48ba-99e3-22786382d8ea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304896421*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4e443bf7-bf97-40a0-9cb6-95617d8101db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304897543*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c29e3b8f-cd4a-4f18-b91f-256b8da8dc79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304898641*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c7fb733d-3098-40bd-bbd3-fe379a902531"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403048997498`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"87489cb7-a1eb-4491-a08f-ec7f96b8eca8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304901043*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"660c14a5-e350-4c91-9ea8-f126a86c2ade"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304902178*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e9d999a8-027c-4e18-b700-004d5afb1f6d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st isogonic center (Fermat point)\"\>"}],
  SequenceForm["i=", 13, " ", "1st isogonic center (Fermat point)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640304903246*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"651fcec8-c08d-41b9-a948-6443d930f318"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403049324493`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0916269e-2a70-453c-be8b-22cb87661f68"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305153372*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"38056cca-2c54-4795-8ae3-6540260c22a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305184249*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f51ad694-e5ad-4813-a2c9-6100535fc34d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305185557*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cc4f7c9d-fe64-4557-aedc-064e6c5ea714"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403052159777`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1898716d-1cb2-463f-b85a-5b06f5294cd1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305217786*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"89b8637f-b6b0-4aba-9976-388fe12020b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305219475*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34b5f011-bd95-4d20-8312-a9c9b0c548c2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305220717*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"93fff589-80bb-4b6a-af16-e7fea38a7f05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305221849*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"53fd02a6-62d8-4e75-93ff-ceca56af79fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403052229853`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"65b2e5ca-006c-4833-a43c-854f105fab14"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isogonic center\"\>"}],
  SequenceForm["i=", 14, " ", "2nd Isogonic center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305224299*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b233062b-9cce-4370-b7bd-93b3d2222674"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305254344*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"edd4c519-5770-4fce-9188-7c49723485e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403054861517`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7ec8838a-ebe4-4047-9a58-61578df66d31"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305519683*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f6b60a06-f8bd-44ef-8fd7-4c5e3619e403"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305521038*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bc124a33-46a7-464b-8927-0b010bb19c66"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305551676*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"494b7c6b-c264-439d-98fc-9ff92866c8ea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403055533133`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b63c9498-9392-4a0c-a2e9-ce216e4a5af4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305554797*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"071b210e-771f-4f46-9052-7d2342c0fc38"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305556097*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c76adf51-3e43-4048-bfe7-daf343a8d176"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403055573874`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9b156eb4-928d-4c36-a950-23ab6a00371d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305558648*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"96f8e069-d5d8-4407-8ec2-29fbf8088eab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Isodynamic point\"\>"}],
  SequenceForm["i=", 15, " ", "1st Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305559782*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b1d2c7c-c421-4c2c-b837-7048fba2475c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403055895147`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"296fe6d6-8c96-4faa-abcb-775dfbc65b78"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305653819*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"58247322-e354-4b50-affe-d98214af5952"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030568519*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c05e1e5d-d89f-40db-aa99-c797a50c66f8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403056865253`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b735b037-c2e3-48a4-975a-fc8e733c35a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305687619*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b6477915-e885-48bc-a22a-effb4dc3ffc5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305688909*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"be36f617-fbdd-4e6b-9f2d-63b48a1e9f8b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305690345*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f62f73cd-1d89-49cb-9190-36e44b7d884f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403056919127`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2d25cb4d-01b1-4ff6-bc28-c86286f4931c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030569312*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f5b09a48-9d77-4153-a039-cbc0380e757b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305694415*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e17e2252-045c-4064-a3a4-8eee2556fc17"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isodynamic point\"\>"}],
  SequenceForm["i=", 16, " ", "2nd Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305695547*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5de125ab-bc29-4057-9687-ffa1048a66bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403057316933`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e9be9383-d8c0-49cc-a2f0-053f31ad36ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030580099*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0baf8718-67d5-4bad-b945-b0483ddf4ce4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403058318787`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c72ab441-0ed1-4573-b809-fbd8f9df6b5b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305833254*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c3a7ba20-4915-4b2f-b848-dcf366e0946e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305834647*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"672e470c-cdb7-405a-ae84-170f487405d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305835883*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"addb5454-5967-41df-af86-f9661bd1a936"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305837014*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bdc07ad6-08ae-46e3-8e0f-7d1ea3dba5ce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305838126*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1bc8429b-8e18-4e93-b73a-bc177a5cf86e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403058394012`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ad5bb9e0-4343-4faf-828f-f82a30b70783"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305848422*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2304a124-cb47-4f35-936c-7b1fb7d9c73f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point\"\>"}],
  SequenceForm["i=", 17, " ", "1st Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305849815*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6eab3614-9b5f-4e31-a829-df60ebeb01dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640305881503*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3ebd7f30-693f-4189-be7e-5f322703d612"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306089512*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ced4b508-5745-402e-9c2a-258ab6274cf0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403061214933`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fff80452-f950-4f74-b051-6b43f41b9add"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030612287*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b1db4b5b-71a8-4e04-b42d-2c643743def0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306130576*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bc5ebe81-24dd-44c4-a2e7-74e03a54e1e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306132146*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7051ca07-53fa-4c57-8a28-858310fde552"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403061333017`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f198d977-227b-4779-995d-40548bdbb544"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306134419*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"871d9142-e473-4a1c-a847-5f95276d7e03"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306135518*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eb917497-9479-4d76-970e-afa07b314470"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306163753*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3f206d02-9014-46af-b2e0-eb9e7a7e9b55"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "18", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point\"\>"}],
  SequenceForm["i=", 18, " ", "2nd Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306165222*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f74e5e08-6cd0-4fc9-b033-e22335d53b79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403061718388`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bf86322f-cdf1-4f71-94f4-53c5bd959ee9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306367805*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f0f9b3ac-2c89-4f79-b8d5-7a63184492c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306398809*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"de8389e2-1e54-44e3-a526-086472f68c32"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306400216*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a3674971-623a-47bc-8f9b-2c5fe96f5d6a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306430251*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7e072d7a-e867-4103-83f4-d2224109a0c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306431695*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5227709d-0417-4241-b515-90e6b8d4017a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306432796*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c9e316ff-fc86-4446-9f51-02141dea700c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030643391*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d59358f9-f4a7-4d9b-991c-d6c4f2e9ce3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403064350157`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ca5e7e70-2206-4837-b0a3-76c70f8e416f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306436097*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7b20748b-80d6-457f-be2b-23839f3a1fc8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point\"\>"}],
  SequenceForm["i=", 19, " ", "Crucial point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306437151*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8c166bff-31ad-4e7d-a8de-72d1fc6784eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306438364*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"26d88f46-1948-4a28-aa54-a785e3e1c08b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030647211*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e2f8a269-5c82-4ef7-b4d9-409338ed77e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306473526*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6219fb21-7be1-4e5a-a8b3-39e2d4e36218"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306474759*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dca87842-e130-4353-89ff-b2b5670ee7d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403064761553`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"436aa17d-8852-456b-94b2-a36bb5c52fff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403064774513`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9803aad8-c55d-4b23-be35-320134d8c212"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306478701*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cac6126a-c79a-49c1-8b36-37f9df40ac64"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306480102*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4ba913b0-3a08-4844-b06c-f815783d353a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306481635*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d106d332-7e48-4a97-a326-5d8b5ea2228e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306483287*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"af9a7f61-5ff0-4226-81d9-161259502696"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point\"\>"}],
  SequenceForm["i=", 20, " ", "De Longchamps point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030648447*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"013f6ae1-aa58-45bd-8009-9ac2905c9a64"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403064914494`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6f2e1ee8-3c94-478c-996d-b3c8c8492411"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403065214977`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ff0ec5cd-3384-486c-9737-e9d7d691a559"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306523003*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ad47ce65-3c34-4085-8579-fcf892547aaf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306524238*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f7d000a5-fdb3-4b89-a261-bf25153bc5e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306525654*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"60f0479c-409f-45fc-8052-e6c76d282af4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403065272617`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2fcdb3a6-5dd9-44ca-86a1-ac08804666c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030652851*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"50948503-bd8f-400e-a2e6-8b43b57c55b0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030652969*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"041f4054-ea45-4007-91b1-986beb8018d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306530846*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e617e75a-81e6-462b-977f-73ac770eee8b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030653203*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"32c46a01-749c-4876-a840-472838b7ea0f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point\"\>"}],
  SequenceForm["i=", 21, " ", "Schiffler point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306533113*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0bfe7bdf-d666-4e8d-a043-ccbb972bf32e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306534196*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"452a2470-aba9-4879-b21a-20330d80e55f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306570311*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"53c56f0c-956a-4217-9392-d421ad35ceaa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403065717773`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2f4f034b-9ac4-4f9e-abca-3f029086db0b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306572863*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9a938391-c83c-40c4-9116-e3f85171c495"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030657397*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7ef80ed8-cb28-4c0f-b8e6-f5bfbd2b72c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306575377*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"240ef66f-07ce-4125-855a-b1efd26723cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306576858*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"42718ac8-02c3-4321-bb67-1dc619ad42fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030657825*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"205616ee-a9ff-468a-8784-0a0616ec6293"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403065798693`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"15c34713-3030-443c-a07a-507842b80412"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403065810966`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7dc7195c-0cbe-4899-abb0-647263e02021"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "22", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point\"\>"}],
  SequenceForm["i=", 22, " ", "Exeter point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306582182*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aee4829e-a15f-40f3-9982-ef04fb361345"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306588921*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"71d6b433-7433-4630-b0a5-1107627a38f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306617824*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3d8943a6-4a36-4ee8-9bc4-46a1a7cf6c08"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403066194153`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5ab31e40-d036-4109-a4e3-6c270f5a814c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403066207867`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6e020ce3-1d0a-4e87-99b5-52777bd24ec8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403066218967`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7cb987b8-ad96-4334-961a-6294e0f468a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306623011*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e0e67b5b-4f7d-460c-8540-1c86427c064e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403066241693`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"35808870-36ad-4275-9ae0-41bdc292f02a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306625308*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5a834c58-b434-4a19-a9b9-75cc028cb0f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306626734*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"14dfb074-8cd5-4949-a36b-3291ea62b185"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306627984*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d0f44a9e-7870-422a-81d6-75c8b677a86f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point\"\>"}],
  SequenceForm["i=", 23, " ", "far out point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306629117*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"488b3311-1040-48b0-bb45-fef1306c7655"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403066302443`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"37809e15-3c1e-4976-8c3f-0109b19dc469"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306659127*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aed38044-45f6-45fb-856f-eb7c2d7aa7d2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403066605873`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f600d0a3-30db-4c9f-8833-8bfaa08cf902"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306661683*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e1a0a31b-45c4-46d7-b710-736407e59c71"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403066628304`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"14d91e4a-a1e9-435e-a0c0-a0971d198818"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306664187*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"828b17ea-d983-4f8e-810a-3d8e54054a70"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306665389*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e1306c7b-7375-48af-a9b1-29201847adbd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306666521*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b770dd6-9433-4fe1-a813-248ca4d5ec82"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306667635*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2522d057-c75b-4a2f-9200-8db85fe64c6d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306668746*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8210e558-e2e8-42f4-95d4-84d645792478"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "24", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24\"\>"}],
  SequenceForm["i=", 24, " ", "X24"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306669794*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7beec9c3-96d9-4443-bf0d-f832849f5f49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306670879*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4022eab6-1bad-46a5-a1a3-450c886acd9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306735072*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"66eff67b-9350-442c-b7e1-0723638f1690"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403067421227`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9fdd136f-35e0-47b6-b25c-6e5c4ddc97dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306743535*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"258be43a-2dfe-4fdd-8e5b-e6b70023d70d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030674465*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d88c33f4-8c2e-4e59-9116-5265808d88f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306745804*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9536ed40-38e8-4c15-9c3c-d123c614d21a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306746991*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"926c090a-b0c1-4c1f-9123-a5d190720581"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403067482367`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"68c30491-9d82-4803-8a83-3731074f2938"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306749414*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2496d30b-7736-44ca-88dc-4a2eeba64440"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306750586*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b710179f-212c-4c0e-b4d3-580c625bd042"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25\"\>"}],
  SequenceForm["i=", 25, " ", "X25"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306751718*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ff31147e-78aa-437b-a157-edcdcb68ea77"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306780279*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6b00c73d-bafc-4e9e-af26-ac0abba2a62d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306813953*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"32595ea0-d3d7-4a6f-84a8-264c9e363814"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306815734*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4854f0c1-d690-4e08-be36-64f948907887"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306817099*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1d6dbdde-1c59-4a56-89b9-ed2e171799cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306818272*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"68c5b7b3-5c2f-4581-a10f-215cebaa1d74"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306819483*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a506cb53-f7e2-4d4c-818b-3742e919f51d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306820704*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aa97d7f5-feb4-4814-9b93-6209910121f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306821928*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"41e322d4-8527-4d47-8c8e-0bc462967e12"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306823125*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b351f986-8da1-4996-8f78-2fa5b5c7028d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403068243732`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b4988dc9-4d29-4cb7-a744-74b729e34c31"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "26", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle\"\>"}],
  SequenceForm["i=", 26, " ", "Circumcenter of tangential triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030682583*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d7b091fd-42c4-4625-8216-0499626210bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306827177*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"24d70559-6607-43f7-8219-f0f7b7a654f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403068868837`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2800d0c3-0220-41c5-8836-e9aab8881b46"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306893805*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fca7ec23-f3de-4a74-831d-5f373812f83f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306895496*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"94bee697-97d1-41ba-8b81-509bcc52aa4e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030689707*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6e7216c3-775c-4505-9b53-cdb16402dc7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306898387*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f03760ba-5cbd-491c-8788-691345c5ae83"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306899626*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fb963cae-ca39-4142-aeef-62ae573931a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403069010067`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a6836856-51dd-4d63-8505-aceb319bfc00"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306902821*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"25faba90-6f7f-4934-8adf-2e67053c00b1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306904484*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6d21bbfc-1c43-498a-9b12-8b7f182e53ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27\"\>"}],
  SequenceForm["i=", 27, " ", "X27"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306905673*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7a970ca9-b862-47a0-b580-1e10375e7ec5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306934073*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4e0654d6-78a6-4434-8df2-1cb70cc53983"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403069826603`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"07044cc5-f888-4734-a440-8501cc1a586f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306984131*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b7fd8abe-09b8-40a8-8ecd-9b25359267b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306985261*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"afaebaa6-544f-476c-8e5f-b684fc5d745a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403069864073`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1719c5e4-17cc-4381-a37e-c06e3cf0c488"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306987586*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4f8358ba-1765-4622-8538-fae2518bc3f2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306988847*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"23838210-91d4-4acf-887a-bb960cd57f8e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403069900227`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9635793e-a56d-4e24-b50a-5176da5f4338"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306991414*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3bae9c31-6637-4235-93e4-ff0349d56931"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306992635*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"507050f6-a914-40dd-bc2e-2e370dbc2c31"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28\"\>"}],
  SequenceForm["i=", 28, " ", "X28"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640306994223*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d11a3965-fdba-453f-9682-c177bc4fbe9c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307001363*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b5612c72-0769-4346-a937-9a8c7e46f5e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307077985*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6f4609df-2507-4a8e-9d21-ca7cd553b385"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307084847*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f2489cec-622c-41be-9337-188df7988a42"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307086275*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"70d98cc7-18fb-4052-b10d-55ae214eeaab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403070874434`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c65a90e6-278d-4fcf-a5b6-6cce5b6345ae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307088678*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7bc86fb0-8a0b-4b5f-af4d-76ae07d2c249"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307089979*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ac15ec5e-404b-4062-9677-d7a34a199f2a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403070912237`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"08cd46b8-0546-4456-9bcb-1b6b508026a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030709245*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"92f7fb75-52c9-49b1-b785-cb22d1e5d6ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307093687*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"96feb088-6436-4e81-9b7f-a3f78865cd6f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "29", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29\"\>"}],
  SequenceForm["i=", 29, " ", "X29"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403070948753`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"58dddcf2-4a72-48c3-ab8e-ae5cec88737b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307123391*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"124a3eb2-a06e-44cc-a2a9-93888d2406f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307192718*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eba9b547-eede-4ab0-941f-83ae1eb49226"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307199724*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8c4c81b0-9f3a-4641-9969-b6a944252480"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307201161*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"258912a5-04dc-4f69-a048-619e17a6d850"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072022963`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0d3bc3cd-6ddf-4c04-b01b-6426432158b1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030720382*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9aa41591-def0-445e-ab71-15f1d2e21218"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307205118*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1a767907-d71d-4958-a7fc-0c1ca36d6c81"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307206379*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d024c396-12eb-4e11-8fe6-3eb2539f55be"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072077227`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"24f13d4c-68c4-401b-a180-410d3c7356b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072089243`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3358f23a-dc16-4b97-901e-f915dd7fef79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30\"\>"}],
  SequenceForm["i=", 30, " ", "X30"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307210033*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7bde9d56-ef8f-4717-a89a-ee2de93c2099"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307211144*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a8992639-0443-4405-b477-c2903d561449"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072399273`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"672b805e-e377-40f5-abe6-83be31a6787d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307241468*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8c22ce1a-572c-403a-9cd5-15f9942310b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307243031*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7d0eff68-6295-477d-967f-e3523e1ce724"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072443933`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f3f41d58-d67f-486f-94db-0da6c031987e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072458277`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4b429f7c-92d5-42b7-b128-4eee7cd57ae6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072471447`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e9fe48d2-6eac-445e-ae67-bb049d8b2c45"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307248369*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"859ab30e-53b1-42cd-91f5-7109bed9e4d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307249695*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ea5b2281-22d6-48f7-bf66-6da224eff8cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072510443`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d605f964-7f9f-4d2b-b5cc-e9f1174701d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point\"\>"}],
  SequenceForm["i=", 31, " ", "2nd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030725219*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"346e9c9a-e7f9-4059-a464-47246ddee634"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072533503`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7a9e0282-67fd-43db-add0-692c8013bda1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307254519*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"78346684-0b03-4dbb-8354-cfe3c8e3f139"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072556543`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3ced9a2a-da44-4b97-8184-8e3a445764b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072567873`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"93c529c8-5d58-482e-adc3-3ac93af32276"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072580433`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3f92c077-3358-4501-a274-c70f727e3e57"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307259284*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9ff9915d-9713-40d5-acc8-b56ea7b8a2fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307260755*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0c7af62e-5680-40b0-9a70-5e633e726550"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072621403`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8a56944c-d0f6-45e1-9b21-8bb82fe97046"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307263379*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"911fb292-2e19-41ec-af90-90816881d7ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307264656*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2e9279bf-8f78-4406-8fb4-e646506b9117"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point\"\>"}],
  SequenceForm["i=", 32, " ", "3rd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307265942*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3976279b-22aa-4d20-9ab0-e3faa7a8194f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307267107*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"87b913ba-4f8c-42b2-9dd4-9187708df555"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072681923`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"adfe97cf-9855-4468-82a4-49b9b0ab9c5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072692966`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"01b8fad2-563d-46d7-a62d-eeedb6e0bf91"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307270371*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7b30751c-3552-4e1b-afcd-08eb35827a5f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307271491*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e91ef356-03ce-48b5-b87a-2ff0ec1b6a83"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072726603`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3cd5603c-ebc8-4cbe-8f75-3078fbddfc83"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307273829*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9a1a24d3-f54a-486d-951a-1e7495afac96"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307275031*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"14b0c91f-f795-4539-b732-429a71623298"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307276217*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"136b8062-9d00-4503-ae5c-f4365857b066"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307277399*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"150f9a8a-2869-4654-b5f5-8ef53800c779"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "33", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33\"\>"}],
  SequenceForm["i=", 33, " ", "X33"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307278522*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fa938e77-a293-4b20-b8ac-9126a3f75716"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403072797937`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"15296b47-8897-4b0c-b5a6-6916294f2d39"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307332613*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8fe8f674-1e76-42a2-a7b6-4f200ee01cd9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307334132*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f9dc5a7a-e237-4178-8a0f-fcf2419707d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307335483*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c7954fec-a356-4647-b836-f52c410dd8cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403073367357`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"72ae1724-f501-4bba-ae1f-365de9044c05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307337986*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2e8f5c3b-1807-4fb9-8568-f82179f895be"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030733921*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"093ae0ca-8d76-424e-959c-0410a61e42a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307340643*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"874df1ed-9bbe-4cd3-bcd2-aba7df29dd7a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307342044*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7090a5d2-af4f-4db1-8ed8-92035c8e5cf9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307343554*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1875e9f3-275f-4c57-bf6d-aee76c747797"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34\"\>"}],
  SequenceForm["i=", 34, " ", "X34"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307344863*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0666368b-36dc-434f-9bb5-7e69cd84d1a4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307352107*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a92aadb1-9355-4547-a9b7-facda385312b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403074398317`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d11afdb8-d68b-43b4-a8aa-352ee955c755"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307441349*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0347873b-6701-4f27-9f78-d539e2740b22"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307442531*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6baf6fd5-ece0-4e4c-81a5-97ce6ce61ca1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307443677*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"22db72b6-4fcc-40e1-99ea-fa5c6a5e5bcd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403074448957`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2923cc89-d594-4e22-b820-850e6808473f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307446106*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"944ac936-3ed5-434d-a4b0-63dff53d147b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307447537*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1e131cd8-315f-4aa0-b9ca-7fe26cdbc977"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307448778*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9198e292-7d1b-4d4f-aef8-77eac4990625"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307450225*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1511f490-0893-4f4c-8bc0-e688adccfff9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35\"\>"}],
  SequenceForm["i=", 35, " ", "X35"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403074514427`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f3009ec7-c565-466d-8456-dd08756f3a50"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403074584303`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"37477112-af66-4cae-aba2-d1238b325e27"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307487726*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"522495b3-998a-4925-8182-4e2a4f3389b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307489255*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7572031b-6d58-4a62-bd32-b7a6b37c8768"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307490851*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9955e781-5a5a-432b-b110-6e53b9f9a88f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307492502*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2f461845-3090-461c-a65b-a6ce0eb3e58d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307493947*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"868274f1-ceb5-4ca8-aa22-ceb9174285d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403074959917`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"551e7a6d-a3ba-4db1-b608-18495a7d2011"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307498043*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f004fa77-c659-418c-9d4b-207585367998"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307499453*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"448ae6b3-743b-4de6-b232-d22a45768a32"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030750072*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0ae27024-454e-454d-a6ea-a9e90106c89e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36\"\>"}],
  SequenceForm["i=", 36, " ", "X36"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307502129*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1bb8fd5d-844c-414a-8a0c-d7e37a7e3966"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307503303*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a36c1f7c-68f4-49d5-a09e-6e12334ce5ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403075337267`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eb4257a8-f8a6-407a-b9ed-401dde9d0ef6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307535262*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8c8a5983-945b-4521-8f7c-476d2f7cf809"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307536628*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e68fb0b6-8e2a-4797-aa1a-c02720b23234"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307538453*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"855ee069-99f8-4ef3-a468-44566a240650"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307539846*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"95ff4e3b-f546-4eda-a709-43c56f0adcb5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403075413933`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5a4a5c0e-d2fb-4e98-ae41-7c9a1d9443c1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307543054*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3ad9f830-a259-4c3b-bd24-6c9d356f04fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307544581*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aced4ac2-edc3-4b39-9b2d-42844291a02a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403075461407`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dc1323ea-af57-4a47-ad08-d52430eb171b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37\"\>"}],
  SequenceForm["i=", 37, " ", "X37"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307547406*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a70a2181-9c34-48b4-b646-2777b4b2420f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307548585*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5cf653a0-7f4a-4f79-812c-a0ec22350239"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307579052*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34ea84a6-a2d3-400c-a398-1d788dd54bbe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307580653*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6ebd473a-f1c5-47cd-8309-9eabc199ba23"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307581863*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"233fcb80-5f1e-40dc-8ad5-aedc93015459"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307583022*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1c918074-f9e3-4190-a871-d62168253641"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307584222*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a5287ea9-c27a-47dc-ac06-9ac45ac86c54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403075854273`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a21f6d64-b8f5-47b9-af5c-5dff164424ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403075866423`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8d1c9fc9-e53d-4426-ac75-f3a0bd681a7d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307587854*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1b43bc71-80c4-43f7-b0f6-a18b26c57343"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403075892267`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"31b367fd-a4a4-484d-bc7a-e6ee32291ea5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38\"\>"}],
  SequenceForm["i=", 38, " ", "X38"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307590436*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"100feb4b-b453-44a2-a7f1-2d4a5205cecf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307591744*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"212f1387-34a2-4387-87ae-14568a95446b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307593454*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"79a4fe08-faee-4c63-9225-2e0e7a4bff30"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403075948067`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7392d03b-9976-4bc5-bc7d-ba28176842e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307596105*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0b237c8b-ffe6-4c89-9a44-57447b95205e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307597361*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4a92d001-e12a-4e87-bb52-caca928ee559"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307598867*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7b0a3e38-a751-4e9b-8ea2-3e95899306a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307600181*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c96cdfdb-9d7a-4eca-aa23-8d2c0a62004f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030760142*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c08cd08a-a58c-48cd-a03f-c16a2145762e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307602953*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"36373791-c874-4b79-8626-ea97b66885e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307604244*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b1571ef-254e-4257-9f43-1dbd679d46ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint\"\>"}],
  SequenceForm["i=", 39, " ", "Brocard midpoint"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403076054153`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"907d4118-8243-4cc2-b951-e261a6ace5a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403076065893`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"799354cc-bb98-49aa-a15b-b95a821d695b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403076137877`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bc58c1b4-c79b-4f18-8e9f-0f42d8394010"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307615259*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b854f3bd-8b08-4f3e-935b-3116e99e7562"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307616745*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c8004efc-431a-4045-8b3e-313133d0bdd4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307618414*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b125316b-ae6a-4022-9b8d-97d7025a2a0b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307619811*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"420188ac-bbe4-4b82-9092-cc535340f57c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307621213*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"44ff0029-03d0-49b6-baaf-4b525d122965"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307622661*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"30a4df86-b3ee-4478-af87-59478de3338b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403076241083`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e28e5c28-4652-4e00-a9a5-ffdc26c8a2ae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307625404*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a8f2042c-5a46-4ffb-a4fc-7955c75f0ddb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40\"\>"}],
  SequenceForm["i=", 40, " ", "X40"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307626589*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1a6118be-6d7a-4b36-a04e-104223464fa2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307655387*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d2c8b3aa-955a-412e-80fc-b17a3401dfca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030769175*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"59616deb-97fc-4a34-b19c-82047fe3de58"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307693741*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"312d4497-e12e-414a-a730-aa5355a66298"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307695095*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"50ec1208-b234-4160-93ce-b34093e92e53"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307696766*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5c246103-1c84-4dba-9c8c-75b8a166a321"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307698051*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"edfcd311-9d59-4e15-9cc8-6105c2d609d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307699396*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"05ecc36d-55a8-49b8-987f-4a4e1b578b7b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307700697*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d92b8f69-0a0d-47bd-8efb-e7a7a4568292"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403077020197`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ac72be8c-fb91-4af2-95d0-478b4a48c7c2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307703402*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f1bb1686-bd33-4b7c-9dae-5a05fed4a303"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41\"\>"}],
  SequenceForm["i=", 41, " ", "X41"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307704587*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"705f9c67-7b77-45c9-a37f-1f804e1ad3f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403077057323`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5f8578d7-0b9f-4019-97a8-d6e83c92496b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403077356586`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ed7040fe-8e49-4ccf-b025-e79bd277cdcc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403077372513`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"09ff4cbb-4bcd-4722-8f02-d3077d7d5161"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030773876*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7ad9916c-bbdf-4a5e-90f8-c76477d0f0fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403077402697`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"77808e15-cea3-4f25-8f39-47bdd0999b8f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307741542*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4462f12d-d97f-4fbc-8916-42c331a2e927"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307743039*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cd68e8ea-fc08-4a8b-9912-e2f50e81e829"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307744438*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"57188cf1-a941-4f40-8e0c-eba1b93ff007"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307745757*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"513450dd-925a-4ad9-9e9f-751964cb22ff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307747052*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"564e1ab5-35c5-4386-b573-c866a513dc9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42\"\>"}],
  SequenceForm["i=", 42, " ", "X42"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403077482767`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3c60a577-1357-4014-96df-0a8611f34512"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307749546*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b107d48f-5063-43ba-8820-7343342afa46"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403077798767`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5e779624-0523-4702-ae75-2539ea527dea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030778144*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"61c0ae7c-e549-4b94-95b9-169e1f305f08"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307782634*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"92ba5cb5-e825-4b25-818d-593920696196"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307783832*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e12fc74f-fadc-4c87-97bb-d3988439b51b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403077850637`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a0214705-b6a6-4601-be6d-cb12759decd2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307786501*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"996b7165-0579-4410-b786-4a4c288e8a1d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307787773*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5564ea93-2344-4416-8d77-d6fdb9b2a29d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307789021*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"047818c5-5692-41cd-9ad4-94fb20149dce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403077902412`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aaea8ae0-5592-4005-8782-357e09f8c38c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43\"\>"}],
  SequenceForm["i=", 43, " ", "X43"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307791461*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"85e3b5c8-3aec-43f0-acb3-77ac4eaaaadc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307792863*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dd62973c-1d51-41e0-86ee-1ceebc402d48"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307800644*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9770694a-6062-49d7-8da4-dcf0010b64ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307802174*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ff14ca64-fade-40a2-bdf0-65367080e3f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307803834*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"915970ae-595c-4f2e-afc1-e3a8327104cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307805077*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"705f82da-bc19-409c-bfc7-c9a185800592"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307806382*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5313ea2c-03fe-448e-b26a-c004669cad79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307807705*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"09b5e3ff-5e18-4a98-8972-952919c44657"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307809051*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5f10d869-6087-4c4f-a3a0-768596419ba2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307810773*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"26681f4a-22c2-4a7e-a880-cec9de7a880f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307812125*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"40418468-a5de-4c79-9862-f604c90268ae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44\"\>"}],
  SequenceForm["i=", 44, " ", "X44"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307813341*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3f338686-9aa9-4371-a4ac-068771417c09"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307814509*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b0060956-a38b-4566-8569-489dadb28464"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403078442907`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"026f050e-a29c-4c1a-a383-3cac3f8fef95"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403078461123`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b5f6e54-5b8b-44c6-b4ab-5a4bf000142f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307847335*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"586d9a26-59f2-409d-bf74-ae0d7d390177"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403078485613`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3575acb9-3fc9-4368-8831-22c684c0824b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403078497972`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"272fbef3-6460-474c-9a76-900bd76af200"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307851054*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ae7f2eb8-b92b-41cd-9a1a-54cc33129c1a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307852404*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"907f20b6-c237-4c31-a67f-7e2f78136eaa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307853853*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"21c00b10-619b-4e30-86fd-957bf12d5c77"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307855147*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f29917e9-c858-4507-b5f2-aab0524170fc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45\"\>"}],
  SequenceForm["i=", 45, " ", "X45"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307856368*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"53c1485c-9084-498e-8f2b-d1ab8acf029e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307857616*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eecc0689-60f6-4ff1-9580-4530a73866c8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403078890133`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c6f5c7bf-1552-4654-858c-de039f974a05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307890957*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2779c2ab-4bbb-4938-90a5-fa2682a56d7a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307892568*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8d425469-888e-4d2e-b0a0-9c9c58679edf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403078940277`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"47ca9ed4-a326-43f1-913b-9dd4f9aebac2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403078955727`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1e975da8-a522-4fce-bde2-3e380cd7de35"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307896965*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9c00a80a-692a-4a0e-b4ef-ec974c090949"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307898498*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f5bcc23a-846e-417b-8399-3bae0d37a75d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307899864*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"477058aa-197a-4cdc-8787-50f1a552f689"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307901224*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8ffa2a30-c562-4ef1-9284-5d8d599ad13d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46\"\>"}],
  SequenceForm["i=", 46, " ", "X46"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307902565*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"982d1b3f-f8e2-4499-98eb-63eaaebf24f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403079038754`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0b1173ad-2e26-4cbf-bddc-579957118772"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403079405937`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9f57bdb4-46e3-4f89-8ae4-83f13190829e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403079424*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"16cbcb61-7984-4130-91af-b27ade6f73a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307944021*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6b23db4e-8bda-4ad1-87c2-10f96f211e52"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403079457073`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6c54d31a-3a52-48a2-ab53-8de083fa1671"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307947542*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"680f1fca-4f03-4557-b9a7-2b55c08788b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307949192*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"036b8010-c451-4974-bb0f-5ee9903ecf70"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307951096*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7ae4d2a8-3b0e-4b48-bc8e-b3f5aa5cad40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307952445*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dd2b573d-244d-4643-a4e4-e93c0dd97d53"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307953865*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3175eaf5-0f3b-4a0c-8cae-6d2ccaeb4e76"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "47", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47\"\>"}],
  SequenceForm["i=", 47, " ", "X47"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307955328*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a5a28597-c0e5-44bd-973f-60959d79b9d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307962166*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"62547833-0217-45c4-a82b-6bbecf4211da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307997964*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1aa17849-58bf-43d8-9b9a-20989a56aea5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640307999631*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e0875617-8c46-47b2-9fec-cb197764fd62"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308000916*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"306f67fc-558f-498c-b02f-3a279e38a905"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403080029707`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34f207de-ef66-4822-b8be-6a8765d1693f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030800456*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f2ffcd1a-9edb-4616-8301-68b1531d0c4c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308006069*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"87acf3d5-58ed-4ebe-b5d7-4f4a591cfc56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403080076323`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4590bbe6-8b91-4731-bb42-f26232505408"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403080090218`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5f1dab81-a40b-40b0-8389-6f41c9d2f3e8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030801075*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"001c7259-3629-467a-91e8-d584e450cb71"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "48", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48\"\>"}],
  SequenceForm["i=", 48, " ", "X48"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403080122747`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d1ccd562-4beb-4f31-85ce-479274c1a965"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308013583*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0edfd185-800c-4a13-a42e-857ee6c0bcdb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308044189*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cecd58d2-b4e9-4083-89c2-9afc80e9a54e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308045842*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0e7f930c-db53-49c1-8879-33920b60f8f4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403080473013`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"12bb60ae-bd94-414e-b8bc-e3c0b64ae60a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403080487947`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cf904d39-718b-4beb-88d0-62cfd86b8325"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308050453*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0fa0e552-0fb8-407f-b675-33ccbacf562a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403080520277`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cb7c667c-46be-4bf5-af58-db63d4fd3e16"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308053423*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4986e1a0-2309-4f5b-a922-b164b966f892"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403080547123`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"300491c4-390e-4f9a-adde-89db51317c90"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308055944*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d238b4e1-5858-40f5-ba49-0a48f517fe26"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "49", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49\"\>"}],
  SequenceForm["i=", 49, " ", "X49"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308057138*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7cac8c53-06dd-4101-8913-825ff1a34c4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403080586767`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d7fff6fd-460b-4bda-9415-8206941310df"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403081034517`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"356a3b5b-3508-4fed-8375-c34be84cc357"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308111618*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"376e1cbf-218a-4523-a338-e79ef02c10f1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308113288*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"07c43dfa-5d09-4669-bea4-5224678f8763"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403081149673`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ef38924e-a807-41b9-ab99-a3d543cfb464"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403081163816`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"06454bf0-2145-4d63-8d67-eec0b4f3d237"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308117774*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1148301c-c53f-4118-8ee6-fb24722be909"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308119173*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ecb331b5-e26e-49fd-b50c-ce6bd44fce31"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308120563*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"91d026c8-9c1e-4c1d-8715-bb7959e3092f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308121851*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"62d6b3fe-95a6-439d-8071-49cd7cfff22b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "50", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50\"\>"}],
  SequenceForm["i=", 50, " ", "X50"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308123044*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f0b76755-3953-414a-863c-e544942972be"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403081242437`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ea4098a7-ff0d-4a0f-8d63-c882319fb1c2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308168379*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f1c0ec96-cb77-4881-814d-255d9222d567"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308170229*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4039e9ff-156b-481e-8477-1edf55f60fb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308171728*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2aa99751-d31a-42be-a02c-4ffabf336fd9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308173378*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"baef3254-0603-47a9-b783-4ba2b37fd0dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308174839*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"65c7a310-16b0-48b5-8ef7-5e6cb559fb20"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308176271*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c6be96a8-06df-4efd-9087-30ec83c1eb9b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308178378*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"11b666d0-11ae-4380-a9f2-25b8c6777514"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403081801643`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f26da6a3-3e81-4dd0-936a-700966681e2c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308181573*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8fc598db-c099-4f0f-a341-533b7ae928f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle\"\>"}],
  SequenceForm["i=", 51, " ", "Centroid of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308182871*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a3015aa4-c53f-4c00-880c-633a1709dcad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308189769*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6c478beb-ffe3-41c2-bd20-0a4c48d4b7f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308219342*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"84cd8ebf-3625-4d42-9ffc-d8970573d63b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308221376*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1367a6ae-3cbd-4cfc-9568-722ffa980bd0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308222649*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"46907dd9-539b-4b07-8b5c-2b8df457cf3b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308224244*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"63c47743-4100-4103-9c29-49925fb773c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030822657*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0c3e72c7-6e22-4509-8989-8cedd744d651"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308228204*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ba2f1972-4afb-4110-8918-ba53ef6ae5a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308229637*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"83554954-08a0-4c40-90ba-12163b29955f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308231172*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ccfc3bff-42f2-427b-b758-2704567a6254"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308232666*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2c59faf9-aa99-4bc5-b8a2-78e891779440"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle\"\>"}],
  SequenceForm["i=", 52, " ", "Orthocenter of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403082341537`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ed6b4813-7868-4163-9fe2-8672bb3705c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030823561*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c813c0b4-9bbc-4e4c-ac84-964b02d69607"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308292756*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0b143da1-57e1-4ca7-9e79-f1e79aae44d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308300704*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3ccc2d83-c953-4fe0-acfa-39a5378424b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308302663*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"972910c7-5274-46ad-bf9a-3e5dee1f42aa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403083041363`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"686ce801-dad0-4878-aee3-37fcf32e7780"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308305539*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b53f2398-0b03-48dc-ad16-f2fc29689106"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308307249*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"26af4de5-e282-4115-b22d-3c7ed262fb3b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308308733*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"51982bfb-6bf0-42df-80ea-993fba229838"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403083101187`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4ab49c04-c0c0-4a95-a036-78cb8cd2a1db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308311516*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9266c6fa-dfd1-417a-bece-dbac97a1430b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle\"\>"}],
  SequenceForm["i=", 53, " ", "Symmedian point of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403083129272`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"73f879da-6004-4f39-af37-9c4fd326d60e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403083144903`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"962904ff-4feb-4547-983e-7427b70ff537"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308385645*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3076186e-4b33-4444-917d-e276202d7421"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403083931103`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"38362787-536b-4707-8d35-e3a3e7147f6a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308395053*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8f80d9e4-72de-4f03-b5d5-0ea73f8df724"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308396488*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f89ba98d-698b-4e77-bbd1-9cad8d63f450"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308397822*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2d16d478-dde4-4215-9519-90b48b91657b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308399166*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"839df755-a90f-4b51-a8e4-4e528a5e71fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308400504*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8f11c904-471f-42ae-919b-4587a07eabff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308402231*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2f0bfc44-22d3-45e4-b785-63c347ebeae3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308404079*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"084a9865-afb0-4db7-9b55-9700b2edf30d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "54", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nine point inv\"\>"}],
  SequenceForm["i=", 54, " ", "Nine point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403084054613`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ded3a7e2-dacd-467a-92e0-f4b18ec642db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308435205*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"99b82019-c19b-4a0a-842b-01f13c7f5625"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308484375*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e2fdd7b9-0d3e-42b1-8fad-29d917d83d51"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403084920053`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"19de4f0a-892d-4f79-a1d4-69a8122b47ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308493661*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"84fd71dc-5eed-4740-9854-da32b5eaff5a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308494972*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ccbe258e-c811-4ced-9bf3-bf891b1bb756"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030849716*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"99d2c2ea-750d-409c-8b08-97dcc412f775"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403084991703`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cbd74b36-b896-4c98-8ba9-15d0a2928a8c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308500641*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b6c97f62-1bdb-439d-9a2d-2031da8ff4e1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308502236*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1dc9500c-b3e9-468c-adae-01d73c3f78df"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308503654*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"60c6872a-2cb6-4870-a25d-b3c6bd60e8ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne inv\"\>"}],
  SequenceForm["i=", 55, " ", "Gergonne inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308504899*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"17708b9e-671f-47ef-941f-3fa45037fc53"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030850633*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d017497f-2c1f-4350-aad9-36b49274eb37"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308536584*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2a013624-a9e3-4205-a11e-96629d3adec0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308538555*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6e2fc6b4-9040-4015-b51d-9968730eb379"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030854009*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"461b5d1b-926b-4ef4-abb7-9265274e8e18"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030854141*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e10d3ef8-68da-4301-8ea2-6c9bd09f7f08"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308543141*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a7feb013-10b6-455c-9510-5cc2c2c70f13"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308544598*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"93d9d49f-33c6-46d0-80f2-7c87817c6a4f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030854615*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"03228898-7652-4fee-8cae-5c1d0c50e70e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403085477543`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c15fcf2b-dd9c-4431-957c-9fa44f7be2f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403085492*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"60ce9b21-4729-45be-8e8f-0658f6d87c91"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel inv\"\>"}],
  SequenceForm["i=", 56, " ", "Nagel inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403085504837`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5021097d-6ce7-4b43-a146-a9a08575fa98"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403085517797`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9264f53a-9206-4d2c-aa2f-9ea540cd1935"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308582123*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f2468978-1b97-4de3-aa56-c278555fcc49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308583825*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"54d62a1e-6d28-4612-9ed1-2f981ebcd6f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308585123*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"31f13255-6208-408a-9288-2acc4c4a7d82"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308586734*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d87f8e50-fae8-47ea-9bf3-e482d98c60f1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308588181*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d83ac48f-472b-47c5-912a-d5e452b7df5e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308589604*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f43dc1dc-6a09-4901-a6a1-84e19ece1e98"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308591084*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"db52242b-621c-4959-9588-e6b53b62c785"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308592853*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3109e2ff-7df0-46fd-a970-fb5dae48abfe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030859487*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"510b51e3-c7ca-49c1-9030-8b00decb3ac9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt inv\"\>"}],
  SequenceForm["i=", 57, " ", "Mittenpunkt inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403085963507`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bd6eb850-f902-4987-97f6-bee6872f04c8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308597752*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9cdb0f9e-c376-408b-937d-e8a649ff078d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030863235*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5021cb04-c9e2-4445-8349-5ce8ff5611f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308634327*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2abc1f53-a278-42c0-95e7-bb0d9eae14c8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030863581*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b06460d8-2172-4fc7-81dd-7629bd6f1fdc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403086371717`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9f0d34f4-7a84-4a29-923b-ad3d05a6e8b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308638567*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"796d0af0-0f17-4981-ae17-f5be0a4a934b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308639999*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7d1b3137-dcd3-4b20-b340-724b02a1488c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308641399*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e3df6ef4-1697-46e6-b3f0-94c2dfa487bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308643341*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ac3edf8c-08d8-4806-b48c-d29335d30625"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308645073*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d47a30a1-966c-4d4c-8469-3cb245316085"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker inv\"\>"}],
  SequenceForm["i=", 58, " ", "Spieker inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308646637*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f9e3b486-bd2c-4370-a46f-ccb4fd0f8bc9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308648024*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e405fabd-7b93-4366-900a-f7b2b4f7e334"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308681397*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1ce4da8f-199c-411b-88e8-f73a3e741f9c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308683674*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4da956a4-0c68-48bd-b1ef-f58f8f1f3ee7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308685072*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"527fee89-4eb2-43b9-af80-67d9376d43ac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308686417*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"89e7258a-031c-477e-8fcc-98349e34c0e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030868778*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"824cbdd3-14ad-4368-b768-1eef4bf8050d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403086894083`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9717e9ec-90e6-4c1b-afff-87cc4d8668ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403086912117`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5541a668-63df-4834-8c0a-97f9d0200f9c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308693308*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"057ba2ff-082f-46f2-a376-4715633be0e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308695425*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a165ee3a-8b4a-43e8-9744-5f34bde51a96"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach inv\"\>"}],
  SequenceForm["i=", 59, " ", "Feuerbach inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308697542*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0e8df2ef-a572-4b92-b1ed-a70d6597a4d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308705031*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"190ced92-65a6-4127-87cb-b10d15a608c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308796956*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9cac9028-43d6-4e26-aa6f-323ca953a377"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403087986717`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"be1f3ecb-9395-4b1f-a8b5-0c34114620a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403087999983`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5f435084-7e4f-4a51-aa45-5a97cddc4130"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403088013077`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"156d51b9-463a-4cb5-9d97-ea5e3ea30ccd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308802678*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3f9113b8-06f1-4d85-a7b0-e56199092dd0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308804224*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5f249a88-7af8-4d90-97fe-dfc604b6ccaa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308805636*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"580e5436-04c1-4ddc-b68d-047304be235c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308807045*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9ef747a6-859e-497b-bd07-9849b8f6884b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308808436*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7cb516ce-eb76-4aec-b1d7-a19cbce8bba5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12 inv\"\>"}],
  
  SequenceForm["i=", 60, " ", "X12 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308809808*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"49a6f1f7-af08-46ae-b916-d244ffcaa483"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403088171864`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a714de16-8911-4052-99f1-fd28aa0ab372"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403088928957`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"65d52426-a7df-463a-9a77-427a9d31d1b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308894608*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7fee4d42-7863-4b63-a892-f2134b45fd10"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308895976*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c836407f-ed87-4d4a-b21a-010ec553a36a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308897331*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c1d8fd25-0d00-4399-83ac-81905da89833"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640308899107*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"72bab27f-975a-48e5-ac33-435922ed3cec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030890058*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4df5fd86-e59e-4ef0-ab92-18ed1e1513a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403089022017`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bc8bbc54-09f1-4011-a2fc-cee0fa2d4012"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403089041758`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5d3194df-f016-47b4-b8d2-af522dc9ef7e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403089056377`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eb0b194a-0a27-4ff5-9360-9529999ef2b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "61", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point inv\"\>"}],
  SequenceForm["i=", 61, " ", "1st Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403089077063`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"13eb7ceb-df5f-4f64-8ced-bb08441e1d9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403089523907`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c125b112-7b83-4c3b-abb3-e838c3bc5c7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403090401*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d4b9c88a-4eba-4d72-808c-090903fb3d4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403090699263`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5e10dc7d-b326-427c-8d9b-1e6f0ecee00e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309071619*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5c76f0b6-b412-4764-a40c-845cedbe7555"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403090729723`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2ce63301-4c6d-498a-bfab-c7eb7e67cc18"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030907471*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3f7929c3-f81d-4b18-a7a4-abacc00def27"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309076524*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6c29f6e4-d625-42cb-b3c8-025f6e030fdc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403090780478`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"11e3e7f3-6cb4-4789-9241-b2ecb616f387"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309079492*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0d006e2a-87c3-4ed2-80ad-8406e49daf83"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309080917*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a5ed25bb-5a1b-4d8e-a74d-98d65745be8f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "62", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point inv\"\>"}],
  SequenceForm["i=", 62, " ", "2nd Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309082649*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"56e236da-7c08-4ef0-9ded-4b50104e264d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403091180573`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7542da36-d19c-4ce6-a424-89fa201a6713"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309197678*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5c668777-80c7-4ca3-8f79-d05e7fee084b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403092269573`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"85132f6f-ab6d-464f-857f-9f1d4135ef82"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309228704*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ac54c17c-7536-4e70-93e1-067d1136aba3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309230081*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2f844ace-6582-48f3-b7cb-605523fc4cb5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309231471*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b290bb35-bdd7-4e23-bef5-fcccba8d4262"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309232835*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b4bf419-633e-4d5d-8e2f-a635a0e82563"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309234503*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"15b9c147-34e7-4e6d-b39e-14263e64c3dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309235999*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"66ffb593-8bce-4721-9abc-ac4dbf855d1d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403092374268`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e95095f0-b37a-48e2-a237-c5dead3a382d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point inv\"\>"}],
  SequenceForm["i=", 63, " ", "Crucial point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403092388153`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7e3f0bd5-8d79-4de0-b5b9-6231f82eaca1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309247727*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0c469893-6e8d-4204-a454-b694fd3b3961"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309278173*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cc793d4a-d062-42d3-904b-95b623c35798"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403092801027`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bcd65d94-c950-48df-87c7-d12ff868ae87"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403092814817`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7aaed8bd-0c67-4de3-b37e-bcddc697083f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403092831707`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b9a2bee5-b6fa-463f-a0d4-43e6d16d3ddc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309284758*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ee9bba0b-7995-4fde-aee4-c86269cf6256"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309286256*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"33407204-02de-45a1-893f-bfc52eeed2fc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309287623*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"39cf9d55-1a1e-4be5-980a-cde33b4e0d6e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309288946*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"82ae7fdc-a687-4afa-bc76-28c716c8ac73"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309290559*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f57ed000-f366-45d8-b88e-cc5a558c34da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "64", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point inv\"\>"}],
  SequenceForm["i=", 64, " ", "De Longchamps point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309292016*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0c1f1dd5-e7bc-4407-a7d6-1d623c662394"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403092936993`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1a8efbc0-9e83-4971-9ba9-eecf1c998163"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030936347*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b78495a4-9b68-460e-be7e-d00fbb3c8c4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309370905*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"724a9159-c88d-43eb-bf78-6a1f32a89f1f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309372593*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"00bd9e50-69fc-4032-af90-d2bd0e85718d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309373951*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c4efd2a6-204f-4e7e-8e82-083579f86857"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309375355*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dab2d69d-f244-4dfb-8985-2b4264523bf3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309377665*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"154e809f-beb5-4c4a-92e9-7fe5d049a30b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309379672*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1a1e2bba-7e42-4f6c-902b-c3146046fa56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309381237*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c1a06529-34b3-428d-8858-e2211b3b02ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309382635*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d06f6c7e-b720-4aa1-9832-316b932b76c6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point inv\"\>"}],
  SequenceForm["i=", 65, " ", "Schiffler point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309384231*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"496fbf61-a1db-431b-8a50-0d25631c439b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309385586*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6c7350a1-4f00-4177-b009-64de98bcf932"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030943642*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7c3fe5fd-7150-428c-9370-d3ffe4ed58b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309438394*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b886553e-e887-4be5-bcdc-d3f03dcd2f41"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309439763*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e716ca43-95fd-49a2-95db-81fce4347b4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309441123*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ae85cd91-e1d6-410c-ad19-89ed447ba8d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403094430637`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"90d5d4fe-b1fc-4382-bb0d-a677bc072aa2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309444688*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"38f1b9e9-5345-4714-948c-35fd5679e108"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309446149*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a5ce8fd3-b862-41bc-8486-3e1d55698e06"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309447603*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5f983733-6110-4de0-a965-bbe7cf1c69e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309449264*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"14bb2d51-1847-4073-8689-bb33c4ed3a7a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "66", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point inv\"\>"}],
  SequenceForm["i=", 66, " ", "Exeter point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030945098*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5ee48e10-7718-4701-8e32-d0160057bc73"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309452392*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3020038d-e388-4e55-89ec-260e08e55c0e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403094821863`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"25d511ff-a160-41d0-89dd-a702326c62f1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309489794*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"42375368-37f3-4e49-b2e6-b9805fae0ddd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309491911*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1ca92ba1-a9a5-40b6-bc54-2a8c44794d0d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030949382*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9d279bf5-6494-4b5e-bf22-9a2aa9bf82d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403094954157`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a720335d-1136-4001-8542-2b0efba0bb50"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403094971313`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3a66e3c2-688c-48ad-b492-ec435a9ed0b1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309499597*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eb065c8e-c9c5-409b-915e-6c10db5b8917"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309501273*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34a3766a-d930-4bba-b24c-e983c5f618b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309502799*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"42de0c01-6a3b-49ca-b0e6-932b271ad506"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point inv\"\>"}],
  SequenceForm["i=", 67, " ", "far out point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309504342*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4fbea527-cd69-4b46-89c3-688f3365cf60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309505961*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bce92840-5fdd-4fe7-bc43-8f9bd018a6dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403095624323`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cda119c1-50bf-4f53-8606-555733e7e9b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309564275*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4ce561a9-1093-426b-b3c1-52ce4c6643e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309565639*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0052c4c2-f7f8-4660-86bb-3c9dad54bb9c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309567173*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8c07ec33-5546-4633-9858-f933f6cdd898"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403095685863`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"20de47db-a98e-4683-9ba1-b846bf799339"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403095700808`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7b767578-6217-4b2d-9515-34358e852218"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309571787*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"80e82847-1511-4b56-b06e-7945f5d6b7c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403095732183`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c22782b2-86e7-4a29-9c09-f28a28cfd5cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403095745897`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8a5a853c-d26d-4ac2-8768-6c2aeb6fa083"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "68", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24 inv\"\>"}],
  
  SequenceForm["i=", 68, " ", "X24 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309576264*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5ad305ac-fb9d-483c-9525-e08a1bcd2719"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403095777903`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3f6966cd-4c79-44ab-b1b5-07cee8cd3105"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309652651*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1822f8ad-6123-44a7-8260-7e888da8a2dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309683647*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4a6d4bb3-dd77-492d-b799-ceb6385e431e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030968568*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0fe9c1a4-6474-4460-9353-1d0e61ac05d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309687091*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"49ec317c-d226-46d2-8d83-1e397a9ad358"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309688651*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"912bd336-0fda-4778-a866-9c42692db59b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403096904087`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7a125ed5-98a9-4322-8dfb-c11185a19873"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309692339*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9cf0b999-83ec-45f6-9689-48e1c8bcd283"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309693989*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"16742a6b-59ce-464c-bc09-03af97985c2f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403096955853`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d644a3f7-dba2-4c86-ab91-68f3f1e1a801"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25 inv\"\>"}],
  
  SequenceForm["i=", 69, " ", "X25 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309696988*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ed82db16-0712-4e5c-ad86-bf5c93defc87"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309698917*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f63aa5bf-4a92-4f5b-bed1-f4fccd795a0f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403097003508`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8d86bd13-ca87-4641-9efa-951d989a6818"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309701688*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b6d60a1e-83b3-45a9-bee5-5b3546bde709"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309703148*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"798f0b7c-cc23-4657-b9e7-b3580b1fbdf1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309704464*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"44f2e905-d8ae-4ea5-8b0d-92fc8adab585"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403097058887`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a61f13d6-4fc9-4381-9ecb-4f4a11e83e74"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403097075167`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9a81115f-377b-44f3-a30f-be48435d5c2f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309709049*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fdecc38c-d644-4329-8d9c-a077acfcc139"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403097105017`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"86bb1d82-fd53-441b-badb-91a7aa4d1042"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309711904*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"81fd692c-008a-4c12-af20-36d9d9bf7dfa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "70", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle inv\"\>"}],
  SequenceForm["i=", 70, " ", "Circumcenter of tangential triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309713243*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"48af94c7-67d1-41ce-8b58-dd8a8ae2ead6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309714946*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"57bd2fe0-c7d5-49a7-9fd9-6bf6f64a689e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309815702*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9051bbf7-086b-43c0-891a-2c32c12d3a0c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403098441057`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6969b230-00ca-4fc2-823d-63774bb4f115"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309845881*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cdab25d9-6af3-4426-854a-3756ffd2b3b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309847376*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b7820de1-71ec-461b-b9f8-73a9f3f9ab21"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309848803*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bc2e2802-91b6-4a4c-80d0-0628b4eabd2f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309850565*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"458c6ca0-eea7-4c1e-b782-1cc3b0b90f07"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403098521357`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"82bfad9a-08db-46b2-b87a-6f401031996a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309853602*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7a941fa0-0653-4d7f-8ace-c894a5253d67"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309855008*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9528988b-104e-48ec-976f-6d2070abfb40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27 inv\"\>"}],
  
  SequenceForm["i=", 71, " ", "X27 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309856531*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"469f8015-c8bf-41db-a3cd-157e5d6b9159"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309858157*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"feafced0-53a7-42d6-8f81-64c2d821fe21"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403098886757`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ffa15388-d9a9-4685-8e5e-6bf775fd846b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030989086*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cf6b1759-da3c-4cc6-8184-717d85a6b300"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309892811*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"99346a4d-0aef-43ad-9097-63cea0424e42"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309894597*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aed56b60-8ea1-4007-91fd-b846f37d7177"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309896348*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c0ca5f3b-2c34-45fa-bdfe-e442e6a3fba5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309897892*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8cee17d5-9dcf-462a-8acd-f4488b0b7130"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403098996363`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c4c215d2-1202-4489-a951-4d912ff3c799"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309901112*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"41236779-29c2-4f7f-8150-16c8e8938127"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309902545*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bb0e6f00-a26b-4db8-ad8e-73886e3b04bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28 inv\"\>"}],
  
  SequenceForm["i=", 72, " ", "X28 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309903905*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d5025a15-a4f4-49e3-8e6a-bc22c36640d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309905315*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ade16b60-e18c-4724-83b8-4a812436cee5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309936102*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0163b20c-31c2-48e7-b338-13cc35b8203d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309938232*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2581746a-a307-4856-83bb-cff5486b2fe4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403099399357`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"731a6473-d9bf-471a-a7a0-499893585bf4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309941395*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"043da7fc-45b3-4fea-836e-7a72ecafd8ea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403099433413`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"647c8f93-4920-411a-bde2-e4963cdbcfa3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309945127*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9f6feff8-d3af-4b82-80b0-6d8add9e7a15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309947071*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4f8391c5-3b40-4491-ac12-d1030f760b44"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309948584*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0c152b8b-5e45-43cd-89f1-786931a9c87d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403099499702`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"27086a65-d814-4ecb-a582-92b1e9dadf34"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "73", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29 inv\"\>"}],
  
  SequenceForm["i=", 73, " ", "X29 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564030995129*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2f132f97-a6f4-49ce-bc97-1f71d0e5d2a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640309952767*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6007df29-e526-4ee7-82c1-d3933012a507"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310060143*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e9dbd29e-7c93-41e2-b01e-a63f31a863ac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403100625753`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d4a99421-6dd9-480c-ad66-fd4cf2097d22"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310064193*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3cdf3dc8-ff53-4d61-8be7-c5aa987c3c8f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403100660143`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5be4c50e-b515-4105-8593-cba367be0fa3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403100680304`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e3ce028e-a07f-4910-91b7-d3a627221d85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031006962*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c71791ab-cdab-4d3e-afa5-cd185204ee6c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310071144*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"76e37a75-7dfe-49ce-954d-14b2c6ff16d2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310072669*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8e8e5b83-0d1b-40ce-8031-3dd7e6e59899"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310074295*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f6e27386-cbf8-4d10-a60c-b4ee80886463"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30 inv\"\>"}],
  
  SequenceForm["i=", 74, " ", "X30 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310076333*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f4173989-1e32-4e97-8d00-830eac65c0bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403101067953`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"245dc1ed-3fdb-42a2-b76a-88c44c26b1ce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031016435*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3cabb41b-c660-4bef-9a91-0556bb5eea78"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403101720753`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8b753f08-0f42-4947-83a1-d29bae0b537b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310173882*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aa1e47bc-5490-43fe-8f3e-c14c01b3a916"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031017631*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c4bcab39-8e95-4b02-9994-02c6f4348ae0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031017813*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"310b0e14-1222-469c-afb5-082e0f15820f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310180256*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e9a3b7b8-19ca-4ae7-a53c-6e1f137c4d77"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310181912*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1c31e3cd-7079-4bb4-aadd-5f1b57deb0f8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403101834373`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"919b0cff-684f-4784-991f-c0eafa7282a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310184848*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ab905b63-9865-4145-82f9-ba6e3e4feeab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point inv\"\>"}],
  SequenceForm["i=", 75, " ", "2nd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031018647*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"95e3a3ff-08de-4b6c-a111-b6610ead61cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310187944*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6b564b3f-a934-4234-97fb-7621884b188e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403101952763`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"46439eaa-6e34-43a1-a70d-868d847f1640"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310197247*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e57026a2-8929-41ee-8f6c-3ded49356d9a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310198659*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5a8f1d21-b5c1-4759-a913-38eca7aa364d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310200116*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6e35dffa-8c73-47ea-b167-96f9832b1bdd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310201614*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"44c9636a-6a79-4d78-9e71-e1fc9d72518c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403102036667`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"12407a9c-cbdd-46d6-9bed-4c8f38d49fb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310205185*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"42ebd32e-bbb6-46f5-9b4d-a986143f90a4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403102066517`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"abe39f07-b367-46ae-bd04-b58095e646c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310208085*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"56e0b3b8-e7f4-412d-9319-3dcaace96e33"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point inv\"\>"}],
  SequenceForm["i=", 76, " ", "3rd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310209436*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d75784d1-6a4d-4dd5-b834-f6de05b2d715"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403102111683`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"30dcd6a4-4695-4f54-b59f-28b26ad618ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310241466*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"215dbd0c-ef29-46df-8535-3f7c13d77cfe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310243607*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1c2e9a4a-5ea6-4c57-901f-367a66642980"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310245014*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0da9b74d-257e-4d14-bddd-6010f629699f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310246372*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a17acfa9-1f0f-44c6-97ab-082c3de225fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403102479277`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"777a1d87-dd73-42ed-a5e4-38da5efd6165"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310249446*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"19361e27-d36e-442e-9e2a-cb226b4331fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310251265*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5c4acc4a-8900-4039-8528-860476030d49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310252746*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3ce4bc54-9af3-4984-9aed-7b1cd32421fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403102541723`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"62ea6e66-2c02-49ce-a0c2-7c56253fd37c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "77", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33 inv\"\>"}],
  
  SequenceForm["i=", 77, " ", "X33 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403102555304`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e5afc769-1583-4afa-9dbb-00568cd9c002"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310256892*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2feb2213-bd21-457e-a484-2fa66999bd21"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310311922*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d2ee647f-a242-4ae1-a26b-cf8a65ff15ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310313768*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5a696970-73d6-472d-8211-ae180568b2a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310315609*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fdd6b5e9-e304-43d9-b9f1-5c254decd113"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310317079*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e9f99483-1599-4f47-bf27-69460798f638"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310318653*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"55c0b5e6-8c07-4983-b9d4-40b25ee8f26e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310320237*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"00845af4-aa5d-4d07-8678-0b515b309d28"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310321879*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b5f6add8-2b96-47b4-97f1-803695f9180b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310323928*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"26dc75d6-5efe-438f-971c-87a7990371e7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310325469*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"703aff96-2804-43e8-a66e-19646dc1e447"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34 inv\"\>"}],
  
  SequenceForm["i=", 78, " ", "X34 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403103273706`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b2192f81-0ea4-43d0-ac40-a81d5a452401"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403103288927`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f37a8b48-025e-44a3-80dd-162b5253623c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310364113*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"941d0a1a-1261-4876-b51e-84aa0beb3bc4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310365971*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cff7b693-517d-4e6a-a6ae-27a044913274"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310367773*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6fe1bdb2-a607-4ab6-9ba6-c6896eedafb5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310369461*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2038857e-9572-41bf-bd3c-af92d19c49de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310371039*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cc7fd701-9eac-4600-bf04-b18f85932b41"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310372854*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a6b4586b-dd70-466c-ab65-a4f90f9995d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031037457*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7d9775d9-5fac-4a9a-ba5a-e7d61f0f2cdb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310376487*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f2b888a1-254e-4257-9c45-f76db95a244e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310378767*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1e851cdf-07e2-48a1-954a-439dca021800"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35 inv\"\>"}],
  
  SequenceForm["i=", 79, " ", "X35 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310380426*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7a102755-f438-4e12-9750-a4c04b050936"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403103818483`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ab7dc79b-74c0-4e08-bc58-4a5eb2cf0aa6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403104192677`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"68a6e567-cebc-4175-8b3b-618003a6e895"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310421113*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6cab4117-a097-456f-9754-a2d5f9c9d286"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310422578*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"505e5ab1-dbe8-4648-ae68-12bd71849387"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310424032*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"078dc381-4454-4154-b6c4-1b2342e3ac5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310425992*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"94542b77-4520-4863-8db3-bc366071f392"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310428031*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8ac7efa4-8a4b-4d94-94c9-d82ba5410680"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310429846*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7e60d4ca-e51a-4471-86d5-0956e3807c0a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310431634*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"00471eb9-9848-4715-acb5-60e676149c47"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310433326*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"74adbf8a-88da-4be4-a344-83f8da5e7375"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36 inv\"\>"}],
  
  SequenceForm["i=", 80, " ", "X36 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403104350853`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"22d94de2-7b70-4572-9241-f48c23738761"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310436529*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b31dd1b8-e454-40a6-b4ef-2c9f5b7f3836"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031047598*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e928b32d-caa7-468c-b400-8be336259ec8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310477991*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"48ecd8f4-3b6b-405e-9dcd-4d4af8a5280d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310479632*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0df1bc27-1aec-409d-a965-71df9ce2326b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310481098*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"00cc97f1-134b-4536-bdab-eb6f797550d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310482688*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"268c63f7-a0e7-410f-9b24-f6bab43551a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310484293*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a9cb1348-a168-4a56-a951-ad1e93bb43bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310485924*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"88bb90d8-e3ca-4b4d-ae9d-91a343a032d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310487607*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f8c111cb-3186-4bd3-ab35-45715610be11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031048907*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d15179db-cb9f-419e-b047-764ac88ae5ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37 inv\"\>"}],
  
  SequenceForm["i=", 81, " ", "X37 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310490449*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"766e4b83-9936-48d9-ad4c-0870fc0c2b17"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310491889*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c059f770-18e2-4633-99ad-e3f030f58e47"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310522545*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ab9778d7-41e0-4b48-b396-84e5f13e98c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310524392*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7f1dc74c-acb2-410d-b3d7-74df7eb68c3d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310526147*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3b1747f2-91c0-409c-9237-94ea8d4b3887"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310527886*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bef3aaf9-8bc2-4586-914b-bcf8c9976ef9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403105295353`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"428b121d-cbc2-49a5-b206-24ff5f201b1e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310531178*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bd7c40ac-b7d6-4c50-ba95-5e5824e64c8d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310533162*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d976be09-4323-480c-a4b0-1875aca5fe5f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310534707*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0b09f208-29cf-4bee-bf93-699e2c7ee1d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403105361423`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e9d29831-da6c-4f4f-95e7-2826b867ec4c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38 inv\"\>"}],
  
  SequenceForm["i=", 82, " ", "X38 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310537551*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"19fa6e32-e17f-4a77-ae12-961d87fd9524"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310538968*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a36b9841-eb9b-4660-90f0-594186b2266e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310571291*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"33ba10e3-b152-4e81-a059-47f3752c4d10"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403105731783`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"764a900f-5d23-4a8c-9c15-47219adf524e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310574675*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9fdda33f-e43d-473b-9709-8fb4b0f67573"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310576476*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a3b41c5d-9123-4bea-8183-0460a739a5fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031057833*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"916452db-60aa-4f0d-b4c4-95c9655815a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403105801373`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"69c20218-7ac5-4298-b47d-77846669469c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310581793*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cc49bf7f-5ca5-40b8-a6ba-c3c34e9758e7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310583486*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cbb34b4a-89ea-47e7-af3f-1ddf75533ec4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310584972*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f08e6b15-e3fa-488c-a0cc-06d4b8e0f221"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint inv\"\>"}],
  SequenceForm["i=", 83, " ", "Brocard midpoint inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310586398*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1c13a405-eb41-4631-ad44-4ca297ae465f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310587953*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ad4c2a66-79a9-4c3b-84d8-6e9b61272d06"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310618606*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fc39530e-e830-48b5-9aaa-f54a0bbd35a4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310620645*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"28bedbeb-fb40-454e-9db0-f20cec6681cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310622106*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"38ad129f-3d00-41d9-991b-acf9a86e59ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403106235733`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4a12f0ba-2721-408d-92fa-001d93d4b128"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310625146*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a5c4f569-c47f-47c6-8e2a-65de2a4a4930"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310627055*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b68414ca-52d5-45f6-962e-c276f7b4a92e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310629084*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"35916964-303a-49d8-a4ec-1b94a2a764e8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310630718*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8c44e2bd-3910-42dd-94d4-59480729d8a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310632189*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"26b15f97-9c0a-4cd4-bf8b-cb77194e517e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "84", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40 inv\"\>"}],
  
  SequenceForm["i=", 84, " ", "X40 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403106336517`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"16991a8d-31d6-4552-839f-fdb7a627ffa5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310635088*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"759cc1ce-01fb-4703-b73c-9e096dfab5c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310742639*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"260a997c-3a20-4346-8877-23127bbccc11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403107446413`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e9eb6e51-61a6-4e35-94ca-d5921c0f64e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310746109*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c235ac88-8f62-4619-8205-240632363f2c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310747617*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ce67b005-884e-4062-8346-ea8cc6652817"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310749136*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a41f116b-43f7-42c4-bc66-33501ef78591"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031075066*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f312716d-279f-47c3-9d67-5f94bf6f17c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031075219*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b69c1ccb-870e-4b12-97b3-c00c25ebdec3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403107538013`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b5638691-a4ef-4932-95c2-3261c7214572"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403107553596`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e89bb508-df73-4a65-a54a-abc953001f3e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41 inv\"\>"}],
  
  SequenceForm["i=", 85, " ", "X41 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403107568274`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b2b557c-29c8-4472-be9d-d993c32d0e68"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310764243*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d1429880-ab29-4ab6-9efc-524429462338"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310802655*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ed05e7d6-bb51-4ec4-a2f8-d858f3020427"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310804598*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"511de702-98b3-473d-a52f-3e6557d9717e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310806089*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"39913ddd-6a36-4ee2-af5a-c29965ea5251"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031080757*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4c7d1629-7229-4fcf-9672-22165ada2bfa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310809366*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"99a66c9f-77d3-4315-a1a2-1f250a6dfea1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310811427*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"799715d4-8e22-41c6-a871-375db267fde8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310813375*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"39208020-cc08-45e6-92c6-29edcd91d394"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403108149977`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cfbaeb24-b10d-4c37-ae55-9c1db8dda6ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310816608*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"77a2c49e-4a06-48f8-a12d-fe6f86c86af0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42 inv\"\>"}],
  
  SequenceForm["i=", 86, " ", "X42 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310818109*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3fdaf1e6-8ff3-45a1-a96d-1e868e1d3083"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310819559*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"637968ff-15a0-4076-9f03-7ae756a43f45"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310849917*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"281fcad1-78c9-4a34-82f4-19699d3c6c59"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310852043*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"38048d1f-f64b-4021-8c7a-13e4472c3c85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310853486*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f078be1a-9ec7-420a-bbe7-26c910f1b58a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403108549013`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d336b906-3172-4c6e-90ef-9eff07fa48f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031085633*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b47319bc-676d-45f8-b42c-ab4362cc1966"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310857767*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"97fe14cf-276b-4b84-b14e-3db9b9f8e2f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031085929*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a40ec768-fca6-478a-b946-2d0c2a511af0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403108612823`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"50f6da40-dab9-47ea-b32f-876689142276"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310862999*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b4078653-b5cb-46f6-8e1f-812e796f3005"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "87", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43 inv\"\>"}],
  
  SequenceForm["i=", 87, " ", "X43 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310864606*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f8fe0902-a8f0-42b6-91e4-d37ee4c1c5b1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310866098*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1654e0f5-f8a6-4d2a-a41a-0638b260f42d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310901209*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0775debf-8eca-41cf-90ae-c4d855d75e6d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310903194*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e8435812-b740-4b90-8aad-a7a7856d3217"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403109047117`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"79793263-7f93-465a-8ac3-847aad671dc3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310906206*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ea774c4c-f227-4a6a-ab69-12f728085ea7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031090777*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"22e10c6b-e1d2-4c95-8a83-2aee7995930c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310909362*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"49a42963-a3bb-4f70-9752-d39ded501f06"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031091159*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"028ac416-ce40-45f0-983d-d0c3a4317904"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310913336*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4b63b765-bc7d-4570-b949-dbcb0d74aefc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403109151*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d86d92f7-c759-49ef-bad0-b15afa6a516d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44 inv\"\>"}],
  
  SequenceForm["i=", 88, " ", "X44 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310916719*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"85cba44b-b037-458d-bae4-8ef0f7fb6907"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403109182377`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b2d39d6-cd14-44ac-8e5a-b8dd300c46e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310954337*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8bd48d93-b398-4d98-a2c8-7876381459fc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310956262*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2bf40628-83f4-4eed-b379-a8d14e6262c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310957753*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6fc98df7-1e5f-4193-a358-1ef514f72c4c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310959256*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"39b6fb7c-efbf-4326-add0-f23fa9a332ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310961458*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7e4a9413-ba07-4a2a-b753-298c4f3b4d23"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031096392*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"47472507-2b03-4490-ab68-7f82ab732fbe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310965769*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1eae20b6-008d-4fb8-a490-4098656ad43f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310967382*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"de5e8293-26a8-4589-8ce8-58fa8e10593f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310969099*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"60da430f-5415-40c4-b05f-766942691446"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45 inv\"\>"}],
  
  SequenceForm["i=", 89, " ", "X45 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640310970572*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"974a1061-0c7a-4775-b66f-4cb0f89e03ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031097198*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c7b11516-c123-46fe-8275-d086a0cfd676"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311012684*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"112e1f03-6601-4e01-9596-f91a2e60dea1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031101477*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"449c623f-0e74-425e-9d57-9c834fdf3e00"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311016369*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5877f09b-497c-4aeb-9130-b4ad954e4892"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403110179033`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"13d36ae1-d525-42cb-8b18-92f0820bbe2c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403110194807`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fe3bcbc9-2df1-4c4f-aa97-7c571f14e2b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031102125*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d48d42e4-0eaa-48c4-a5dd-e5cb63518442"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311023172*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"85bf95ba-90a8-4454-9ec9-87f9c9cb6830"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311024931*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b7b2be23-07d0-43b1-b251-6052d4e3410d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311026752*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"06ecd63e-f5c8-42a6-8095-44191760ce9b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "90", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46 inv\"\>"}],
  
  SequenceForm["i=", 90, " ", "X46 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311028234*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"35041033-a0ba-4bd4-9110-6ce9bde78ca1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311057898*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"91ad3239-3dfb-450c-bebc-d827f0820e63"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311144114*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"98ce1f50-9386-45b4-aaf4-480250fe5adc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311146091*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bdd9d6b8-b4a4-4598-982d-bb8f3e3b4bf1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311147613*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5101c081-fee7-4ed1-ac98-31169acdb012"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403111491213`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"86622360-e948-4a02-8ad7-ae34a3809030"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311150732*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aafc60fd-c4fd-4675-ad1c-173ed8f4f197"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403111522913`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"93d75944-bf53-43db-a05e-82d0edb45760"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403111540613`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"44818169-fd92-4638-bc13-b131346bc32f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031115595*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9acfc522-b47f-4471-b5fc-c31db313befa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311157938*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f681b43e-ce1c-4aad-8e78-38b0c420d49a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "91", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47 inv\"\>"}],
  
  SequenceForm["i=", 91, " ", "X47 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311159531*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"781bcb77-1572-4a84-9e79-52bb3fe38ae5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311166984*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c95a0421-2b7b-4ad2-a107-e0c3bc93444e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311251237*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c68d4fab-f2dd-451f-883b-f68b1c3cffeb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403112588243`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cc4ddef2-4c6b-437a-857e-7d64fce42251"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403112607203`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ad9611d9-7f9d-4d9e-a600-fd65f066c7e7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403112622433`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"87159d15-4ab4-426e-93ec-9f4ddd51a081"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311263844*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aa430cf9-3192-435c-9c3f-b2053f185e09"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311265429*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d5778655-0eac-4a1d-8915-ffc2a97ba78c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311267016*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"05610a40-6591-4f70-be3c-d688748d7cd1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403112685757`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e1ef173a-ef03-4314-a4cc-3f68e16da7f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311270149*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d6fc85af-197c-45c2-8c90-0c6a9c0ab471"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "92", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48 inv\"\>"}],
  
  SequenceForm["i=", 92, " ", "X48 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031127181*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"68baad1c-619a-4da2-a99f-f1496d0b255d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311273295*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"252bcc2f-ef92-4a1e-96fd-afbbb50b311a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311315195*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ab0b432d-2d19-4195-b83c-552553567f6c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311317225*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"328fb18a-789c-4379-8d1e-a6f32a92c5dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311318746*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"27f73465-4905-471a-9a1e-0b78e553893b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311320414*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8a90652b-6525-4050-856d-a65b6938e4c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311322047*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"81971bac-41de-44bf-a306-cd0882289ad4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311323697*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d6d0e9e5-439d-421e-8a7d-559f598c059b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403113253727`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"23e1a66f-1880-48a4-b827-81a2a061603e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311327092*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c80fa4fe-5a32-463e-9187-d8994e3bed3c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311328723*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7ccf35f3-45f8-4708-8e42-22eb32af7459"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "93", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49 inv\"\>"}],
  
  SequenceForm["i=", 93, " ", "X49 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311330365*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a3bf47b6-78c1-4be8-8587-644f9c20c3f4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311359315*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"46cdd806-d6b0-4637-a9f5-287c56656f3b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311464322*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d4d00da7-e845-4097-8b54-6bb853006369"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311471796*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ff675fdc-e56c-47ec-ae03-69be72e05ccc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403114736958`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9b3b42a0-007e-4d74-a843-a4f851c070c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311475256*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8155af98-d0f0-4497-9674-95a9721414fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031147683*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dcb14ac4-b325-4977-a150-e7882c073c71"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311478428*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aeaadb81-b109-44c2-a035-b5a69cc9ec52"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403114801407`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e00fa4aa-6870-435e-8500-e35e107c335d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311482297*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"210952b6-62ac-4ef0-9039-59455e2a324a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311484085*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"63c4b4d2-c204-4172-8b6d-6fe87753a795"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50 inv\"\>"}],
  
  SequenceForm["i=", 94, " ", "X50 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311485869*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ee3d5e4e-2040-4c96-937b-ac28e14a6a85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311516136*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"499bba34-375d-4e12-85ad-b10d91ae7a85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403115910378`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c481075d-3e2e-40fd-9584-ddd78a12172b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403115984898`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1bcbb7f2-54f5-4ac5-be2e-a1085f958198"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311600484*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b0a0adfd-f854-41fa-a07f-3b7d8510fee0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311601988*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"69015c9a-ec57-438f-97d1-83558d693761"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311603566*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f2430e70-6c46-4862-afbf-89e635b1b5ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311605123*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4a8c316e-2cc1-4ed6-b9bd-3a2e2215bf4f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311607058*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"82720f83-cf0c-4947-9545-2d1889890dc8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311608934*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aa2d12c1-1404-4712-8418-f38d8ce68f59"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311610546*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"620785a4-52fa-4dc8-904c-af79da36c601"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle inv\"\>"}],
  SequenceForm["i=", 95, " ", "Centroid of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311612131*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"86176a1c-fc9b-4b3a-9064-d957eaf502f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311641592*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d3c2e3b0-e0a6-4165-93e7-09994814af0f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311672069*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"633830b1-a9f1-4d93-b8c8-ba65b1e9ae11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311680284*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"923b7a8b-46e7-4e4a-a338-4ca858222fe8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031168224*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e40ad8e8-c23a-47f8-b7e3-7c50308fc19e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311683793*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"da23d74e-dc9c-4a10-b1c4-764cb12cfc98"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311685423*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c5da540a-5a0f-4b3b-ad00-6b53bb826d89"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311688361*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"be2d3d00-c040-44c3-a5e0-63140a4cb0fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311690384*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c3a879fc-021f-4a2f-af37-c7cd8898f3d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311692274*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0c223b41-efa6-422c-9cbc-d691e6dfad47"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311694083*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"08890745-fd1b-4931-9ee4-e213897a42e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "96", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle inv\"\>"}],
  SequenceForm["i=", 96, " ", "Orthocenter of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311695664*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2f440f2e-1982-4d81-98ab-4bd0ce269784"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403117251177`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8e9d37e3-06bc-4d48-b65c-756ba78f582e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311841193*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c6501a05-ce61-49c0-8059-3393dc654d93"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311848753*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7826bab9-2ff5-4b1a-b3da-f1a0ec76795e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311850697*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a1d80e08-77ad-4381-a669-36defe235e95"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311852253*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e72bc371-6fcc-4662-8f1f-6b4c439ca478"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311853984*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a8826971-c8bb-4d5a-abe6-6c30166fc0bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403118555517`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8dc34edc-2374-46c8-a2da-b85021fd6e90"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311857113*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ff45bf08-6176-4e0e-ab0a-52cbbbbbe374"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311858725*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fa18e637-7c19-404a-af42-fbb85a8a7768"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403118603477`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ce52f194-f67c-4b52-99a0-909322176e4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "97", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle inv\"\>"}],
  SequenceForm["i=", 97, " ", "Symmedian point of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311862028*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6fdcfd01-11cd-4764-b857-81f7bcc83377"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311892153*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c21d5e7f-7eef-4431-b22e-f32dce93db7e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311968199*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ce8dab0e-9014-4878-a862-93825ff82187"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311975922*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5771b2cd-f43f-414a-be0b-da114d4c4bb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311977841*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d3f9eb64-8a57-4e07-93f3-081ee46c7df6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311979363*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2d665c21-0f09-4b11-8d68-4a1dadd9e5df"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311980957*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"84139d67-8b7e-4458-afc2-fea0cdc2778d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311982624*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"21bbe291-9b20-4028-bf0a-5bdec02e0d91"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031198437*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"74b40bf4-46e5-441b-aa2f-fe1c28cb7847"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311986085*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f2fdbecd-57c1-4224-9ff8-3b3fb31fe3d0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311987729*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bc4ebfa4-4909-47ed-804e-ba08e026a5f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Tarry point\"\>"}],
  SequenceForm["i=", 98, " ", "Tarry point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403119894743`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"718002cd-0a81-4dee-aecf-3531df5d3597"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640311991274*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bb03b764-ebb3-4f71-8996-5c50a271bef1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312034374*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9c0f8f95-0403-48cf-a9e5-3a842a95c389"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312042132*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e5eb65db-2be5-4873-b4af-1afefa2915a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312044207*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7b8b4b82-f3db-49db-9109-a4c48787721e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312046073*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d48ffba4-0bdd-4e08-8edc-1871f5e489e7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312048057*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2431b5d9-170a-477c-a1c8-ae1d08dbe885"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403120496902`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c8436e48-d167-40ea-b066-dd82f654fa48"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312051527*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4d215391-cb11-485d-b53b-b969c2bf0ef7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312053121*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b1bf3c5a-a2a6-4fbc-86a9-4bb5a2323945"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403120546703`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"460f3031-0e9e-432b-bf96-012833b0a7bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Steiner point\"\>"}],
  SequenceForm["i=", 99, " ", "Steiner point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403120561323`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d144fe47-a0f9-4ef5-a785-1e4412549ee1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312057622*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"51d29457-5ed3-45ef-81fb-9c867080485b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312096849*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9bc1ce6e-ded5-4c71-a172-1f98d44a451e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312099238*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4e64fcdd-0a9f-457e-96a8-15dda8015312"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312100963*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"05eced32-dd6c-4205-950c-43695a9945a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403121025867`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"63010cac-87bf-4504-9834-ea5730a8176e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403121044292`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"55fe33a1-c515-4311-a289-dac14e361067"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031210614*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"428ec412-e621-4a86-bdab-119e76caeb87"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312108018*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"679dc1f1-70f4-46f7-a3c7-1ebd6e0e64e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312109777*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8123fdc5-1da1-49fd-84c8-40f73978c428"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312111347*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3fab3c21-3c42-47b5-aa17-0e5a430f558e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X100\"\>"}],
  SequenceForm["i=", 100, " ", "X100"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312112844*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cc8c6de0-59ca-4584-8bae-073cad1e9282"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312114349*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3ad72497-4287-47de-a466-f34937ed3c24"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403121453733`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6b70562b-6bb4-4bd4-9538-7f4c59ef9cbd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403121476707`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8693a2a2-14d7-4c83-a40e-184a7967b482"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312149321*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f6bf1959-85a3-4a62-b25a-1bec91047fc6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312151122*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7c00e5d3-1f74-4d12-b932-def911e3b2c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312152726*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9ad1add3-85ac-4ac9-9468-309144c5ce9a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312154273*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a6470d6e-6ddd-480b-973e-2fc2fcca142a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312155879*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6919c49b-9a89-4ff1-b5c3-05239b7d5b29"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312157558*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34951311-9cf0-40f8-84fc-9eb9890a1463"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312159259*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d312149e-07ce-4046-ba95-f7a8f81d90e1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "101", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X101\"\>"}],
  SequenceForm["i=", 101, " ", "X101"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031216117*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c1d00faf-5eb6-4550-b691-68347e73ec9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312162895*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6d018dd0-431f-4e76-ac8d-874cc11552d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312193864*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5a5c738e-2785-4561-bf83-5f8a0ad43a30"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312196189*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a1d8f965-79c5-4f74-a13c-a619514376e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312197834*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"065cf3dc-5c3a-4b07-8e14-5be338708f28"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312199563*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"119ca0fe-7afd-40b3-bb7e-f1cf8de0972a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403122012243`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"470d0365-5551-4e5a-a4e3-804b80f4c7e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312202903*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f371bee2-a3db-4258-ad79-7cbd8e3fe01e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312204525*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8633ee75-eceb-4e2e-be5f-de44aa103073"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312206121*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"43700818-f0a7-41d2-aef8-18607eb41c48"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312207703*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1e76b130-5d5b-42ee-aa41-2d5b1d59f85b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "102", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X102\"\>"}],
  SequenceForm["i=", 102, " ", "X102"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312209303*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"83d55935-993d-475e-9fb7-ae1b7606feb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403122113647`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"749e611d-3e5e-4d85-b72d-c54a0cf3257e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403122415524`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"18e7120c-1fc1-4bd4-811f-e83941479830"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403122443867`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"03f4e0b1-89b5-4ed1-8e6c-2b5e38c7c614"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312246654*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"580a15cc-ff34-4278-a454-33dbd1d097b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403122485247`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"375b56a5-c171-4394-91dc-325721765876"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312250367*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5f4f18ae-506b-422a-9133-43528eb54ae6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312252249*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"23ebf6b0-4265-45a7-b0d9-bbed8e5a80f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403122538567`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"65562cbc-1f29-4db4-b101-288f82fbec73"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312255446*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"31206230-5166-44a6-9a61-85eded64bfe8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312257196*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"71f278c8-79ba-47d9-83ea-f8cb6f54326b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "103", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X103\"\>"}],
  SequenceForm["i=", 103, " ", "X103"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312258861*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"49c1a502-f5c0-45ef-af40-1a39aa09dc5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312288742*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"21dfd499-4f6c-46e6-aeb2-7e3b517e8fcb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312332987*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e2910b61-a669-48ab-b6c4-bd552e236fc7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312335026*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d1ca0dad-c12a-4e99-a53e-6fdb0720e0f8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "104", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X104\"\>"}],
  SequenceForm["i=", 104, " ", "X104"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312336833*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"93accc89-58c9-4845-adb2-b2788d808872"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403123666677`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ce1d06e6-4806-437a-ba36-dcd299a41a00"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312415552*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"985e0bb5-5b52-45bc-8633-9914e80d26fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403124177427`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"96c5e61c-b13f-4376-8b1d-a68d78a13caa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "105", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X105\"\>"}],
  SequenceForm["i=", 105, " ", "X105"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312419578*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0428ab11-dcc6-40c5-bd86-9c1541285a15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403124500427`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a5e33a94-4318-43ac-8f95-d6332e59c123"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312483385*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4cd12470-0589-4e5d-a874-c45d037c0e71"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403124854107`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1e015110-406b-4271-a29d-e1f8b92937dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312486944*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7013e45a-95b8-4d1e-9f43-58cff89309de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312488496*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d32bd064-7405-4435-8b6b-4af67cec1d84"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312490168*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"36b8ef4d-8e54-4dd7-aa5d-39913fd8cff5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312491807*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b67d20e1-7b80-4f8e-8539-943376248080"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031249347*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f17d778a-44d9-47d4-addf-27b5f5df78e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403124955473`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dcf95c2d-57bd-4fcb-90fc-b0b6cb35e03e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312497365*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f5d1c0a7-0e44-4541-9880-2ed8c557f0d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "106", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X106\"\>"}],
  SequenceForm["i=", 106, " ", "X106"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312499036*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f792e555-ed0e-40e0-a504-c8450ccc3559"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312500703*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d13e9ff2-60cd-4890-9263-b90170009678"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312502521*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"abd03448-949d-432d-a56f-3ca94f04ad91"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312505292*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9959bbb6-abda-4ab6-9c1a-b946cd0ccf77"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312507395*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"73f33646-84ce-48e5-ab7f-d35f2e926976"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403125093727`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b8dc7dd1-1f87-4227-adbd-95551232b66c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312511314*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d1411664-d2d2-4c90-b2b7-cf53f502d488"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312513056*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6ce792f7-607d-481a-a35e-646033027752"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403125150833`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3e55c5e5-9623-462c-971a-aa162cabc114"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403125169563`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"57e73ffb-3b81-4d3f-b92d-503051f5a4b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403125185843`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0ff7a324-5c01-4629-9067-6a7f9504862f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "107", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X107\"\>"}],
  SequenceForm["i=", 107, " ", "X107"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403125201473`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"72ac7eb3-5e6e-46f0-9810-bda41bc928e1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312521715*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a7cd7785-5397-4d04-8c1a-25d278962aef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312552017*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b9d06ce9-12a4-408b-ad6a-45f9206309c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403125540953`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"155efae8-537b-4e32-bee0-3d279b0a8493"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312555846*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"910fd06a-4ee7-4ae7-8b9a-0971828eb219"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312557396*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"53c2fdc8-7474-4fb0-b79d-c9238150be1a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403125589657`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dfc45157-d20b-42a3-9d24-17cfded0e5b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312560739*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2dff74cb-572d-4405-9551-7de3632ee3d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312562729*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"45915433-e165-4ff4-8ff2-e709482e562a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312564563*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7926dbc3-6860-42e7-9333-fa5ec5764ccb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403125663223`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9aa5ea74-aaaa-4eb4-b8b3-74935afc7665"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "108", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X108\"\>"}],
  SequenceForm["i=", 108, " ", "X108"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312567973*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eb31b200-e5bc-4b10-918d-7e80a3a2ea70"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312569577*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"589b4faa-6d92-49e4-b172-ff52af469d5f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312599457*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"918dc6e4-b010-4085-ab14-e2ce79234231"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312601486*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7505a596-0379-4adb-a5a7-cce2bd617600"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312603026*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"796cb553-edbd-42c0-a8fa-5a3130ab344b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312604607*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3576db1b-cd51-45df-99e9-6c2b5a1a186e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403126062517`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d8fa753d-f1b6-4430-97dc-324fab5319ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403126078653`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6af08a70-b681-45c4-a369-0e6d9ff92bac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031260956*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3cc396fa-4acb-4551-92ea-4853ea93ddc4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312611691*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"89eb18fc-7a0d-436e-ac5c-7d2af0f0192c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312613625*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3a50c2f6-6ece-4b6d-88d9-4d697702676c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "109", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X109\"\>"}],
  SequenceForm["i=", 109, " ", "X109"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312615384*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c943630b-ba77-4757-a557-aed0ad7edc07"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312617052*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d2b6a188-be43-4b61-8d35-8ca2887b0fc4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312618699*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"023c0aba-e629-496c-b6e1-045ae9506caa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403126203413`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"80522b84-95c3-4344-90fe-7772646ff746"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031262226*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b3ff59af-381f-4992-b095-7af3059c4d48"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312623928*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c2837711-f5cc-41f4-93cb-1137315910d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403126259947`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"66bc4f27-4c04-484f-8494-84fb477087a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031262777*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e086eb32-4725-4076-a421-e541a1c79ca3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312629507*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"faca5caf-01bc-4f2d-8ad7-e7307a55a36a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403126314383`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"321b4441-405a-4a06-b0eb-0580d148dd60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312633093*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e9569878-17b7-42f6-94c5-23110a361c0f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "110", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X110\"\>"}],
  SequenceForm["i=", 110, " ", "X110"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312634635*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4394d3ec-1461-40b7-8fff-7e47fd2ef7ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312636174*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1da2e110-b43f-43e2-8ade-d57bc2217c0b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312667143*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"493fecae-47ad-4409-a756-51f84dd6774a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312674823*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2bb64cf4-288b-40d4-bb56-04bc68879b20"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312677246*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6e3e75d9-1981-465f-af48-1fe89cd3ab48"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312679167*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3034a1ad-1b17-4c8b-8965-2d7705efe0ae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312681403*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2e397743-d4b2-454b-9803-7834398b8cb5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312683157*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e0d5144c-8316-4752-a0f2-6815bcfdbd59"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312684965*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"124db792-8316-40be-88be-e19c7a8eb6ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403126866217`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"61673fdd-bdc0-4109-8871-1195df785ca8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403126883297`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3f5bb9dc-a579-4361-992e-e6252719778c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "111", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X111\"\>"}],
  SequenceForm["i=", 111, " ", "X111"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403126899633`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2048f28f-7c50-4ab5-b209-214c7133a126"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312691846*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aaa39ec4-a76f-40e1-9787-40398fc00a40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312693964*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7f496a89-82bb-481c-b382-7361bfb9ca94"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312695959*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3c9a92e0-fd91-43fa-bfeb-122bdae1f0b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312697598*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"40e1193f-2b3b-401c-857d-39dc7cc0f927"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312699574*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"febbdc95-1405-415f-98a8-2c2a3642d61c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312701284*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"59603731-29a4-4358-bc57-ffa7b695e970"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312702919*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8f4e3a97-0b78-4f85-acf4-0a0d9335aee0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312704565*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c5d3ce29-b2a6-4ac0-985d-7b1902cf9d31"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312706229*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fa85e670-f186-438c-9cf4-948e37868d43"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312707884*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9064ae31-cc58-46ae-92ae-0d84663197cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "112", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X112\"\>"}],
  SequenceForm["i=", 112, " ", "X112"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312709544*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d9ed5940-49ee-44b4-8d65-e219aa69b1e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312711178*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e7612753-30ab-4760-9169-2f9f9cb914fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312741354*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"65a6245c-c754-4cd8-9903-6d620956c936"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403127436867`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fa31bfee-e6ee-41fe-b447-8365aa55c5fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312745583*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5a2ed7aa-6f57-4245-bb46-20722bb81e76"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312747389*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5754648f-f7c2-428e-9a3b-f604b519914c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403127490997`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1ecf4c1a-e71d-4661-ab57-37e0187ffe2f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312751137*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ca071234-1cb5-469f-99b9-e04197b6a73c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312752843*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c20ccb3a-670c-4ce4-990b-449c57aea3c2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403127544537`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"491fe8d2-00af-433e-a806-6518396176d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403127560577`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7ca54427-9377-46a4-b809-106112e49dfa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "113", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X113\"\>"}],
  SequenceForm["i=", 113, " ", "X113"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312757622*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cc648baa-a5b8-4a78-8e78-36c40101c6a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312759386*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d1fbc793-a8ca-4b29-922a-952b3e780df8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312761096*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c3013dfb-32c4-4087-8945-07ff3ad09a7a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312762733*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bcdc08b2-bede-415e-b186-8b3c9ed99850"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403127643538`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f23ba476-2f3a-4e81-9346-6ac64401bdef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312766082*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e5f98148-e5a9-4f8c-91fb-641ddd750256"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312767828*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e12cddc9-c193-4d97-a517-51645ec505f4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312769559*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"47288549-0a10-42ca-8b98-77f803a1168f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312771474*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ae1cc3a7-a86a-4aae-91aa-4c23e58b0384"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312773163*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7cc60a22-9df8-42fd-a8de-e22109da077f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312774819*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"26bd35b0-6dfc-47d2-b87b-f932f1e3ee5e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "114", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X114\"\>"}],
  SequenceForm["i=", 114, " ", "X114"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403127764072`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"60a55f3c-9260-4993-aa49-87d587a9f961"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312777993*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f24084e3-49ae-426a-8b5e-25d58bf5d42b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312815854*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2c31801d-4d7c-4655-966a-b7d33bf3c85c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312818087*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c4d132d1-7822-4a37-9a1d-25d8791d6dfb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312819757*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bab13e1c-f3b5-4229-b451-2f9faa85fe6c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312821409*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"993512c6-83dc-446c-9402-4bf98a426cf2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312823303*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"54ab88a1-b9a7-4405-8b8c-44ad0882f31a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403128250513`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"44585be2-0502-4363-b609-4c46473ec175"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403128269863`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34c73d22-a267-4a06-a48a-293e75a9553e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312828741*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c21d6c3d-2430-401b-820b-3a0400615f8a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312830387*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"86d772a1-636e-482b-833e-3bace08e9d72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "115", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X115\"\>"}],
  SequenceForm["i=", 115, " ", "X115"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312832066*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"736e1b39-6030-4722-a9b6-86de5bc19af3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312833696*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"59bbc67c-3b51-4df0-b2c9-8ac7a0dd9f44"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031286462*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1c82892a-262e-4566-8046-ec201b4a53db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403128668003`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e03f9dca-af86-4efa-a06e-7d550fa4ba1c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031286852*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ddc41765-b4bf-4a76-a4d9-3ff987abb2ce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031287043*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dc6f056a-5c32-441c-910c-143151e06d19"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403128722677`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"58e768ee-8c44-4816-b497-5061c68df17f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312873934*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e8f3b29e-d4c8-4679-8baa-dec6ae665403"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312875608*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"77cc82b7-b801-416c-b3ec-1e3fea1cf1c7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031287782*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fdb27c1e-a4e6-4bfb-ab26-b0c8d63f3223"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312879731*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"91fd69bd-87fc-4a35-a88c-fc65aefc65c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "116", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X116\"\>"}],
  SequenceForm["i=", 116, " ", "X116"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403128815002`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ca065135-a6dd-4dd6-baf7-6773743195e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312883286*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e4722b6c-3b1e-4250-8f88-d91dbf1382c1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031291741*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"38c7b55d-2698-4328-8aeb-45b37f6fc570"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312919566*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6bcf4b5c-5b0a-4e0e-8c82-e99bbd5f4fe9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312921303*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5d2f3680-2e71-486f-a722-98d070ce1896"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403129230013`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"771aae08-341a-4232-bcf0-215174ec9500"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312924796*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"89ae89d7-5222-444e-ae9f-5f076cf38b58"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312926738*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f1bf5e34-27b5-4e19-b4d3-e57742650c3b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312929324*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b1770cd5-2c4b-4b09-80dd-021b8256947c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403129314013`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"60fbd4d3-4b0d-4f4b-9f78-b77bb1f721c7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312933167*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"97c8a54a-8380-4a4c-8c5d-7a57a5a28fa8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "117", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X117\"\>"}],
  SequenceForm["i=", 117, " ", "X117"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312934906*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0719923f-603a-4a6d-817f-b6527baef1a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312936564*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6ba99ab2-6e61-42ac-827e-c0c49364e7bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312967125*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9dd0a185-9b32-4e5f-84df-6bc206bf60a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403129692507`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"75001f2b-e10a-4206-84bd-0bb200027fd1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403129709*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"65394dd7-ca8b-4605-b7fe-7720ac01e0da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312972558*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d20a662d-e77f-49c7-8fdc-413bd6062f95"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403129744577`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a8e9888f-c324-47dc-8c30-5ab9b9f314f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312976219*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cb9e8839-4a5b-4603-82f0-e9ebdcbcf99f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403129783993`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9f9cc15c-c448-4d99-b101-1508b60db549"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312980365*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"72479690-3170-4ae7-aeda-cac881545412"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312982251*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b4ade13b-5c31-494d-93e0-5a74aa151e15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "118", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r-power point\"\>"}],
  SequenceForm["i=", 118, " ", "r-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403129841833`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4fe8c8fe-d37b-42d6-9dc9-9e06409f0e93"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312985935*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ec9945bc-2a9d-46df-b44f-21d252ae6753"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031298779*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1566cf9a-44f5-47bf-9f93-5aac17820ab1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312989551*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"125c349d-ce1c-4e04-af01-d11ac6824102"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312991271*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c1ee45fd-ec49-4d3b-ab0f-c990c35f8424"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312993185*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"040ecd72-76a4-462e-b3c5-0a8ca9d82663"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312994997*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fe7139f5-a172-4c46-9b98-37db9db7e803"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312996673*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8b3c49cb-bcc3-4306-b573-998b27fdcff3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640312998354*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b04d1a40-7ec3-4397-803c-05e3a97a445b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313000073*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"54e4ae40-fd29-4d8a-93f5-53eeeff5012a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313001807*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6d847572-0c91-4ff1-8928-e64e8cbaae93"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "119", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r2-power point\"\>"}],
  SequenceForm["i=", 119, " ", "r2-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313003634*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3fd01582-840f-4eae-9ce3-e9f4f59b0463"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403130061703`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e444219b-554f-4f25-9524-1860c4964a86"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313014513*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bb92253d-df9e-41b0-bd83-8833bef06462"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313016667*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"35a78c81-dd5c-4f6c-a9f8-2808d52b6edc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313018412*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"452a4124-cc32-4f93-9fd7-baff3bd8ec9e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313020632*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9450d2f0-f581-486e-a37a-d48881c8f646"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403130225887`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1e958a41-1c40-4acc-8067-b9f96bcbfbf7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313024412*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a568faba-ac77-4c85-b053-76feafee33ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313026433*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d6dd1df6-a6db-4055-be6a-c807574d404f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313028248*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"08e6fa33-9d30-4304-9e05-121c9069d069"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313029928*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5ced5c45-7f11-4fcc-a64e-a8f15b2f984b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "120", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r3-power point\"\>"}],
  SequenceForm["i=", 120, " ", "r3-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403130315638`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2557c1db-3808-4ae5-b590-9200825c66cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313033207*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d565a389-6d60-41e9-8139-8f9d1be6c939"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313062788*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d8845c8a-af2d-4af4-b01f-43ef1e365de3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313065144*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b041e938-6926-4f1e-9bae-9eae5609c44b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403130667963`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"edaad52a-608f-4063-9f61-92dee1d942cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313068386*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d0a3a2e5-f9b3-410b-8b94-cf70bfab6ac4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313070058*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d8c581ee-b382-4d99-b158-bebe104ffa9b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403130717497`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f5366072-7d51-431a-b301-635e8907cbbd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031307343*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7cacb2f1-2c38-4cf7-9573-fbc19a331188"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313075115*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"be0f27c4-800b-457a-af31-18222bba4218"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031307686*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b210bb70-dc93-49c6-ab7e-247876f53c03"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "121", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z1\"\>"}],
  SequenceForm["i=", 121, " ", "Z1"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313078939*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e3d61bf8-3027-4014-b2aa-193d4519f9f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031308083*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6c6daf3f-de4d-4361-ab12-65101804d263"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403131107693`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1b30ec86-329d-4f40-8a82-48ff2647827a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313112935*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ff051ea8-827a-43ae-982c-0253b7493813"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313114893*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fa0f36e0-bd36-4b88-94f0-3971b5f5eceb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313116789*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7890d7bf-488e-4eee-93e7-8b98f07089d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313118699*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e9bd37c8-75d5-4af0-8aae-59a5f4289642"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313120585*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5a158d69-daaa-4c2e-9460-c0e8ec4d0292"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313122357*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3ec0dbf4-8649-48b3-870e-0c7661644ea6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403131243134`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0f2f3c3d-d714-4b5c-b0c7-58ee520fda3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403131260653`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ab3960f5-c08a-4714-80fd-2e37d7041401"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "122", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z2\"\>"}],
  SequenceForm["i=", 122, " ", "Z2"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403131281843`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"25b8d354-378c-40c2-aece-ac16cb747032"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313129994*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a403e412-6638-49b4-8bd8-d146e78440cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403131701107`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7172cee9-3e08-48a4-b7d0-94d07abd8ae0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031317242*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8a4ae953-96c1-49be-8249-3422646c8197"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403131742764`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4dbcd1d9-3770-4e35-b147-730b19fecae4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403131764183`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"72c948ec-2966-4487-9d1b-3e6d035e088c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313178838*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"56173482-a2a5-4ff1-b214-e5421b0656ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313180935*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"81963513-6472-47a7-82a4-0d7e3b6b81fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403131828527`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"51c45308-6cf9-478c-96fc-8dc844b9f96e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313184723*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6708a4d6-d1d3-43e5-8bf4-764eac95136b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313186757*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f31df282-4e2b-4fbd-81a9-ed95d4c46d74"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "123", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z3\"\>"}],
  SequenceForm["i=", 123, " ", "Z3"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313188449*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"513c7edd-a11c-42fc-bb4f-c0495a282254"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313190164*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"220d9962-6b42-4e33-a1d6-6aca8ee6c1e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313238467*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1acf072b-c914-47e3-b8ac-9fcca7f7392a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313240787*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c4447b87-6b85-4ef3-b965-cd432a7c04fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313242846*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b64c9fa3-faf7-46df-af37-5692206472a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403132448273`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"67eda690-a0e8-4d4c-aca8-b2cee0cdfbac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313246702*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fccc59a0-aed7-40a1-bce7-f7a9eb0a3cff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313248781*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"77e1d41f-baca-4f93-bb62-f6df44626c70"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313250944*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"325abeb0-bbbd-4efe-9cb5-a350d73b03c2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313252782*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"281ffb8c-d1c1-48ae-bb1b-1fc3cf684946"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313254746*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"283d5036-3829-4f0e-a9cf-282089450b12"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "124", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z4\"\>"}],
  SequenceForm["i=", 124, " ", "Z4"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403132566032`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"930d7acf-adcf-47dc-b0fa-894270f234b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313258305*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ba9a063b-1950-410e-90ff-a9d31453cf58"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403133139067`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6519900b-7a4c-4429-ab0b-c63ecce7bb73"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313316173*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"62353a82-899b-4cdc-ba1e-f711d9e24097"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313318067*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cc590536-532b-4930-bbdd-a1c2248833d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313320204*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c44dbaa3-a4e5-48d7-82cc-923c9e401ba2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031332205*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e3420604-58e8-4c5e-b80b-ec72b180c881"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031332393*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6cf9194e-a913-4a31-8ef7-e41f15c2e5eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313325817*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1009359b-514b-4613-8dc6-561850b04402"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403133276567`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ac535f8d-97ad-4508-842c-16b2becb8b0e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313329496*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9d9f9ad7-6ba5-4ceb-b7e5-b361298cb322"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "125", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z5\"\>"}],
  SequenceForm["i=", 125, " ", "Z5"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403133313637`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"09edc52b-4915-42ab-869f-3e1bff1680f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403133331327`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0161c84f-b2dc-498a-a9ed-f7ee7bd6f317"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313379692*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f1b7a88d-4e6c-4f03-ba27-333fc26556c7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313382045*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f324f809-2038-4724-adf2-fde0fac737d0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403133838797`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6a7eab23-296e-454e-8f52-de07cd8eca3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313386037*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d182fc8f-fe62-4e3f-becd-4b66fbb68029"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313387924*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"015e7445-3c3f-461c-913a-b04466152234"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313389791*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"493aa411-ccbd-4fc3-9001-977cb5b2200c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403133915854`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"52b7ccba-93b4-4fa9-8954-9d5c3d79c617"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313393488*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"915d60ea-0e67-4414-b9ab-ab6e5a2cdbea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313395419*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e12bca27-6501-40c0-8ff0-c92909420352"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "126", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z6\"\>"}],
  SequenceForm["i=", 126, " ", "Z6"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031339713*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"96f2c59a-6d4c-407c-b535-ac3ef049d530"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313398776*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"90951315-fa53-41a4-94d7-5926503dde49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313444768*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ed72a2b2-7e20-4762-9a2e-8d6736522c78"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313447206*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9c41f503-8f88-4d7d-b510-67582d86453d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403134491*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"35853a0d-cb0e-401d-b771-999c94164cc0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313451193*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0b580d5f-e9ef-465f-9fe3-baaa13a7eb25"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313453187*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5f1b23b3-9bfc-4f21-a73c-774038ffd628"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313455367*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bd4ab72a-d052-43f0-bbd7-0e649973964d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313457354*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2ac062c6-b25b-490e-9439-56953fe2e0e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313459229*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d58a8088-89fb-425f-be01-8902bf52411e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313461196*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9fd5dda5-de63-4419-b1dc-b3d10766e23e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "127", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z7\"\>"}],
  SequenceForm["i=", 127, " ", "Z7"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313463077*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"54f81747-9d61-48f2-9452-928a0583b3bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313464796*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"05db837b-a9a2-478e-a553-bdf550327b42"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313528729*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"74e3d6b6-1a30-4033-bc5d-52ed92fa5767"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313531005*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"30a8c295-f5b2-4dd8-b3be-c34ce0df1757"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313532796*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6d7cbc79-60eb-4197-8f9e-528921a1d995"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403135349407`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"27fefd3e-0b10-400a-954f-46bd80df85d0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313536811*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d7a63dbe-071a-476a-8fd8-1a1554a95933"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403135388317`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1c8329bc-1597-4e36-ada3-a44ba190c089"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313540756*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"62571fb4-6a49-427f-aa13-22b9adff274d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403135429363`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cd168c8d-34a7-47df-959d-ada3e86f4537"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313544945*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"68f999fa-8219-421c-97d4-d5bd2c59b448"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "128", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z8\"\>"}],
  SequenceForm["i=", 128, " ", "Z8"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313546822*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f4d45aa5-d5c7-47ac-ae37-0dc926b2becc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313548572*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"71c87f8e-5294-4f8d-88f3-e79aec532f15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313581011*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"03706821-33b1-4a2b-98c6-18c18d863f2e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313583346*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"98b6685a-fde3-4640-b192-a0fcdf7a715d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403135851593`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1354b225-3310-49ca-a313-7a9d8f7da43b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313586953*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7684b20e-3ba5-453d-aa20-d38626e6041c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403135887833`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d6e790e1-07d1-4efd-980a-96ef088f3aec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313591*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8da6c432-9b12-445b-b7ce-29858e341957"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031359309*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"47c9266d-6317-4ef4-bb0e-0d6e2fcaa4cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313595276*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3672cb7c-09e1-4024-8dfe-ad05b7dcf92f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313597522*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bd668d7e-6ae5-43fb-ba83-9028f2ee2c15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "129", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r4-power point\"\>"}],
  SequenceForm["i=", 129, " ", "r4-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313599332*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fc6980b1-872f-4d30-a621-765daf9c518e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313601431*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"79896ae4-834a-4782-9234-8360f4d13639"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313632937*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f634fa7b-dbaa-4ac8-9e5f-3a802db2d91f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313635109*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"02c89f2e-0956-4517-8a2a-5853ab4b36b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403136368093`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f8db0ce9-70f5-4feb-a4aa-576bf484ae9c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313638535*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3c198efc-97df-40e1-be68-485b96b947e8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403136403303`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2185d607-ce77-47d2-882b-6f2191adca0a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313642284*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"55340318-5c84-46cb-9ca6-93b94b187753"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403136446533`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5acd01fc-f20d-479f-84da-45660685cb40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313646677*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a6d0c616-b6a7-42bd-8650-e69989c3d8b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313648637*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bc3aca19-2f91-490b-92ad-17fcbc84fc59"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "130", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"arbitrary center\"\>"}],
  SequenceForm["i=", 130, " ", "arbitrary center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313650386*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"905da045-6c66-4d25-a434-c25dd89e0749"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians have same length.\"\>"}],
  SequenceForm["  ", "Cevians have same length."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313652196*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"46c7709c-8cd1-489d-9fdf-023bbd4a685c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isosceles.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isosceles."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403136539593`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a7724190-b44b-4688-8b78-5add3a531a4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403136557493`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"563cdc1c-2756-47f7-976c-3a7cbf69873e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313657468*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9557ec89-3c23-4414-a911-54f5194f3fa6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403136594276`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3f9f2030-ef6e-4450-9494-bff56058bca2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313661458*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b7fbfddb-3690-45ea-921a-7955a4fd6d72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Monge point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564031366354*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"60252bf7-f3b9-40ad-b192-cb256ea3ed8e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "incenter", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313665411*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cc3e1326-4a9f-4b89-a580-10352d069a61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "Euler point", " coincides with reference ", "centroid", 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313667227*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7cd3ee50-2f1b-446d-8988-0028fb170af2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313669031*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1d0baef0-b18d-4d12-a614-f3cc005f96ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "131", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"areal center\"\>"}],
  SequenceForm["i=", 131, " ", "areal center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403136708508`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"49a30ae1-b772-49ec-949e-7de8717bd369"],

Cell[BoxData["\<\"  --> Some pairs of edges have same length.\"\>"], "Print",
 CellChangeTimes->{3.805640313678629*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bb0930d2-8923-4c29-b2fd-5012b0071a9d"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.805640313771327*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"af548061-54f7-425a-8a4f-0fd0346de6f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CASE \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", "\<\"Circumscriptible Tetrahedron\"\>"}],
  SequenceForm["CASE ", 3, ": ", "Circumscriptible Tetrahedron"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313773616*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"50c2b5f6-c3bf-41b8-adec-26eddd5811a4"],

Cell[BoxData["\<\"------\"\>"], "Print",
 CellChangeTimes->{3.805640313775302*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"10220929-13d8-4a8e-8d5e-02914b3792a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>"}],
  SequenceForm["i=", 1, " ", "incenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313782714*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6e9b8ccc-6ed6-420f-84c1-d8dbef720a5a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640313814205*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"40539411-b449-4804-985a-b90c8a20b5d9"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.8056403146295652`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c663b24e-f629-4431-939c-8dbfa5885060"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a1", "-", "a2", "-", "a3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"a1", "+", "a2", "-", "a3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"a1", "-", "a2", "+", "a3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "100"}], " ", 
       SuperscriptBox["a1", "2"]}], "+", 
      SuperscriptBox["a1", "3"], "+", 
      RowBox[{"200", " ", "a1", " ", "a2"}], "-", 
      RowBox[{
       SuperscriptBox["a1", "2"], " ", "a2"}], "-", 
      RowBox[{"100", " ", 
       SuperscriptBox["a2", "2"]}], "-", 
      RowBox[{"a1", " ", 
       SuperscriptBox["a2", "2"]}], "+", 
      SuperscriptBox["a2", "3"], "+", 
      RowBox[{"200", " ", "a1", " ", "a3"}], "-", 
      RowBox[{
       SuperscriptBox["a1", "2"], " ", "a3"}], "+", 
      RowBox[{"200", " ", "a2", " ", "a3"}], "-", 
      RowBox[{"2", " ", "a1", " ", "a2", " ", "a3"}], "-", 
      RowBox[{
       SuperscriptBox["a2", "2"], " ", "a3"}], "-", 
      RowBox[{"100", " ", 
       SuperscriptBox["a3", "2"]}], "-", 
      RowBox[{"a1", " ", 
       SuperscriptBox["a3", "2"]}], "-", 
      RowBox[{"a2", " ", 
       SuperscriptBox["a3", "2"]}], "+", 
      SuperscriptBox["a3", "3"]}], ")"}]}]}],
  SequenceForm[
  "    ", ($CellContext`a1 - $CellContext`a2 - $CellContext`a3) \
($CellContext`a1 + $CellContext`a2 - $CellContext`a3) ($CellContext`a1 - \
$CellContext`a2 + $CellContext`a3) ((-100) $CellContext`a1^2 + \
$CellContext`a1^3 + 
    200 $CellContext`a1 $CellContext`a2 - $CellContext`a1^2 $CellContext`a2 - 
    100 $CellContext`a2^2 - $CellContext`a1 $CellContext`a2^2 + \
$CellContext`a2^3 + 
    200 $CellContext`a1 $CellContext`a3 - $CellContext`a1^2 $CellContext`a3 + 
    200 $CellContext`a2 $CellContext`a3 - 
    2 $CellContext`a1 $CellContext`a2 $CellContext`a3 - $CellContext`a2^2 \
$CellContext`a3 - 
    100 $CellContext`a3^2 - $CellContext`a1 $CellContext`a3^2 - \
$CellContext`a2 $CellContext`a3^2 + $CellContext`a3^3)],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314632399*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"23255cf0-8720-4a09-8591-a6d787a9802a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403146344223`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"824cc23d-3ee8-495a-b841-90aaa464da75"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>"}],
  SequenceForm["i=", 2, " ", "centroid"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314636269*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"abaa31c8-bee6-43a1-8101-42b109843c26"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Faces are parallel.\"\>"}],
  SequenceForm["  ", "Faces are parallel."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314643868*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f192fb97-25d1-4262-b41e-7ca217792f7d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}],
  SequenceForm["    Coordinates of intersection point:  ", {1, 1, 1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314646089*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e73595cf-a615-4c67-a524-f22277cef1a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "centroid", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314647786*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2e3c2399-9332-4f7b-a3c1-aa41fef2dafc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "1", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 1, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314678048*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"45bdce21-c03c-4e9a-ac36-f1f03beafe6f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403146804953`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c252256d-c36c-468f-9a86-48810c849def"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is circumscriptible.\"\>"}],
  SequenceForm["  ", "Tetrahedron is circumscriptible."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314682439*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c637e46e-eaf8-4c6e-8692-f399eb86d7d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314684248*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a3742c0d-8be8-4e03-af27-9d7616baf887"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403146859818`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bdc9977b-602e-45b7-8943-02de3fbd5c6e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra are similar.\"\>"}],
  SequenceForm["  ", "Tetrahedra are similar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314687763*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e382c03f-2137-4b92-a992-196d3ffe1fbb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314689513*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"31ffb113-890b-4b27-ba07-5bcc76893b60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "Euler point",
    "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314726534*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f8e1ed72-ceab-49d0-b9ae-61a4f2a51c09"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Central Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["2", "3"], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Central Monge point", " lies on reference Euler line (at ", 
   Rational[2, 3], ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640314920917*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f371eb5a-8434-4c3b-8b5d-2ad1a8a74954"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Central Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["8", "9"], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Central Euler point", " lies on reference Euler line (at ", 
   Rational[8, 9], ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640315274436*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dcdb85ec-0b3d-454a-a683-026782b65418"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Reference \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" lies on central Euler line (at \"\>", 
   "\[InvisibleSpace]", "4", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    Reference ", "circumcenter", " lies on central Euler line (at ", 4, 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640315411502*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a1e5e457-c34d-4691-a75b-6f2bff910f81"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Reference \"\>", 
   "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on central Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    Reference ", "Monge point", " lies on central Euler line (at ", -2, 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403155204277`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1aee4ac6-7151-400f-a10c-84f601966fb0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640315582295*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5488016e-dd95-4ef1-8f65-395cd1613d78"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>"}],
  SequenceForm["i=", 3, " ", "circumcenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640315584786*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"85fbea3e-fb7f-4200-89d6-77fd5e3f7633"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm[
  "    Point coincides with ", "circumcenter", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322612177*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"73934049-73fc-4ec5-a913-85927aa1e2e7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "0", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 0, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322673614*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b3b84a81-4ec7-4349-b5ce-b4163e9d03ff"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.805640322676095*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7fac583e-c24b-4c53-8e2c-4b0ffbe638f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"10000", " ", 
     SuperscriptBox["a1", "4"]}], "-", 
    RowBox[{"200", " ", 
     SuperscriptBox["a1", "5"]}], "+", 
    SuperscriptBox["a1", "6"], "-", 
    RowBox[{"20000", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"]}], "+", 
    RowBox[{"200", " ", 
     SuperscriptBox["a1", "3"], " ", 
     SuperscriptBox["a2", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "4"], " ", 
     SuperscriptBox["a2", "2"]}], "+", 
    RowBox[{"200", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "3"]}], "+", 
    RowBox[{"10000", " ", 
     SuperscriptBox["a2", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "4"]}], "-", 
    RowBox[{"200", " ", 
     SuperscriptBox["a2", "5"]}], "+", 
    SuperscriptBox["a2", "6"], "-", 
    RowBox[{"20000", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"200", " ", 
     SuperscriptBox["a1", "3"], " ", 
     SuperscriptBox["a3", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "4"], " ", 
     SuperscriptBox["a3", "2"]}], "-", 
    RowBox[{"20000", " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"200", " ", 
     SuperscriptBox["a2", "3"], " ", 
     SuperscriptBox["a3", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a2", "4"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"200", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "3"]}], "+", 
    RowBox[{"200", " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "3"]}], "+", 
    RowBox[{"10000", " ", 
     SuperscriptBox["a3", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "4"]}], "-", 
    RowBox[{"200", " ", 
     SuperscriptBox["a3", "5"]}], "+", 
    SuperscriptBox["a3", "6"]}]}],
  SequenceForm[
  "    ", 10000 $CellContext`a1^4 - 200 $CellContext`a1^5 + $CellContext`a1^6 - 
   20000 $CellContext`a1^2 $CellContext`a2^2 + 
   200 $CellContext`a1^3 $CellContext`a2^2 - $CellContext`a1^4 \
$CellContext`a2^2 + 200 $CellContext`a1^2 $CellContext`a2^3 + 
   10000 $CellContext`a2^4 - $CellContext`a1^2 $CellContext`a2^4 - 
   200 $CellContext`a2^5 + $CellContext`a2^6 - 
   20000 $CellContext`a1^2 $CellContext`a3^2 + 
   200 $CellContext`a1^3 $CellContext`a3^2 - $CellContext`a1^4 \
$CellContext`a3^2 - 20000 $CellContext`a2^2 $CellContext`a3^2 + 
   2 $CellContext`a1^2 $CellContext`a2^2 $CellContext`a3^2 + 
   200 $CellContext`a2^3 $CellContext`a3^2 - $CellContext`a2^4 \
$CellContext`a3^2 + 200 $CellContext`a1^2 $CellContext`a3^3 + 
   200 $CellContext`a2^2 $CellContext`a3^3 + 
   10000 $CellContext`a3^4 - $CellContext`a1^2 $CellContext`a3^4 - \
$CellContext`a2^2 $CellContext`a3^4 - 
   200 $CellContext`a3^5 + $CellContext`a3^6],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322678616*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c4535632-738d-42c0-8217-138f2b853ab6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322681635*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"77bfb34f-5db8-47b4-8b55-571c3a914f14"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"orthocenter\"\>"}],
  SequenceForm["i=", 4, " ", "orthocenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322683651*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"91778b61-710d-43be-bc32-6aa190060eaf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"nine point center\"\>"}],
  SequenceForm["i=", 5, " ", "nine point center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322715534*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6775c7f1-4a13-4c46-9a8a-14edb0481b01"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"symmedian point\"\>"}],
  SequenceForm["i=", 6, " ", "symmedian point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322774279*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c2bfb837-115e-4ae1-8c99-90b00dc12e04"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322806712*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"199c1c9d-e7fd-4682-ac21-2cb377d10ea6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne point\"\>"}],
  SequenceForm["i=", 7, " ", "Gergonne point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403228089952`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"710822d7-b581-4e3b-8c10-7cb8d32da00b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a1", "+", "a2", "-", "a3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a1", "-", "a2", "+", "a3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "200"}], "+", "a1", "+", "a2", "+", "a3"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"a1", "-", "a2", "-", "a3"}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{"a1", "+", "a2", "-", "a3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "200"}], "+", "a1", "+", "a2", "+", "a3"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"a1", "-", "a2", "-", "a3"}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{"a1", "-", "a2", "+", "a3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "200"}], "+", "a1", "+", "a2", "+", "a3"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a1", "-", "a2", "-", "a3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a1", "+", "a2", "-", "a3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a1", "-", "a2", "+", "a3"}], ")"}]}]}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {($CellContext`a1 + \
$CellContext`a2 - $CellContext`a3) ($CellContext`a1 - $CellContext`a2 + \
$CellContext`a3) (-200 + $CellContext`a1 + $CellContext`a2 + \
$CellContext`a3), -($CellContext`a1 - $CellContext`a2 - $CellContext`a3) \
($CellContext`a1 + $CellContext`a2 - $CellContext`a3) (-200 + $CellContext`a1 + \
$CellContext`a2 + $CellContext`a3), -($CellContext`a1 - $CellContext`a2 - \
$CellContext`a3) ($CellContext`a1 - $CellContext`a2 + $CellContext`a3) (-200 + \
$CellContext`a1 + $CellContext`a2 + $CellContext`a3), ($CellContext`a1 - \
$CellContext`a2 - $CellContext`a3) ($CellContext`a1 + $CellContext`a2 - \
$CellContext`a3) ($CellContext`a1 - $CellContext`a2 + $CellContext`a3)}],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564032284081*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2b4dbd3d-a5f0-4e62-88d7-8437dccbda91"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322872799*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e913b4d8-51a6-4fa4-bea2-2c4772a9ad81"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322874995*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"039b6ad9-1f2b-464c-bb85-908c0393cff9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel point\"\>"}],
  SequenceForm["i=", 8, " ", "Nagel point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564032287716*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"db654629-69ac-4b52-8e87-c15a10e65534"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a1"}], "+", "a2", "+", "a3"}], ",", 
     RowBox[{"a1", "-", "a2", "+", "a3"}], ",", 
     RowBox[{"a1", "+", "a2", "-", "a3"}], ",", 
     RowBox[{"200", "-", "a1", "-", "a2", "-", "a3"}]}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {-$CellContext`a1 + \
$CellContext`a2 + $CellContext`a3, $CellContext`a1 - $CellContext`a2 + \
$CellContext`a3, $CellContext`a1 + $CellContext`a2 - $CellContext`a3, 
    200 - $CellContext`a1 - $CellContext`a2 - $CellContext`a3}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322885887*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a6b3129e-7c45-4671-8a32-047e34397081"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403229164753`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f0e6815f-4650-47a4-9e87-49d34effb054"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403229188147`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"93399ba4-9072-45c7-b7d5-950eaad5aae8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt\"\>"}],
  SequenceForm["i=", 9, " ", "Mittenpunkt"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640322920898*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"094949ce-57b5-4dc0-90a3-12e4047f6522"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403229544353`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b0c63927-83c1-4d00-af08-fd30352bca5f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker center\"\>"}],
  SequenceForm["i=", 10, " ", "Spieker center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403229567432`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"80b7180a-e456-4a33-88cf-412d45d14b08"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach point\"\>"}],
  SequenceForm["i=", 11, " ", "Feuerbach point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403229649267`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9b8cb6a8-9dc2-4b64-964a-1802d38c06b2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Points are coplanar.\"\>"}],
  
  SequenceForm["  ", "Points are coplanar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403229976673`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b0971e74-dc48-4436-b193-911810f94ec6"],

Cell[BoxData["\<\"  --> Some pairs of edges have same length.\"\>"], "Print",
 CellChangeTimes->{3.8056403230002832`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"58ad8f9c-f4bc-48f3-97b8-e9eb91ae26ae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640323002372*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d9bcff50-eb1c-4691-a11e-069a4a3a7cc0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12\"\>"}],
  SequenceForm["i=", 12, " ", "X12"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640323004219*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"572e1714-c711-4eae-b1c6-abd12314f3da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st isogonic center (Fermat point)\"\>"}],
  SequenceForm["i=", 13, " ", "1st isogonic center (Fermat point)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640323037538*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a05fb4ad-a786-4385-99f1-2a59fff47e0d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isogonic center\"\>"}],
  SequenceForm["i=", 14, " ", "2nd Isogonic center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640323608972*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"093d86f1-178c-4602-aa8c-609be560e761"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Isodynamic point\"\>"}],
  SequenceForm["i=", 15, " ", "1st Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640324122053*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"02a8a471-2bb3-46dc-a104-93d589e70221"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isodynamic point\"\>"}],
  SequenceForm["i=", 16, " ", "2nd Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640324434066*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2ad4346d-3b96-4548-92e0-b048d701b3e8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point\"\>"}],
  SequenceForm["i=", 17, " ", "1st Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640324765308*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1b9ce7f4-c7f0-47c8-b469-340cf5f13be3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "18", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point\"\>"}],
  SequenceForm["i=", 18, " ", "2nd Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640325511573*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a64febd9-9a07-4216-8bd5-2b88f67d0735"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point\"\>"}],
  SequenceForm["i=", 19, " ", "Crucial point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640326134646*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cbc7a76d-97c9-4e73-a378-02ccf4784341"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point\"\>"}],
  SequenceForm["i=", 20, " ", "De Longchamps point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403261897717`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2c3e25cf-921f-4ba2-aaa7-11d1fae02823"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point\"\>"}],
  SequenceForm["i=", 21, " ", "Schiffler point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640326271611*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f7e341cc-feb2-40b2-9985-c0dec491bb62"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "22", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point\"\>"}],
  SequenceForm["i=", 22, " ", "Exeter point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640326308201*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2d740f81-102f-44b6-8783-82362f0b4b8c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point\"\>"}],
  SequenceForm["i=", 23, " ", "far out point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640326359432*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5d928892-6876-4ef9-81e6-7d7d772267b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "24", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24\"\>"}],
  SequenceForm["i=", 24, " ", "X24"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403264152517`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"abb73491-ba14-4d97-a81c-daa25465ca44"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25\"\>"}],
  SequenceForm["i=", 25, " ", "X25"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640326567498*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"799f0dfe-9bc6-4535-bb5f-138631403c55"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "26", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle\"\>"}],
  SequenceForm["i=", 26, " ", "Circumcenter of tangential triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403266192513`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"899c38a0-5874-4fae-a98d-b8152bfddfc0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27\"\>"}],
  SequenceForm["i=", 27, " ", "X27"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640326885188*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4b58861d-ea07-40db-811c-927ab53f114b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28\"\>"}],
  SequenceForm["i=", 28, " ", "X28"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640326952141*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"672aab8a-ba5e-4615-a9e6-8d8cc283c510"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "29", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29\"\>"}],
  SequenceForm["i=", 29, " ", "X29"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640327006415*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"894c7c69-eee7-4d61-b6c0-30323724979f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30\"\>"}],
  SequenceForm["i=", 30, " ", "X30"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640327057564*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"93b27b07-6a7a-43d1-88d4-6e4faff017b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640327090208*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ac84bb2a-ea2d-40dd-ba10-34da8b351a08"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403270926657`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1c59e883-23ce-4dff-9619-641ad24b3d33"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640328330361*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ec014d3b-9b23-4742-ab21-a4c7ccf9b24c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point\"\>"}],
  SequenceForm["i=", 31, " ", "2nd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640328332717*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"312e659e-e920-43e7-9f2c-3347f69976a7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403283632603`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e03d8b12-771a-444e-808f-30dc0a6f9e1e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point\"\>"}],
  SequenceForm["i=", 32, " ", "3rd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403283659277`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9d9c795c-61d6-40b0-8a8e-d34109b66f27"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640328373906*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aac1f939-c780-431f-9ea0-ffc18d4763eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "33", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33\"\>"}],
  SequenceForm["i=", 33, " ", "X33"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640328376808*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c4932297-851b-4d5d-b89b-dd859937a24a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34\"\>"}],
  SequenceForm["i=", 34, " ", "X34"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640328429262*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d6f3a01d-0e0a-4dee-b83b-dec7b693dc20"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35\"\>"}],
  SequenceForm["i=", 35, " ", "X35"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403284860888`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b8c6ef4f-a557-4dae-8a3c-324cd1e40ba2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Property \"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" failed in general,\"\>", 
   "\[InvisibleSpace]", "\<\" but numeric example succeeded.\"\>"}],
  SequenceForm[
  "  Property ", 17, " failed in general,", " but numeric example succeeded."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403285981913`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e16e56e9-efb8-449c-bc48-b3d30bf3fd49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36\"\>"}],
  SequenceForm["i=", 36, " ", "X36"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640328606655*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"964b82b1-9ec8-4e1b-949a-4f10f7bdc190"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Property \"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" failed in general,\"\>", 
   "\[InvisibleSpace]", "\<\" but numeric example succeeded.\"\>"}],
  SequenceForm[
  "  Property ", 17, " failed in general,", " but numeric example succeeded."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640328711255*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"81184445-3405-42f8-97a5-286bacbfa7e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37\"\>"}],
  SequenceForm["i=", 37, " ", "X37"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640328720016*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2f10f616-cb33-4ae3-91e5-bc0f2baad1aa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38\"\>"}],
  SequenceForm["i=", 38, " ", "X38"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640328751285*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5d3e865b-fdd6-4c9f-9c02-07f6d4018cf3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint\"\>"}],
  SequenceForm["i=", 39, " ", "Brocard midpoint"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403287885036`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"61f353e9-2d13-4b03-a83f-8ea3228de6a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40\"\>"}],
  SequenceForm["i=", 40, " ", "X40"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640328821974*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"759c3be8-c141-4a68-9236-7368aec67418"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.805640337075593*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6b43a04c-4247-411d-8048-264624be20a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"20000", " ", 
     SuperscriptBox["a1", "4"]}], "-", 
    RowBox[{"300", " ", 
     SuperscriptBox["a1", "5"]}], "+", 
    SuperscriptBox["a1", "6"], "-", 
    RowBox[{"300", " ", 
     SuperscriptBox["a1", "4"], " ", "a2"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a1", "5"], " ", "a2"}], "-", 
    RowBox[{"40000", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"]}], "+", 
    RowBox[{"600", " ", 
     SuperscriptBox["a1", "3"], " ", 
     SuperscriptBox["a2", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "4"], " ", 
     SuperscriptBox["a2", "2"]}], "+", 
    RowBox[{"600", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "3"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["a1", "3"], " ", 
     SuperscriptBox["a2", "3"]}], "+", 
    RowBox[{"20000", " ", 
     SuperscriptBox["a2", "4"]}], "-", 
    RowBox[{"300", " ", "a1", " ", 
     SuperscriptBox["a2", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "4"]}], "-", 
    RowBox[{"300", " ", 
     SuperscriptBox["a2", "5"]}], "+", 
    RowBox[{"2", " ", "a1", " ", 
     SuperscriptBox["a2", "5"]}], "+", 
    SuperscriptBox["a2", "6"], "-", 
    RowBox[{"300", " ", 
     SuperscriptBox["a1", "4"], " ", "a3"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a1", "5"], " ", "a3"}], "+", 
    RowBox[{"400", " ", 
     SuperscriptBox["a1", "3"], " ", "a2", " ", "a3"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a1", "4"], " ", "a2", " ", "a3"}], "-", 
    RowBox[{"200", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"], " ", "a3"}], "+", 
    RowBox[{"400", " ", "a1", " ", 
     SuperscriptBox["a2", "3"], " ", "a3"}], "-", 
    RowBox[{"300", " ", 
     SuperscriptBox["a2", "4"], " ", "a3"}], "-", 
    RowBox[{"2", " ", "a1", " ", 
     SuperscriptBox["a2", "4"], " ", "a3"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a2", "5"], " ", "a3"}], "-", 
    RowBox[{"40000", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"600", " ", 
     SuperscriptBox["a1", "3"], " ", 
     SuperscriptBox["a3", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "4"], " ", 
     SuperscriptBox["a3", "2"]}], "-", 
    RowBox[{"200", " ", 
     SuperscriptBox["a1", "2"], " ", "a2", " ", 
     SuperscriptBox["a3", "2"]}], "-", 
    RowBox[{"40000", " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "-", 
    RowBox[{"200", " ", "a1", " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"600", " ", 
     SuperscriptBox["a2", "3"], " ", 
     SuperscriptBox["a3", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a2", "4"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"600", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "3"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["a1", "3"], " ", 
     SuperscriptBox["a3", "3"]}], "+", 
    RowBox[{"400", " ", "a1", " ", "a2", " ", 
     SuperscriptBox["a3", "3"]}], "+", 
    RowBox[{"600", " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "3"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["a2", "3"], " ", 
     SuperscriptBox["a3", "3"]}], "+", 
    RowBox[{"20000", " ", 
     SuperscriptBox["a3", "4"]}], "-", 
    RowBox[{"300", " ", "a1", " ", 
     SuperscriptBox["a3", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "4"]}], "-", 
    RowBox[{"300", " ", "a2", " ", 
     SuperscriptBox["a3", "4"]}], "-", 
    RowBox[{"2", " ", "a1", " ", "a2", " ", 
     SuperscriptBox["a3", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "4"]}], "-", 
    RowBox[{"300", " ", 
     SuperscriptBox["a3", "5"]}], "+", 
    RowBox[{"2", " ", "a1", " ", 
     SuperscriptBox["a3", "5"]}], "+", 
    RowBox[{"2", " ", "a2", " ", 
     SuperscriptBox["a3", "5"]}], "+", 
    SuperscriptBox["a3", "6"]}]}],
  SequenceForm[
  "    ", 20000 $CellContext`a1^4 - 300 $CellContext`a1^5 + $CellContext`a1^6 - 
   300 $CellContext`a1^4 $CellContext`a2 + 
   2 $CellContext`a1^5 $CellContext`a2 - 
   40000 $CellContext`a1^2 $CellContext`a2^2 + 
   600 $CellContext`a1^3 $CellContext`a2^2 - $CellContext`a1^4 \
$CellContext`a2^2 + 600 $CellContext`a1^2 $CellContext`a2^3 - 
   4 $CellContext`a1^3 $CellContext`a2^3 + 20000 $CellContext`a2^4 - 
   300 $CellContext`a1 $CellContext`a2^4 - $CellContext`a1^2 \
$CellContext`a2^4 - 300 $CellContext`a2^5 + 
   2 $CellContext`a1 $CellContext`a2^5 + $CellContext`a2^6 - 
   300 $CellContext`a1^4 $CellContext`a3 + 
   2 $CellContext`a1^5 $CellContext`a3 + 
   400 $CellContext`a1^3 $CellContext`a2 $CellContext`a3 - 
   2 $CellContext`a1^4 $CellContext`a2 $CellContext`a3 - 
   200 $CellContext`a1^2 $CellContext`a2^2 $CellContext`a3 + 
   400 $CellContext`a1 $CellContext`a2^3 $CellContext`a3 - 
   300 $CellContext`a2^4 $CellContext`a3 - 
   2 $CellContext`a1 $CellContext`a2^4 $CellContext`a3 + 
   2 $CellContext`a2^5 $CellContext`a3 - 
   40000 $CellContext`a1^2 $CellContext`a3^2 + 
   600 $CellContext`a1^3 $CellContext`a3^2 - $CellContext`a1^4 \
$CellContext`a3^2 - 200 $CellContext`a1^2 $CellContext`a2 $CellContext`a3^2 - 
   40000 $CellContext`a2^2 $CellContext`a3^2 - 
   200 $CellContext`a1 $CellContext`a2^2 $CellContext`a3^2 + 
   2 $CellContext`a1^2 $CellContext`a2^2 $CellContext`a3^2 + 
   600 $CellContext`a2^3 $CellContext`a3^2 - $CellContext`a2^4 \
$CellContext`a3^2 + 600 $CellContext`a1^2 $CellContext`a3^3 - 
   4 $CellContext`a1^3 $CellContext`a3^3 + 
   400 $CellContext`a1 $CellContext`a2 $CellContext`a3^3 + 
   600 $CellContext`a2^2 $CellContext`a3^3 - 
   4 $CellContext`a2^3 $CellContext`a3^3 + 20000 $CellContext`a3^4 - 
   300 $CellContext`a1 $CellContext`a3^4 - $CellContext`a1^2 \
$CellContext`a3^4 - 300 $CellContext`a2 $CellContext`a3^4 - 
   2 $CellContext`a1 $CellContext`a2 $CellContext`a3^4 - $CellContext`a2^2 \
$CellContext`a3^4 - 300 $CellContext`a3^5 + 
   2 $CellContext`a1 $CellContext`a3^5 + 
   2 $CellContext`a2 $CellContext`a3^5 + $CellContext`a3^6],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640337079*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b0b3e2d-2bd5-4bac-89e0-1d449e6f8063"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640337081955*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"580978a5-23e3-45aa-b57a-2f3495baa666"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41\"\>"}],
  SequenceForm["i=", 41, " ", "X41"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640337084498*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"64a85afa-2973-4301-a66e-184447bc5d95"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640337115382*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3b620d53-f6ac-470e-a695-11271d0bd024"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42\"\>"}],
  SequenceForm["i=", 42, " ", "X42"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640337118083*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"84aee96d-0f41-4249-bc0b-82f5b91020a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43\"\>"}],
  SequenceForm["i=", 43, " ", "X43"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403371492443`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"336ea870-7bf9-45c6-952a-83a27fb43d78"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44\"\>"}],
  SequenceForm["i=", 44, " ", "X44"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403371860332`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"289b27b8-9724-4845-8811-6fd884e2c584"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45\"\>"}],
  SequenceForm["i=", 45, " ", "X45"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403372192907`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5afb92ff-7515-4914-930d-54fbdf4a4983"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46\"\>"}],
  SequenceForm["i=", 46, " ", "X46"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640337258965*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e63de566-fd17-415c-a1ce-35294149abb0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Property \"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" failed in general,\"\>", 
   "\[InvisibleSpace]", "\<\" but numeric example succeeded.\"\>"}],
  SequenceForm[
  "  Property ", 17, " failed in general,", " but numeric example succeeded."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403374357452`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"589de357-9ec1-49da-a09b-b9ce68f80aee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "47", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47\"\>"}],
  SequenceForm["i=", 47, " ", "X47"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640337444373*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a6f6551b-c2bc-4183-b016-b05580515c83"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "48", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48\"\>"}],
  SequenceForm["i=", 48, " ", "X48"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403375232058`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cd6fe7b7-d72d-44e2-8434-2fe1f9fcc16b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "49", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49\"\>"}],
  SequenceForm["i=", 49, " ", "X49"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403375627413`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c6bab34c-e993-4ea2-aaac-c77fbec1862c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "50", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50\"\>"}],
  SequenceForm["i=", 50, " ", "X50"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640337690248*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3a0bc06f-98d2-4603-a0d4-358936f9a1e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle\"\>"}],
  SequenceForm["i=", 51, " ", "Centroid of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640337776643*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"21f2efad-5c3c-491b-a259-104eb580f476"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle\"\>"}],
  SequenceForm["i=", 52, " ", "Orthocenter of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640337856824*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"347dc0b2-dc9b-4b01-9f93-05ebbf005e47"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle\"\>"}],
  SequenceForm["i=", 53, " ", "Symmedian point of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640338020544*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7ac56204-a562-4090-b9d8-d7d13ba7277d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "54", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nine point inv\"\>"}],
  SequenceForm["i=", 54, " ", "Nine point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640338183134*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0c36f72c-f241-44c9-81bf-bec84020ee54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne inv\"\>"}],
  SequenceForm["i=", 55, " ", "Gergonne inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640338340619*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0539d524-b261-444b-adb2-b2e00909cf8a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640338372109*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b4f16152-a8dc-4fd1-ace1-80f262eabec4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Property \"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" failed in general,\"\>", 
   "\[InvisibleSpace]", "\<\" but numeric example succeeded.\"\>"}],
  SequenceForm[
  "  Property ", 17, " failed in general,", " but numeric example succeeded."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564033838347*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bd1c8b07-1bff-4a19-91fb-ab4b2f3e22f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel inv\"\>"}],
  SequenceForm["i=", 56, " ", "Nagel inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564033841591*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9824ed21-e967-4776-9322-0089666e622b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640338419018*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1acd5cad-1a46-463a-858f-1bf2b6f0cf46"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Property \"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" failed in general,\"\>", 
   "\[InvisibleSpace]", "\<\" but numeric example succeeded.\"\>"}],
  SequenceForm[
  "  Property ", 17, " failed in general,", " but numeric example succeeded."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403384953947`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a845b694-e117-4217-832f-abc950e1ac92"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt inv\"\>"}],
  SequenceForm["i=", 57, " ", "Mittenpunkt inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640338504401*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c877fb61-0400-4215-add6-f22bc4051608"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640338535761*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8632eb06-6a2f-49ac-aceb-7075427d9e30"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Property \"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" failed in general,\"\>", 
   "\[InvisibleSpace]", "\<\" but numeric example succeeded.\"\>"}],
  SequenceForm[
  "  Property ", 17, " failed in general,", " but numeric example succeeded."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403385750017`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8f8b6f0a-c0cc-4e02-bba3-eac9367bd60e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker inv\"\>"}],
  SequenceForm["i=", 58, " ", "Spieker inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640338578052*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0b3b9c7f-79c9-480f-8f9e-e6981d930243"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach inv\"\>"}],
  SequenceForm["i=", 59, " ", "Feuerbach inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640338610618*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"443354ab-5b9f-4010-9738-18acdc23abf4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640338645153*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"db7c44dd-92cb-493d-82d3-63336574eaa5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12 inv\"\>"}],
  
  SequenceForm["i=", 60, " ", "X12 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640338654866*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f4caed17-940d-47cd-9cf0-cf9bca50a28f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "61", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point inv\"\>"}],
  SequenceForm["i=", 61, " ", "1st Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403387037687`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"590a8cb2-ff33-4fd9-9c22-8325cd624897"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "62", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point inv\"\>"}],
  SequenceForm["i=", 62, " ", "2nd Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640339157179*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7d89116d-640d-4019-a20e-65bed72cea3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point inv\"\>"}],
  SequenceForm["i=", 63, " ", "Crucial point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640339571093*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9c205daa-cc06-41fa-9e34-c7990f20769f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "64", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point inv\"\>"}],
  SequenceForm["i=", 64, " ", "De Longchamps point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564033960189*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f1c1f1a1-392b-4924-8d3b-add3b3e5265a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point inv\"\>"}],
  SequenceForm["i=", 65, " ", "Schiffler point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403398702383`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0eb70a86-bcd9-4242-afa3-81bf25344d66"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Property \"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" failed in general,\"\>", 
   "\[InvisibleSpace]", "\<\" but numeric example succeeded.\"\>"}],
  SequenceForm[
  "  Property ", 17, " failed in general,", " but numeric example succeeded."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640339941486*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"722f14ec-3e7f-46d0-be92-32243a2d02b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "66", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point inv\"\>"}],
  SequenceForm["i=", 66, " ", "Exeter point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403399439507`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0439cfff-627a-4f9c-882d-cfc7605f3cc7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point inv\"\>"}],
  SequenceForm["i=", 67, " ", "far out point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403400215816`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"13c1094f-b8db-400e-a432-742e6e7cb479"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "68", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24 inv\"\>"}],
  
  SequenceForm["i=", 68, " ", "X24 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640340126004*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"45d9d331-7799-4d4f-ac50-22dff6dc140a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25 inv\"\>"}],
  
  SequenceForm["i=", 69, " ", "X25 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640340249385*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ecdd4227-1969-451d-ad35-12530d671a1f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "70", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle inv\"\>"}],
  SequenceForm["i=", 70, " ", "Circumcenter of tangential triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640340284102*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e46df4a6-a241-4cc9-87b1-a57df066eac8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27 inv\"\>"}],
  
  SequenceForm["i=", 71, " ", "X27 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640340563696*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4271adaf-d09f-458d-b148-c7da1009eba6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28 inv\"\>"}],
  
  SequenceForm["i=", 72, " ", "X28 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640340600115*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"44da8bea-34fd-4a3e-bc66-bb5be15e2a1c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "73", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29 inv\"\>"}],
  
  SequenceForm["i=", 73, " ", "X29 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403406353273`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a1706af9-12b4-4f95-8aae-5e852e217376"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30 inv\"\>"}],
  
  SequenceForm["i=", 74, " ", "X30 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640340677205*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eb4b05ea-964d-4772-aabf-6600325c9de3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point inv\"\>"}],
  SequenceForm["i=", 75, " ", "2nd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640340940751*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b7c76995-cb94-429c-9485-0976f2beaedc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640340974125*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d6a9fa5a-fc17-492f-acb1-b50e74f7e46f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point inv\"\>"}],
  SequenceForm["i=", 76, " ", "3rd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640340976521*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34453a0e-a328-4f40-a50a-6203466f996c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564034097847*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7e392964-3d3b-4726-bcab-8c66548487ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "77", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33 inv\"\>"}],
  
  SequenceForm["i=", 77, " ", "X33 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640340980378*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7b6f4d01-15a8-4efd-a8d0-d1ce13f313e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34 inv\"\>"}],
  
  SequenceForm["i=", 78, " ", "X34 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341025524*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7a043a46-68d9-4e98-ae3d-9b229fce3d46"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35 inv\"\>"}],
  
  SequenceForm["i=", 79, " ", "X35 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341059298*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d49a7ed0-8f2d-41b0-b912-5f15c0dfc218"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36 inv\"\>"}],
  
  SequenceForm["i=", 80, " ", "X36 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341111247*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b394b7cc-62bc-4f95-a68d-d333321d4b36"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37 inv\"\>"}],
  
  SequenceForm["i=", 81, " ", "X37 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341168294*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e3d4e99b-c86a-4adc-aaef-fc4b19938c70"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38 inv\"\>"}],
  
  SequenceForm["i=", 82, " ", "X38 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341203621*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8e679355-71fb-425b-a4d4-f60593c9f75b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint inv\"\>"}],
  SequenceForm["i=", 83, " ", "Brocard midpoint inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341246159*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"79ff6ae6-4029-4a36-8ca6-c9d61d0bcdad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "84", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40 inv\"\>"}],
  
  SequenceForm["i=", 84, " ", "X40 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341280686*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9f046a07-10fa-40db-b9d0-4483a234cd78"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41 inv\"\>"}],
  
  SequenceForm["i=", 85, " ", "X41 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341404808*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6d6228c8-e3ad-420e-b045-b062fd126a72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341439394*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5fcdb67c-e11a-4440-ab9c-42c967666934"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42 inv\"\>"}],
  
  SequenceForm["i=", 86, " ", "X42 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341441884*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a22e6a5d-12ff-465d-abd5-3cddad1592a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "87", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43 inv\"\>"}],
  
  SequenceForm["i=", 87, " ", "X43 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341478869*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4d30c886-3800-452d-9016-03f1b1b058c6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44 inv\"\>"}],
  
  SequenceForm["i=", 88, " ", "X44 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341535088*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"08709555-da0e-49bd-8604-6338a42730ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45 inv\"\>"}],
  
  SequenceForm["i=", 89, " ", "X45 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341569948*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e1052810-b7ba-4276-b278-13a32b92c513"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "90", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46 inv\"\>"}],
  
  SequenceForm["i=", 90, " ", "X46 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341611803*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"65483eb6-1aab-4791-9c1b-5b98f576d46a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "91", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47 inv\"\>"}],
  
  SequenceForm["i=", 91, " ", "X47 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341749173*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3660cedf-caf7-406d-ac6f-8188b7e184d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "92", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48 inv\"\>"}],
  
  SequenceForm["i=", 92, " ", "X48 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640341904303*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"870320dd-ceb2-4b24-9c06-9a326c646031"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "93", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49 inv\"\>"}],
  
  SequenceForm["i=", 93, " ", "X49 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403419751883`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2351bf37-29a8-4398-a485-cf08a89d7249"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50 inv\"\>"}],
  
  SequenceForm["i=", 94, " ", "X50 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403422495127`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dbce596a-4136-40d8-b6a5-6b280b1da3c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle inv\"\>"}],
  SequenceForm["i=", 95, " ", "Centroid of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640342417891*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"851e63d5-0431-420e-b2e3-de20cb359fef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "96", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle inv\"\>"}],
  SequenceForm["i=", 96, " ", "Orthocenter of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640342556815*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"45530a8c-19f6-4824-85a2-1d73670a2eab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "97", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle inv\"\>"}],
  SequenceForm["i=", 97, " ", "Symmedian point of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640342910005*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f3e36d59-0d29-40b9-b7fe-d716dee2b4ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Tarry point\"\>"}],
  SequenceForm["i=", 98, " ", "Tarry point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343070224*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"95b2a8cb-6ea8-4707-96f1-3bd0c8029bfa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Steiner point\"\>"}],
  SequenceForm["i=", 99, " ", "Steiner point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343187151*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9649ea6a-e933-4df2-aa65-586e039f6dfc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X100\"\>"}],
  SequenceForm["i=", 100, " ", "X100"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343220389*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a5147702-1062-4205-93f7-ccaf5e7b908f"],

Cell[BoxData["\<\"  --> Some pairs of edges have same sum.\"\>"], "Print",
 CellChangeTimes->{3.805640343231885*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"99425815-a1a7-4dc1-9e84-a1baa24fba8e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "101", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X101\"\>"}],
  SequenceForm["i=", 101, " ", "X101"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343265868*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"93e281f7-50d8-4fe7-98c0-fc16f4e6924a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "102", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X102\"\>"}],
  SequenceForm["i=", 102, " ", "X102"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343268382*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9b7a3915-b5a4-4912-bf2c-6f4c4f01c3d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "103", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X103\"\>"}],
  SequenceForm["i=", 103, " ", "X103"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403433416557`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4f30e02d-428a-4982-8d85-cc1606c46d46"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "104", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X104\"\>"}],
  SequenceForm["i=", 104, " ", "X104"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343377252*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"77db6406-e088-4a72-ba38-fa235d61d46f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "105", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X105\"\>"}],
  SequenceForm["i=", 105, " ", "X105"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564034341083*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8697c825-5aa1-4d47-a96f-9f878cc8ebbe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "106", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X106\"\>"}],
  SequenceForm["i=", 106, " ", "X106"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564034344575*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c82befcc-7aca-4397-88a1-e932b20cb8eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "107", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X107\"\>"}],
  SequenceForm["i=", 107, " ", "X107"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343454772*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"300a26a3-0ba2-422f-a24a-9e34fd3b58de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "108", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X108\"\>"}],
  SequenceForm["i=", 108, " ", "X108"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343491427*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b85c4269-d1fe-4832-83c0-31bfbfcdc493"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "109", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X109\"\>"}],
  SequenceForm["i=", 109, " ", "X109"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343539712*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7e050477-9044-4ff6-a130-129a5504a8f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "110", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X110\"\>"}],
  SequenceForm["i=", 110, " ", "X110"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343577663*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"358c95b6-a36e-4f61-b252-023c9bccdcd4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "111", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X111\"\>"}],
  SequenceForm["i=", 111, " ", "X111"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403436327353`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1b1207c7-6dd1-44a3-ac61-b7e3700f48af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "112", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X112\"\>"}],
  SequenceForm["i=", 112, " ", "X112"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343665205*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a9f32ef1-55a9-4fee-a331-736294e677bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "113", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X113\"\>"}],
  SequenceForm["i=", 113, " ", "X113"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403436989937`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f41a28c8-e4a6-4cb5-a852-0abb4ee0ff60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "114", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X114\"\>"}],
  SequenceForm["i=", 114, " ", "X114"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564034373316*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cc7e2850-6585-4310-9de3-d66c57d3797b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "115", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X115\"\>"}],
  SequenceForm["i=", 115, " ", "X115"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343742402*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a786b6dd-6f9c-4b2d-ad28-eeaa611ea37a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "116", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X116\"\>"}],
  SequenceForm["i=", 116, " ", "X116"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403437738657`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ae42ecdb-d7cd-4b42-b4aa-c82a5f606840"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "117", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X117\"\>"}],
  SequenceForm["i=", 117, " ", "X117"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343811593*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b4ee6e8c-a8bc-414b-b53a-23e6e9e01a99"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "118", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r-power point\"\>"}],
  SequenceForm["i=", 118, " ", "r-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403438476973`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"046303e0-fd23-4a57-8039-3941c9b1701f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343882082*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0f3314eb-bac6-430b-9e65-01a0a6062eaf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "119", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r2-power point\"\>"}],
  SequenceForm["i=", 119, " ", "r2-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343884486*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ff7a3613-7f63-42a5-af19-580daa472360"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "120", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r3-power point\"\>"}],
  SequenceForm["i=", 120, " ", "r3-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564034391707*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"024d774b-c6af-4082-845a-152cd712bd8e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "121", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z1\"\>"}],
  SequenceForm["i=", 121, " ", "Z1"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640343950452*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2a1a24fb-8838-4c96-a731-c4b623b0561d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "122", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z2\"\>"}],
  SequenceForm["i=", 122, " ", "Z2"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640344007139*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ac967315-932e-4465-99dd-be21c357e701"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "123", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z3\"\>"}],
  SequenceForm["i=", 123, " ", "Z3"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640344045062*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c5b09e50-a122-4fde-a80c-3965da633798"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564034408119*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bf336c9f-fd66-4939-bd1a-b8c87b155dcb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "124", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z4\"\>"}],
  SequenceForm["i=", 124, " ", "Z4"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403441152477`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a97e196c-40b7-4d6c-9e26-d47717137589"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "125", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z5\"\>"}],
  SequenceForm["i=", 125, " ", "Z5"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564034414815*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2cadf0b4-22a0-4bfb-b673-043160d84a54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "126", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z6\"\>"}],
  SequenceForm["i=", 126, " ", "Z6"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640344216425*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4c49ffac-44ca-4237-8570-e08ba6830d75"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "127", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z7\"\>"}],
  SequenceForm["i=", 127, " ", "Z7"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640344270252*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ab55da03-d16d-4ac4-9ca9-f881e435081b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "128", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z8\"\>"}],
  SequenceForm["i=", 128, " ", "Z8"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640344336543*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8b9f76b0-e3b1-4ef5-91bc-05d34335eef1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "129", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r4-power point\"\>"}],
  SequenceForm["i=", 129, " ", "r4-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640344374248*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"25740787-1860-462f-842d-6e35e54a3ebf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640344411104*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a127f724-7a6d-4dfe-9ced-ff812899737f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640344419153*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f00b77cd-206f-4995-9caa-32688729405e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640381225296*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"930c0e1b-0c86-41dc-a8f5-1e45e222febe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "130", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"arbitrary center\"\>"}],
  SequenceForm["i=", 130, " ", "arbitrary center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640381228244*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"308f8ee3-50a9-49d0-86ee-7e71049a02d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "131", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"areal center\"\>"}],
  SequenceForm["i=", 131, " ", "areal center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640381261093*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"acbfb327-cf09-4a0e-b5e4-78ec1f84687f"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.805640381934917*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1455ff7d-1291-4c8d-851a-f11e5326b329"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CASE \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", "\<\"Isodynamic Tetrahedron\"\>"}],
  SequenceForm["CASE ", 4, ": ", "Isodynamic Tetrahedron"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403819372272`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aa574963-d9da-486f-b382-b7cb14fe587e"],

Cell[BoxData["\<\"------\"\>"], "Print",
 CellChangeTimes->{3.805640381939004*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e937d4d4-125c-43aa-894c-385b6ffc12c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>"}],
  SequenceForm["i=", 1, " ", "incenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640381946603*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8c2d7371-4bbf-410b-9878-0b001ee96f45"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"100", " ", "a1"}], ",", 
     RowBox[{"100", " ", "a2"}], ",", 
     RowBox[{"100", " ", "a3"}], ",", 
     RowBox[{"a1", " ", "a2", " ", "a3"}]}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {
   100 $CellContext`a1, 100 $CellContext`a2, 
    100 $CellContext`a3, $CellContext`a1 $CellContext`a2 $CellContext`a3}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640381979816*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d6714415-f699-4b8d-9441-df3192941e9b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640381988661*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1a3c89d1-758c-4774-8842-bcde49e8b5f0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640381991106*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6d901acf-1fee-4f7c-98f4-7824c7c05c45"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>"}],
  SequenceForm["i=", 2, " ", "centroid"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640382022553*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4406555b-2eb4-446c-be4f-d8e987be74c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Faces are parallel.\"\>"}],
  SequenceForm["  ", "Faces are parallel."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403820248957`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6676e934-5cfb-444d-83e7-28b04629a8da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}],
  SequenceForm["    Coordinates of intersection point:  ", {1, 1, 1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640382026751*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6ae7110d-5de6-4d36-8d9f-1392f48550a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "centroid", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640382028582*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"18135d76-542d-4a54-ba5b-d34bc1140295"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "1", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 1, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403820306273`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"63a41945-b3c0-4352-921a-6e71c35ab3ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564038203305*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1fda6d6b-9c0c-4e35-8846-e98de5f646e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isodynamic.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isodynamic."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403820351267`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f635b5e2-65aa-4feb-a5bf-1fd469166409"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403820371313`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f5c83972-e598-4630-b0c9-1b8df2882628"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640382039007*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"74ccf150-3d5e-44cf-9360-410d56b4cf20"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra are similar.\"\>"}],
  SequenceForm["  ", "Tetrahedra are similar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640382040821*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2029b766-daf0-4446-bf19-169548d0dee8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403820428267`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"54207251-be88-4d09-9420-fedea06a9bfe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "Euler point",
    "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640382074499*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"57be43f7-a746-46ec-8aca-d4c7afa9966b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Central Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["2", "3"], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Central Monge point", " lies on reference Euler line (at ", 
   Rational[2, 3], ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403822277107`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bcbc918f-aa7e-4c70-8ab4-1b3330ddce9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Central Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["8", "9"], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Central Euler point", " lies on reference Euler line (at ", 
   Rational[8, 9], ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403824704514`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"59f7470a-d25d-4881-9bfd-6d44a8d35abd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Reference \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" lies on central Euler line (at \"\>", 
   "\[InvisibleSpace]", "4", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    Reference ", "circumcenter", " lies on central Euler line (at ", 4, 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640382545394*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"62fe37dd-ed53-464f-b94a-e9ba4ee0f529"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Reference \"\>", 
   "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on central Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    Reference ", "Monge point", " lies on central Euler line (at ", -2, 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640382648581*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"266a1e90-481e-49f7-b590-7bb1ad0d26b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640382687826*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"59b96ad1-df23-4cb0-b3b4-2f8985a182dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>"}],
  SequenceForm["i=", 3, " ", "circumcenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640382690875*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"70802b57-7920-4285-9dbf-7df1bfd637d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm[
  "    Point coincides with ", "circumcenter", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383378069*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a0512586-51bb-4880-9cb0-c3ef9741624d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "0", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 0, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383413712*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"feeaea25-7dc4-4956-aced-ce69c027974f"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.805640383416815*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"30a2d48b-18e0-4856-81e1-39c349a67649"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a1", "2"], " ", 
    SuperscriptBox["a2", "2"], " ", 
    SuperscriptBox["a3", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "5000"}], " ", 
       SuperscriptBox["a1", "2"]}], "-", 
      RowBox[{"5000", " ", 
       SuperscriptBox["a2", "2"]}], "-", 
      RowBox[{"5000", " ", 
       SuperscriptBox["a3", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "2"]}]}], ")"}]}]}],
  SequenceForm[
  "    ", $CellContext`a1^2 $CellContext`a2^2 $CellContext`a3^2 ((-5000) \
$CellContext`a1^2 - 5000 $CellContext`a2^2 - 
    5000 $CellContext`a3^2 + $CellContext`a1^2 $CellContext`a2^2 \
$CellContext`a3^2)],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383419059*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a154508c-49ba-4154-aff3-5ba887e4a27a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383421349*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1f02b1e3-36c6-4ede-a1d6-c0cc67d0f3a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"orthocenter\"\>"}],
  SequenceForm["i=", 4, " ", "orthocenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403834236927`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"de01cd3c-b380-4599-a05a-e1d8d72f2cbf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"nine point center\"\>"}],
  SequenceForm["i=", 5, " ", "nine point center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383480398*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e2527b12-4fe3-4886-af37-78d1e0ac4800"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"symmedian point\"\>"}],
  SequenceForm["i=", 6, " ", "symmedian point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383574481*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1631eb76-980e-4e45-9b35-7cfc08066e95"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"10000", " ", 
      SuperscriptBox["a1", "2"]}], ",", 
     RowBox[{"10000", " ", 
      SuperscriptBox["a2", "2"]}], ",", 
     RowBox[{"10000", " ", 
      SuperscriptBox["a3", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a1", "2"], " ", 
      SuperscriptBox["a2", "2"], " ", 
      SuperscriptBox["a3", "2"]}]}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {
   10000 $CellContext`a1^2, 10000 $CellContext`a2^2, 
    10000 $CellContext`a3^2, $CellContext`a1^2 $CellContext`a2^2 \
$CellContext`a3^2}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383607583*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5e10d3ef-522b-4871-b24f-42b46cf3ef66"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383610375*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0964ed8b-d867-48e9-82b5-fe80635fa792"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403836123734`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"22f9d2ef-344c-4e79-8ef9-d820e4ed9331"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne point\"\>"}],
  SequenceForm["i=", 7, " ", "Gergonne point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383621244*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4472ff8c-2de6-46f9-bc08-eb9872167a41"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel point\"\>"}],
  SequenceForm["i=", 8, " ", "Nagel point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403836906347`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"efa3054c-d141-45c0-9856-b70d9f88b906"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt\"\>"}],
  SequenceForm["i=", 9, " ", "Mittenpunkt"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383725965*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b4bdae1e-537e-4096-a345-18e63bc0ee50"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker center\"\>"}],
  SequenceForm["i=", 10, " ", "Spieker center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564038376052*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5a8631c6-660c-466f-a563-1e3942d99018"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383762959*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ea8d971a-ed15-4188-b2a7-7d636b118b8e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach point\"\>"}],
  SequenceForm["i=", 11, " ", "Feuerbach point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383765697*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cfa913e8-d226-4b60-abc0-a6ec08275c07"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Points are coplanar.\"\>"}],
  
  SequenceForm["  ", "Points are coplanar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383813941*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e17964d0-6ac0-4661-8223-d90282475526"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12\"\>"}],
  SequenceForm["i=", 12, " ", "X12"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383847849*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ed9f08b8-27c2-47a4-9281-320eaec0897c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st isogonic center (Fermat point)\"\>"}],
  SequenceForm["i=", 13, " ", "1st isogonic center (Fermat point)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640383892519*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"281e53ee-cc29-402c-831f-fe969628350e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isogonic center\"\>"}],
  SequenceForm["i=", 14, " ", "2nd Isogonic center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640384397498*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"639d795b-b530-4228-8274-d72b6e587c84"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Isodynamic point\"\>"}],
  SequenceForm["i=", 15, " ", "1st Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640384832213*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3cb8670f-88e2-437f-a693-f35d965b3fae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isodynamic point\"\>"}],
  SequenceForm["i=", 16, " ", "2nd Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640385199651*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eb616269-095f-4f0f-8c51-519255427fa8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point\"\>"}],
  SequenceForm["i=", 17, " ", "1st Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640385622943*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cbabcd34-785a-496d-862c-499263a4c691"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "18", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point\"\>"}],
  SequenceForm["i=", 18, " ", "2nd Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640386121544*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dc4466a2-6409-4e43-bc7f-d5c432d41896"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point\"\>"}],
  SequenceForm["i=", 19, " ", "Crucial point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640386557003*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d3c2edc8-d99c-488a-81e0-cabf62d48680"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point\"\>"}],
  SequenceForm["i=", 20, " ", "De Longchamps point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640386631279*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8d8a3a52-bb27-4731-a775-e7cf39f83fa1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point\"\>"}],
  SequenceForm["i=", 21, " ", "Schiffler point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640386748858*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a923d036-c0f2-4547-afcc-7fe0fdf87588"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "22", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point\"\>"}],
  SequenceForm["i=", 22, " ", "Exeter point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403868115873`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b08b96b3-b796-4da9-bff8-510560f9b8fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point\"\>"}],
  SequenceForm["i=", 23, " ", "far out point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640386896244*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8322b90c-4498-43c0-84ad-0fceea0e8cb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "24", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24\"\>"}],
  SequenceForm["i=", 24, " ", "X24"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640386995969*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c86549c2-ae53-4432-8d6a-9ff2eaf418c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25\"\>"}],
  SequenceForm["i=", 25, " ", "X25"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640387105715*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"71cbaacd-77b5-4967-bc68-26c84b05710e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "26", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle\"\>"}],
  SequenceForm["i=", 26, " ", "Circumcenter of tangential triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640387173296*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"044c2ba7-6d37-471e-a3d6-3c60a91e531f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27\"\>"}],
  SequenceForm["i=", 27, " ", "X27"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640387309207*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1f56ccf4-8004-406d-9c95-a49a1be704f2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28\"\>"}],
  SequenceForm["i=", 28, " ", "X28"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403874221487`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"076cb4b3-050c-47ce-b011-3a9500cddcce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "29", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29\"\>"}],
  SequenceForm["i=", 29, " ", "X29"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640387530389*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dc73bcee-6ce7-4f2a-aed1-4571f5f1c554"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30\"\>"}],
  SequenceForm["i=", 30, " ", "X30"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640387617118*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2ad9ec68-55de-4276-af27-6a85b976f420"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640387655191*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"926a02bb-3fb0-4494-b4c9-8cd3e0de2c49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640387663333*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9e3eb083-0d47-400c-9793-dfb324a361c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403887929688`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"823a6740-1fe5-4fb7-b6cf-1c0a10dbd2af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point\"\>"}],
  SequenceForm["i=", 31, " ", "2nd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640388795624*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ed811706-9d5a-4162-a5fb-2f25a3e793c2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1000000", " ", 
      SuperscriptBox["a1", "3"]}], ",", 
     RowBox[{"1000000", " ", 
      SuperscriptBox["a2", "3"]}], ",", 
     RowBox[{"1000000", " ", 
      SuperscriptBox["a3", "3"]}], ",", 
     RowBox[{
      SuperscriptBox["a1", "3"], " ", 
      SuperscriptBox["a2", "3"], " ", 
      SuperscriptBox["a3", "3"]}]}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {
   1000000 $CellContext`a1^3, 1000000 $CellContext`a2^3, 
    1000000 $CellContext`a3^3, $CellContext`a1^3 $CellContext`a2^3 \
$CellContext`a3^3}],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403888275757`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"023892a5-5808-4283-9524-2803de5023a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640388836883*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bc10996d-a8f3-4e3a-af2f-66dc23ddb19a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403888394737`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a56a8143-2372-4d0b-b015-0359db1296b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point\"\>"}],
  SequenceForm["i=", 32, " ", "3rd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403888714733`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"80af0fbc-91a5-4210-a01c-2586fe744c63"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"100000000", " ", 
      SuperscriptBox["a1", "4"]}], ",", 
     RowBox[{"100000000", " ", 
      SuperscriptBox["a2", "4"]}], ",", 
     RowBox[{"100000000", " ", 
      SuperscriptBox["a3", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a1", "4"], " ", 
      SuperscriptBox["a2", "4"], " ", 
      SuperscriptBox["a3", "4"]}]}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {
   100000000 $CellContext`a1^4, 100000000 $CellContext`a2^4, 
    100000000 $CellContext`a3^4, $CellContext`a1^4 $CellContext`a2^4 \
$CellContext`a3^4}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640388874058*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fd66e8ec-17a4-4be5-b90f-6e9dea0cdffa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640388881878*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8ec7a40d-2a9c-4544-89fa-a90277d7752e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640388915586*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c115c927-2123-4da5-8e9d-7161139da925"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "33", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33\"\>"}],
  SequenceForm["i=", 33, " ", "X33"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403889189253`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d49f4c0b-e1b1-4e4a-b5a1-611e354cb04d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34\"\>"}],
  SequenceForm["i=", 34, " ", "X34"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640388990847*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a996bbba-0508-4c41-b276-5ce8108a1645"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35\"\>"}],
  SequenceForm["i=", 35, " ", "X35"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403890767813`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a6345deb-5b0f-4e0b-ac90-7f01688f4ec8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36\"\>"}],
  SequenceForm["i=", 36, " ", "X36"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389158046*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2e249d5b-956b-4efc-ad2f-da9c22563b97"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37\"\>"}],
  SequenceForm["i=", 37, " ", "X37"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389241498*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a38e8406-18e5-48e1-ba4a-9a15df1b984e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403892739162`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"27c69bd7-2d0b-4386-8fe3-b1e989b5318f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38\"\>"}],
  SequenceForm["i=", 38, " ", "X38"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389276463*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"726eb77a-3740-453e-ab59-9ec16b9501b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403893103657`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6a87e381-c7e7-44e0-a89b-d382df3e9fe3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint\"\>"}],
  SequenceForm["i=", 39, " ", "Brocard midpoint"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403893128643`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2d2e8b4d-616f-4ccf-a87e-e6b9c7535ea1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389314906*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8675a82c-96b0-4352-b23c-7da35faa9db9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40\"\>"}],
  SequenceForm["i=", 40, " ", "X40"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389323545*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"32626644-211d-4791-a27b-7d25f88677ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41\"\>"}],
  SequenceForm["i=", 41, " ", "X41"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389438624*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"686f0185-5ab2-4c0d-8f78-1ee04defbdd0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42\"\>"}],
  SequenceForm["i=", 42, " ", "X42"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389484045*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a2ea0a6a-20a0-44db-982f-ea722aef502d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389517178*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"221ee0e7-c322-4607-9d68-05c7a32784af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43\"\>"}],
  SequenceForm["i=", 43, " ", "X43"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389519799*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b4c8e027-710f-45a5-ac2b-8fe2549a856d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44\"\>"}],
  SequenceForm["i=", 44, " ", "X44"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389559331*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f10c3341-60b9-4b4c-8402-34dc895a6e62"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Points are coplanar.\"\>"}],
  
  SequenceForm["  ", "Points are coplanar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403895927134`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b95d83c7-cd1d-4c5c-b057-57ee95c7d5de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45\"\>"}],
  SequenceForm["i=", 45, " ", "X45"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389628195*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f82f88c6-6679-478e-813c-46df35338868"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46\"\>"}],
  SequenceForm["i=", 46, " ", "X46"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389663101*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d72e8832-d7ae-48c4-adbb-ea06f1604347"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "47", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47\"\>"}],
  SequenceForm["i=", 47, " ", "X47"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389768012*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4ffbbca8-bee7-426e-9494-e97d89e1d9b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "48", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48\"\>"}],
  SequenceForm["i=", 48, " ", "X48"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403898604727`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"04bf3467-ef3f-4914-bbe8-a88e492d5281"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "49", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49\"\>"}],
  SequenceForm["i=", 49, " ", "X49"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640389936284*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8532417c-ce64-4477-b503-05c1ff204b78"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "50", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50\"\>"}],
  SequenceForm["i=", 50, " ", "X50"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640390038374*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e1732bc4-3452-4910-b016-a5c8dd54dbae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle\"\>"}],
  SequenceForm["i=", 51, " ", "Centroid of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403901610126`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e644be14-b1f2-4b22-9090-944b4475dbe9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle\"\>"}],
  SequenceForm["i=", 52, " ", "Orthocenter of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640390236644*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"72618fe0-e1b3-4fb5-ab55-0454e6d98235"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle\"\>"}],
  SequenceForm["i=", 53, " ", "Symmedian point of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640390336534*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"61c3542c-6a8c-471c-a23e-b87a5828331c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "54", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nine point inv\"\>"}],
  SequenceForm["i=", 54, " ", "Nine point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403904451733`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d547c924-b49f-46fd-976d-fbb873c851b2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne inv\"\>"}],
  SequenceForm["i=", 55, " ", "Gergonne inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640390524795*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fe9959c5-fac8-413e-81b8-f35ae2a8c4d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel inv\"\>"}],
  SequenceForm["i=", 56, " ", "Nagel inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403905736523`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4103b642-7ec2-401c-ba19-053faf45fa55"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt inv\"\>"}],
  SequenceForm["i=", 57, " ", "Mittenpunkt inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403906317997`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ecf610ee-a3a1-4527-99a4-259f92b615cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker inv\"\>"}],
  SequenceForm["i=", 58, " ", "Spieker inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640390672985*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9aa5e729-ea88-4fe7-8c96-38e77b468fda"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640390704802*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b77e3ae8-d024-4e89-a068-1e7ba3547df0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach inv\"\>"}],
  SequenceForm["i=", 59, " ", "Feuerbach inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640390707712*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"504dace4-dd1e-4057-b461-a895e4eb2e69"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12 inv\"\>"}],
  
  SequenceForm["i=", 60, " ", "X12 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640390777897*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2c41018b-3eb3-4a41-9f6e-899485b3a924"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "61", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point inv\"\>"}],
  SequenceForm["i=", 61, " ", "1st Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640390843424*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"201c721b-e057-4249-95ef-1f3c769ccd43"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "62", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point inv\"\>"}],
  SequenceForm["i=", 62, " ", "2nd Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640391279027*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7d35c835-bf9f-43a9-80f8-2526a14b875e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point inv\"\>"}],
  SequenceForm["i=", 63, " ", "Crucial point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640391663066*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1e21a8a9-9e4e-43cf-bd8e-19e3dbe23c11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "64", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point inv\"\>"}],
  SequenceForm["i=", 64, " ", "De Longchamps point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403917327337`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c8f4fa3e-c219-414a-9a31-2beee928df98"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point inv\"\>"}],
  SequenceForm["i=", 65, " ", "Schiffler point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640391873402*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7b2719af-a2b1-474c-b4f1-0701f1ccc8bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "66", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point inv\"\>"}],
  SequenceForm["i=", 66, " ", "Exeter point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564039191602*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"352f681d-9838-48de-86b5-bbd6e46ef5ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point inv\"\>"}],
  SequenceForm["i=", 67, " ", "far out point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392002719*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b3636c75-d9f8-4cd4-8f8a-e86f3e9b7da8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "68", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24 inv\"\>"}],
  
  SequenceForm["i=", 68, " ", "X24 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392103755*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"78f1773d-94e2-4f86-81de-bc50b58c9a40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25 inv\"\>"}],
  
  SequenceForm["i=", 69, " ", "X25 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392236558*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7800459c-7f65-402a-a6ba-ac2d961c101c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "70", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle inv\"\>"}],
  SequenceForm["i=", 70, " ", "Circumcenter of tangential triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392280484*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d7537a8d-d0d4-4006-ba04-8fed89263e2d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27 inv\"\>"}],
  
  SequenceForm["i=", 71, " ", "X27 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403924205313`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d49482ed-a7b1-4132-99a9-db669050973f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28 inv\"\>"}],
  
  SequenceForm["i=", 72, " ", "X28 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392496667*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1f58ff9b-3701-479b-a5eb-413e182c1c4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "73", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29 inv\"\>"}],
  
  SequenceForm["i=", 73, " ", "X29 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392555558*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8a7e2dab-748d-43b6-b334-330db3ff4982"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30 inv\"\>"}],
  
  SequenceForm["i=", 74, " ", "X30 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392640822*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8c631ba4-adc6-4101-92b4-64f2467635b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point inv\"\>"}],
  SequenceForm["i=", 75, " ", "2nd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392750537*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a369ae15-8408-4ba3-8cfc-625fd225017f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a2", " ", "a3"}], ",", 
     RowBox[{"a1", " ", "a3"}], ",", 
     RowBox[{"a1", " ", "a2"}], ",", "100"}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {$CellContext`a2 \
$CellContext`a3, $CellContext`a1 $CellContext`a3, $CellContext`a1 \
$CellContext`a2, 100}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392782579*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aaf5ca31-f70a-4785-8aa7-444ce6bd4770"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392791696*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0fae3041-b9a5-4b2d-a3f7-2270cf730a79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392794259*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"403b7c6e-136c-4dd2-b6f6-1a3f9430ba0d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point inv\"\>"}],
  SequenceForm["i=", 76, " ", "3rd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403927963877`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"13c6205f-5ac7-4c79-bd00-50ca11be1c10"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a2", "2"], " ", 
      SuperscriptBox["a3", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a1", "2"], " ", 
      SuperscriptBox["a3", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a1", "2"], " ", 
      SuperscriptBox["a2", "2"]}], ",", "10000"}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {$CellContext`a2^2 \
$CellContext`a3^2, $CellContext`a1^2 $CellContext`a3^2, $CellContext`a1^2 \
$CellContext`a2^2, 10000}],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403928279943`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1cea9922-42df-44d1-ab8e-a7f117509166"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403928375607`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"35b84d55-5832-4906-bb63-e5bb6f5c11ce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392840171*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d0adbaab-cef9-4aa8-9ba7-aadc67456fbb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "77", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33 inv\"\>"}],
  
  SequenceForm["i=", 77, " ", "X33 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392842297*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f2c1962f-b09e-4311-83de-a2ff559e8040"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34 inv\"\>"}],
  
  SequenceForm["i=", 78, " ", "X34 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392928678*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"72bb595a-de37-4111-a994-7fc183486def"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35 inv\"\>"}],
  
  SequenceForm["i=", 79, " ", "X35 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640392988969*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bd7d9508-c263-4660-a61f-51caab60388d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36 inv\"\>"}],
  
  SequenceForm["i=", 80, " ", "X36 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393104455*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0d3f7765-7b59-4c65-82af-f7fb2e308ad8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37 inv\"\>"}],
  
  SequenceForm["i=", 81, " ", "X37 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393177389*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2e5f21ee-6b01-4215-bcf7-06b99ad4f8b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393210195*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b44535dc-a0ee-4633-ba22-fa855d2e46fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38 inv\"\>"}],
  
  SequenceForm["i=", 82, " ", "X38 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403932134447`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"eddb9581-0104-4790-b0f1-974389c0483d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403932761793`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3bf6dfb8-f21e-4eb9-b160-ea5515e47e50"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint inv\"\>"}],
  SequenceForm["i=", 83, " ", "Brocard midpoint inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393278658*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"824b448a-2950-4a5c-86e8-9397179e1947"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393280718*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"63f6e50e-3c0c-4c70-a534-3e7ab60931e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "84", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40 inv\"\>"}],
  
  SequenceForm["i=", 84, " ", "X40 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393289624*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8603e821-419e-4275-b329-760501385e55"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41 inv\"\>"}],
  
  SequenceForm["i=", 85, " ", "X41 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393410941*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6095e45e-33ce-4390-8e75-1d2e653cf422"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42 inv\"\>"}],
  
  SequenceForm["i=", 86, " ", "X42 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393471393*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fc900a4c-394c-46f4-a3fd-bfe5dade150f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393505293*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5150d744-e330-4ae4-9be0-66d57428b245"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "87", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43 inv\"\>"}],
  
  SequenceForm["i=", 87, " ", "X43 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393508642*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6c21f9aa-a321-44a7-ba48-8592f6cac070"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44 inv\"\>"}],
  
  SequenceForm["i=", 88, " ", "X44 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393542828*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b2a6fd35-3362-47d4-9da7-eb34f0163007"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45 inv\"\>"}],
  
  SequenceForm["i=", 89, " ", "X45 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393594536*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b22dfe2f-be31-4ff0-8cf7-81f63ddcc92e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "90", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46 inv\"\>"}],
  
  SequenceForm["i=", 90, " ", "X46 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564039365098*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5fd8de5b-d8e9-4ed9-9b1d-5e38a448659b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "91", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47 inv\"\>"}],
  
  SequenceForm["i=", 91, " ", "X47 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403937702208`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"62d46eab-4c6c-49ce-a13d-0c50b256143f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "92", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48 inv\"\>"}],
  
  SequenceForm["i=", 92, " ", "X48 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393876758*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7139943e-03cf-4396-9bc0-93641a54bfbc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "93", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49 inv\"\>"}],
  
  SequenceForm["i=", 93, " ", "X49 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640393969263*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2f1168c8-ba8a-4e4e-8751-80f8a5a4a547"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50 inv\"\>"}],
  
  SequenceForm["i=", 94, " ", "X50 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640394096751*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c26436f4-4bee-461f-bfcf-0774946660b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle inv\"\>"}],
  SequenceForm["i=", 95, " ", "Centroid of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640394302253*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"30e81482-e0e6-4c06-aa47-93c6b1b92c66"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "96", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle inv\"\>"}],
  SequenceForm["i=", 96, " ", "Orthocenter of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403944212837`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"527eb7da-624e-43cc-9314-5409cdfec899"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "97", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle inv\"\>"}],
  SequenceForm["i=", 97, " ", "Symmedian point of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403945673513`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bc82468b-1cad-4a91-9212-17fe9d83a809"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Tarry point\"\>"}],
  SequenceForm["i=", 98, " ", "Tarry point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564039467842*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ea4cbd76-f7fa-463d-abe5-09477a72b49c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Steiner point\"\>"}],
  SequenceForm["i=", 99, " ", "Steiner point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403947657833`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c812b522-f599-4578-a147-de83f1c3e669"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isodynamic.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isodynamic."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403949939127`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"984b881e-2084-491b-988d-40b01a7a2d61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X100\"\>"}],
  SequenceForm["i=", 100, " ", "X100"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395026402*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a88f6a5a-be5d-461f-b535-e2bccba38d99"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isodynamic.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isodynamic."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395236088*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"75f14997-2dab-48e2-ade5-2c4695833c7a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "101", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X101\"\>"}],
  SequenceForm["i=", 101, " ", "X101"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395244706*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c0d04cc7-cb63-4ced-812f-41da8c680963"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isodynamic.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isodynamic."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403955035753`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0b7f1966-a54c-408e-aeec-06e35cca1327"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "102", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X102\"\>"}],
  SequenceForm["i=", 102, " ", "X102"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403955385036`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"617520a0-6bb9-4e9b-ac80-750b8740f54a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "103", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X103\"\>"}],
  SequenceForm["i=", 103, " ", "X103"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395577359*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"14b2931d-3325-4186-9087-0edc6f5a5404"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is isodynamic.\"\>"}],
  SequenceForm["  ", "Tetrahedron is isodynamic."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395801881*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ee2f288d-d28a-4341-b978-043086a41dae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "104", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X104\"\>"}],
  SequenceForm["i=", 104, " ", "X104"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395836485*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f920dc9a-d03b-48da-9022-cda8071c98cd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Points are coplanar.\"\>"}],
  
  SequenceForm["  ", "Points are coplanar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395839343*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"838c150c-74b2-4068-baae-5a6938913eb5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Faces are parallel.\"\>"}],
  SequenceForm["  ", "Faces are parallel."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403958415947`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f2f3d785-4fa1-438f-8c1f-1d5a63c14b3d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Points are collinear.\"\>"}],
  SequenceForm["  ", "Points are collinear."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403958767633`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cb033198-5e25-444f-947b-10c23bf96291"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "105", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X105\"\>"}],
  SequenceForm["i=", 105, " ", "X105"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395879649*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"142ca76f-ded7-4b83-a88e-7702f2390c98"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Points are coplanar.\"\>"}],
  
  SequenceForm["  ", "Points are coplanar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403959128923`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"27b4531c-dc06-40af-9bd7-eb4639e9a5fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Property \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" failed in general,\"\>", 
   "\[InvisibleSpace]", "\<\" but numeric example succeeded.\"\>"}],
  SequenceForm[
  "  Property ", 2, " failed in general,", " but numeric example succeeded."],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395915395*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9002a613-1bc7-4460-a836-1d23286ab270"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Points are collinear.\"\>"}],
  SequenceForm["  ", "Points are collinear."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395949011*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b776c008-b020-4f78-8a9f-1862d3c6b533"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "106", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X106\"\>"}],
  SequenceForm["i=", 106, " ", "X106"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395952251*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"86a7f233-d210-4cb6-bd89-50fb5cb8b76c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395985528*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4a684565-5ca2-46a7-9615-4aaac77d2230"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "107", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X107\"\>"}],
  SequenceForm["i=", 107, " ", "X107"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640395989139*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9d3e918b-baad-41bb-8de5-8f64b4edba30"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640396000469*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"095776e1-608b-4afd-9e47-4f7dd49ff300"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "108", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X108\"\>"}],
  SequenceForm["i=", 108, " ", "X108"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640396035124*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d95ccfd7-513f-472c-aa6a-3b8226b03805"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403960450563`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d3d9aed6-3151-49b1-bd8e-508de522dee4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "109", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X109\"\>"}],
  SequenceForm["i=", 109, " ", "X109"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403960791073`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9e11e0f2-e656-4b3c-8db7-fabca53d1a44"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640396081788*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b724fe70-5b5d-49f7-9429-367297f69416"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "110", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X110\"\>"}],
  SequenceForm["i=", 110, " ", "X110"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403960839853`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"deee769b-a39b-4745-b897-c8fe2ba31c64"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403961178207`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7fc2de09-b6db-4ea7-a233-298a8a2eeff8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "111", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X111\"\>"}],
  SequenceForm["i=", 111, " ", "X111"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640396121722*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"116cec83-db96-4124-a9bd-c77ca65ebee9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640396159223*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"688ae2d4-22ab-4998-b71f-3abd87367177"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "112", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X112\"\>"}],
  SequenceForm["i=", 112, " ", "X112"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564039616234*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"12e0168e-25be-4e6c-9673-44e8d07a9834"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Points are coplanar.\"\>"}],
  
  SequenceForm["  ", "Points are coplanar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403961946907`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fa348472-f0fd-4ff3-8890-4c3acadc5330"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "113", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X113\"\>"}],
  SequenceForm["i=", 113, " ", "X113"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403961977997`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0531d051-4562-494b-863e-13307571985c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "114", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X114\"\>"}],
  SequenceForm["i=", 114, " ", "X114"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403962437563`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b3d23517-fa70-42e7-b81a-1252d54e5df6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "115", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X115\"\>"}],
  SequenceForm["i=", 115, " ", "X115"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640396290442*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0c141f55-a9ee-4414-af79-5bc649a23df9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Points are coplanar.\"\>"}],
  
  SequenceForm["  ", "Points are coplanar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564039632446*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"234f8965-eeac-4dde-9476-d58bb8abbd2a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "116", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X116\"\>"}],
  SequenceForm["i=", 116, " ", "X116"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564039636136*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d275302a-b770-4411-8abe-6e615a37e4e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "117", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X117\"\>"}],
  SequenceForm["i=", 117, " ", "X117"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403964105186`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e24f6d48-71df-4223-8c7c-b1cffbcc9d33"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "118", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r-power point\"\>"}],
  SequenceForm["i=", 118, " ", "r-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640396445652*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f5c543e5-a9b5-485a-9fda-6b94f5c4c044"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["4", 
        RowBox[{"1", "+", "r"}]]}], " ", 
      SuperscriptBox["5", 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", "r"}]}]], " ", "a1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["4", 
          RowBox[{"1", "+", "r"}]], " ", 
         SuperscriptBox["5", 
          RowBox[{"3", "+", 
           RowBox[{"2", " ", "r"}]}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "a2"], ")"}], "r"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["a1", 
          RowBox[{"1", "+", "r"}]], " ", "a2"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "a3"], ")"}], "r"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["4", 
        RowBox[{"1", "+", "r"}]]}], " ", 
      SuperscriptBox["5", 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", "r"}]}]], " ", "a2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["4", 
          RowBox[{"1", "+", "r"}]], " ", 
         SuperscriptBox["5", 
          RowBox[{"3", "+", 
           RowBox[{"2", " ", "r"}]}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "a1"], ")"}], "r"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "a3"], ")"}], "r"]}], "-", 
        RowBox[{"13", " ", "a1", " ", 
         SuperscriptBox["a2", 
          RowBox[{"1", "+", "r"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "a3"], ")"}], "r"]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "a1"], ")"}], "r"], " ", 
         SuperscriptBox["a1", 
          RowBox[{"1", "+", "r"}]], " ", "a3"}], "+", 
        RowBox[{"12", " ", "a1", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "a2"], ")"}], "r"], " ", 
         SuperscriptBox["a2", "r"], " ", "a3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["4", 
        RowBox[{"1", "+", "r"}]]}], " ", 
      SuperscriptBox["5", 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", "r"}]}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "a1"], ")"}], "r"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["4", 
          RowBox[{"1", "+", "r"}]], " ", 
         SuperscriptBox["5", 
          RowBox[{"3", "+", 
           RowBox[{"2", " ", "r"}]}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "a2"], ")"}], "r"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["a1", 
          RowBox[{"1", "+", "r"}]], " ", "a2"}]}], ")"}], " ", "a3"}], ",", 
     RowBox[{"a1", " ", 
      SuperscriptBox["a2", 
       RowBox[{"1", "+", "r"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["4", 
          RowBox[{"1", "+", "r"}]], " ", 
         SuperscriptBox["5", 
          RowBox[{"3", "+", 
           RowBox[{"2", " ", "r"}]}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "a2"], ")"}], "r"]}], "+", 
        RowBox[{"13", " ", 
         SuperscriptBox["a1", 
          RowBox[{"1", "+", "r"}]], " ", "a2"}]}], ")"}], " ", "a3"}]}], 
    "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {-4^(1 + $CellContext`r) 
    5^(2 + 2 $CellContext`r) $CellContext`a1 (
     3 4^(1 + $CellContext`r) 
      5^(3 + 2 $CellContext`r) ($CellContext`a2^(-1))^$CellContext`r - 
     13 $CellContext`a1^(
       1 + $CellContext`r) $CellContext`a2) \
($CellContext`a3^(-1))^$CellContext`r, -4^(1 + $CellContext`r) 
    5^(2 + 2 $CellContext`r) $CellContext`a2 (
     3 4^(1 + $CellContext`r) 
      5^(3 + 2 $CellContext`r) ($CellContext`a1^(-1))^$CellContext`r \
($CellContext`a3^(-1))^$CellContext`r - 
     13 $CellContext`a1 $CellContext`a2^(
       1 + $CellContext`r) ($CellContext`a3^(-1))^$CellContext`r - 
     12 ($CellContext`a1^(-1))^$CellContext`r $CellContext`a1^(
       1 + $CellContext`r) $CellContext`a3 + 
     12 $CellContext`a1 ($CellContext`a2^(-1))^$CellContext`r \
$CellContext`a2^$CellContext`r $CellContext`a3), -4^(1 + $CellContext`r) 
    5^(2 + 2 $CellContext`r) ($CellContext`a1^(-1))^$CellContext`r (
     3 4^(1 + $CellContext`r) 
      5^(3 + 2 $CellContext`r) ($CellContext`a2^(-1))^$CellContext`r - 
     13 $CellContext`a1^(
       1 + $CellContext`r) $CellContext`a2) $CellContext`a3, $CellContext`a1 \
$CellContext`a2^(1 + $CellContext`r) ((-3) 4^(1 + $CellContext`r) 
      5^(3 + 2 $CellContext`r) ($CellContext`a2^(-1))^$CellContext`r + 
     13 $CellContext`a1^(
        1 + $CellContext`r) $CellContext`a2) $CellContext`a3}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640396588037*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e92db17e-3dcf-4c93-9989-5bc6c0fd03d1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403967846613`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5f1b4351-4e63-42b8-ae94-e4eb8031b1f0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640397170332*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7e2f8c49-f747-46fb-be2c-55896bce95a7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "119", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r2-power point\"\>"}],
  SequenceForm["i=", 119, " ", "r2-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403972078876`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"61a6cdc2-6778-4b81-b189-0d40191ad893"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Property \"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" failed in general,\"\>", 
   "\[InvisibleSpace]", "\<\" but numeric example succeeded.\"\>"}],
  SequenceForm[
  "  Property ", 10, " failed in general,", " but numeric example succeeded."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640397785964*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"305338f5-f11c-47a3-bc4b-165ec440c8ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "120", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r3-power point\"\>"}],
  SequenceForm["i=", 120, " ", "r3-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640397842881*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"72027916-0577-4d2b-a6eb-f01969d088fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "121", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z1\"\>"}],
  SequenceForm["i=", 121, " ", "Z1"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640398486524*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d37ea465-c756-437b-8c55-d9dcf305a393"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640398910407*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4f2d3b65-fa4d-4a11-a28c-6e73026a2e8d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "122", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z2\"\>"}],
  SequenceForm["i=", 122, " ", "Z2"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403989489117`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5168758c-ad11-4af4-b36b-a576892ea08a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403993874807`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3d4ee03b-d7fd-4539-ba41-c82879a47c64"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "123", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z3\"\>"}],
  SequenceForm["i=", 123, " ", "Z3"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403994267607`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"68003a3a-6371-4ca3-b1c5-2df4bbb6ef2f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "124", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z4\"\>"}],
  SequenceForm["i=", 124, " ", "Z4"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056403999715557`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1f572f1d-7ba5-4fa0-b63f-0f015657f15b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Property \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" failed in general,\"\>", 
   "\[InvisibleSpace]", "\<\" but numeric example succeeded.\"\>"}],
  SequenceForm[
  "  Property ", 1, " failed in general,", " but numeric example succeeded."],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.80564040031214*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fd75d9a1-d563-445e-9296-9c1981effe4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "125", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z5\"\>"}],
  SequenceForm["i=", 125, " ", "Z5"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640400770914*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"20c590ec-8188-4805-8cad-446421850dda"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "126", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z6\"\>"}],
  SequenceForm["i=", 126, " ", "Z6"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640401362802*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"273ab226-9981-4866-bcc1-2730f2434e9b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640401807207*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ac808836-7c71-47b0-9dae-a259fb350d25"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "127", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z7\"\>"}],
  SequenceForm["i=", 127, " ", "Z7"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640401845233*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b4f2cda2-4274-474d-8960-76c37750f81e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640402292138*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d00f8dd3-ed02-4825-bde7-deec47faa058"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "128", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z8\"\>"}],
  SequenceForm["i=", 128, " ", "Z8"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564040233041*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3918eed8-12f5-487a-ae4c-b404e2352305"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Property \"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" failed in general,\"\>", 
   "\[InvisibleSpace]", "\<\" but numeric example succeeded.\"\>"}],
  SequenceForm[
  "  Property ", 10, " failed in general,", " but numeric example succeeded."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640402733304*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fd40be86-5261-4ae1-bbda-2455206ffadc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "129", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r4-power point\"\>"}],
  SequenceForm["i=", 129, " ", "r4-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640402768237*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dc9cc577-7d2d-46bf-adf7-166d31ba6223"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640403430731*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"96bbac10-dca6-4aae-a640-1725ea3459c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640403496208*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e644bf3a-025a-4d9a-9e5f-ef773c45fb60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640407584635*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"96343f9a-b3b7-4db3-b680-0695d6ff7245"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "130", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"arbitrary center\"\>"}],
  SequenceForm["i=", 130, " ", "arbitrary center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640407587378*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5056f0b0-068e-45ef-9f02-3e609f47eebd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "131", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"areal center\"\>"}],
  SequenceForm["i=", 131, " ", "areal center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640407619587*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"82dc4e6a-4d43-49d5-af0e-e8c6f5759d8b"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.805640408247666*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f3d0b258-e02a-4846-b909-cc17249d613c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CASE \"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocentric Tetrahedron\"\>"}],
  SequenceForm["CASE ", 5, ": ", "Orthocentric Tetrahedron"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564040825025*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"964ca50f-67de-40f6-be50-b33835b19c25"],

Cell[BoxData["\<\"------\"\>"], "Print",
 CellChangeTimes->{3.805640408252203*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34a2bddb-5bbc-4ada-8743-41d2e9578002"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>"}],
  SequenceForm["i=", 1, " ", "incenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404082599707`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7a77c985-4f95-4aa7-8a01-61a024053954"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408293198*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aa423383-8558-464d-8df9-fad21c54960f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>"}],
  SequenceForm["i=", 2, " ", "centroid"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408296241*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3570e7d7-2d21-4a50-aeeb-3ec289c0c56e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Faces are parallel.\"\>"}],
  SequenceForm["  ", "Faces are parallel."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408298479*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5730c153-6aa7-4732-be31-87b3d5280091"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}],
  SequenceForm["    Coordinates of intersection point:  ", {1, 1, 1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404083006973`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fc2aeb22-8943-4acd-ae99-2ef97dca5d25"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "centroid", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408302897*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c44aab57-2276-4d37-aead-c6c6d776ed11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "1", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 1, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408305319*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b17c5c81-dbf6-467a-a357-03bef6d0172c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408307851*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4c5d4c0d-225c-4a17-8d7f-4ab55b0535ff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedron is orthocentric.\"\>"}],
  SequenceForm["  ", "Tetrahedron is orthocentric."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408310699*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3e0e7037-b622-44dd-aecd-82a288699bf6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408313052*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6ae9da75-91ff-414d-a1b7-3453a648caf4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408315217*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7314fc0c-aa90-4052-af7c-627670d3d64e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra are similar.\"\>"}],
  SequenceForm["  ", "Tetrahedra are similar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404083173323`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3c04eb6d-ed19-4a09-ac3d-9c935029ce96"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["2", "3"], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 
   Rational[2, 3], ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404083609133`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d8441627-40ff-4b67-8df0-81217b9623df"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.805640408363708*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ee6a6efe-09a4-477a-a215-67ce81992d6a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"a1", "-", "a2", "-", "a3"}], ")"}]}], " ", 
    RowBox[{"(", 
     RowBox[{"a1", "+", "a2", "-", "a3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"a1", "-", "a2", "+", "a3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"a1", "+", "a2", "+", "a3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "200"}], "+", 
      SuperscriptBox["a1", "2"], "+", 
      SuperscriptBox["a2", "2"], "+", 
      SuperscriptBox["a3", "2"]}], ")"}]}]}],
  SequenceForm[
  "    ", -($CellContext`a1 - $CellContext`a2 - $CellContext`a3) \
($CellContext`a1 + $CellContext`a2 - $CellContext`a3) ($CellContext`a1 - \
$CellContext`a2 + $CellContext`a3) ($CellContext`a1 + $CellContext`a2 + \
$CellContext`a3) (-200 + $CellContext`a1^2 + $CellContext`a2^2 + \
$CellContext`a3^2)],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408365971*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"76929c19-8212-4f59-8ce4-2436853722b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404083681107`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4c3a2549-8831-4228-970b-a376aa417a13"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404083702993`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8d9c5d93-6d4e-42e9-8893-f2b33a1157cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "Euler point",
    "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408402678*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"58375448-183e-4fa9-b704-d89f60ebdaba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Central Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["2", "3"], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Central Monge point", " lies on reference Euler line (at ", 
   Rational[2, 3], ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404084878607`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6d2c01f6-6111-4f99-b65c-ef9f4e6d255f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Central Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["8", "9"], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Central Euler point", " lies on reference Euler line (at ", 
   Rational[8, 9], ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404086463137`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e8186ddc-3316-42d3-a110-6ca94962200d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Reference \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" lies on central Euler line (at \"\>", 
   "\[InvisibleSpace]", "4", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    Reference ", "circumcenter", " lies on central Euler line (at ", 4, 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408690436*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fe22df7b-7716-4398-9786-16a80b928d6c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Reference \"\>", 
   "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on central Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    Reference ", "Monge point", " lies on central Euler line (at ", -2, 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408749371*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cf596b93-3351-48fe-b257-4f68742b180e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640408782847*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c3d36803-36ff-4096-b015-fae2119b4172"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>"}],
  SequenceForm["i=", 3, " ", "circumcenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404087865553`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a20142ac-3b26-4f1c-be91-01b1ae681dd2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404087893353`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ab5a60db-9309-49ab-8e8f-060653df3277"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm[
  "    Point coincides with ", "circumcenter", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564040929058*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8bfe85ec-9c6b-44a2-8c19-8b424df353e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "0", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 0, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404093236427`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"49b81949-ac32-4084-88fa-d0f86984aed8"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.80564040932629*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d5e2efc2-3d34-4c53-ac94-f89590458e1c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"100", " ", 
     SuperscriptBox["a1", "4"]}], "-", 
    SuperscriptBox["a1", "6"], "-", 
    RowBox[{"200", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a1", "4"], " ", 
     SuperscriptBox["a2", "2"]}], "+", 
    RowBox[{"100", " ", 
     SuperscriptBox["a2", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "4"]}], "-", 
    SuperscriptBox["a2", "6"], "-", 
    RowBox[{"200", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a1", "4"], " ", 
     SuperscriptBox["a3", "2"]}], "-", 
    RowBox[{"200", " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a2", "4"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"100", " ", 
     SuperscriptBox["a3", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "4"]}], "-", 
    SuperscriptBox["a3", "6"]}]}],
  SequenceForm[
  "    ", 100 $CellContext`a1^4 - $CellContext`a1^6 - 
   200 $CellContext`a1^2 $CellContext`a2^2 + $CellContext`a1^4 \
$CellContext`a2^2 + 
   100 $CellContext`a2^4 + $CellContext`a1^2 $CellContext`a2^4 - \
$CellContext`a2^6 - 
   200 $CellContext`a1^2 $CellContext`a3^2 + $CellContext`a1^4 \
$CellContext`a3^2 - 200 $CellContext`a2^2 $CellContext`a3^2 + 
   2 $CellContext`a1^2 $CellContext`a2^2 $CellContext`a3^2 + \
$CellContext`a2^4 $CellContext`a3^2 + 
   100 $CellContext`a3^4 + $CellContext`a1^2 $CellContext`a3^4 + \
$CellContext`a2^2 $CellContext`a3^4 - $CellContext`a3^6],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404093288918`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9bcc75f6-6a6d-4b96-9751-98a4d93dda9b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640409331237*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"04953537-7955-4d12-baea-407dac8828ae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"orthocenter\"\>"}],
  SequenceForm["i=", 4, " ", "orthocenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564040933335*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5aed6fd5-fd42-4d97-a75a-5519597e171f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a1", "2"], "+", 
        SuperscriptBox["a2", "2"], "-", 
        SuperscriptBox["a3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a1", "2"], "-", 
        SuperscriptBox["a2", "2"], "+", 
        SuperscriptBox["a3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "200"}], "+", 
        SuperscriptBox["a1", "2"], "+", 
        SuperscriptBox["a2", "2"], "+", 
        SuperscriptBox["a3", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a1", "2"], "-", 
         SuperscriptBox["a2", "2"], "-", 
         SuperscriptBox["a3", "2"]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a1", "2"], "+", 
        SuperscriptBox["a2", "2"], "-", 
        SuperscriptBox["a3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "200"}], "+", 
        SuperscriptBox["a1", "2"], "+", 
        SuperscriptBox["a2", "2"], "+", 
        SuperscriptBox["a3", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a1", "2"], "-", 
         SuperscriptBox["a2", "2"], "-", 
         SuperscriptBox["a3", "2"]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a1", "2"], "-", 
        SuperscriptBox["a2", "2"], "+", 
        SuperscriptBox["a3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "200"}], "+", 
        SuperscriptBox["a1", "2"], "+", 
        SuperscriptBox["a2", "2"], "+", 
        SuperscriptBox["a3", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a1", "2"], "-", 
        SuperscriptBox["a2", "2"], "-", 
        SuperscriptBox["a3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a1", "2"], "+", 
        SuperscriptBox["a2", "2"], "-", 
        SuperscriptBox["a3", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a1", "2"], "-", 
        SuperscriptBox["a2", "2"], "+", 
        SuperscriptBox["a3", "2"]}], ")"}]}]}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {($CellContext`a1^2 + \
$CellContext`a2^2 - $CellContext`a3^2) ($CellContext`a1^2 - $CellContext`a2^2 + \
$CellContext`a3^2) (-200 + $CellContext`a1^2 + $CellContext`a2^2 + \
$CellContext`a3^2), -($CellContext`a1^2 - $CellContext`a2^2 - \
$CellContext`a3^2) ($CellContext`a1^2 + $CellContext`a2^2 - \
$CellContext`a3^2) (-200 + $CellContext`a1^2 + $CellContext`a2^2 + \
$CellContext`a3^2), -($CellContext`a1^2 - $CellContext`a2^2 - \
$CellContext`a3^2) ($CellContext`a1^2 - $CellContext`a2^2 + \
$CellContext`a3^2) (-200 + $CellContext`a1^2 + $CellContext`a2^2 + \
$CellContext`a3^2), ($CellContext`a1^2 - $CellContext`a2^2 - \
$CellContext`a3^2) ($CellContext`a1^2 + $CellContext`a2^2 - \
$CellContext`a3^2) ($CellContext`a1^2 - $CellContext`a2^2 + \
$CellContext`a3^2)}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640409367546*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9524dfe9-b20a-4147-8f24-edbac6bd619f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "Monge point", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640409370495*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"58a29a32-ffbe-473b-81fc-e0a620194321"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "2", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 2, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404093794117`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"96201719-086a-4152-95af-4355230905d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404093821983`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"27cd492e-54fc-4f8f-94b2-f03537c5a792"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640409384536*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"158bd75e-8297-4003-a69f-d4e4e76a714f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "Monge point", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640409647114*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f51e08f8-39b2-461d-8693-a8a693c482d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "2", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 2, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640409683424*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a88b3041-a102-4753-9142-c8218b1b4b59"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.805640409686523*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"abeeb904-e3e6-48ee-8e1f-8ec6b53092b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a1", "2"], "-", 
      SuperscriptBox["a2", "2"], "-", 
      SuperscriptBox["a3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a1", "2"], "+", 
      SuperscriptBox["a2", "2"], "-", 
      SuperscriptBox["a3", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a1", "2"], "-", 
      SuperscriptBox["a2", "2"], "+", 
      SuperscriptBox["a3", "2"]}], ")"}]}]}],
  SequenceForm[
  "    ", ($CellContext`a1^2 - $CellContext`a2^2 - $CellContext`a3^2) \
($CellContext`a1^2 + $CellContext`a2^2 - $CellContext`a3^2) \
($CellContext`a1^2 - $CellContext`a2^2 + $CellContext`a3^2)],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564040968894*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"72ff10fa-8541-4efa-b3d7-fd390b3bf251"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404096914988`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7053149d-22b1-4429-ad59-3d766db3fbca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"nine point center\"\>"}],
  SequenceForm["i=", 5, " ", "nine point center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640409694187*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a79f0e5c-dc1b-48ff-8211-a9a59907377f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640409728589*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8b4a126e-00a3-457e-a89b-5de8ccfdfda8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "centroid", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640410300405*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b757f18f-a8b1-4aa4-a376-8ef274aa48ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "1", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 1, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404103089867`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f4870087-5327-43da-a15b-131f32a606f7"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.805640410311657*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"31f5d0cb-5499-4700-9112-829e40dba9af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["    ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640410313944*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8ae1b327-29c0-4de8-b21e-b8b750d66fdc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640410316297*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d2b98130-7b1c-4639-91c7-f7ecdfe73caf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564041031847*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"20d440cb-a0bc-441d-85f0-8dee73020cee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640410923832*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"60f14c4d-9dce-4191-b053-fc0b03c3f135"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"symmedian point\"\>"}],
  SequenceForm["i=", 6, " ", "symmedian point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640410927211*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c161d676-d055-495d-82a1-799e2cad6e89"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640410929447*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"35afd273-452f-4131-8b29-3c2366ebed6d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne point\"\>"}],
  SequenceForm["i=", 7, " ", "Gergonne point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640410931962*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"60ea5e48-14c1-43a2-878a-ef0113f15ed2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel point\"\>"}],
  SequenceForm["i=", 8, " ", "Nagel point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404109709263`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c41771be-830a-4258-8816-ea153c4a80c1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt\"\>"}],
  SequenceForm["i=", 9, " ", "Mittenpunkt"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640411005385*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"48907d7b-771f-4dad-a5f7-abbf9d2e3f8e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker center\"\>"}],
  SequenceForm["i=", 10, " ", "Spieker center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640411039935*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"999ead4a-b95e-4194-8380-baaf491bf36e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach point\"\>"}],
  SequenceForm["i=", 11, " ", "Feuerbach point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640411043209*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5d2804bc-7ea6-4bef-87d8-07194b6a9af1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12\"\>"}],
  SequenceForm["i=", 12, " ", "X12"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640411100235*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8bdf63b6-f598-409e-a106-ca98abb848dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st isogonic center (Fermat point)\"\>"}],
  SequenceForm["i=", 13, " ", "1st isogonic center (Fermat point)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640411160408*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"413fd56e-917e-43ae-8b12-c0477f30261b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isogonic center\"\>"}],
  SequenceForm["i=", 14, " ", "2nd Isogonic center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640411596592*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2d7ce944-33f0-4f34-9aef-25f8dcb59624"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Isodynamic point\"\>"}],
  SequenceForm["i=", 15, " ", "1st Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404119872007`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2d2af2b1-dedf-4505-95be-9348d79686a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isodynamic point\"\>"}],
  SequenceForm["i=", 16, " ", "2nd Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640412240634*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b4888be2-d833-4158-9fc1-542a7e463320"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point\"\>"}],
  SequenceForm["i=", 17, " ", "1st Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640412483232*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ffb887a0-d875-4133-9d26-e42262ea6cb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "18", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point\"\>"}],
  SequenceForm["i=", 18, " ", "2nd Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404128823423`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3e3e8155-6845-4c2d-b886-9742f28062dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point\"\>"}],
  SequenceForm["i=", 19, " ", "Crucial point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640413214254*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cdfb4adf-5285-4ece-8103-8ac5436bca03"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640413247373*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"01650861-ba6d-46ed-9a72-e6b0fbbf360a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point\"\>"}],
  SequenceForm["i=", 20, " ", "De Longchamps point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640413250362*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0b047718-4a1b-4545-ac0f-07d18dc5d3fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", -2, 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640414050764*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"104bc433-4278-4798-a197-a9dbf83d3ca7"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.805640414053597*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c41ce66d-9aca-4a2d-98f8-42026f7a5e1a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"200", " ", 
     SuperscriptBox["a1", "4"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a1", "6"]}], "-", 
    RowBox[{"400", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a1", "4"], " ", 
     SuperscriptBox["a2", "2"]}], "+", 
    RowBox[{"200", " ", 
     SuperscriptBox["a2", "4"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "4"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a2", "6"]}], "-", 
    RowBox[{"400", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a1", "4"], " ", 
     SuperscriptBox["a3", "2"]}], "-", 
    RowBox[{"400", " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a2", "4"], " ", 
     SuperscriptBox["a3", "2"]}], "+", 
    RowBox[{"200", " ", 
     SuperscriptBox["a3", "4"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a1", "2"], " ", 
     SuperscriptBox["a3", "4"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a2", "2"], " ", 
     SuperscriptBox["a3", "4"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a3", "6"]}]}]}],
  SequenceForm[
  "    ", 200 $CellContext`a1^4 - 3 $CellContext`a1^6 - 
   400 $CellContext`a1^2 $CellContext`a2^2 + 
   3 $CellContext`a1^4 $CellContext`a2^2 + 200 $CellContext`a2^4 + 
   3 $CellContext`a1^2 $CellContext`a2^4 - 3 $CellContext`a2^6 - 
   400 $CellContext`a1^2 $CellContext`a3^2 + 
   3 $CellContext`a1^4 $CellContext`a3^2 - 
   400 $CellContext`a2^2 $CellContext`a3^2 + 
   2 $CellContext`a1^2 $CellContext`a2^2 $CellContext`a3^2 + 
   3 $CellContext`a2^4 $CellContext`a3^2 + 200 $CellContext`a3^4 + 
   3 $CellContext`a1^2 $CellContext`a3^4 + 
   3 $CellContext`a2^2 $CellContext`a3^4 - 3 $CellContext`a3^6],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564041405613*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"178eef16-7dc7-4b23-9eda-1c410457e434"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640414058744*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2ab79d06-8b6c-4d38-b0a3-1ce36471ffe6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point\"\>"}],
  SequenceForm["i=", 21, " ", "Schiffler point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404140612698`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cf6be7b6-ced5-400a-b242-093b87590f54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "22", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point\"\>"}],
  SequenceForm["i=", 22, " ", "Exeter point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640414134076*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"abab0b31-7def-4b6c-941d-eabaa456ece4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point\"\>"}],
  SequenceForm["i=", 23, " ", "far out point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404141813297`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b0be5f5a-0f91-4556-8630-375bd7969dc1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "24", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24\"\>"}],
  SequenceForm["i=", 24, " ", "X24"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640414236362*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b359e90b-11f4-484f-955b-5c822273ecec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25\"\>"}],
  SequenceForm["i=", 25, " ", "X25"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640414308209*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b1d16b0a-cd9b-4377-aa23-cc37afe0e30a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640414341056*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"959ae247-5adc-49d7-a669-2ff22dfffaa5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "26", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle\"\>"}],
  SequenceForm["i=", 26, " ", "Circumcenter of tangential triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404143444138`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"da9975d8-451b-48d6-90a2-d0f234a4be63"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27\"\>"}],
  SequenceForm["i=", 27, " ", "X27"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404145769663`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"768dd976-688c-4e8a-ba34-aa359555087d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28\"\>"}],
  SequenceForm["i=", 28, " ", "X28"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404146362534`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ec23616a-340b-4af4-80ff-d93f93fa7437"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "29", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29\"\>"}],
  SequenceForm["i=", 29, " ", "X29"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640414690786*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d5442893-7251-4ddc-993d-d7259845f157"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30\"\>"}],
  SequenceForm["i=", 30, " ", "X30"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564041476933*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f06cbf74-dd1a-47c2-bfe0-6321eb2710c2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640414802272*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"45c2c477-d8ff-4142-9d6b-c0c1b27c6c92"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640414805146*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8b46c42f-f824-4e4d-bfbf-4342ec76c88a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416103599*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b841aced-29f6-44a4-8afd-c2e3781ee192"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point\"\>"}],
  SequenceForm["i=", 31, " ", "2nd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416106394*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d4580fa2-cf94-42b5-b081-9dc26076ad51"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404161385527`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d2cd773a-edea-4c70-b580-ac509339c781"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point\"\>"}],
  SequenceForm["i=", 32, " ", "3rd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416141848*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2f3c1c1e-03f7-442f-a84f-d9e56b019ed8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416144414*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"86bec850-24b8-4d57-bbb8-27e47e3c9014"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "33", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33\"\>"}],
  SequenceForm["i=", 33, " ", "X33"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416153068*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cd68b4ce-47f0-44ff-8e75-fe94139efc5f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34\"\>"}],
  SequenceForm["i=", 34, " ", "X34"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404162211103`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4577027d-2608-4a84-b368-22ee5440026f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35\"\>"}],
  SequenceForm["i=", 35, " ", "X35"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416301715*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4f870942-41bc-4f1e-8229-701f6109fac6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36\"\>"}],
  SequenceForm["i=", 36, " ", "X36"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416379223*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6107776f-ce66-455e-b85f-c1aac5a88de5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37\"\>"}],
  SequenceForm["i=", 37, " ", "X37"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416442719*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cba9160f-ec7d-4c66-9c87-71fa7b3e90f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38\"\>"}],
  SequenceForm["i=", 38, " ", "X38"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416476118*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"89e724df-a5cf-4508-9d6a-e0c78ed0ad0d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint\"\>"}],
  SequenceForm["i=", 39, " ", "Brocard midpoint"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416517145*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9bc0c547-0fa7-457b-b429-023b862ee132"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40\"\>"}],
  SequenceForm["i=", 40, " ", "X40"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416527108*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1ba2031f-08f6-4f43-a49c-98946c505afb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41\"\>"}],
  SequenceForm["i=", 41, " ", "X41"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404169028378`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"46d46662-af0d-4321-84d2-35416f17a31e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42\"\>"}],
  SequenceForm["i=", 42, " ", "X42"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640416964745*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8fd7a38a-9bec-4cbe-b00d-c9478ced337a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43\"\>"}],
  SequenceForm["i=", 43, " ", "X43"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404169980297`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9a89ce35-f1ed-43e7-8ab1-27eec13fba3e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44\"\>"}],
  SequenceForm["i=", 44, " ", "X44"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404171560993`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b80a1eee-3ffd-448f-b2cd-ca5a38099df3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45\"\>"}],
  SequenceForm["i=", 45, " ", "X45"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404171997633`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2af8c60f-7e17-4d20-853e-1e4385ebc162"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46\"\>"}],
  SequenceForm["i=", 46, " ", "X46"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404172608128`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"77ced8c3-b1d3-4afa-b075-d73491ec01d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "47", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47\"\>"}],
  SequenceForm["i=", 47, " ", "X47"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640417527781*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"56b932f8-8c2d-47e2-be31-8433138ee956"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "48", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48\"\>"}],
  SequenceForm["i=", 48, " ", "X48"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640417610895*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7e394ba3-7b5a-4da9-bd17-13d2ee26bcc8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404176473513`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6d1fecd6-6caa-45cc-b6ee-87a9d5ae1d88"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "49", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49\"\>"}],
  SequenceForm["i=", 49, " ", "X49"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404176573143`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f4e7b76b-2a62-4f47-8717-3b245c159ce7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "50", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50\"\>"}],
  SequenceForm["i=", 50, " ", "X50"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640417738682*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"20c145ad-bea1-4988-b6c3-afcc2e909028"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle\"\>"}],
  SequenceForm["i=", 51, " ", "Centroid of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640417850307*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"32abbb80-c17b-4b59-b090-ed9876c37854"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle\"\>"}],
  SequenceForm["i=", 52, " ", "Orthocenter of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640417909484*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9d8c0a65-2ab8-4567-a255-13a3cbf51c06"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle\"\>"}],
  SequenceForm["i=", 53, " ", "Symmedian point of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640417998296*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"24c62086-c25f-4c7c-8285-465207aa33c6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "54", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nine point inv\"\>"}],
  SequenceForm["i=", 54, " ", "Nine point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640418077635*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8540a26c-b3d1-46a5-add0-3cf1a23d6e84"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne inv\"\>"}],
  SequenceForm["i=", 55, " ", "Gergonne inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640418157281*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"545fd4e3-f5b4-4a00-9202-6758533f78ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel inv\"\>"}],
  SequenceForm["i=", 56, " ", "Nagel inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404182046328`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"77a909e2-f587-4672-9f8a-694dcfee0dcc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt inv\"\>"}],
  SequenceForm["i=", 57, " ", "Mittenpunkt inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404182609673`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f8894b8c-d9a7-477c-95f8-4bfd8234b120"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker inv\"\>"}],
  SequenceForm["i=", 58, " ", "Spieker inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640418300027*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c8ad8044-1e75-4d79-95ff-ffb075aaf7d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach inv\"\>"}],
  SequenceForm["i=", 59, " ", "Feuerbach inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404183368483`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0148d006-1a47-4728-9c67-0b731f6964ae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12 inv\"\>"}],
  
  SequenceForm["i=", 60, " ", "X12 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564041843499*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f3aff589-377e-4f7d-be40-5cc156cb16fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "61", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point inv\"\>"}],
  SequenceForm["i=", 61, " ", "1st Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640418506157*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8eae0525-750b-475f-9038-06bde46f6571"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "62", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point inv\"\>"}],
  SequenceForm["i=", 62, " ", "2nd Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404188363457`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0691477b-ef16-4cf3-a960-7b6c6c73423e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point inv\"\>"}],
  SequenceForm["i=", 63, " ", "Crucial point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640419113348*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b9a8a3bc-8647-4f2c-afa3-53ef2dd84b35"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404191450243`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a098f875-8c79-44aa-a952-4f5da9c2a8da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "64", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point inv\"\>"}],
  SequenceForm["i=", 64, " ", "De Longchamps point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404191481943`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b2d30cc2-9f6b-4b98-bbdd-f437d2072153"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point inv\"\>"}],
  SequenceForm["i=", 65, " ", "Schiffler point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640419250856*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1f89a913-14c7-4396-b5a7-e09c1433b198"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "66", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point inv\"\>"}],
  SequenceForm["i=", 66, " ", "Exeter point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640419316229*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d965d9c4-119c-4a02-8d39-5d6c015d1495"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point inv\"\>"}],
  SequenceForm["i=", 67, " ", "far out point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640419363598*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"15cae825-8a3e-49ef-a7dd-dbf041434d90"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "68", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24 inv\"\>"}],
  
  SequenceForm["i=", 68, " ", "X24 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640419432522*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a4085b34-670e-4125-8ab1-d423ad378f1a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25 inv\"\>"}],
  
  SequenceForm["i=", 69, " ", "X25 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640419509389*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"003199e2-c3fc-4ad1-9608-a05c52840b19"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a1", "2"]}], "+", 
      SuperscriptBox["a2", "2"], "+", 
      SuperscriptBox["a3", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a1", "2"], "-", 
      SuperscriptBox["a2", "2"], "+", 
      SuperscriptBox["a3", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a1", "2"], "+", 
      SuperscriptBox["a2", "2"], "-", 
      SuperscriptBox["a3", "2"]}], ",", 
     RowBox[{"200", "-", 
      SuperscriptBox["a1", "2"], "-", 
      SuperscriptBox["a2", "2"], "-", 
      SuperscriptBox["a3", "2"]}]}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {-$CellContext`a1^2 + \
$CellContext`a2^2 + $CellContext`a3^2, $CellContext`a1^2 - $CellContext`a2^2 + \
$CellContext`a3^2, $CellContext`a1^2 + $CellContext`a2^2 - $CellContext`a3^2, 
    200 - $CellContext`a1^2 - $CellContext`a2^2 - $CellContext`a3^2}],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404195422*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"452f16fa-e631-4b9b-938f-8ff34d9334a4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404195451927`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"293a4d20-4b18-4cc7-8363-80eedb3a1903"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404195479717`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f8f75591-9862-4607-b73e-605b6f88721e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "70", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle inv\"\>"}],
  SequenceForm["i=", 70, " ", "Circumcenter of tangential triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564041955028*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1883a0f0-9e77-49f8-8c25-5580336f953e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27 inv\"\>"}],
  
  SequenceForm["i=", 71, " ", "X27 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640419777815*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f4c3342b-55b3-499e-9182-92c50731dcc8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28 inv\"\>"}],
  
  SequenceForm["i=", 72, " ", "X28 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640419825572*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"80161d09-2a68-42b4-a8d6-d2efe045e313"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "73", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29 inv\"\>"}],
  
  SequenceForm["i=", 73, " ", "X29 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404198680897`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"89b1f154-cabc-41bc-9a15-c7c549628c1d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30 inv\"\>"}],
  
  SequenceForm["i=", 74, " ", "X30 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640419954208*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d4fcd7a6-2cc3-421a-9fee-36c03ef801e1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point inv\"\>"}],
  SequenceForm["i=", 75, " ", "2nd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640420072741*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e6854e97-d3f7-458d-b2b4-81fb26d1a674"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640420105451*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5340cb0a-c0d2-4536-82a3-584fc12fc85b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point inv\"\>"}],
  SequenceForm["i=", 76, " ", "3rd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640420108426*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7543d066-77ba-4231-b6f9-f1ccf0611a60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640420111261*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5e9b3200-5adf-4bbd-8ce1-ada23a9e53d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "77", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33 inv\"\>"}],
  
  SequenceForm["i=", 77, " ", "X33 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640420119815*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aa57b8da-c73e-4e6b-801a-d93630cae315"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34 inv\"\>"}],
  
  SequenceForm["i=", 78, " ", "X34 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640420204206*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d26da36c-75ad-4266-8bea-b5f560fd7681"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35 inv\"\>"}],
  
  SequenceForm["i=", 79, " ", "X35 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404202567263`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"30922086-4c5c-46fe-bb1a-60eb324f0d6b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36 inv\"\>"}],
  
  SequenceForm["i=", 80, " ", "X36 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640420350585*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ca3ab680-7f01-49c3-9e4d-d1e8cdfaecd9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37 inv\"\>"}],
  
  SequenceForm["i=", 81, " ", "X37 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564042041424*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1d976504-8cab-4154-a3c9-08d2c6d03cff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38 inv\"\>"}],
  
  SequenceForm["i=", 82, " ", "X38 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640420448447*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8e240f3d-d7f5-432b-b6ef-c579764a2574"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint inv\"\>"}],
  SequenceForm["i=", 83, " ", "Brocard midpoint inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404204901648`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3ca5da2c-a010-4808-8f3f-d2505f6091c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "84", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40 inv\"\>"}],
  
  SequenceForm["i=", 84, " ", "X40 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640420522903*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bd0f9678-7924-4ad7-86d1-61a7985b6768"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41 inv\"\>"}],
  
  SequenceForm["i=", 85, " ", "X41 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640420922161*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a6a5bfb2-7448-463c-89f5-c1b568c665b2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42 inv\"\>"}],
  
  SequenceForm["i=", 86, " ", "X42 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404210128527`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"98715a66-963a-415a-bca3-6345c35c53ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "87", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43 inv\"\>"}],
  
  SequenceForm["i=", 87, " ", "X43 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404210455713`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b7a2988-9d20-442c-92b2-3aab2be60372"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44 inv\"\>"}],
  
  SequenceForm["i=", 88, " ", "X44 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640421163176*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ab166388-4757-4995-9897-61f1c4069752"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45 inv\"\>"}],
  
  SequenceForm["i=", 89, " ", "X45 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404212243223`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6dd40f00-d84c-4784-9b37-d4a9d92ddf7e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "90", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46 inv\"\>"}],
  
  SequenceForm["i=", 90, " ", "X46 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640421293655*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"664a48ab-2aa9-4d0e-bbf7-fa5a522ef193"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "91", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47 inv\"\>"}],
  
  SequenceForm["i=", 91, " ", "X47 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640421598856*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"727e54c7-2a00-4cfe-a4cd-d4b4fb3dead2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "92", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48 inv\"\>"}],
  
  SequenceForm["i=", 92, " ", "X48 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640421697216*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b2d4134e-422a-432e-9ac0-9e02a92037a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640421732567*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"810f2e77-af80-410e-a97f-c6bf47db5350"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "93", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49 inv\"\>"}],
  
  SequenceForm["i=", 93, " ", "X49 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640421741542*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"724a100e-a49e-4a50-905d-62c865853539"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50 inv\"\>"}],
  
  SequenceForm["i=", 94, " ", "X50 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404218597937`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0f14722b-9100-4874-91ed-800871c34a41"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle inv\"\>"}],
  SequenceForm["i=", 95, " ", "Centroid of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640422015827*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f9d3e993-5d40-4e82-8524-90911715ae1c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "96", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle inv\"\>"}],
  SequenceForm["i=", 96, " ", "Orthocenter of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404221241217`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e2a68d47-3e18-4891-853d-224185b0e6f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "97", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle inv\"\>"}],
  SequenceForm["i=", 97, " ", "Symmedian point of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640422285419*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a53b5a7f-b035-4492-96e3-ff1f8f7d9c9b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Tarry point\"\>"}],
  SequenceForm["i=", 98, " ", "Tarry point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640422375988*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"91ac83ef-e1cf-486f-b438-10ce1ee3abec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Steiner point\"\>"}],
  SequenceForm["i=", 99, " ", "Steiner point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640422450324*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"09519fb4-25ee-488f-b6c2-3f7f3adbc108"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X100\"\>"}],
  SequenceForm["i=", 100, " ", "X100"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404225002403`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cfe7f495-3125-4934-bc27-3935d9cc29e1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "101", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X101\"\>"}],
  SequenceForm["i=", 101, " ", "X101"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564042253791*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"863933a8-0582-4635-bb26-936757bfea2b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "102", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X102\"\>"}],
  SequenceForm["i=", 102, " ", "X102"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404225823*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7593f05c-eb8f-440b-bb5a-a630a2c332cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "103", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X103\"\>"}],
  SequenceForm["i=", 103, " ", "X103"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640422687628*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a6c39efd-59d5-4edc-8dd5-b5d1be827d5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "104", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X104\"\>"}],
  SequenceForm["i=", 104, " ", "X104"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404227207327`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"90ffaf3e-fad4-42d4-a0eb-9d5ddbbb5a0c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "105", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X105\"\>"}],
  SequenceForm["i=", 105, " ", "X105"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640422754179*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"da4675ed-ab8b-4e9f-ad41-46a8137da123"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "106", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X106\"\>"}],
  SequenceForm["i=", 106, " ", "X106"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640422806677*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2be41da4-ed02-4e93-ab67-92b2e495551b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "107", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X107\"\>"}],
  SequenceForm["i=", 107, " ", "X107"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404228468857`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d8fa39de-4a87-450b-a44c-d7cd970537bc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "108", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X108\"\>"}],
  SequenceForm["i=", 108, " ", "X108"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564042289056*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bd852adc-3c58-4964-b9d5-eb53e3382021"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "109", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X109\"\>"}],
  SequenceForm["i=", 109, " ", "X109"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640422930016*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"182d82e4-cfc7-4585-9199-994ed1061ec9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "110", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X110\"\>"}],
  SequenceForm["i=", 110, " ", "X110"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640422969583*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"aa958ff5-655a-4def-b57a-cd28324aec82"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "111", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X111\"\>"}],
  SequenceForm["i=", 111, " ", "X111"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404230175037`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1a774bc7-6728-4adc-9c61-97e6788e7a4e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "112", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X112\"\>"}],
  SequenceForm["i=", 112, " ", "X112"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423049987*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7b1b3e57-0f3f-42c8-978f-c63fb863113f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "113", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X113\"\>"}],
  SequenceForm["i=", 113, " ", "X113"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564042309095*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3964ec17-8078-46e3-a383-690b4c1919f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "114", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X114\"\>"}],
  SequenceForm["i=", 114, " ", "X114"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564042313343*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7de8f3f6-febb-4fcb-96a2-adbf186e727f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "115", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X115\"\>"}],
  SequenceForm["i=", 115, " ", "X115"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423198279*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a881710a-a32a-4b61-8b3f-99e6540647e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "116", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X116\"\>"}],
  SequenceForm["i=", 116, " ", "X116"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423242258*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"010e58e0-b5bc-44e8-841d-f9d0801b52be"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "117", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X117\"\>"}],
  SequenceForm["i=", 117, " ", "X117"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423320426*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"25ce3fe2-c81b-4ddb-a916-d1a4844fb6e7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "118", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r-power point\"\>"}],
  SequenceForm["i=", 118, " ", "r-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423374271*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b2d17eda-c221-4f3c-9f4d-bb4bade74484"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423406631*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"18789632-3932-47ad-b5a4-4fd12e7ca570"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "119", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r2-power point\"\>"}],
  SequenceForm["i=", 119, " ", "r2-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423409733*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"260ede7c-8414-491d-83df-f59f9146d57e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "120", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r3-power point\"\>"}],
  SequenceForm["i=", 120, " ", "r3-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404234426823`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"33e96e48-bbf5-4b90-89a0-8e6c965de93b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "121", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z1\"\>"}],
  SequenceForm["i=", 121, " ", "Z1"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423482777*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"062e0fad-ecc3-4dee-9af8-2644acbeb207"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "122", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z2\"\>"}],
  SequenceForm["i=", 122, " ", "Z2"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423520545*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"29d00775-1312-4296-933a-13d7ff9540db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "123", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z3\"\>"}],
  SequenceForm["i=", 123, " ", "Z3"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404235635633`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fc3dd73a-d1f3-47a5-a625-2490b1fcee1a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "124", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z4\"\>"}],
  SequenceForm["i=", 124, " ", "Z4"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564042363645*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8d50b7f1-9d86-4676-8301-959a6622b280"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "125", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z5\"\>"}],
  SequenceForm["i=", 125, " ", "Z5"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423719558*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34d252ad-a8c7-40a1-913b-c4035635932a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423767437*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"116219e1-5da8-4160-8278-8d334b1f735e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "126", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z6\"\>"}],
  SequenceForm["i=", 126, " ", "Z6"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423776175*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4238a5a1-7711-4e22-a93a-7869a6fdf8f8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "127", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z7\"\>"}],
  SequenceForm["i=", 127, " ", "Z7"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423842916*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e4b4f167-cffb-4111-891f-f3f9ec4aecfc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "128", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z8\"\>"}],
  SequenceForm["i=", 128, " ", "Z8"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423931019*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"39dcc0a7-3229-4821-adfa-6c95f6b57f97"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "129", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r4-power point\"\>"}],
  SequenceForm["i=", 129, " ", "r4-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640423965713*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fb5d8bf4-aa18-4bd1-a283-ae921d8b403c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640424003921*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6a904fcd-cebd-4cb3-a262-8e724bb774c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640424013735*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9a124662-12c7-4112-9b2f-96397cb0a6cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640427228198*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6a71da21-a48d-447d-b0fa-8531cf2b36af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "130", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"arbitrary center\"\>"}],
  SequenceForm["i=", 130, " ", "arbitrary center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640427231517*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2502e9c0-877d-429b-9ae0-67f6c6964391"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "131", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"areal center\"\>"}],
  SequenceForm["i=", 131, " ", "areal center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640427265689*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"83953672-e6ff-429a-a44d-7abd694deeba"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.805640427875422*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2bd520e2-02d6-473a-a6a2-4dafcf44a950"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"CASE \"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", "\<\"Harmonic Tetrahedron\"\>"}],
  SequenceForm["CASE ", 6, ": ", "Harmonic Tetrahedron"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640427878038*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6d86b41e-acd6-406e-9497-542b36dc82f3"],

Cell[BoxData["\<\"------\"\>"], "Print",
 CellChangeTimes->{3.805640427880204*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"819a125b-87df-460d-a8d8-f8871a1ffe17"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"incenter\"\>"}],
  SequenceForm["i=", 1, " ", "incenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640427913766*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dd1986db-8469-4004-809c-5376ec2b96a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640427916513*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fd05c962-4190-4d7f-9edb-8ca79091f7ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>"}],
  SequenceForm["i=", 2, " ", "centroid"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640427926552*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"959754a9-bfea-428a-9c78-cc196c25edc0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Faces are parallel.\"\>"}],
  SequenceForm["  ", "Faces are parallel."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640427961144*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"87e8d24e-eafe-4541-a1b0-bdd3e7982a2b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}],
  SequenceForm["    Coordinates of intersection point:  ", {1, 1, 1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640427964816*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"681dc22e-5327-47b5-8edf-0236e0e6ac26"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm["    Point coincides with ", "centroid", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640427967341*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9808d2b9-2b4b-4617-a7ef-545a159283dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "1", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 1, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640428048402*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ea62ea5e-1305-481a-9764-ed4253c626be"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640428051476*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d065eb6c-d8e0-4014-beba-a986561fe60f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404280538387`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"587af666-4853-47e4-a863-84f6bb28e351"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640428056066*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"50886b82-879f-4086-a54e-f45fe2f759d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra are similar.\"\>"}],
  SequenceForm["  ", "Tetrahedra are similar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640428058264*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ee6cc113-7ed3-4107-b6df-4baa84d64305"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640428091379*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d4dcf169-0bb5-4fa3-9a00-18b00c949f77"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"circumcenter\"\>",
    "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"Euler point\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "circumcenter", " coincides with reference ", "Euler point",
    "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640429009252*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9c144a14-74f8-4e2d-a5d9-8573f16d4845"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Central Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["2", "3"], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Central Monge point", " lies on reference Euler line (at ", 
   Rational[2, 3], ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404315240297`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a1dba588-ef75-4fa5-951f-30504c83747f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Central Euler point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["8", "9"], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Central Euler point", " lies on reference Euler line (at ", 
   Rational[8, 9], ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404363883333`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"704605b2-a7ba-428d-adb7-797ee0cdc147"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Reference \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" lies on central Euler line (at \"\>", 
   "\[InvisibleSpace]", "4", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    Reference ", "circumcenter", " lies on central Euler line (at ", 4, 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640439092032*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2438ef2b-80dd-472a-a7e2-8f45a4e5b2fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Reference \"\>", 
   "\[InvisibleSpace]", "\<\"Monge point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on central Euler line (at \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    Reference ", "Monge point", " lies on central Euler line (at ", -2, 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564043971323*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"61db5cd0-0076-4a92-9670-3b567f6bf296"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640440527141*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c33a8e97-060e-41fb-95e0-6ab449af4e62"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>"}],
  SequenceForm["i=", 3, " ", "circumcenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640440530037*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"94eae01e-9513-48d0-b215-8b39d64d8c46"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Point coincides with \"\>", 
   "\[InvisibleSpace]", "\<\"circumcenter\"\>", 
   "\[InvisibleSpace]", "\<\" of tetrahedron.\"\>"}],
  SequenceForm[
  "    Point coincides with ", "circumcenter", " of tetrahedron."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640453386098*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"757074f9-9efa-4c91-8efa-aaa755c13627"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", "\<\"Intersection point\"\>", 
   "\[InvisibleSpace]", "\<\" lies on reference Euler line (at \"\>", 
   "\[InvisibleSpace]", "0", "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "    ", "Intersection point", " lies on reference Euler line (at ", 0, ")."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640454559799*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"58fd54ff-feea-435d-8273-cdccc2802e99"],

Cell[BoxData["\<\"    4th coordinate of point of intersection is:\"\>"], \
"Print",
 CellChangeTimes->{3.8056404545625143`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5a8f1369-072f-42b5-95d8-b15f3bec3be5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"100", " ", "a1"}]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"100", " ", "a2"}]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"100", " ", "a3"}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a1", "6"], "-", 
      RowBox[{"200", " ", 
       SuperscriptBox["a1", "6"], " ", "a2"}], "-", 
      RowBox[{
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "2"]}], "+", 
      RowBox[{"10000", " ", 
       SuperscriptBox["a1", "6"], " ", 
       SuperscriptBox["a2", "2"]}], "+", 
      RowBox[{"200", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "4"]}], "+", 
      RowBox[{"200", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a2", "4"]}], "-", 
      RowBox[{"20000", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "4"]}], "+", 
      SuperscriptBox["a2", "6"], "-", 
      RowBox[{"200", " ", "a1", " ", 
       SuperscriptBox["a2", "6"]}], "+", 
      RowBox[{"10000", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "6"]}], "-", 
      RowBox[{"200", " ", 
       SuperscriptBox["a1", "6"], " ", "a3"}], "+", 
      RowBox[{"40000", " ", 
       SuperscriptBox["a1", "6"], " ", "a2", " ", "a3"}], "+", 
      RowBox[{"200", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "2"], " ", "a3"}], "-", 
      RowBox[{"2000000", " ", 
       SuperscriptBox["a1", "6"], " ", 
       SuperscriptBox["a2", "2"], " ", "a3"}], "-", 
      RowBox[{"40000", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "3"], " ", "a3"}], "+", 
      RowBox[{"200", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "4"], " ", "a3"}], "-", 
      RowBox[{"40000", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a2", "4"], " ", "a3"}], "+", 
      RowBox[{"4000000", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "4"], " ", "a3"}], "-", 
      RowBox[{"200", " ", 
       SuperscriptBox["a2", "6"], " ", "a3"}], "+", 
      RowBox[{"40000", " ", "a1", " ", 
       SuperscriptBox["a2", "6"], " ", "a3"}], "-", 
      RowBox[{"2000000", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "6"], " ", "a3"}], "-", 
      RowBox[{
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a3", "2"]}], "+", 
      RowBox[{"10000", " ", 
       SuperscriptBox["a1", "6"], " ", 
       SuperscriptBox["a3", "2"]}], "+", 
      RowBox[{"200", " ", 
       SuperscriptBox["a1", "4"], " ", "a2", " ", 
       SuperscriptBox["a3", "2"]}], "-", 
      RowBox[{"2000000", " ", 
       SuperscriptBox["a1", "6"], " ", "a2", " ", 
       SuperscriptBox["a3", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "2"]}], "-", 
      RowBox[{"400", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "2"]}], "+", 
      RowBox[{"100000000", " ", 
       SuperscriptBox["a1", "6"], " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "2"]}], "-", 
      RowBox[{"400", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "3"], " ", 
       SuperscriptBox["a3", "2"]}], "+", 
      RowBox[{"80000", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a2", "3"], " ", 
       SuperscriptBox["a3", "2"]}], "-", 
      RowBox[{"2000000", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "3"], " ", 
       SuperscriptBox["a3", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "2"]}], "+", 
      RowBox[{"200", " ", "a1", " ", 
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "2"]}], "-", 
      RowBox[{"2000000", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "2"]}], "+", 
      RowBox[{"10000", " ", 
       SuperscriptBox["a2", "6"], " ", 
       SuperscriptBox["a3", "2"]}], "-", 
      RowBox[{"2000000", " ", "a1", " ", 
       SuperscriptBox["a2", "6"], " ", 
       SuperscriptBox["a3", "2"]}], "+", 
      RowBox[{"100000000", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "6"], " ", 
       SuperscriptBox["a3", "2"]}], "+", 
      RowBox[{"200", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a3", "3"]}], "-", 
      RowBox[{"40000", " ", 
       SuperscriptBox["a1", "4"], " ", "a2", " ", 
       SuperscriptBox["a3", "3"]}], "-", 
      RowBox[{"400", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "3"]}], "+", 
      RowBox[{"80000", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "3"]}], "-", 
      RowBox[{"2000000", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "3"]}], "+", 
      RowBox[{"80000", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "3"], " ", 
       SuperscriptBox["a3", "3"]}], "-", 
      RowBox[{"16000000", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a2", "3"], " ", 
       SuperscriptBox["a3", "3"]}], "+", 
      RowBox[{"800000000", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "3"], " ", 
       SuperscriptBox["a3", "3"]}], "+", 
      RowBox[{"200", " ", 
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "3"]}], "-", 
      RowBox[{"40000", " ", "a1", " ", 
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "3"]}], "-", 
      RowBox[{"2000000", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "3"]}], "+", 
      RowBox[{"800000000", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "3"]}], "-", 
      RowBox[{"40000000000", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a3", "4"]}], "+", 
      RowBox[{"200", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a3", "4"]}], "-", 
      RowBox[{"20000", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a3", "4"]}], "+", 
      RowBox[{"200", " ", 
       SuperscriptBox["a1", "2"], " ", "a2", " ", 
       SuperscriptBox["a3", "4"]}], "-", 
      RowBox[{"40000", " ", 
       SuperscriptBox["a1", "3"], " ", "a2", " ", 
       SuperscriptBox["a3", "4"]}], "+", 
      RowBox[{"4000000", " ", 
       SuperscriptBox["a1", "4"], " ", "a2", " ", 
       SuperscriptBox["a3", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "4"]}], "+", 
      RowBox[{"200", " ", "a1", " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "4"]}], "-", 
      RowBox[{"2000000", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "4"]}], "+", 
      RowBox[{"200", " ", 
       SuperscriptBox["a2", "3"], " ", 
       SuperscriptBox["a3", "4"]}], "-", 
      RowBox[{"40000", " ", "a1", " ", 
       SuperscriptBox["a2", "3"], " ", 
       SuperscriptBox["a3", "4"]}], "-", 
      RowBox[{"2000000", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "3"], " ", 
       SuperscriptBox["a3", "4"]}], "+", 
      RowBox[{"800000000", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a2", "3"], " ", 
       SuperscriptBox["a3", "4"]}], "-", 
      RowBox[{"40000000000", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "3"], " ", 
       SuperscriptBox["a3", "4"]}], "-", 
      RowBox[{"20000", " ", 
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "4"]}], "+", 
      RowBox[{"4000000", " ", "a1", " ", 
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "4"]}], "-", 
      RowBox[{"40000000000", " ", 
       SuperscriptBox["a1", "3"], " ", 
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "4"]}], "+", 
      RowBox[{"2000000000000", " ", 
       SuperscriptBox["a1", "4"], " ", 
       SuperscriptBox["a2", "4"], " ", 
       SuperscriptBox["a3", "4"]}], "+", 
      SuperscriptBox["a3", "6"], "-", 
      RowBox[{"200", " ", "a1", " ", 
       SuperscriptBox["a3", "6"]}], "+", 
      RowBox[{"10000", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a3", "6"]}], "-", 
      RowBox[{"200", " ", "a2", " ", 
       SuperscriptBox["a3", "6"]}], "+", 
      RowBox[{"40000", " ", "a1", " ", "a2", " ", 
       SuperscriptBox["a3", "6"]}], "-", 
      RowBox[{"2000000", " ", 
       SuperscriptBox["a1", "2"], " ", "a2", " ", 
       SuperscriptBox["a3", "6"]}], "+", 
      RowBox[{"10000", " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "6"]}], "-", 
      RowBox[{"2000000", " ", "a1", " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "6"]}], "+", 
      RowBox[{"100000000", " ", 
       SuperscriptBox["a1", "2"], " ", 
       SuperscriptBox["a2", "2"], " ", 
       SuperscriptBox["a3", "6"]}]}], ")"}]}]}],
  SequenceForm[
  "    ", (-1 + 100 $CellContext`a1)^2 (-1 + 100 $CellContext`a2)^2 (-1 + 
     100 $CellContext`a3)^2 ($CellContext`a1^6 - 
    200 $CellContext`a1^6 $CellContext`a2 - $CellContext`a1^4 \
$CellContext`a2^2 + 10000 $CellContext`a1^6 $CellContext`a2^2 + 
    200 $CellContext`a1^4 $CellContext`a2^3 - $CellContext`a1^2 \
$CellContext`a2^4 + 200 $CellContext`a1^3 $CellContext`a2^4 - 
    20000 $CellContext`a1^4 $CellContext`a2^4 + $CellContext`a2^6 - 
    200 $CellContext`a1 $CellContext`a2^6 + 
    10000 $CellContext`a1^2 $CellContext`a2^6 - 
    200 $CellContext`a1^6 $CellContext`a3 + 
    40000 $CellContext`a1^6 $CellContext`a2 $CellContext`a3 + 
    200 $CellContext`a1^4 $CellContext`a2^2 $CellContext`a3 - 
    2000000 $CellContext`a1^6 $CellContext`a2^2 $CellContext`a3 - 
    40000 $CellContext`a1^4 $CellContext`a2^3 $CellContext`a3 + 
    200 $CellContext`a1^2 $CellContext`a2^4 $CellContext`a3 - 
    40000 $CellContext`a1^3 $CellContext`a2^4 $CellContext`a3 + 
    4000000 $CellContext`a1^4 $CellContext`a2^4 $CellContext`a3 - 
    200 $CellContext`a2^6 $CellContext`a3 + 
    40000 $CellContext`a1 $CellContext`a2^6 $CellContext`a3 - 
    2000000 $CellContext`a1^2 $CellContext`a2^6 $CellContext`a3 - \
$CellContext`a1^4 $CellContext`a3^2 + 
    10000 $CellContext`a1^6 $CellContext`a3^2 + 
    200 $CellContext`a1^4 $CellContext`a2 $CellContext`a3^2 - 
    2000000 $CellContext`a1^6 $CellContext`a2 $CellContext`a3^2 + 
    2 $CellContext`a1^2 $CellContext`a2^2 $CellContext`a3^2 - 
    400 $CellContext`a1^3 $CellContext`a2^2 $CellContext`a3^2 + 
    100000000 $CellContext`a1^6 $CellContext`a2^2 $CellContext`a3^2 - 
    400 $CellContext`a1^2 $CellContext`a2^3 $CellContext`a3^2 + 
    80000 $CellContext`a1^3 $CellContext`a2^3 $CellContext`a3^2 - 
    2000000 $CellContext`a1^4 $CellContext`a2^3 $CellContext`a3^2 - \
$CellContext`a2^4 $CellContext`a3^2 + 
    200 $CellContext`a1 $CellContext`a2^4 $CellContext`a3^2 - 
    2000000 $CellContext`a1^3 $CellContext`a2^4 $CellContext`a3^2 + 
    10000 $CellContext`a2^6 $CellContext`a3^2 - 
    2000000 $CellContext`a1 $CellContext`a2^6 $CellContext`a3^2 + 
    100000000 $CellContext`a1^2 $CellContext`a2^6 $CellContext`a3^2 + 
    200 $CellContext`a1^4 $CellContext`a3^3 - 
    40000 $CellContext`a1^4 $CellContext`a2 $CellContext`a3^3 - 
    400 $CellContext`a1^2 $CellContext`a2^2 $CellContext`a3^3 + 
    80000 $CellContext`a1^3 $CellContext`a2^2 $CellContext`a3^3 - 
    2000000 $CellContext`a1^4 $CellContext`a2^2 $CellContext`a3^3 + 
    80000 $CellContext`a1^2 $CellContext`a2^3 $CellContext`a3^3 - 
    16000000 $CellContext`a1^3 $CellContext`a2^3 $CellContext`a3^3 + 
    800000000 $CellContext`a1^4 $CellContext`a2^3 $CellContext`a3^3 + 
    200 $CellContext`a2^4 $CellContext`a3^3 - 
    40000 $CellContext`a1 $CellContext`a2^4 $CellContext`a3^3 - 
    2000000 $CellContext`a1^2 $CellContext`a2^4 $CellContext`a3^3 + 
    800000000 $CellContext`a1^3 $CellContext`a2^4 $CellContext`a3^3 - 
    40000000000 $CellContext`a1^4 $CellContext`a2^4 $CellContext`a3^3 - \
$CellContext`a1^2 $CellContext`a3^4 + 200 $CellContext`a1^3 $CellContext`a3^4 - 
    20000 $CellContext`a1^4 $CellContext`a3^4 + 
    200 $CellContext`a1^2 $CellContext`a2 $CellContext`a3^4 - 
    40000 $CellContext`a1^3 $CellContext`a2 $CellContext`a3^4 + 
    4000000 $CellContext`a1^4 $CellContext`a2 $CellContext`a3^4 - \
$CellContext`a2^2 $CellContext`a3^4 + 
    200 $CellContext`a1 $CellContext`a2^2 $CellContext`a3^4 - 
    2000000 $CellContext`a1^3 $CellContext`a2^2 $CellContext`a3^4 + 
    200 $CellContext`a2^3 $CellContext`a3^4 - 
    40000 $CellContext`a1 $CellContext`a2^3 $CellContext`a3^4 - 
    2000000 $CellContext`a1^2 $CellContext`a2^3 $CellContext`a3^4 + 
    800000000 $CellContext`a1^3 $CellContext`a2^3 $CellContext`a3^4 - 
    40000000000 $CellContext`a1^4 $CellContext`a2^3 $CellContext`a3^4 - 
    20000 $CellContext`a2^4 $CellContext`a3^4 + 
    4000000 $CellContext`a1 $CellContext`a2^4 $CellContext`a3^4 - 
    40000000000 $CellContext`a1^3 $CellContext`a2^4 $CellContext`a3^4 + 
    2000000000000 $CellContext`a1^4 $CellContext`a2^4 $CellContext`a3^4 + \
$CellContext`a3^6 - 200 $CellContext`a1 $CellContext`a3^6 + 
    10000 $CellContext`a1^2 $CellContext`a3^6 - 
    200 $CellContext`a2 $CellContext`a3^6 + 
    40000 $CellContext`a1 $CellContext`a2 $CellContext`a3^6 - 
    2000000 $CellContext`a1^2 $CellContext`a2 $CellContext`a3^6 + 
    10000 $CellContext`a2^2 $CellContext`a3^6 - 
    2000000 $CellContext`a1 $CellContext`a2^2 $CellContext`a3^6 + 
    100000000 $CellContext`a1^2 $CellContext`a2^2 $CellContext`a3^6)],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640454592307*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a5957cdf-9162-4007-880e-97720821759b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Normals concur.\"\>"}],
  SequenceForm["  ", "Normals concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640454596465*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"67099b6d-3f9f-4e9f-8c70-7fe45d6d28c8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"orthocenter\"\>"}],
  SequenceForm["i=", 4, " ", "orthocenter"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640454598832*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8d7d31b5-d01a-4fd0-b0fc-3a2a20592526"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"nine point center\"\>"}],
  SequenceForm["i=", 5, " ", "nine point center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640454765025*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"19d5d27a-7b27-4c2d-b18a-1810d80a8152"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"symmedian point\"\>"}],
  SequenceForm["i=", 6, " ", "symmedian point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404551335497`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c74056d0-71bd-41dd-b76a-d920033ff166"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640455168915*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ad12bb74-a5dc-484b-8483-cfcd09f53342"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne point\"\>"}],
  SequenceForm["i=", 7, " ", "Gergonne point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640455172514*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b851fa30-2102-4f5d-971f-710eb8625ecf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel point\"\>"}],
  SequenceForm["i=", 8, " ", "Nagel point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640455317459*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"42b9f8c7-848a-473e-b3f0-7f13c3e8ca88"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt\"\>"}],
  SequenceForm["i=", 9, " ", "Mittenpunkt"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640455383144*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bac9e26c-6a2f-4821-a5f9-b8822ec2cfe8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker center\"\>"}],
  SequenceForm["i=", 10, " ", "Spieker center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404554805117`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"20ec0805-cec5-47e6-be1a-29f7b9f1b3aa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach point\"\>"}],
  SequenceForm["i=", 11, " ", "Feuerbach point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640455527584*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6eca1651-2ccc-4ac0-8da5-15a8671baebb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Points are coplanar.\"\>"}],
  
  SequenceForm["  ", "Points are coplanar."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564045620284*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6af036ca-eb7d-4512-8114-dfe7a3fec40e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12\"\>"}],
  SequenceForm["i=", 12, " ", "X12"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404562397127`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a3bbea34-2d46-4413-963a-ea4c7ede3dd5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st isogonic center (Fermat point)\"\>"}],
  SequenceForm["i=", 13, " ", "1st isogonic center (Fermat point)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640456412435*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"20169c0a-0949-4bb7-b066-4336c7a59ad3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isogonic center\"\>"}],
  SequenceForm["i=", 14, " ", "2nd Isogonic center"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404585069857`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"75eeb638-e984-4aa5-9633-87e022896de3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Isodynamic point\"\>"}],
  SequenceForm["i=", 15, " ", "1st Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564046052003*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"22a5f006-8f09-4fc6-a0d2-13c4a962c818"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Isodynamic point\"\>"}],
  SequenceForm["i=", 16, " ", "2nd Isodynamic point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640461728561*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8013984a-5c39-4395-9e3a-108e2b804609"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point\"\>"}],
  SequenceForm["i=", 17, " ", "1st Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640462911807*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c3a57ae3-5dfe-41b5-b1c7-ce5d7e3eaad2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "18", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point\"\>"}],
  SequenceForm["i=", 18, " ", "2nd Napoleon point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640465000719*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"684003af-e2ac-4d0e-97da-bace875c9034"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point\"\>"}],
  SequenceForm["i=", 19, " ", "Crucial point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640466918293*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6f344841-57b0-430a-b1f9-39614c046631"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point\"\>"}],
  SequenceForm["i=", 20, " ", "De Longchamps point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640467087764*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8088bd4a-2f79-4ed4-bedd-b32d38360c38"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point\"\>"}],
  SequenceForm["i=", 21, " ", "Schiffler point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640467470539*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"937e35e5-3cef-460a-9130-2ce7c04124a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "22", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point\"\>"}],
  SequenceForm["i=", 22, " ", "Exeter point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640467576105*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"6d01d6e0-b215-4cc5-acff-de9d75cb3b7b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point\"\>"}],
  SequenceForm["i=", 23, " ", "far out point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404677347517`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3612a20e-6a15-4f93-9bef-d19ad1df5351"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "24", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24\"\>"}],
  SequenceForm["i=", 24, " ", "X24"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404679309397`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e7ce8aee-df9c-4429-9419-aa7dba490776"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25\"\>"}],
  SequenceForm["i=", 25, " ", "X25"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640468318722*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"98ecb6d9-4127-4276-810f-c9b7289316d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "26", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle\"\>"}],
  SequenceForm["i=", 26, " ", "Circumcenter of tangential triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404684579353`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"3227f53e-432b-4987-a1c8-64aec8ac78d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27\"\>"}],
  SequenceForm["i=", 27, " ", "X27"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640469942646*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"104e98fa-c6e3-4e44-a051-e3f916865b58"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28\"\>"}],
  SequenceForm["i=", 28, " ", "X28"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564047023232*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bed622ff-29c8-4111-a1ce-c0765c31262d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "29", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29\"\>"}],
  SequenceForm["i=", 29, " ", "X29"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640470477522*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5a244631-28b8-4c93-9aa3-9a37234d39e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30\"\>"}],
  SequenceForm["i=", 30, " ", "X30"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056404708198442`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"33e717c2-defa-4f60-a63a-0b631df6a872"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640470870339*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"91c4dc18-9311-418e-9db3-29067f4a6a51"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564047090972*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"35cab28f-a8c1-4050-bdf5-e089e64c6135"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have centers in common.\"\>"}],
  SequenceForm["  ", "Tetrahedra have centers in common."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405242224083`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"27a9a4b3-f53e-43ba-a6c0-f4486c6a29f0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point\"\>"}],
  SequenceForm["i=", 31, " ", "2nd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564052422541*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2c00f0a0-924c-4722-be85-c8259a247a3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640524265951*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"390ad224-9a86-4565-b24f-415cf3a0d2db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point\"\>"}],
  SequenceForm["i=", 32, " ", "3rd power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640524269578*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c5f48879-aac0-453b-9ecd-8d31ad336a07"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640524309023*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5eb89828-5c34-413a-9a15-b7d848c65e37"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "33", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33\"\>"}],
  SequenceForm["i=", 33, " ", "X33"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640524318253*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"8db65027-dca2-4748-b6ee-2b47c9a0d9dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34\"\>"}],
  SequenceForm["i=", 34, " ", "X34"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640524581373*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"14c6e5bc-f793-4b37-9932-46abc0daa919"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35\"\>"}],
  SequenceForm["i=", 35, " ", "X35"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405249207783`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34b0eb42-8851-4640-b889-dcb05128cb8e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36\"\>"}],
  SequenceForm["i=", 36, " ", "X36"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640525108568*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"69824359-fa4f-4e42-b33c-670a41797db3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37\"\>"}],
  SequenceForm["i=", 37, " ", "X37"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640525272032*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"73af87a7-6b89-445e-b033-874c93ef0484"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38\"\>"}],
  SequenceForm["i=", 38, " ", "X38"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405253296423`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"009818a4-cfd2-4848-9763-153198ec82eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint\"\>"}],
  SequenceForm["i=", 39, " ", "Brocard midpoint"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405254251127`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"0ff6f2b3-9955-4e3d-8685-b9831914e6cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40\"\>"}],
  SequenceForm["i=", 40, " ", "X40"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640525504582*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"67b0aeb8-3000-4c3a-bdf9-bba477f07785"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41\"\>"}],
  SequenceForm["i=", 41, " ", "X41"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405260273533`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"39158c36-d65f-4247-8aab-0740538d4bca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42\"\>"}],
  SequenceForm["i=", 42, " ", "X42"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405261789093`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4a9618ac-63eb-4cb5-81db-4b993e63e966"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43\"\>"}],
  SequenceForm["i=", 43, " ", "X43"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640526249551*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"415ee5f0-d24e-44b9-ace5-0ad64aefe55b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405262945213`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"22fa5a2b-db5f-4485-b579-f1ee2fdd6550"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44\"\>"}],
  SequenceForm["i=", 44, " ", "X44"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640526323348*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"cfafd1f1-d2cf-4b87-a5a4-0f2e609b0f9c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45\"\>"}],
  SequenceForm["i=", 45, " ", "X45"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640526443528*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"79bd6759-8531-4875-9535-c1f992f741a4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46\"\>"}],
  SequenceForm["i=", 46, " ", "X46"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640526592852*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"44b187e0-1b46-42f8-bb82-2bf7b02d7b0b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "47", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47\"\>"}],
  SequenceForm["i=", 47, " ", "X47"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640527133897*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d6e473b5-408c-4671-81ca-2d15961687d1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "48", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48\"\>"}],
  SequenceForm["i=", 48, " ", "X48"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640527406507*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"efecf301-2193-4811-ad40-ac159d381e9a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "49", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49\"\>"}],
  SequenceForm["i=", 49, " ", "X49"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640527553649*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7c1086f0-afc8-4d15-b205-8b232509da74"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "50", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50\"\>"}],
  SequenceForm["i=", 50, " ", "X50"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405280519238`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c6dfe17b-474d-4893-bb01-02efec922dc8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle\"\>"}],
  SequenceForm["i=", 51, " ", "Centroid of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405284447317`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"453ead8f-a61d-4a08-bc18-560a9098cb31"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle\"\>"}],
  SequenceForm["i=", 52, " ", "Orthocenter of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640528878594*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a8e755e2-0bb0-4383-80fa-0086cdc3b3c6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle\"\>"}],
  SequenceForm["i=", 53, " ", "Symmedian point of orthic triangle"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640529685808*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"51f0bfba-d47a-4c27-b74e-2cb85f98e1cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "54", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nine point inv\"\>"}],
  SequenceForm["i=", 54, " ", "Nine point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405302569847`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"dc3505b2-e9ee-4774-8c2e-269835a6e6d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Gergonne inv\"\>"}],
  SequenceForm["i=", 55, " ", "Gergonne inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640530713575*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"38521d6f-53a1-4e35-9d13-73b4793669f0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Nagel inv\"\>"}],
  SequenceForm["i=", 56, " ", "Nagel inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640530853505*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b7d698ae-31e3-42b8-ab0f-04faffc605f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Mittenpunkt inv\"\>"}],
  SequenceForm["i=", 57, " ", "Mittenpunkt inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640530952506*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"236ac498-1e3a-4975-9d90-e72eedd7c224"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Spieker inv\"\>"}],
  SequenceForm["i=", 58, " ", "Spieker inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405310216*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a0fb6ceb-2485-4e0b-a558-55fe719c49a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Feuerbach inv\"\>"}],
  SequenceForm["i=", 59, " ", "Feuerbach inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640531100987*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c58bd6ea-4160-402e-9a49-ecdbd2ec48ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X12 inv\"\>"}],
  
  SequenceForm["i=", 60, " ", "X12 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640531232223*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fd42e18c-8925-4120-8ed3-a3d5610c0d54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "61", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"1st Napoleon point inv\"\>"}],
  SequenceForm["i=", 61, " ", "1st Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640531358781*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2de60ee6-c050-4842-8b0f-ffae22f90623"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "62", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd Napoleon point inv\"\>"}],
  SequenceForm["i=", 62, " ", "2nd Napoleon point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405325555973`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"240ac400-1228-49e7-99e0-f2a529adc820"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Crucial point inv\"\>"}],
  SequenceForm["i=", 63, " ", "Crucial point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640533663322*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c24950b4-db6a-40e1-a787-65a28949505c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "64", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"De Longchamps point inv\"\>"}],
  SequenceForm["i=", 64, " ", "De Longchamps point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405337906303`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4c170645-6c91-42ee-83cd-0477f909e9d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Schiffler point inv\"\>"}],
  SequenceForm["i=", 65, " ", "Schiffler point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405344561653`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b252d646-b2a4-43b0-b5ce-653f6e2013a7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "66", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Exeter point inv\"\>"}],
  SequenceForm["i=", 66, " ", "Exeter point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405345381737`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ef9cf6de-005e-4bd8-99fc-78d857709489"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"far out point inv\"\>"}],
  SequenceForm["i=", 67, " ", "far out point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640534717762*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fd1e726f-48a8-4cef-b03a-2f2d0bdc91e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "68", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X24 inv\"\>"}],
  
  SequenceForm["i=", 68, " ", "X24 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405349350452`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2f7254f7-cefd-4fa7-bbe7-0badf2487c22"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X25 inv\"\>"}],
  
  SequenceForm["i=", 69, " ", "X25 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640535296302*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ab5b8f38-e65f-4fa2-a3be-bb9326376cd0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "70", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Circumcenter of tangential triangle inv\"\>"}],
  SequenceForm["i=", 70, " ", "Circumcenter of tangential triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640535361023*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"48b2ac41-fa58-4e5f-a60b-2d410ed07b8a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X27 inv\"\>"}],
  
  SequenceForm["i=", 71, " ", "X27 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640536759362*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a650ded3-6fa8-48f9-bd4c-a39fa3df1f72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X28 inv\"\>"}],
  
  SequenceForm["i=", 72, " ", "X28 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640536948667*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ed30dbfc-d784-43a5-baab-11c1b9c0cffa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "73", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X29 inv\"\>"}],
  
  SequenceForm["i=", 73, " ", "X29 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405370893507`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5ff72c83-99ef-447e-a025-8edd47659c51"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X30 inv\"\>"}],
  
  SequenceForm["i=", 74, " ", "X30 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640537475555*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a726ab17-5627-4007-8d43-197fb1dbd187"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"2nd power point inv\"\>"}],
  SequenceForm["i=", 75, " ", "2nd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640538211343*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"972c8911-febb-4762-91c7-80cfa82022ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640538238718*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"47372527-1848-4f90-bce8-6ed02e650757"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"3rd power point inv\"\>"}],
  SequenceForm["i=", 76, " ", "3rd power point inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405382672453`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"15916a91-486d-4bf2-86b0-ef7c29ca2b27"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405382770767`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4637f2aa-eb89-4170-912f-bee7f3530d00"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "77", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X33 inv\"\>"}],
  
  SequenceForm["i=", 77, " ", "X33 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640538306394*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"84547ec9-3eae-48ba-bf59-7d88b350497e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X34 inv\"\>"}],
  
  SequenceForm["i=", 78, " ", "X34 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640538539906*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"40665dce-be30-4267-aae0-3c50f54a2f8d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X35 inv\"\>"}],
  
  SequenceForm["i=", 79, " ", "X35 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640538759418*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4dcba5ee-247e-4f50-9530-df5d7523b425"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X36 inv\"\>"}],
  
  SequenceForm["i=", 80, " ", "X36 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640538960785*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b696564-00e6-4984-ade1-ee80f423a268"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X37 inv\"\>"}],
  
  SequenceForm["i=", 81, " ", "X37 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640539117675*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e3d56359-fd3c-4d5f-a180-3b01af90ab8d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X38 inv\"\>"}],
  
  SequenceForm["i=", 82, " ", "X38 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640539188109*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"314dcb19-d65c-4b82-b93a-4c481eff5fc6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Brocard midpoint inv\"\>"}],
  SequenceForm["i=", 83, " ", "Brocard midpoint inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405393058*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5dc73a8a-f6d7-46f3-8f05-8223853bc410"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "84", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X40 inv\"\>"}],
  
  SequenceForm["i=", 84, " ", "X40 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640539372758*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"29bc4254-fc71-4241-a8b0-ac6728c8027d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X41 inv\"\>"}],
  
  SequenceForm["i=", 85, " ", "X41 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405399928923`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b753665b-f4cd-45e1-bde4-bebb43bad8c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X42 inv\"\>"}],
  
  SequenceForm["i=", 86, " ", "X42 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640540147002*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"38be557f-f962-4979-855d-e9ade09aa0a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "87", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X43 inv\"\>"}],
  
  SequenceForm["i=", 87, " ", "X43 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640540201082*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"92ecdd4d-1141-4a24-a72c-2e5bc1f6c5a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640540245013*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5b39203b-3b41-44ed-a838-1e349da3cf94"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X44 inv\"\>"}],
  
  SequenceForm["i=", 88, " ", "X44 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405402757177`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4c4f9722-0fed-497a-8899-6edb543913e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X45 inv\"\>"}],
  
  SequenceForm["i=", 89, " ", "X45 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564054040625*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f1f2a0fa-89f7-4ac5-8428-4425e0c5a16b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "90", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X46 inv\"\>"}],
  
  SequenceForm["i=", 90, " ", "X46 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640540532074*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d62f8c90-867c-4924-bd87-4a705ad277f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "91", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X47 inv\"\>"}],
  
  SequenceForm["i=", 91, " ", "X47 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405411663017`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"df0cde3f-cdc7-4e58-aaa2-de002620570a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "92", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X48 inv\"\>"}],
  
  SequenceForm["i=", 92, " ", "X48 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640541491922*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9321da27-90ad-4f67-8116-5df02ffaf0f4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "93", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X49 inv\"\>"}],
  
  SequenceForm["i=", 93, " ", "X49 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640541695692*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bd4459a4-4aa6-41ae-a587-2e71723911e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X50 inv\"\>"}],
  
  SequenceForm["i=", 94, " ", "X50 inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640542432184*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"d7bc06c3-25ba-4636-9d68-ea9f49499985"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Centroid of orthic triangle inv\"\>"}],
  SequenceForm["i=", 95, " ", "Centroid of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640542867147*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"88cefb63-736b-402e-99d7-8bf2406612ea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "96", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Orthocenter of orthic triangle inv\"\>"}],
  SequenceForm["i=", 96, " ", "Orthocenter of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640543288838*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1bce28f8-d994-4176-8cbb-dcdd1f64ba20"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "97", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Symmedian point of orthic triangle inv\"\>"}],
  SequenceForm["i=", 97, " ", "Symmedian point of orthic triangle inv"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640544204585*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"658e1a73-942f-4d09-b22b-2e14ec51f7a4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Tarry point\"\>"}],
  SequenceForm["i=", 98, " ", "Tarry point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640544782013*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"bc68ea02-eed5-436b-aeb0-78fbbd167529"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"Steiner point\"\>"}],
  SequenceForm["i=", 99, " ", "Steiner point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640545105542*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b778a36c-d7e1-4021-831e-f0da0835e4e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X100\"\>"}],
  SequenceForm["i=", 100, " ", "X100"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405451870117`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f23b73ab-cb75-452c-b5be-0cbd7a73a276"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "101", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X101\"\>"}],
  SequenceForm["i=", 101, " ", "X101"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640545263879*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"205a72c3-08ce-4938-8b92-58e9dfaab067"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "102", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X102\"\>"}],
  SequenceForm["i=", 102, " ", "X102"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405453411283`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"833b20e4-1124-4789-a614-e9d01ee8b331"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", "a2"}], "-", 
        RowBox[{"a1", " ", "a3"}], "-", 
        RowBox[{"a2", " ", "a3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", "a2"}], "-", 
        RowBox[{"a1", " ", "a3"}], "+", 
        RowBox[{"a2", " ", "a3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a1"}], " ", "a2"}], "-", 
        RowBox[{"a1", " ", "a3"}], "-", 
        RowBox[{"a2", " ", "a3"}], "+", 
        RowBox[{"200", " ", "a1", " ", "a2", " ", "a3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", "a2"}], "-", 
        RowBox[{"a1", " ", "a3"}], "-", 
        RowBox[{"a2", " ", "a3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", "a2"}], "+", 
        RowBox[{"a1", " ", "a3"}], "-", 
        RowBox[{"a2", " ", "a3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a1"}], " ", "a2"}], "-", 
        RowBox[{"a1", " ", "a3"}], "-", 
        RowBox[{"a2", " ", "a3"}], "+", 
        RowBox[{"200", " ", "a1", " ", "a2", " ", "a3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a1", " ", "a2"}], "+", 
         RowBox[{"a1", " ", "a3"}], "-", 
         RowBox[{"a2", " ", "a3"}]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", "a2"}], "-", 
        RowBox[{"a1", " ", "a3"}], "+", 
        RowBox[{"a2", " ", "a3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a1"}], " ", "a2"}], "-", 
        RowBox[{"a1", " ", "a3"}], "-", 
        RowBox[{"a2", " ", "a3"}], "+", 
        RowBox[{"200", " ", "a1", " ", "a2", " ", "a3"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", "a2"}], "-", 
        RowBox[{"a1", " ", "a3"}], "-", 
        RowBox[{"a2", " ", "a3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", "a2"}], "+", 
        RowBox[{"a1", " ", "a3"}], "-", 
        RowBox[{"a2", " ", "a3"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", "a2"}], "-", 
        RowBox[{"a1", " ", "a3"}], "+", 
        RowBox[{"a2", " ", "a3"}]}], ")"}]}]}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {($CellContext`a1 \
$CellContext`a2 - $CellContext`a1 $CellContext`a3 - $CellContext`a2 \
$CellContext`a3) ($CellContext`a1 $CellContext`a2 - $CellContext`a1 \
$CellContext`a3 + $CellContext`a2 $CellContext`a3) (-$CellContext`a1 \
$CellContext`a2 - $CellContext`a1 $CellContext`a3 - $CellContext`a2 \
$CellContext`a3 + 
     200 $CellContext`a1 $CellContext`a2 $CellContext`a3), ($CellContext`a1 \
$CellContext`a2 - $CellContext`a1 $CellContext`a3 - $CellContext`a2 \
$CellContext`a3) ($CellContext`a1 $CellContext`a2 + $CellContext`a1 \
$CellContext`a3 - $CellContext`a2 $CellContext`a3) (-$CellContext`a1 \
$CellContext`a2 - $CellContext`a1 $CellContext`a3 - $CellContext`a2 \
$CellContext`a3 + 
     200 $CellContext`a1 $CellContext`a2 $CellContext`a3), -($CellContext`a1 \
$CellContext`a2 + $CellContext`a1 $CellContext`a3 - $CellContext`a2 \
$CellContext`a3) ($CellContext`a1 $CellContext`a2 - $CellContext`a1 \
$CellContext`a3 + $CellContext`a2 $CellContext`a3) (-$CellContext`a1 \
$CellContext`a2 - $CellContext`a1 $CellContext`a3 - $CellContext`a2 \
$CellContext`a3 + 
     200 $CellContext`a1 $CellContext`a2 $CellContext`a3), ($CellContext`a1 \
$CellContext`a2 - $CellContext`a1 $CellContext`a3 - $CellContext`a2 \
$CellContext`a3) ($CellContext`a1 $CellContext`a2 + $CellContext`a1 \
$CellContext`a3 - $CellContext`a2 $CellContext`a3) ($CellContext`a1 \
$CellContext`a2 - $CellContext`a1 $CellContext`a3 + $CellContext`a2 \
$CellContext`a3)}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640545401236*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"74b65311-efe6-4f3e-9f42-27dbf61f6a2a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405456505823`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fe68ac05-1aa4-4bee-89c3-c9f2bef7dfe8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.80564054565341*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e86386dc-2c18-4493-ba6f-934f593235d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "103", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X103\"\>"}],
  SequenceForm["i=", 103, " ", "X103"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405456807213`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"34157b5b-cf7b-4389-b3e4-34f6cf673d79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "104", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X104\"\>"}],
  SequenceForm["i=", 104, " ", "X104"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405457980413`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"f37a1592-259e-41af-996d-ee580d5e81a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "105", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X105\"\>"}],
  SequenceForm["i=", 105, " ", "X105"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405458552513`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"70566f0c-a501-4746-ab39-26842bb99048"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "106", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X106\"\>"}],
  SequenceForm["i=", 106, " ", "X106"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640545931465*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ba495407-7c47-4f29-b956-8bcc02d35054"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "107", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X107\"\>"}],
  SequenceForm["i=", 107, " ", "X107"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640546000916*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"5ab85b62-50d9-4a95-92e8-0e05611bfefa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "108", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X108\"\>"}],
  SequenceForm["i=", 108, " ", "X108"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640546069921*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9884949e-d1ac-4be2-9388-46f5d55dbe3f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "109", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X109\"\>"}],
  SequenceForm["i=", 109, " ", "X109"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405461835957`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4a757db4-d2c8-4b83-9ae6-521033d06eb3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "110", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X110\"\>"}],
  SequenceForm["i=", 110, " ", "X110"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405462803802`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"9cf9eeb8-eb2d-4db2-a591-52e6ca61468f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "111", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X111\"\>"}],
  SequenceForm["i=", 111, " ", "X111"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640546396283*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"97c664e1-be42-440c-bb26-a44f2222e3f4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "112", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X112\"\>"}],
  SequenceForm["i=", 112, " ", "X112"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640546445201*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"94eafeb4-7604-4f71-8933-6c87ee850f62"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "113", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X113\"\>"}],
  SequenceForm["i=", 113, " ", "X113"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640546601191*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4b685a8c-b94e-49bd-a3fc-d012490831a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "114", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X114\"\>"}],
  SequenceForm["i=", 114, " ", "X114"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405467175493`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a16b4c27-e7f7-403d-94e3-16b5d84ebe97"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "115", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X115\"\>"}],
  SequenceForm["i=", 115, " ", "X115"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640546837434*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"190864e7-381e-43d7-ba57-2ee95c901bcd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "116", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X116\"\>"}],
  SequenceForm["i=", 116, " ", "X116"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640546972148*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"400d9209-11a4-407a-ac6b-a2c65a34d4b2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "117", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"X117\"\>"}],
  SequenceForm["i=", 117, " ", "X117"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640547137054*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"fde6a5e8-9c3a-44a3-b72a-b44bf35ec944"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Coordinates of intersection point:  \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a1", " ", "a2"}], "+", 
      RowBox[{"a1", " ", "a3"}], "-", 
      RowBox[{"a2", " ", "a3"}]}], ",", 
     RowBox[{
      RowBox[{"a1", " ", "a2"}], "-", 
      RowBox[{"a1", " ", "a3"}], "+", 
      RowBox[{"a2", " ", "a3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a1"}], " ", "a2"}], "+", 
      RowBox[{"a1", " ", "a3"}], "+", 
      RowBox[{"a2", " ", "a3"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a1"}], " ", "a2"}], "-", 
      RowBox[{"a1", " ", "a3"}], "-", 
      RowBox[{"a2", " ", "a3"}], "+", 
      RowBox[{"200", " ", "a1", " ", "a2", " ", "a3"}]}]}], "}"}]}],
  SequenceForm[
  "    Coordinates of intersection point:  ", {$CellContext`a1 \
$CellContext`a2 + $CellContext`a1 $CellContext`a3 - $CellContext`a2 \
$CellContext`a3, $CellContext`a1 $CellContext`a2 - $CellContext`a1 \
$CellContext`a3 + $CellContext`a2 $CellContext`a3, -$CellContext`a1 \
$CellContext`a2 + $CellContext`a1 $CellContext`a3 + $CellContext`a2 \
$CellContext`a3, -$CellContext`a1 $CellContext`a2 - $CellContext`a1 \
$CellContext`a3 - $CellContext`a2 $CellContext`a3 + 
    200 $CellContext`a1 $CellContext`a2 $CellContext`a3}],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640547177593*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b121f0f0-bc59-416b-841c-0495934cfde9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", "\[InvisibleSpace]", "\<\"Cevians concur.\"\>"}],
  SequenceForm["  ", "Cevians concur."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640547377256*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"a7754ec9-e724-467b-ab8a-6fb4487809e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405473801737`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e51ade34-61be-42b7-94ee-72820daea340"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "118", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r-power point\"\>"}],
  SequenceForm["i=", 118, " ", "r-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640547407462*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"50660b20-72e7-476a-b59e-2ffc75454145"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Cevians form a hyperbolic group.\"\>"}],
  SequenceForm["  ", "Cevians form a hyperbolic group."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640547439527*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c6b5442b-763c-4d55-b875-0acd55ac7224"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "119", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r2-power point\"\>"}],
  SequenceForm["i=", 119, " ", "r2-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640547471018*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"4566fd87-5332-4f44-a329-a6b2fe25cc9f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "120", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r3-power point\"\>"}],
  SequenceForm["i=", 120, " ", "r3-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640547513646*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"7398d87a-df2d-4676-896e-d7595cf3344b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "121", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z1\"\>"}],
  SequenceForm["i=", 121, " ", "Z1"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405475721807`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c6cddb1a-500b-4235-81ae-0ba8dcc26c28"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "122", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z2\"\>"}],
  SequenceForm["i=", 122, " ", "Z2"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405476721773`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"20b62377-fa87-412f-8b61-3fa115192db9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "123", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z3\"\>"}],
  SequenceForm["i=", 123, " ", "Z3"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640547827188*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e637838d-365c-4747-90ae-f239dd5d49c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "124", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z4\"\>"}],
  SequenceForm["i=", 124, " ", "Z4"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640548063097*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"e9530aad-08b3-4d25-a428-e9c9a1bceedc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "125", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z5\"\>"}],
  SequenceForm["i=", 125, " ", "Z5"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640548316568*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"c350c24f-8af3-41f0-8952-ff0bff1e81af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "126", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z6\"\>"}],
  SequenceForm["i=", 126, " ", "Z6"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640548520081*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"80719f87-cdf6-4964-93b4-2f3d6817388e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "127", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z7\"\>"}],
  SequenceForm["i=", 127, " ", "Z7"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405486201963`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"2d3fb804-b465-43ef-8d63-670541c9f48c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "128", 
   "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "\<\"Z8\"\>"}],
  SequenceForm["i=", 128, " ", "Z8"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640548828648*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"75d88415-02b2-461f-bedf-9e943d031476"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "129", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"r4-power point\"\>"}],
  SequenceForm["i=", 129, " ", "r4-power point"],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640548893385*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"b885a4d8-f54c-4500-aed5-9ad387d8f714"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  \"\>", 
   "\[InvisibleSpace]", "\<\"Tetrahedra have same centroid.\"\>"}],
  SequenceForm["  ", "Tetrahedra have same centroid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.805640548937901*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"1f174a7f-20f9-407c-bd48-c13a246c36ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    Central \"\>", "\[InvisibleSpace]", "\<\"centroid\"\>", 
   "\[InvisibleSpace]", "\<\" coincides with reference \"\>", 
   "\[InvisibleSpace]", "\<\"centroid\"\>", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "    Central ", "centroid", " coincides with reference ", "centroid", "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8056405489665318`*^9},
 CellLabel->
  "During evaluation of \
In[346]:=",ExpressionUUID->"ca40c952-9f62-49fb-a8d0-7952abe5432a"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.8056435459550323`*^9},
 CellLabel->
  "Out[386]=",ExpressionUUID->"c17f15b9-d7ee-47d9-8924-5d7d6db66c5a"]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{882, 921},
WindowMargins->{{809, Automatic}, {Automatic, 152}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb",
PrivateNotebookOptions -> {"ColorPalette" -> {RGBColor, -1}},
RenderingOptions -> {"ObjectDithering" -> True},
RenderingOptions -> {"RasterDithering" -> False},
MacintoshSystemPageSetup -> \
"00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001\n\
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 893, 16, 196, "Text",ExpressionUUID->"371ff2f8-f3d0-420c-b039-e77672a2725a"],
Cell[1454, 38, 896, 19, 115, "Input",ExpressionUUID->"b1163c4e-79d8-4c96-b931-923fe0f4dfc2"],
Cell[CellGroupData[{
Cell[2375, 61, 1306, 47, 766, "Input",ExpressionUUID->"4234ab68-a109-4864-a278-29656578f3a7",
 InitializationCell->True],
Cell[3684, 110, 256, 5, 24, "Print",ExpressionUUID->"51ccb197-f6cc-4555-8c1a-6e0f71201997"],
Cell[3943, 117, 496, 12, 24, "Print",ExpressionUUID->"76ac379a-1d58-4294-bb88-66de29a0315e"],
Cell[4442, 131, 256, 5, 24, "Print",ExpressionUUID->"ee91ec92-eaea-439f-9dc5-4123c0a1f45a"],
Cell[4701, 138, 536, 13, 40, "Print",ExpressionUUID->"5e85d021-a840-4b44-852d-43cadcdf930b"],
Cell[5240, 153, 256, 5, 24, "Print",ExpressionUUID->"405d1c23-165e-4030-8cdf-d0e1667e7907"],
Cell[5499, 160, 776, 22, 27, "Print",ExpressionUUID->"28daf1c5-1250-42c8-8971-94a3fcf917da"],
Cell[6278, 184, 256, 5, 24, "Print",ExpressionUUID->"38078b31-b19c-4f75-aa86-5d920f1e7a70"],
Cell[6537, 191, 807, 23, 46, "Print",ExpressionUUID->"5fc19aee-aeb8-4081-8562-220f34827195"],
Cell[7347, 216, 256, 5, 24, "Print",ExpressionUUID->"5bfc5989-acaa-4c41-9605-74c0159aad6e"],
Cell[7606, 223, 1081, 29, 43, "Print",ExpressionUUID->"4cbf2f36-0b25-4eef-b2e9-de5d8e4768b2"],
Cell[8690, 254, 256, 5, 24, "Print",ExpressionUUID->"7fdb971a-426d-4eef-94d1-48c9cd03beaf"],
Cell[8949, 261, 525, 12, 24, "Print",ExpressionUUID->"03fc96fc-877f-4642-b2da-e828604f51f6"],
Cell[9477, 275, 256, 5, 24, "Print",ExpressionUUID->"a6acf05d-f4da-4fab-97a3-a761755d08e0"],
Cell[9736, 282, 720, 20, 42, "Print",ExpressionUUID->"c4889aab-d6df-433b-90e8-9053ee5bdbc2"],
Cell[10459, 304, 256, 5, 24, "Print",ExpressionUUID->"3294a03e-b2b2-4672-90ac-10ee1fb11d5c"],
Cell[10718, 311, 655, 18, 41, "Print",ExpressionUUID->"a7bc21b2-9c87-47d7-8c04-de889c314ca8"],
Cell[11376, 331, 258, 5, 24, "Print",ExpressionUUID->"82012601-404e-4f94-9c99-a83ef3fa4ad7"],
Cell[11637, 338, 610, 16, 24, "Print",ExpressionUUID->"30d62214-60aa-430d-8a4e-89a689242e87"],
Cell[12250, 356, 255, 5, 24, "Print",ExpressionUUID->"67c0ee30-5d03-4a4c-bea0-4bbab63ea4f3"],
Cell[12508, 363, 618, 16, 41, "Print",ExpressionUUID->"83827553-bdc9-4a65-b70f-3754299f36e8"],
Cell[13129, 381, 256, 5, 24, "Print",ExpressionUUID->"f36d9b9f-d255-4ad0-9d57-e4476751bbf1"],
Cell[13388, 388, 867, 24, 43, "Print",ExpressionUUID->"6539b65b-0bee-476e-8d4b-cd6cf3d9b136"],
Cell[14258, 414, 258, 5, 24, "Print",ExpressionUUID->"3ad217ac-314c-4ecc-9755-80cd5afc02ec"],
Cell[14519, 421, 813, 22, 45, "Print",ExpressionUUID->"d838eeea-d168-47a6-858c-ebefba39a062"],
Cell[15335, 445, 256, 5, 24, "Print",ExpressionUUID->"9ba04be4-0ea3-466d-8d4c-77f99b023caf"],
Cell[15594, 452, 1619, 44, 51, "Print",ExpressionUUID->"c29c7334-659a-4aa9-99e8-8a3e5c310bf0"],
Cell[17216, 498, 256, 5, 24, "Print",ExpressionUUID->"dd834b83-9cda-424c-bcaf-04910a1acb74"],
Cell[17475, 505, 1560, 43, 51, "Print",ExpressionUUID->"b95ef58c-a054-47e4-a6e3-c4f7ebfaf660"],
Cell[19038, 550, 256, 5, 24, "Print",ExpressionUUID->"dfbda8bb-6e6e-4a53-a1c1-6616d0068ac4"],
Cell[19297, 557, 970, 28, 28, "Print",ExpressionUUID->"83a205bc-954f-4203-9605-f01215db58d3"],
Cell[20270, 587, 258, 5, 24, "Print",ExpressionUUID->"a75ca343-33c3-421c-b5e9-d16bb20bddf5"],
Cell[20531, 594, 940, 27, 28, "Print",ExpressionUUID->"94433305-7375-41ef-8cfc-c06db4084cc8"],
Cell[21474, 623, 256, 5, 24, "Print",ExpressionUUID->"259ccaa3-3be7-475e-aad6-140cb05ada63"],
Cell[21733, 630, 1525, 41, 49, "Print",ExpressionUUID->"2be48901-9118-492c-8884-2c90d2ab8a6f"],
Cell[23261, 673, 256, 5, 24, "Print",ExpressionUUID->"1d75df1c-8fdd-4196-959e-9fcf5199e317"],
Cell[23520, 680, 1502, 40, 49, "Print",ExpressionUUID->"a3452c6c-ad7c-46c2-b316-5b5d983f43af"],
Cell[25025, 722, 256, 5, 24, "Print",ExpressionUUID->"a12b56cd-23cd-4847-9117-41231a6c5e2d"],
Cell[25284, 729, 736, 20, 41, "Print",ExpressionUUID->"87caa698-1893-45e1-8dda-b417a5d5e411"],
Cell[26023, 751, 258, 5, 24, "Print",ExpressionUUID->"da77f11a-191a-41fc-8643-962f6f19774a"],
Cell[26284, 758, 1231, 33, 43, "Print",ExpressionUUID->"93164cb1-274e-413a-a632-9e745f33bd73"],
Cell[27518, 793, 256, 5, 24, "Print",ExpressionUUID->"2c84754f-7736-4ea6-963b-807a5a9345b8"],
Cell[27777, 800, 713, 19, 41, "Print",ExpressionUUID->"8a3c5239-f63f-45b6-8d6c-8b330fe03a61"],
Cell[28493, 821, 256, 5, 24, "Print",ExpressionUUID->"16f03b13-d528-4b19-8618-296563a17650"],
Cell[28752, 828, 778, 22, 27, "Print",ExpressionUUID->"9a6aef59-f2cf-4a6e-aa05-eed7b131d0bc"],
Cell[29533, 852, 255, 5, 24, "Print",ExpressionUUID->"d934694e-cf41-41e0-8302-83ad795fe196"],
Cell[29791, 859, 913, 25, 27, "Print",ExpressionUUID->"1af41dd6-9647-4076-97d4-49e658cb17bc"],
Cell[30707, 886, 256, 5, 24, "Print",ExpressionUUID->"503dfba2-7ebf-4fb6-a4e4-da0a76b17671"],
Cell[30966, 893, 1267, 34, 45, "Print",ExpressionUUID->"b8e2960e-67c6-4381-a854-314aa6fa1bfc"],
Cell[32236, 929, 258, 5, 24, "Print",ExpressionUUID->"b761960f-2d1b-495a-851f-33ec0d031e67"],
Cell[32497, 936, 724, 20, 39, "Print",ExpressionUUID->"3d4fe4bf-c361-4b53-97d2-3c7b6c73c800"],
Cell[33224, 958, 256, 5, 24, "Print",ExpressionUUID->"42d05af0-2716-41a9-aea2-f93a3cdf086e"],
Cell[33483, 965, 1848, 47, 27, "Print",ExpressionUUID->"715e642f-7664-4e1f-ade4-bc11107bb36e"],
Cell[35334, 1014, 256, 5, 24, "Print",ExpressionUUID->"853ebbd0-8b0f-40cb-b550-d374456ae021"],
Cell[35593, 1021, 894, 25, 46, "Print",ExpressionUUID->"82741e14-875e-4168-a5e7-a2c4e418fb2b"],
Cell[36490, 1048, 256, 5, 24, "Print",ExpressionUUID->"a2782d39-f7a2-4f58-9874-f8d9d64ab97f"],
Cell[36749, 1055, 862, 24, 46, "Print",ExpressionUUID->"bc4848fd-579d-4122-b051-c62a4a21b57a"],
Cell[37614, 1081, 256, 5, 24, "Print",ExpressionUUID->"2177ea89-50cf-4339-89c6-1f26c82387b4"],
Cell[37873, 1088, 955, 25, 47, "Print",ExpressionUUID->"9ab0a8db-45b3-4756-add6-c3251644c1ae"],
Cell[38831, 1115, 258, 5, 24, "Print",ExpressionUUID->"072f0f3b-0133-46b8-a664-9956acf28719"],
Cell[39092, 1122, 650, 17, 41, "Print",ExpressionUUID->"f9bca379-59d3-4188-aa48-1b489b4c0c00"],
Cell[39745, 1141, 256, 5, 24, "Print",ExpressionUUID->"77175869-ccc7-4878-b90b-a4f23fb5670c"],
Cell[40004, 1148, 552, 13, 25, "Print",ExpressionUUID->"7888a723-7fad-4a12-af78-70504f89f5cd"],
Cell[40559, 1163, 256, 5, 24, "Print",ExpressionUUID->"4476c4ad-11b4-4a2a-a271-a7d60a708583"],
Cell[40818, 1170, 552, 13, 25, "Print",ExpressionUUID->"5dbec48a-54c8-48c9-926e-9886004bf610"],
Cell[41373, 1185, 256, 5, 24, "Print",ExpressionUUID->"63c5b55c-4089-420b-be91-fbf6b2a8489b"],
Cell[41632, 1192, 817, 22, 42, "Print",ExpressionUUID->"9343b70b-968f-417e-a899-c89db675cc2c"],
Cell[42452, 1216, 256, 5, 24, "Print",ExpressionUUID->"1e910ce5-aacd-4b5e-9f12-9c876b205cac"],
Cell[42711, 1223, 914, 26, 46, "Print",ExpressionUUID->"6b9a8f07-9c32-4d49-a3ca-613138d738c8"],
Cell[43628, 1251, 256, 5, 24, "Print",ExpressionUUID->"5ccedeeb-1b8b-489e-bb89-b858c3dc6a75"],
Cell[43887, 1258, 827, 22, 27, "Print",ExpressionUUID->"e82703f7-d208-4d2b-862a-1226e22bb27f"],
Cell[44717, 1282, 258, 5, 24, "Print",ExpressionUUID->"6de262f6-da72-4278-a0bd-bad3abf0f4a1"],
Cell[44978, 1289, 803, 21, 27, "Print",ExpressionUUID->"4ba353d1-366c-4bde-a55d-83272e3b9c1d"],
Cell[45784, 1312, 256, 5, 24, "Print",ExpressionUUID->"2fbe6791-e453-42fc-ace2-f4ac098d6beb"],
Cell[46043, 1319, 538, 12, 24, "Print",ExpressionUUID->"441203b2-dee5-48aa-9618-847560dd972b"],
Cell[46584, 1333, 258, 5, 24, "Print",ExpressionUUID->"5937fed9-93af-4a3f-9868-334ebb5b1ef0"],
Cell[46845, 1340, 594, 14, 25, "Print",ExpressionUUID->"1964eb1b-ac90-4361-a777-972f5fbab02c"],
Cell[47442, 1356, 256, 5, 24, "Print",ExpressionUUID->"fd9177e1-2467-4c07-a116-074df7baddfa"],
Cell[47701, 1363, 703, 19, 27, "Print",ExpressionUUID->"15462f16-5795-415a-bfc8-7b7883686b54"],
Cell[48407, 1384, 258, 5, 24, "Print",ExpressionUUID->"beeeb58a-8aa3-4337-a9fa-e1e3657ba1dc"],
Cell[48668, 1391, 1346, 34, 25, "Print",ExpressionUUID->"443e3e9d-c4ab-4553-87ff-318127a9e0c9"],
Cell[50017, 1427, 255, 5, 24, "Print",ExpressionUUID->"02f07f4d-083f-490f-a402-1bbaa71b1d94"],
Cell[50275, 1434, 691, 18, 25, "Print",ExpressionUUID->"9a0b4794-bb05-4692-a247-6aab9900004d"],
Cell[50969, 1454, 255, 5, 24, "Print",ExpressionUUID->"0543221b-70d0-4f60-9332-bb59fa2b404e"],
Cell[51227, 1461, 609, 15, 24, "Print",ExpressionUUID->"0fea522d-a925-4652-b019-2937d7a394a5"],
Cell[51839, 1478, 256, 5, 24, "Print",ExpressionUUID->"64b52802-9e92-4e8b-85aa-536e42b6e363"],
Cell[52098, 1485, 694, 18, 24, "Print",ExpressionUUID->"423b821b-b0de-4163-9f47-c059bf38cf00"],
Cell[52795, 1505, 256, 5, 24, "Print",ExpressionUUID->"21f40674-62cf-42ef-a9a7-f570cc201290"],
Cell[53054, 1512, 623, 16, 24, "Print",ExpressionUUID->"3a86ecf2-bcbf-4c18-8177-9dd9a91a2b1c"],
Cell[53680, 1530, 256, 5, 24, "Print",ExpressionUUID->"1dd0e29a-48f1-4988-a9d6-27144ec6b95e"],
Cell[53939, 1537, 649, 17, 24, "Print",ExpressionUUID->"7669c966-6b91-4332-98d0-bb1f77d87f9c"],
Cell[54591, 1556, 256, 5, 24, "Print",ExpressionUUID->"756093f6-ecc9-47a5-93ee-b8038f734c4c"],
Cell[54850, 1563, 1238, 32, 25, "Print",ExpressionUUID->"de121f17-6986-45d9-a1b7-81827a96cda1"],
Cell[56091, 1597, 256, 5, 24, "Print",ExpressionUUID->"c1bfd83b-9f3d-4917-bb4c-48bae8ca1a02"],
Cell[56350, 1604, 1054, 28, 27, "Print",ExpressionUUID->"c7d6bae5-d066-476b-8887-e9fb0ba5a0f4"],
Cell[57407, 1634, 256, 5, 24, "Print",ExpressionUUID->"fef30252-0508-439d-aff7-4bdaaf37ea02"],
Cell[57666, 1641, 783, 22, 27, "Print",ExpressionUUID->"a4fd87e3-8e46-4430-b110-0b08263f2648"],
Cell[58452, 1665, 256, 5, 24, "Print",ExpressionUUID->"e75c94a0-2062-4db1-9f32-d5748b725851"],
Cell[58711, 1672, 1425, 39, 27, "Print",ExpressionUUID->"71ba4eda-d340-4b3c-b9c0-f434a5f2d248"],
Cell[60139, 1713, 256, 5, 24, "Print",ExpressionUUID->"52415aa3-90d4-49da-9697-fc3259b816c6"],
Cell[60398, 1720, 1112, 29, 27, "Print",ExpressionUUID->"547556e0-145c-498a-a010-4dbf4ba00106"],
Cell[61513, 1751, 256, 5, 24, "Print",ExpressionUUID->"ec7d7278-cbf1-4b0c-a419-5eb211db49bf"],
Cell[61772, 1758, 1136, 30, 27, "Print",ExpressionUUID->"256439b8-5060-4eda-91af-0f37bd97a3b9"],
Cell[62911, 1790, 256, 5, 24, "Print",ExpressionUUID->"51e79423-8e7f-4dda-9a1c-5fdcb7e12406"],
Cell[63170, 1797, 1651, 43, 27, "Print",ExpressionUUID->"20b64273-2427-4cca-b52a-6371e339016b"],
Cell[64824, 1842, 256, 5, 24, "Print",ExpressionUUID->"cd2131de-7dac-4002-9c99-5ae348647a56"],
Cell[65083, 1849, 1381, 37, 49, "Print",ExpressionUUID->"f6f52034-359f-4965-9b39-2e3b4cb051fb"],
Cell[66467, 1888, 256, 5, 24, "Print",ExpressionUUID->"b29cfa0b-c9e8-4394-8ed6-37c415fe4e6b"],
Cell[66726, 1895, 1073, 29, 39, "Print",ExpressionUUID->"a3f56cee-0813-4b1a-9078-7c59937e564a"],
Cell[67802, 1926, 256, 5, 24, "Print",ExpressionUUID->"ae8b1540-06fc-4e24-a61f-9b2124c87d03"],
Cell[68061, 1933, 685, 18, 24, "Print",ExpressionUUID->"c7dbf858-0b2e-4007-b606-1128c4b1dd29"],
Cell[68749, 1953, 258, 5, 24, "Print",ExpressionUUID->"4ecacb8c-08cd-49e8-9ac7-581d4b11d48d"],
Cell[69010, 1960, 650, 17, 38, "Print",ExpressionUUID->"f0085f72-ea00-4710-9d4d-e3d017a1491a"],
Cell[69663, 1979, 256, 5, 24, "Print",ExpressionUUID->"61822e1e-863c-484c-99b5-ae1ba703d0d5"],
Cell[69922, 1986, 652, 17, 40, "Print",ExpressionUUID->"3af666fc-9a49-44eb-a06d-6b18e8bbd4c8"],
Cell[70577, 2005, 258, 5, 24, "Print",ExpressionUUID->"8de2d586-83f3-4664-b094-7c554ec2ddaa"],
Cell[70838, 2012, 605, 16, 38, "Print",ExpressionUUID->"6738566e-0703-4bc1-b987-3c41d317e5eb"],
Cell[71446, 2030, 256, 5, 24, "Print",ExpressionUUID->"88c3c56b-5c9f-46fe-ab03-488ad4e10f23"],
Cell[71705, 2037, 861, 24, 42, "Print",ExpressionUUID->"632c732a-57a1-4201-a13f-43f0a226a9b5"],
Cell[72569, 2063, 258, 5, 24, "Print",ExpressionUUID->"eea6689a-f702-49e0-a104-7069c39ed328"],
Cell[72830, 2070, 821, 23, 45, "Print",ExpressionUUID->"03c56ae1-02fc-45ab-98b3-e5ba2ef30876"],
Cell[73654, 2095, 256, 5, 24, "Print",ExpressionUUID->"3f4d7b40-c3d3-4a6a-b86a-9c32e6a79df3"],
Cell[73913, 2102, 887, 24, 28, "Print",ExpressionUUID->"70e60c5c-fc0e-4a6a-81b7-2baaed68f24c"],
Cell[74803, 2128, 256, 5, 24, "Print",ExpressionUUID->"e2896ab5-d5b0-4129-9e0c-d9393fb8baec"],
Cell[75062, 2135, 861, 23, 28, "Print",ExpressionUUID->"a56dcfed-ccc5-4724-a3fb-3c5b7e43f32e"],
Cell[75926, 2160, 256, 5, 24, "Print",ExpressionUUID->"a7f618d4-5fb7-4502-bfd7-f7d8ee9bd8f6"],
Cell[76185, 2167, 710, 19, 25, "Print",ExpressionUUID->"e4628727-1bbe-4811-9ca6-a9d758d29dc8"],
Cell[76898, 2188, 256, 5, 24, "Print",ExpressionUUID->"0bb0720f-e8d2-4cbd-9a37-fad887ee652b"],
Cell[77157, 2195, 1229, 33, 39, "Print",ExpressionUUID->"2ba6f63c-579c-4866-9bc8-a6c4cd860ce5"],
Cell[78389, 2230, 256, 5, 24, "Print",ExpressionUUID->"cc75b2fd-b8a2-4d12-9ea3-64df15aaf48c"],
Cell[78648, 2237, 718, 19, 41, "Print",ExpressionUUID->"e57d3d06-a034-4e40-ab31-d4608daf1d72"],
Cell[79369, 2258, 253, 5, 24, "Print",ExpressionUUID->"604463a6-9c68-494e-9e40-93fe627c9ac1"],
Cell[79625, 2265, 820, 23, 46, "Print",ExpressionUUID->"2dfe7f3c-bf2a-4277-aaa7-23c23d7de488"],
Cell[80448, 2290, 256, 5, 24, "Print",ExpressionUUID->"2372cef8-fbcb-4b5e-a160-66f9a1089b69"],
Cell[80707, 2297, 956, 26, 46, "Print",ExpressionUUID->"bf0fb608-8a17-46c4-ab25-d99a0557af33"],
Cell[81666, 2325, 256, 5, 24, "Print",ExpressionUUID->"5580697a-0a83-4801-a9c0-2b1cb43a5cb1"],
Cell[81925, 2332, 1277, 35, 49, "Print",ExpressionUUID->"809740bf-2610-4553-bf92-9ddc90addd71"],
Cell[83205, 2369, 256, 5, 24, "Print",ExpressionUUID->"c3652db1-79d1-4004-92c7-299d289d392e"],
Cell[83464, 2376, 743, 21, 43, "Print",ExpressionUUID->"65b2dd76-86db-47d5-9bcb-825816ebebc9"],
Cell[84210, 2399, 255, 5, 24, "Print",ExpressionUUID->"2dbce668-56a1-4498-9118-e393d361f43a"],
Cell[84468, 2406, 1906, 48, 65, "Print",ExpressionUUID->"ecf7352d-f8bf-4ec5-9c19-d6f196e6530e"],
Cell[86377, 2456, 258, 5, 24, "Print",ExpressionUUID->"04ff3b02-e9c1-4f8b-b780-9cc679b59f39"],
Cell[86638, 2463, 863, 24, 27, "Print",ExpressionUUID->"653c5b24-aeea-400e-9a61-c86d3c9ded9c"],
Cell[87504, 2489, 258, 5, 24, "Print",ExpressionUUID->"82bf62da-30e1-4525-ab56-eb99a996dd45"],
Cell[87765, 2496, 840, 24, 27, "Print",ExpressionUUID->"839c4ef0-d715-4c7e-8c4e-08980f0b48ca"],
Cell[88608, 2522, 258, 5, 24, "Print",ExpressionUUID->"1fa3e877-67eb-4ae4-b60d-1a497b49d383"],
Cell[88869, 2529, 964, 26, 44, "Print",ExpressionUUID->"a094d815-8208-40bb-a5f4-738db1308396"],
Cell[89836, 2557, 256, 5, 24, "Print",ExpressionUUID->"7c324041-53d6-46ae-b403-c0731cde7da4"],
Cell[90095, 2564, 1167, 32, 39, "Print",ExpressionUUID->"9582d9c6-44a9-4e28-bbb3-3007148d5c19"],
Cell[91265, 2598, 256, 5, 24, "Print",ExpressionUUID->"d68bd58c-3090-450d-b7ec-a88a18f9b62d"],
Cell[91524, 2605, 586, 14, 41, "Print",ExpressionUUID->"809b718f-7acf-4f7c-9eea-538029178bc6"],
Cell[92113, 2621, 258, 5, 24, "Print",ExpressionUUID->"53e81a49-933d-4927-bd6f-d02085fa2199"],
Cell[92374, 2628, 586, 14, 41, "Print",ExpressionUUID->"97bda6be-44d8-481f-9526-189066878b90"],
Cell[92963, 2644, 255, 5, 24, "Print",ExpressionUUID->"626f52cc-42fa-4d3e-8604-235a233edd25"],
Cell[93221, 2651, 834, 23, 43, "Print",ExpressionUUID->"fdad4d9b-2458-4cc1-85b9-36cc6b48c6e4"],
Cell[94058, 2676, 256, 5, 24, "Print",ExpressionUUID->"b06a3bec-f687-4d4c-b55e-89d4c154f0ba"],
Cell[94317, 2683, 890, 25, 27, "Print",ExpressionUUID->"0a664050-ead7-488f-828c-1087f5bd51b8"],
Cell[95210, 2710, 256, 5, 24, "Print",ExpressionUUID->"82b621e2-8d3d-4bb4-a206-244d5dc28030"],
Cell[95469, 2717, 872, 24, 46, "Print",ExpressionUUID->"0b11c4c4-40f0-4157-997f-3525149c58d2"],
Cell[96344, 2743, 256, 5, 24, "Print",ExpressionUUID->"7febb892-f675-4e41-8334-f2243820a908"],
Cell[96603, 2750, 849, 23, 46, "Print",ExpressionUUID->"58e801f8-d323-4f07-8ad9-9a755bc3b716"],
Cell[97455, 2775, 256, 5, 24, "Print",ExpressionUUID->"a42293d8-0e0d-4b29-befc-73b744513095"],
Cell[97714, 2782, 583, 15, 40, "Print",ExpressionUUID->"1b47772a-cdfa-49c8-a426-0e8cec774fd8"],
Cell[98300, 2799, 255, 5, 24, "Print",ExpressionUUID->"33da6a5d-9ce8-44e0-83e8-8d1c61ba4e12"],
Cell[98558, 2806, 641, 17, 41, "Print",ExpressionUUID->"4a8cfad3-2e1e-42d2-8e24-281e42dbf479"],
Cell[99202, 2825, 256, 5, 24, "Print",ExpressionUUID->"d9c66f93-f535-4ed3-959d-6760f5fb6593"],
Cell[99461, 2832, 745, 20, 46, "Print",ExpressionUUID->"c0baf930-f524-4e97-9627-83ea8d880c0e"],
Cell[100209, 2854, 255, 5, 24, "Print",ExpressionUUID->"e771183d-a0f4-4332-8e25-8bcf33702064"],
Cell[100467, 2861, 1405, 36, 41, "Print",ExpressionUUID->"fa4808ce-64bc-4071-863c-42976f94db35"],
Cell[101875, 2899, 258, 5, 24, "Print",ExpressionUUID->"c09e8795-f9da-43cf-9938-18e1a9edd4c4"],
Cell[102136, 2906, 735, 21, 42, "Print",ExpressionUUID->"a24f411f-1d81-42f4-a0f1-62167594e3dd"],
Cell[102874, 2929, 256, 5, 24, "Print",ExpressionUUID->"0cb5931b-b704-46de-b3d4-8f5d6c7a58e6"],
Cell[103133, 2936, 657, 18, 42, "Print",ExpressionUUID->"de425fcf-0d08-4588-bb69-73d5a2731830"],
Cell[103793, 2956, 256, 5, 24, "Print",ExpressionUUID->"2bfd6c35-55d8-49dc-a391-5e63e5f4e708"],
Cell[104052, 2963, 739, 20, 40, "Print",ExpressionUUID->"f82c8f58-f1cd-48bf-8b05-6f2f8e10a7ac"],
Cell[104794, 2985, 258, 5, 24, "Print",ExpressionUUID->"96667089-b9c0-4770-a1e3-2bb7acb6f032"],
Cell[105055, 2992, 667, 18, 40, "Print",ExpressionUUID->"8e5d9b34-a744-4efc-8d90-9521dba50f17"],
Cell[105725, 3012, 256, 5, 24, "Print",ExpressionUUID->"f64d7967-7df0-460e-9e0a-f6316cca2256"],
Cell[105984, 3019, 694, 19, 40, "Print",ExpressionUUID->"82c5cec4-26d4-406a-b97f-9ad9bbd93319"],
Cell[106681, 3040, 256, 5, 24, "Print",ExpressionUUID->"c61822d5-f299-41a9-804b-a52f4c618666"],
Cell[106940, 3047, 1297, 34, 41, "Print",ExpressionUUID->"240f78b9-eed5-4725-af0f-a23440da1cf6"],
Cell[108240, 3083, 256, 5, 24, "Print",ExpressionUUID->"8d939d92-73c1-4676-9828-da176a09fa11"],
Cell[108499, 3090, 1098, 29, 46, "Print",ExpressionUUID->"7626366c-767c-4ffa-bf6d-32dc99510d22"],
Cell[109600, 3121, 256, 5, 24, "Print",ExpressionUUID->"e83ed515-b33e-48ab-9d6b-c83d7482fef6"],
Cell[109859, 3128, 829, 24, 46, "Print",ExpressionUUID->"c3a67ad6-b84f-44b6-9c54-ddca3db38649"],
Cell[110691, 3154, 256, 5, 24, "Print",ExpressionUUID->"678a25fe-08fa-43d4-b99d-00bed7989469"],
Cell[110950, 3161, 1489, 41, 46, "Print",ExpressionUUID->"e7769183-d41e-404e-94b3-7846f0c5f217"],
Cell[112442, 3204, 256, 5, 24, "Print",ExpressionUUID->"010ba9ad-f23e-44dd-b085-8910d4d51be0"],
Cell[112701, 3211, 1168, 31, 46, "Print",ExpressionUUID->"2feafbb2-7dc3-4112-b749-aef16896fbaa"],
Cell[113872, 3244, 256, 5, 24, "Print",ExpressionUUID->"cbb92654-b65d-437e-9666-f36054b6e098"],
Cell[114131, 3251, 1185, 31, 46, "Print",ExpressionUUID->"94995a70-19f7-4910-9fbd-2e539359b849"],
Cell[115319, 3284, 258, 5, 24, "Print",ExpressionUUID->"9d6e2e37-8372-41d1-b212-814d757ee337"],
Cell[115580, 3291, 1717, 45, 46, "Print",ExpressionUUID->"6c6c3a07-27a5-4f40-b8db-924d1f031926"],
Cell[117300, 3338, 258, 5, 24, "Print",ExpressionUUID->"646871a4-857c-447a-9ee1-85455e24a313"],
Cell[117561, 3345, 1380, 37, 45, "Print",ExpressionUUID->"c1842c61-d405-4ded-a6cd-a5dd36c3b78e"],
Cell[118944, 3384, 258, 5, 24, "Print",ExpressionUUID->"b27dd74f-a4a3-4382-895a-0887a3f165a3"],
Cell[119205, 3391, 1021, 28, 46, "Print",ExpressionUUID->"044a371e-3c2b-48eb-b6f4-3065b529a161"],
Cell[120229, 3421, 256, 5, 24, "Print",ExpressionUUID->"283a00f0-2241-47b1-8db6-b980331be831"],
Cell[120488, 3428, 918, 26, 43, "Print",ExpressionUUID->"fdd8e7c1-859c-4b41-a056-24e0f80b2a53"],
Cell[121409, 3456, 256, 5, 24, "Print",ExpressionUUID->"b1f592ef-d0d9-4829-8673-9bf1baf029e3"],
Cell[121668, 3463, 739, 22, 24, "Print",ExpressionUUID->"f44e329a-ec7a-4741-a7b1-68e3810ba5eb"],
Cell[122410, 3487, 256, 5, 24, "Print",ExpressionUUID->"f597bba7-f350-4b9e-bf90-0c8e94d54ce8"],
Cell[122669, 3494, 764, 22, 24, "Print",ExpressionUUID->"808ab5e4-613c-4f9e-86e3-956a38906f22"],
Cell[123436, 3518, 256, 5, 24, "Print",ExpressionUUID->"a6ccf6e7-e957-4ffb-87a1-cea69f1d546e"],
Cell[123695, 3525, 821, 23, 42, "Print",ExpressionUUID->"4e1dcfb0-535f-415e-ae22-0c3da310f0e1"],
Cell[124519, 3550, 255, 5, 24, "Print",ExpressionUUID->"684e506b-156b-4e07-bf33-a872f77a1214"],
Cell[124777, 3557, 651, 18, 39, "Print",ExpressionUUID->"e828c4ac-444e-4ac3-a345-2b40f3131dfc"],
Cell[125431, 3577, 256, 5, 24, "Print",ExpressionUUID->"b0b15a09-e337-4347-805d-7bcab0db736e"],
Cell[125690, 3584, 626, 17, 42, "Print",ExpressionUUID->"ff137390-f66d-4812-b033-5938d9587c01"],
Cell[126319, 3603, 256, 5, 24, "Print",ExpressionUUID->"a7a2f863-b5c6-4379-b9b9-616c025b8d86"],
Cell[126578, 3610, 788, 23, 40, "Print",ExpressionUUID->"a39bd450-d3f7-40b5-91d9-fdd14b4ecd80"],
Cell[127369, 3635, 256, 5, 24, "Print",ExpressionUUID->"99d57015-4150-4e5c-aa7b-3962728c2bbc"],
Cell[127628, 3642, 645, 17, 25, "Print",ExpressionUUID->"5e6cd9b3-a35b-4dc7-92c6-5ed2b60bd86b"],
Cell[128276, 3661, 256, 5, 24, "Print",ExpressionUUID->"4d3ce550-4ab3-445d-83e6-a98e94fc98d8"],
Cell[128535, 3668, 678, 19, 42, "Print",ExpressionUUID->"c1a6b206-81cb-453c-abac-1ef16f598cc4"],
Cell[129216, 3689, 256, 5, 24, "Print",ExpressionUUID->"8d9ade43-f274-4254-a014-f602b144e099"],
Cell[129475, 3696, 653, 18, 39, "Print",ExpressionUUID->"8a2f81b4-385d-41ad-881f-9050a0615c3c"],
Cell[130131, 3716, 258, 5, 24, "Print",ExpressionUUID->"aa29ba6d-fea4-4b9d-a6a7-efe6e926bc9a"],
Cell[130392, 3723, 711, 20, 27, "Print",ExpressionUUID->"6c26d426-9eab-4e0b-9b1a-fb8f1bc4b356"],
Cell[131106, 3745, 256, 5, 24, "Print",ExpressionUUID->"5da3e7fb-57e3-43e2-8c85-c43fedd14926"],
Cell[131365, 3752, 740, 21, 46, "Print",ExpressionUUID->"8cc76e0a-636d-47d6-84eb-c41112c37550"],
Cell[132108, 3775, 254, 5, 24, "Print",ExpressionUUID->"2e5f2870-d24c-48b2-97c3-0aa83a5f37f0"],
Cell[132365, 3782, 655, 18, 43, "Print",ExpressionUUID->"1807ea47-c9c2-4bae-a0c2-be0b2ab3fe79"],
Cell[133023, 3802, 255, 5, 24, "Print",ExpressionUUID->"b0ba2011-ebb9-4dad-a259-aa0d1f8353ca"],
Cell[133281, 3809, 707, 20, 24, "Print",ExpressionUUID->"836339a4-a10a-453e-b8da-3067a93c24e5"],
Cell[133991, 3831, 256, 5, 24, "Print",ExpressionUUID->"6a304bbe-9498-4481-9571-d81f49a96c60"],
Cell[134250, 3838, 739, 21, 42, "Print",ExpressionUUID->"f0d3837d-533c-4078-9b88-3f34813bc144"],
Cell[134992, 3861, 256, 5, 24, "Print",ExpressionUUID->"3de7cd00-f753-4c84-a3be-83f5fd8b1a5b"],
Cell[135251, 3868, 677, 19, 38, "Print",ExpressionUUID->"ac09a20c-8d3b-4d07-bffa-b881a78edea0"],
Cell[135931, 3889, 258, 5, 24, "Print",ExpressionUUID->"7845bab8-1c18-40e3-aca8-3b5bd44aca51"],
Cell[136192, 3896, 733, 21, 25, "Print",ExpressionUUID->"3a24b073-1230-4934-9d12-e9cd1046dd7f"],
Cell[136928, 3919, 256, 5, 24, "Print",ExpressionUUID->"73085de4-fa65-47ef-8a3f-fe9a3847fddd"],
Cell[137187, 3926, 764, 22, 42, "Print",ExpressionUUID->"d3315c2a-cd48-49a9-9fa8-3ab22eb49cf3"],
Cell[137954, 3950, 256, 5, 24, "Print",ExpressionUUID->"e6c8fa86-1878-4a4d-8aab-b259ca63e73b"],
Cell[138213, 3957, 666, 18, 41, "Print",ExpressionUUID->"446d802a-50ba-448b-955d-329a20912f84"],
Cell[138882, 3977, 258, 5, 24, "Print",ExpressionUUID->"1c7533d7-588b-4fff-8778-d6415e38fb95"],
Cell[139143, 3984, 566, 14, 24, "Print",ExpressionUUID->"b29546ba-04a1-4421-9d85-271302704d2e"],
Cell[139712, 4000, 256, 5, 24, "Print",ExpressionUUID->"96d324b1-17d6-40b3-9cf9-b4fc791d354c"],
Cell[139971, 4007, 706, 19, 42, "Print",ExpressionUUID->"4cb39c81-1353-42f9-b2d4-912ea189916b"],
Cell[140680, 4028, 256, 5, 24, "Print",ExpressionUUID->"222280cc-cac7-43d0-9ea1-94620d350aa5"],
Cell[140939, 4035, 796, 21, 42, "Print",ExpressionUUID->"c9934314-f3ba-4d7d-ab1c-ee3367a3733e"],
Cell[141738, 4058, 258, 5, 24, "Print",ExpressionUUID->"74fa001f-7769-4e7f-abd4-d59aa8f66db8"],
Cell[141999, 4065, 654, 17, 24, "Print",ExpressionUUID->"eda4db63-3f9e-49f5-a2c8-8bd548738b9a"],
Cell[142656, 4084, 258, 5, 24, "Print",ExpressionUUID->"4624bda6-8ba3-4538-8a4e-fca7ade64782"],
Cell[142917, 4091, 717, 20, 27, "Print",ExpressionUUID->"5e776865-b3c4-4526-ac78-b05d2baa1294"],
Cell[143637, 4113, 256, 5, 24, "Print",ExpressionUUID->"a8dc2e72-12c4-4a78-a203-b945411d32fe"],
Cell[143896, 4120, 708, 19, 24, "Print",ExpressionUUID->"f65d6539-d0d1-4550-a596-91c38eab21f5"],
Cell[144607, 4141, 256, 5, 24, "Print",ExpressionUUID->"9651c933-ce7f-4804-81be-081c04b427d8"],
Cell[144866, 4148, 738, 20, 24, "Print",ExpressionUUID->"60352cc5-3ab8-4c95-a5a0-f2d7cd94012d"],
Cell[145607, 4170, 256, 5, 24, "Print",ExpressionUUID->"2267bf23-917b-4fdf-8012-953539026d07"],
Cell[145866, 4177, 797, 22, 27, "Print",ExpressionUUID->"b89064eb-ff2c-4e0c-b895-5ee58313053c"],
Cell[146666, 4201, 256, 5, 24, "Print",ExpressionUUID->"3eae4d4d-26ae-4711-aaae-384ec3c7f47a"],
Cell[146925, 4208, 719, 20, 27, "Print",ExpressionUUID->"ffb128cd-4914-4982-976e-ab7f6bef5e0c"],
Cell[147647, 4230, 256, 5, 24, "Print",ExpressionUUID->"7a045eeb-0945-4555-9090-67a3d5fcbf59"],
Cell[147906, 4237, 784, 21, 27, "Print",ExpressionUUID->"adc49578-a461-4a1b-85eb-8debb33fb14b"],
Cell[148693, 4260, 258, 5, 24, "Print",ExpressionUUID->"fb574810-f993-4765-8f21-8fc1f5caf2c7"],
Cell[148954, 4267, 674, 18, 24, "Print",ExpressionUUID->"dde5ca0b-c99b-4ebc-97d8-7ba86dc331e7"],
Cell[149631, 4287, 256, 5, 24, "Print",ExpressionUUID->"4ac41cc4-814f-4f44-874c-631177d75cce"],
Cell[149890, 4294, 809, 22, 42, "Print",ExpressionUUID->"a69256f4-ba12-4507-a4f2-9441e1bb5d43"],
Cell[150702, 4318, 255, 5, 24, "Print",ExpressionUUID->"db1f0aa5-d042-4c0a-be9a-081ac9eb98ee"],
Cell[150960, 4325, 714, 18, 24, "Print",ExpressionUUID->"6c0e85e7-85e4-455a-b79d-d028acc4da62"],
Cell[151677, 4345, 256, 5, 24, "Print",ExpressionUUID->"206a3129-b852-4dd9-a369-d599e84b54ca"],
Cell[151936, 4352, 686, 18, 41, "Print",ExpressionUUID->"655a9a68-690d-402b-b8cf-2f0f583d6064"],
Cell[152625, 4372, 412, 9, 24, "Print",ExpressionUUID->"4f2a2e34-6158-4ddf-aec3-6ba636add4ad"]
}, Open  ]],
Cell[153052, 4384, 2433, 95, 1648, "Input",ExpressionUUID->"ced5749c-396f-4d37-a140-5c82afc0c811",
 InitializationCell->True],
Cell[155488, 4481, 7252, 261, 4636, "Input",ExpressionUUID->"ceaca7e7-6ed5-4628-8cfd-15034dd504cd",
 InitializationCell->True],
Cell[162743, 4744, 18064, 626, 11188, "Input",ExpressionUUID->"c6e32e54-0604-467d-a964-2984f98c1d1e",
 InitializationCell->True],
Cell[180810, 5372, 6332, 200, 3538, "Input",ExpressionUUID->"946e07da-c32d-4f6b-8c3f-26f83440993b",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[187167, 5576, 279, 8, 84, "Input",ExpressionUUID->"823fae71-366a-4996-820b-c71d4ec979d6",
 Evaluatable->False],
Cell[187449, 5586, 1816, 31, 295, "Graphics",ExpressionUUID->"84ed5b7b-3083-44e9-a997-6d5db940bf81",
 Evaluatable->False]
}, Open  ]],
Cell[189280, 5620, 3429, 100, 1738, "Input",ExpressionUUID->"3611b796-46ce-4baf-98f0-4ec44bfe3eea",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[192734, 5724, 3024, 100, 1740, "Input",ExpressionUUID->"dbcebd92-0be6-4d67-928b-77e052207010"],
Cell[195761, 5826, 222, 4, 24, "Print",ExpressionUUID->"9c2abb94-4493-4e03-9056-27607469835e"],
Cell[195986, 5832, 199, 4, 24, "Print",ExpressionUUID->"d3f43e2f-217c-4871-81e6-45090933691c"],
Cell[196188, 5838, 203, 4, 24, "Print",ExpressionUUID->"f45b1579-321d-4979-a41a-25fa905677f7"],
Cell[196394, 5844, 204, 4, 24, "Print",ExpressionUUID->"4e901449-f76f-4f7f-bfd0-22c17a8081d8"],
Cell[196601, 5850, 199, 4, 24, "Print",ExpressionUUID->"76ef299e-9706-4d0f-87ba-2edd05fefafa"],
Cell[196803, 5856, 202, 4, 24, "Print",ExpressionUUID->"6ca2af8f-ab56-4471-9699-ec170ea95b46"],
Cell[197008, 5862, 185, 4, 24, "Print",ExpressionUUID->"61851c4f-79d2-4206-a53f-3b7e52d237c0"],
Cell[197196, 5868, 418, 10, 24, "Print",ExpressionUUID->"852a16bc-12eb-4648-81eb-28581823c727"],
Cell[197617, 5880, 188, 4, 24, "Print",ExpressionUUID->"8569086b-b2e2-42d1-970f-ff3831b69170"],
Cell[197808, 5886, 384, 9, 24, "Print",ExpressionUUID->"e2ea3737-604b-4a26-b9f0-8fe1c6326d81"],
Cell[198195, 5897, 363, 9, 24, "Print",ExpressionUUID->"19f374be-6f85-47b3-a531-0070086e6f0e"],
Cell[198561, 5908, 384, 9, 24, "Print",ExpressionUUID->"7c2c1899-552c-4811-bc88-bac7b63aaa4d"],
Cell[198948, 5919, 334, 8, 24, "Print",ExpressionUUID->"c6041b47-9a39-4647-bd29-fd578a0e1e59"],
Cell[199285, 5929, 450, 11, 24, "Print",ExpressionUUID->"ae1738d4-4331-436b-8e87-7613205c5bf0"],
Cell[199738, 5942, 437, 10, 24, "Print",ExpressionUUID->"a3535f4c-db4c-411c-b581-3421e147fadc"],
Cell[200178, 5954, 521, 11, 24, "Print",ExpressionUUID->"11dcc305-3148-488f-9c17-5479163ad944"],
Cell[200702, 5967, 326, 8, 24, "Print",ExpressionUUID->"36d0ec96-f7da-4991-ab9a-89ef0716d9b6"],
Cell[201031, 5977, 360, 9, 24, "Print",ExpressionUUID->"6a618272-e15d-4669-a2ac-71a7230953b0"],
Cell[201394, 5988, 364, 9, 24, "Print",ExpressionUUID->"337a6289-cb82-4aa8-9135-8255091390d7"],
Cell[201761, 5999, 346, 9, 24, "Print",ExpressionUUID->"77c57d29-f94a-4c4e-b1bf-b8458a700b11"],
Cell[202110, 6010, 526, 11, 24, "Print",ExpressionUUID->"d5e7e192-080a-48fc-bc52-b34291619458"],
Cell[202639, 6023, 546, 13, 24, "Print",ExpressionUUID->"a7119445-1ece-457b-8ab6-9113e70817c0"],
Cell[203188, 6038, 563, 13, 40, "Print",ExpressionUUID->"b93b61b4-7b9f-46da-92a0-7c6a19ba4b40"],
Cell[203754, 6053, 563, 13, 40, "Print",ExpressionUUID->"805dcc43-1610-4c79-adda-4a6b6de07509"],
Cell[204320, 6068, 536, 13, 24, "Print",ExpressionUUID->"088e1d52-ff68-48ef-a43b-6b6a1f3280ee"],
Cell[204859, 6083, 554, 14, 24, "Print",ExpressionUUID->"93af3f87-8d45-4973-ac42-1742f22c8fd3"],
Cell[205416, 6099, 367, 9, 24, "Print",ExpressionUUID->"3d3d1cb4-34e5-4daa-b9de-fe6b6f621a2f"],
Cell[205786, 6110, 396, 10, 24, "Print",ExpressionUUID->"67620ae0-4593-4dff-8a95-c72e8c00250c"],
Cell[206185, 6122, 448, 11, 24, "Print",ExpressionUUID->"ad473ed5-a5c3-42e8-a4a1-c5ba5d11b247"],
Cell[206636, 6135, 524, 11, 24, "Print",ExpressionUUID->"e423ef22-9992-45e9-b9b5-540aa9cd7775"],
Cell[207163, 6148, 231, 5, 24, "Print",ExpressionUUID->"8ba90fe5-77f8-4d4a-897e-8905e2a87461"],
Cell[207397, 6155, 2001, 53, 25, "Print",ExpressionUUID->"20471d4e-ca4d-4f05-aa2c-b6c797f54a5d"],
Cell[209401, 6210, 326, 8, 24, "Print",ExpressionUUID->"79e0fa2f-cdda-4948-9968-834e47088181"],
Cell[209730, 6220, 394, 10, 24, "Print",ExpressionUUID->"d63aa755-2c98-4a7b-9adf-6bfc738d82f9"],
Cell[210127, 6232, 406, 10, 24, "Print",ExpressionUUID->"5c967f6c-9737-4474-a3b9-7a53c6ff37f5"],
Cell[210536, 6244, 402, 10, 24, "Print",ExpressionUUID->"7a5d7d3e-687b-420e-b608-b64c419075fc"],
Cell[210941, 6256, 364, 9, 24, "Print",ExpressionUUID->"40c9ec49-054a-4469-9530-485d2cb9ef79"],
Cell[211308, 6267, 400, 10, 24, "Print",ExpressionUUID->"78532b1b-a92b-4887-9b1d-e9e2e69ea4d0"],
Cell[211711, 6279, 394, 10, 24, "Print",ExpressionUUID->"d8a5d62f-f4a8-49d5-909d-8ddfa9207ebc"],
Cell[212108, 6291, 394, 10, 24, "Print",ExpressionUUID->"c7ab2528-6ddb-4403-ada9-ee5c3d5835ba"],
Cell[212505, 6303, 402, 10, 24, "Print",ExpressionUUID->"ba0472a2-0fe9-4cc8-af1b-67892af57477"],
Cell[212910, 6315, 404, 10, 24, "Print",ExpressionUUID->"f1a64fe8-0c8e-4894-9a5b-f865aa155204"],
Cell[213317, 6327, 378, 9, 24, "Print",ExpressionUUID->"9db589b3-9647-465c-82df-938b481389ea"],
Cell[213698, 6338, 441, 10, 24, "Print",ExpressionUUID->"faef6ddd-04dc-4946-9e71-a63f317e32b7"],
Cell[214142, 6350, 412, 10, 24, "Print",ExpressionUUID->"03396519-aeb1-4b00-a722-e077aae332c3"],
Cell[214557, 6362, 414, 10, 24, "Print",ExpressionUUID->"90a615a5-86da-4720-a937-b3287ddfc4b3"],
Cell[214974, 6374, 416, 10, 24, "Print",ExpressionUUID->"cc3b2664-496b-4fb1-9875-baacebc17da7"],
Cell[215393, 6386, 409, 10, 24, "Print",ExpressionUUID->"77d22860-bb01-4a30-9b77-a9442ec3e2d5"],
Cell[215805, 6398, 412, 10, 24, "Print",ExpressionUUID->"7db3bb49-4d08-4459-9fe1-3ab70cf64eec"],
Cell[216220, 6410, 402, 10, 24, "Print",ExpressionUUID->"982b4106-a887-4978-bc0c-aeceb588147c"],
Cell[216625, 6422, 412, 10, 24, "Print",ExpressionUUID->"d68651a6-72c9-4a9f-acce-9434639084a8"],
Cell[217040, 6434, 404, 10, 24, "Print",ExpressionUUID->"667e0853-6740-4802-a850-536669bcd1fb"],
Cell[217447, 6446, 398, 10, 24, "Print",ExpressionUUID->"ca99398d-9d1f-4aea-931e-83d7f51c1894"],
Cell[217848, 6458, 400, 10, 24, "Print",ExpressionUUID->"5a89c572-12a7-4c0e-acb3-e8eb878c8904"],
Cell[218251, 6470, 378, 9, 24, "Print",ExpressionUUID->"9fb0565e-155a-4daa-9691-325426559b6c"],
Cell[218632, 6481, 376, 9, 24, "Print",ExpressionUUID->"e1fba38c-dfda-4696-9705-c026e351c6c9"],
Cell[219011, 6492, 444, 10, 24, "Print",ExpressionUUID->"2e4de72a-f5a2-49a2-9858-c77e5599d2d0"],
Cell[219458, 6504, 376, 9, 24, "Print",ExpressionUUID->"df55f275-6491-4202-8d7d-d686244c0505"],
Cell[219837, 6515, 376, 9, 24, "Print",ExpressionUUID->"614a2ff8-4835-41c4-a70d-a15f7653ee7e"],
Cell[220216, 6526, 376, 9, 24, "Print",ExpressionUUID->"1013e40c-4c03-4b57-abe4-44f769e41297"],
Cell[220595, 6537, 376, 9, 24, "Print",ExpressionUUID->"838ab076-3afd-490e-a027-7b9593aed008"],
Cell[220974, 6548, 360, 9, 24, "Print",ExpressionUUID->"b52c6319-3700-477f-89b2-c850dd798fbd"],
Cell[221337, 6559, 524, 11, 24, "Print",ExpressionUUID->"033e753b-605b-466b-93a8-b8fce5f6d6f8"],
Cell[221864, 6572, 368, 9, 24, "Print",ExpressionUUID->"da7aafa6-da1b-4134-a62f-806ae50dd6d7"],
Cell[222235, 6583, 406, 10, 24, "Print",ExpressionUUID->"fecadb8d-f07f-4be0-b733-52e8873c41eb"],
Cell[222644, 6595, 364, 9, 24, "Print",ExpressionUUID->"d842687e-c54e-4d0f-9307-13f9203d91b3"],
Cell[223011, 6606, 404, 10, 24, "Print",ExpressionUUID->"b9c9243a-7da0-489e-89ea-ee7b0b22796f"],
Cell[223418, 6618, 366, 9, 24, "Print",ExpressionUUID->"560ba00e-95dc-46b7-9630-922428636267"],
Cell[223787, 6629, 376, 9, 24, "Print",ExpressionUUID->"0b723a03-c74b-4cc9-9634-67ec81bc871f"],
Cell[224166, 6640, 378, 9, 24, "Print",ExpressionUUID->"5421d628-3293-43f9-9f80-73e967d6fed8"],
Cell[224547, 6651, 376, 9, 24, "Print",ExpressionUUID->"de39644b-c40c-48f9-90bb-4507d38ad6fe"],
Cell[224926, 6662, 376, 9, 24, "Print",ExpressionUUID->"4df2e2ff-2640-433d-80bc-37dd7827a147"],
Cell[225305, 6673, 378, 9, 24, "Print",ExpressionUUID->"fc905fac-f6d5-453c-b68b-5c702dcdf729"],
Cell[225686, 6684, 376, 9, 24, "Print",ExpressionUUID->"a00cf050-3288-42bf-a39e-8e3978745c00"],
Cell[226065, 6695, 406, 10, 24, "Print",ExpressionUUID->"4a2b5ed2-1b7c-4865-a037-df52539a0377"],
Cell[226474, 6707, 376, 9, 24, "Print",ExpressionUUID->"47aadfd3-703f-4d28-8ff5-08c0781b0c01"],
Cell[226853, 6718, 376, 9, 24, "Print",ExpressionUUID->"4c204fc7-2c00-49c6-a3d8-1e257b3824c8"],
Cell[227232, 6729, 376, 9, 24, "Print",ExpressionUUID->"2076d98e-5668-4230-a450-0a73d3fd43be"],
Cell[227611, 6740, 376, 9, 24, "Print",ExpressionUUID->"da3b7619-50c6-45af-9b76-072df3f0269d"],
Cell[227990, 6751, 376, 9, 24, "Print",ExpressionUUID->"119f10c6-6719-4a3c-b39c-cdfd13ee85b2"],
Cell[228369, 6762, 378, 9, 24, "Print",ExpressionUUID->"e5955500-95b3-43d6-8fc2-c78f74b5aeb2"],
Cell[228750, 6773, 378, 9, 24, "Print",ExpressionUUID->"ebf088b5-432f-47e6-90ed-786c1270da2a"],
Cell[229131, 6784, 376, 9, 24, "Print",ExpressionUUID->"521c57d0-e9d2-43a5-9451-58f296f2110a"],
Cell[229510, 6795, 376, 9, 24, "Print",ExpressionUUID->"099f273c-adb6-4e54-b125-027f10de18e8"],
Cell[229889, 6806, 376, 9, 24, "Print",ExpressionUUID->"f8d227e7-9c0d-4c52-9e38-4d734b8b1dfe"],
Cell[230268, 6817, 376, 9, 24, "Print",ExpressionUUID->"6b62d5fc-2508-485f-8c54-17e95864df28"],
Cell[230647, 6828, 428, 10, 24, "Print",ExpressionUUID->"89a8c6ea-1969-4694-9c0d-b405e4843dbd"],
Cell[231078, 6840, 434, 10, 24, "Print",ExpressionUUID->"7922cc65-9fc2-4b4a-8dc7-b18f654e3d1b"],
Cell[231515, 6852, 441, 10, 24, "Print",ExpressionUUID->"cdf4b289-434a-4edd-a5a1-f2e4ba53442e"],
Cell[231959, 6864, 404, 10, 24, "Print",ExpressionUUID->"dab80396-84c0-466a-a858-e3b60517bbad"],
Cell[232366, 6876, 400, 10, 24, "Print",ExpressionUUID->"786b6e23-a700-4070-a7fe-e174f23d728f"],
Cell[232769, 6888, 392, 10, 24, "Print",ExpressionUUID->"6ecc383b-2d92-436b-b7a8-8a772208eae6"],
Cell[233164, 6900, 404, 10, 24, "Print",ExpressionUUID->"29291453-cc84-482c-acd2-67ed79f091a7"],
Cell[233571, 6912, 398, 10, 24, "Print",ExpressionUUID->"6142d65d-f914-4f83-ac9b-7e62e5986f85"],
Cell[233972, 6924, 399, 10, 24, "Print",ExpressionUUID->"afdec6cf-8d8b-4c81-9348-9d1520de76bd"],
Cell[234374, 6936, 387, 10, 24, "Print",ExpressionUUID->"06b3c2ca-b38e-42ce-b710-1c34ac51f73a"],
Cell[234764, 6948, 418, 10, 24, "Print",ExpressionUUID->"95fec1a0-0ab0-4fd7-8bfb-6114fb14fdfe"],
Cell[235185, 6960, 420, 10, 24, "Print",ExpressionUUID->"ae0e7d8e-71ed-4ef7-86d7-139d918eac29"],
Cell[235608, 6972, 408, 10, 24, "Print",ExpressionUUID->"a0016b32-f688-4976-b718-040f120561f9"],
Cell[236019, 6984, 420, 10, 24, "Print",ExpressionUUID->"d880af38-02d6-4e07-a9e2-ca915960ff05"],
Cell[236442, 6996, 412, 10, 24, "Print",ExpressionUUID->"f4844b27-2b8b-4c2e-be0b-1ecd914a943f"],
Cell[236857, 7008, 406, 10, 24, "Print",ExpressionUUID->"0c7cbfc1-17a1-49c5-99ce-e3559983e251"],
Cell[237266, 7020, 408, 10, 24, "Print",ExpressionUUID->"39691d46-c68b-48e7-8ae8-f53e5097b654"],
Cell[237677, 7032, 387, 10, 24, "Print",ExpressionUUID->"09556604-b6fe-4ae2-aa8f-2f99b2e17734"],
Cell[238067, 7044, 387, 10, 24, "Print",ExpressionUUID->"97d98980-9b35-4a09-b289-cf29baf1641d"],
Cell[238457, 7056, 452, 10, 24, "Print",ExpressionUUID->"875a96a9-0394-4853-99e2-8220485032b3"],
Cell[238912, 7068, 389, 10, 24, "Print",ExpressionUUID->"85be37a4-8a76-4edc-9cac-b3249bac63d9"],
Cell[239304, 7080, 386, 10, 24, "Print",ExpressionUUID->"2ff2bdcb-bc3f-440d-a419-a5cba62bf3f0"],
Cell[239693, 7092, 387, 10, 24, "Print",ExpressionUUID->"85e4b186-dec9-4b07-835a-7f0b264336d9"],
Cell[240083, 7104, 387, 10, 24, "Print",ExpressionUUID->"6fd42880-f0cd-4d27-a7d7-d5b2c24bb51f"],
Cell[240473, 7116, 414, 10, 24, "Print",ExpressionUUID->"507ef26e-865d-4f63-af3d-6d9bb27da8f5"],
Cell[240890, 7128, 363, 9, 24, "Print",ExpressionUUID->"d0cb0cc5-19ae-4fc7-949e-1cd14a9a6e66"],
Cell[241256, 7139, 412, 10, 24, "Print",ExpressionUUID->"863bb3aa-3bc7-40b0-b163-6a86861bcb54"],
Cell[241671, 7151, 366, 9, 24, "Print",ExpressionUUID->"eb947ff0-4b51-4f1e-8543-0be86a2cc339"],
Cell[242040, 7162, 387, 10, 24, "Print",ExpressionUUID->"4ee0f0d0-9f50-4b33-b934-9437c206e008"],
Cell[242430, 7174, 387, 10, 24, "Print",ExpressionUUID->"df4f1454-aefa-4dd3-87f7-b95042432070"],
Cell[242820, 7186, 387, 10, 24, "Print",ExpressionUUID->"1a6c82ff-adfe-49c9-b4ad-f57c894483b4"],
Cell[243210, 7198, 389, 10, 24, "Print",ExpressionUUID->"240644e2-3d4f-47bf-9a70-1bf70cb096c4"],
Cell[243602, 7210, 387, 10, 24, "Print",ExpressionUUID->"afb791c5-3057-450b-a697-c3c836feea80"],
Cell[243992, 7222, 389, 10, 24, "Print",ExpressionUUID->"b430b451-5235-4637-ac37-ce95b6e5f5ef"],
Cell[244384, 7234, 414, 10, 24, "Print",ExpressionUUID->"1112cb2b-7093-45a7-a3ee-a89371ec7891"],
Cell[244801, 7246, 387, 10, 24, "Print",ExpressionUUID->"3290574d-4e2d-434c-9f2f-07ad77c37ab3"],
Cell[245191, 7258, 387, 10, 24, "Print",ExpressionUUID->"0f667cba-f1f3-48a0-ac6e-e9f328df1e46"],
Cell[245581, 7270, 387, 10, 24, "Print",ExpressionUUID->"1c0fd936-dbb0-4598-b664-0b935c3e7ba9"],
Cell[245971, 7282, 387, 10, 24, "Print",ExpressionUUID->"4ee94d49-8152-44d7-aaaf-c1939b9763b5"],
Cell[246361, 7294, 387, 10, 24, "Print",ExpressionUUID->"15b20e51-737a-4c14-a37f-15fb5fed8da5"],
Cell[246751, 7306, 387, 10, 24, "Print",ExpressionUUID->"2397d759-4946-42ff-8e10-0aeb732f18c2"],
Cell[247141, 7318, 387, 10, 24, "Print",ExpressionUUID->"48bb5c38-2754-4feb-ba53-ad8c7ac3a686"],
Cell[247531, 7330, 389, 10, 24, "Print",ExpressionUUID->"90a813bb-f18a-40c1-ac89-b2b5066504b0"],
Cell[247923, 7342, 387, 10, 24, "Print",ExpressionUUID->"da693dba-ce6e-480e-9635-bd92114ae62f"],
Cell[248313, 7354, 387, 10, 24, "Print",ExpressionUUID->"9a01959c-a30e-4599-93d7-8bac92e5dc45"],
Cell[248703, 7366, 387, 10, 24, "Print",ExpressionUUID->"53f7df52-1c47-484b-b8e0-8bf2f9920be8"],
Cell[249093, 7378, 436, 10, 24, "Print",ExpressionUUID->"38fc67af-6513-4b22-a4e7-9c473d2ce889"],
Cell[249532, 7390, 442, 10, 24, "Print",ExpressionUUID->"7e495f59-2841-49f6-9e89-161bbb8dd16d"],
Cell[249977, 7402, 450, 10, 24, "Print",ExpressionUUID->"5370a7f3-bf14-482e-89d3-b248c678daa7"],
Cell[250430, 7414, 396, 10, 24, "Print",ExpressionUUID->"d3d7006a-387b-4aff-a1e1-7e228e24c1a4"],
Cell[250829, 7426, 402, 10, 24, "Print",ExpressionUUID->"afd9490a-c072-4402-8feb-a34691d6608a"],
Cell[251234, 7438, 380, 9, 24, "Print",ExpressionUUID->"410af620-0e50-4266-b623-23c05901e94a"],
Cell[251617, 7449, 380, 9, 24, "Print",ExpressionUUID->"ea5b51f6-79ac-4b3d-ae5e-0fc4bd6896da"],
Cell[252000, 7460, 380, 9, 24, "Print",ExpressionUUID->"2b0553c9-8308-400d-9d0e-1ff0b18b5a8a"],
Cell[252383, 7471, 380, 9, 24, "Print",ExpressionUUID->"872667b2-dd5b-4072-b904-ac844638326a"],
Cell[252766, 7482, 382, 9, 24, "Print",ExpressionUUID->"2a8e9bb2-2c33-40c1-9502-736ac7e6f707"],
Cell[253151, 7493, 380, 9, 24, "Print",ExpressionUUID->"864d1feb-53c7-4110-b964-740d24c73ddd"],
Cell[253534, 7504, 382, 9, 24, "Print",ExpressionUUID->"0285236e-5290-4307-8054-2e3249aa6037"],
Cell[253919, 7515, 382, 9, 24, "Print",ExpressionUUID->"974c5321-0b36-4033-ab9f-20132281b064"],
Cell[254304, 7526, 380, 9, 24, "Print",ExpressionUUID->"b2104916-1273-4a49-a2a8-3419a88facc8"],
Cell[254687, 7537, 380, 9, 24, "Print",ExpressionUUID->"906e8a7c-cd7a-4292-9d02-9819f9862fd3"],
Cell[255070, 7548, 380, 9, 24, "Print",ExpressionUUID->"02c2637d-9da1-4191-8fc0-a4ed39708264"],
Cell[255453, 7559, 382, 9, 24, "Print",ExpressionUUID->"4ae733eb-b0f7-4eb6-aa03-abdccf1cdd1d"],
Cell[255838, 7570, 380, 9, 24, "Print",ExpressionUUID->"e4c28837-f900-418d-bcfd-9bf843ddb36d"],
Cell[256221, 7581, 380, 9, 24, "Print",ExpressionUUID->"b6d8e765-9a9c-4579-9c4b-7f7172a5f8d3"],
Cell[256604, 7592, 382, 9, 24, "Print",ExpressionUUID->"1f247bcb-a16c-45cd-ad64-c734f0f0f8c4"],
Cell[256989, 7603, 382, 9, 24, "Print",ExpressionUUID->"b426517e-4512-436e-b245-dbb21ac9e9a8"],
Cell[257374, 7614, 382, 9, 24, "Print",ExpressionUUID->"dd56925f-9048-43dc-81e3-05ace3ebed90"],
Cell[257759, 7625, 380, 9, 24, "Print",ExpressionUUID->"a436f191-60d1-49fb-8337-9c3ebdc3c6d5"],
Cell[258142, 7636, 402, 10, 24, "Print",ExpressionUUID->"d422ddd7-7f05-4e98-99dd-18130da8d198"],
Cell[258547, 7648, 364, 9, 24, "Print",ExpressionUUID->"c7ea991c-ffbb-4ac3-84cc-0e3c46b571ee"],
Cell[258914, 7659, 402, 10, 24, "Print",ExpressionUUID->"a5f0afce-61f1-4fb2-90bc-110eec999199"],
Cell[259319, 7671, 403, 10, 24, "Print",ExpressionUUID->"e8653cda-114d-415a-b8f8-c009279c3e57"],
Cell[259725, 7683, 376, 9, 24, "Print",ExpressionUUID->"b7fffb14-9b85-40f1-a80d-31f285927997"],
Cell[260104, 7694, 378, 9, 24, "Print",ExpressionUUID->"e79fbc14-bc8e-46c5-bcc1-25aa19092f8e"],
Cell[260485, 7705, 376, 9, 24, "Print",ExpressionUUID->"eafb03d3-0323-4c31-8f1c-12df60bd93d8"],
Cell[260864, 7716, 378, 9, 24, "Print",ExpressionUUID->"5bf87cef-d8c5-4a2e-aba3-0595968e162e"],
Cell[261245, 7727, 376, 9, 24, "Print",ExpressionUUID->"a07eeb8d-b602-4983-87b2-8b872b24dd3e"],
Cell[261624, 7738, 375, 9, 24, "Print",ExpressionUUID->"c0be2871-bd40-4d3a-8a77-f4259b62f03b"],
Cell[262002, 7749, 376, 9, 24, "Print",ExpressionUUID->"cd46855e-61b7-4255-a709-b4f5d24ca7d8"],
Cell[262381, 7760, 376, 9, 24, "Print",ExpressionUUID->"bc8daebf-b43a-4ea9-9eb1-710de84ba1f0"],
Cell[262760, 7771, 404, 10, 24, "Print",ExpressionUUID->"d57f52f7-0989-48ce-af38-9807c4387d0e"],
Cell[263167, 7783, 362, 9, 24, "Print",ExpressionUUID->"1860ef45-6d7a-4c32-b8e7-a3691f882b92"],
Cell[263532, 7794, 524, 11, 24, "Print",ExpressionUUID->"f3f39d84-eb6b-48df-9ca6-5c4a5e2de933"],
Cell[264059, 7807, 368, 9, 24, "Print",ExpressionUUID->"c0d3acf8-670e-4a73-bf5c-3f3484859b84"],
Cell[264430, 7818, 408, 10, 24, "Print",ExpressionUUID->"d96b3595-4f85-4d3c-9c9d-14a3da595535"],
Cell[264841, 7830, 400, 10, 24, "Print",ExpressionUUID->"06dd7cf6-186e-4231-93b2-1a23bdf348be"],
Cell[265244, 7842, 183, 4, 24, "Print",ExpressionUUID->"bcc903b0-d751-4ec1-8516-5cc55c3f9573"],
Cell[265430, 7848, 424, 10, 24, "Print",ExpressionUUID->"592ebb34-ccbb-4503-96cd-d327ff6e6285"],
Cell[265857, 7860, 188, 4, 24, "Print",ExpressionUUID->"81d0dc1f-5a65-4ae9-9a4d-1abcfd5583b8"],
Cell[266048, 7866, 386, 9, 24, "Print",ExpressionUUID->"15517421-6a45-4fe3-9561-8024996e2861"],
Cell[266437, 7877, 352, 9, 24, "Print",ExpressionUUID->"77e69562-687a-48cf-aaea-e22bcfcd90a2"],
Cell[266792, 7888, 352, 9, 24, "Print",ExpressionUUID->"0b198c8c-9fd4-4943-82db-fa9a28f158f5"],
Cell[267147, 7899, 360, 9, 24, "Print",ExpressionUUID->"5b8ef1d4-1f96-4ad8-891a-a787cfaa1aa3"],
Cell[267510, 7910, 366, 9, 24, "Print",ExpressionUUID->"dda277ac-a316-461a-bc76-054c606c7b63"],
Cell[267879, 7921, 524, 11, 24, "Print",ExpressionUUID->"f3a49b3a-bfa2-4416-a1ec-297b8c2f179f"],
Cell[268406, 7934, 536, 12, 24, "Print",ExpressionUUID->"006cf50d-60f9-4e68-bc27-3684c5a2c509"],
Cell[268945, 7948, 536, 12, 24, "Print",ExpressionUUID->"519f1139-4eb1-4a32-8dff-7c55baea1337"],
Cell[269484, 7962, 526, 11, 24, "Print",ExpressionUUID->"b622efa2-a101-46c6-b439-ce51281774fa"],
Cell[270013, 7975, 536, 12, 24, "Print",ExpressionUUID->"e54c8a72-3f34-4fec-a734-c64adb44d0f1"],
Cell[270552, 7989, 370, 9, 24, "Print",ExpressionUUID->"f79354e1-e162-4334-980b-52f84e241acc"],
Cell[270925, 8000, 384, 9, 24, "Print",ExpressionUUID->"57fa2a91-22b1-4bab-b52c-54f3556c9f5a"],
Cell[271312, 8011, 334, 8, 24, "Print",ExpressionUUID->"aaca4b46-ffeb-469a-bfdc-22ed82652d31"],
Cell[271649, 8021, 448, 11, 24, "Print",ExpressionUUID->"088b0835-7885-44d0-adee-488c0e5ed228"],
Cell[272100, 8034, 435, 10, 24, "Print",ExpressionUUID->"f8197239-2e98-406e-b5ac-826ad51789c1"],
Cell[272538, 8046, 448, 11, 24, "Print",ExpressionUUID->"8306fa51-eee9-465c-b93f-84386bcaa050"],
Cell[272989, 8059, 441, 10, 24, "Print",ExpressionUUID->"73462778-00cd-42ea-80b2-c4795eeeeb3e"],
Cell[273433, 8071, 435, 10, 24, "Print",ExpressionUUID->"3e6c1b17-549a-49bf-aef7-ed72c65287a9"],
Cell[273871, 8083, 441, 10, 24, "Print",ExpressionUUID->"a7e60955-d35a-4a9c-b7df-d315ddc89b33"],
Cell[274315, 8095, 521, 11, 24, "Print",ExpressionUUID->"80a29330-31a6-462e-baf7-c1ff7d4ecd0b"],
Cell[274839, 8108, 326, 8, 24, "Print",ExpressionUUID->"385371b6-8d61-46cb-a775-517cf02c00a3"],
Cell[275168, 8118, 350, 9, 24, "Print",ExpressionUUID->"1d82838d-ec1f-4401-a1e3-53550475c8d4"],
Cell[275521, 8129, 350, 9, 24, "Print",ExpressionUUID->"0101d518-c0e3-4fe7-a35a-a013e46957ae"],
Cell[275874, 8140, 360, 9, 24, "Print",ExpressionUUID->"7466cdde-d6e2-4fa2-934b-e41419b4b8cf"],
Cell[276237, 8151, 366, 9, 24, "Print",ExpressionUUID->"58abb50e-d03c-484b-b5b2-7d2425018e5e"],
Cell[276606, 8162, 346, 9, 24, "Print",ExpressionUUID->"efab5d81-8966-4ad0-b194-8bc25a32cd30"],
Cell[276955, 8173, 524, 11, 24, "Print",ExpressionUUID->"ee6670cd-79f3-465d-b0dc-34354aeff9bd"],
Cell[277482, 8186, 536, 12, 24, "Print",ExpressionUUID->"ef2f50a1-c66e-4413-a645-b4cd575d8041"],
Cell[278021, 8200, 536, 12, 24, "Print",ExpressionUUID->"69c1ed6e-9125-4184-9b27-e46e1d705e43"],
Cell[278560, 8214, 524, 11, 24, "Print",ExpressionUUID->"dcad4262-c985-4d0f-9176-93387129f054"],
Cell[279087, 8227, 534, 12, 24, "Print",ExpressionUUID->"41bb4a92-5034-4f2f-871b-b22e0b7b157f"],
Cell[279624, 8241, 367, 9, 24, "Print",ExpressionUUID->"c7bc8b46-10da-45d7-bca1-12019dc57cc4"],
Cell[279994, 8252, 398, 10, 24, "Print",ExpressionUUID->"d45beffc-cdab-411c-8246-04e69620e0aa"],
Cell[280395, 8264, 350, 9, 24, "Print",ExpressionUUID->"ffecfd32-4eef-4eeb-9190-8aa56531e703"],
Cell[280748, 8275, 350, 9, 24, "Print",ExpressionUUID->"1b022d58-c298-43d0-b9b9-b128aa30d7ca"],
Cell[281101, 8286, 360, 9, 24, "Print",ExpressionUUID->"d14e2278-3572-4548-a377-2ff953f620d0"],
Cell[281464, 8297, 364, 9, 24, "Print",ExpressionUUID->"c1da1928-7465-4a52-86b2-2ec6bee28b9d"],
Cell[281831, 8308, 435, 10, 24, "Print",ExpressionUUID->"285a575a-6aac-4821-b6a9-94d39e980e2b"],
Cell[282269, 8320, 448, 11, 24, "Print",ExpressionUUID->"018b0eba-278c-47b2-b077-8d743f11cdc8"],
Cell[282720, 8333, 443, 10, 24, "Print",ExpressionUUID->"00f510bc-13da-4f8c-b9fb-93ec92edd99e"],
Cell[283166, 8345, 435, 10, 24, "Print",ExpressionUUID->"e1551546-33fd-4484-bbbf-244b4ea67075"],
Cell[283604, 8357, 441, 10, 24, "Print",ExpressionUUID->"34c27977-0d3e-47c3-8112-36b4bab3ddb1"],
Cell[284048, 8369, 524, 11, 24, "Print",ExpressionUUID->"0f491ae0-5973-4daf-b9bc-175ee1d0634c"],
Cell[284575, 8382, 231, 5, 24, "Print",ExpressionUUID->"59b1b0c0-3a5a-4bb7-9922-08f415cc709d"],
Cell[284809, 8389, 292, 8, 24, "Print",ExpressionUUID->"e819d094-b190-40bd-bba8-4d3a92ed261d"],
Cell[285104, 8399, 326, 8, 24, "Print",ExpressionUUID->"8d2d9479-30d6-4438-98ac-945177438941"],
Cell[285433, 8409, 524, 11, 24, "Print",ExpressionUUID->"0a0ec2f0-b6bb-4676-846a-8ef67e19e187"],
Cell[285960, 8422, 536, 12, 24, "Print",ExpressionUUID->"09f6e77f-f064-4427-8648-e934cdf12efd"],
Cell[286499, 8436, 536, 12, 24, "Print",ExpressionUUID->"72f26f05-70b9-471f-b9ff-5124470ae963"],
Cell[287038, 8450, 524, 11, 24, "Print",ExpressionUUID->"ebdb69e5-e4b6-4f82-87d1-5c065f9ac4d4"],
Cell[287565, 8463, 534, 12, 24, "Print",ExpressionUUID->"27ade93e-4d2f-46cd-bdf5-2e52b67b18d1"],
Cell[288102, 8477, 370, 9, 24, "Print",ExpressionUUID->"fd984479-b08c-43e2-8d17-7a5a3fb0cff8"],
Cell[288475, 8488, 396, 10, 24, "Print",ExpressionUUID->"0d363715-8e08-4eea-86f2-e74006e12bf7"],
Cell[288874, 8500, 350, 9, 24, "Print",ExpressionUUID->"fc60175a-c2e4-4db4-bc0b-5b3f0566feec"],
Cell[289227, 8511, 352, 9, 24, "Print",ExpressionUUID->"f2e10c4a-21e1-4abe-8b22-86e551aa708e"],
Cell[289582, 8522, 360, 9, 24, "Print",ExpressionUUID->"f0eaf316-0011-45a4-b31c-af6315ac940b"],
Cell[289945, 8533, 366, 9, 24, "Print",ExpressionUUID->"72c0a2b5-0d35-444b-9435-32677009a167"],
Cell[290314, 8544, 524, 11, 24, "Print",ExpressionUUID->"0d5ce6b1-d2c5-4fbc-970d-e1087460cba3"],
Cell[290841, 8557, 536, 12, 24, "Print",ExpressionUUID->"8bf15219-94b1-4245-b2aa-9a1c631b8042"],
Cell[291380, 8571, 536, 12, 24, "Print",ExpressionUUID->"5d6689b8-a928-436f-864b-ea134591105d"],
Cell[291919, 8585, 524, 11, 24, "Print",ExpressionUUID->"73a084f8-dd7d-405c-8212-b997b82883e8"],
Cell[292446, 8598, 534, 12, 24, "Print",ExpressionUUID->"b2bbff70-3a3c-405f-8e53-fe60d6567598"],
Cell[292983, 8612, 368, 9, 24, "Print",ExpressionUUID->"ec40667c-453a-461d-938f-5190386fba2d"],
Cell[293354, 8623, 406, 10, 24, "Print",ExpressionUUID->"e5bcf21d-e649-40c2-b6eb-c8a06ca0bea2"],
Cell[293763, 8635, 352, 9, 24, "Print",ExpressionUUID->"8cd78f7a-d022-4080-8dc5-040690544925"],
Cell[294118, 8646, 352, 9, 24, "Print",ExpressionUUID->"b7d8077e-5546-4cab-85f3-7291205282b0"],
Cell[294473, 8657, 360, 9, 24, "Print",ExpressionUUID->"3a4818fe-fd40-4c7b-bf28-84dd4d5f315f"],
Cell[294836, 8668, 364, 9, 24, "Print",ExpressionUUID->"4cbd9497-c5ce-41a5-9df1-03e00a26bd1e"],
Cell[295203, 8679, 524, 11, 24, "Print",ExpressionUUID->"bfcbdce1-aa60-42d2-b22c-90d685485894"],
Cell[295730, 8692, 538, 12, 24, "Print",ExpressionUUID->"42eb4795-17a7-43cb-9a17-1f62bef44171"],
Cell[296271, 8706, 534, 12, 24, "Print",ExpressionUUID->"f36e44e4-321e-4ab2-bdcf-7032aca007cc"],
Cell[296808, 8720, 524, 11, 24, "Print",ExpressionUUID->"fd9149b3-1d5a-47d7-8ac0-2c165da9fbd0"],
Cell[297335, 8733, 534, 12, 24, "Print",ExpressionUUID->"1d9a685e-d185-4790-ac6f-7d5d70e1df35"],
Cell[297872, 8747, 368, 9, 24, "Print",ExpressionUUID->"1c5bf385-c603-4dd6-a265-63c87f859537"],
Cell[298243, 8758, 402, 10, 24, "Print",ExpressionUUID->"924082fc-512b-485a-9811-517e97a63130"],
Cell[298648, 8770, 350, 9, 24, "Print",ExpressionUUID->"7581baea-ecdc-4e6f-a49f-9e3cf8354f03"],
Cell[299001, 8781, 352, 9, 24, "Print",ExpressionUUID->"7ac73288-9c00-42ec-8d00-6c9c87c34a51"],
Cell[299356, 8792, 360, 9, 24, "Print",ExpressionUUID->"06b82576-91c9-4568-aa03-a058d34e6e27"],
Cell[299719, 8803, 366, 9, 24, "Print",ExpressionUUID->"e3d86004-7985-40dc-a27d-27c76633a546"],
Cell[300088, 8814, 524, 11, 24, "Print",ExpressionUUID->"724cad43-6575-478e-8196-2a9a56e5a8d3"],
Cell[300615, 8827, 536, 12, 24, "Print",ExpressionUUID->"12eeccb0-9224-4a28-a475-01a54ed5f226"],
Cell[301154, 8841, 533, 12, 24, "Print",ExpressionUUID->"f0416fa3-735f-4704-a880-71f2f4a20f2d"],
Cell[301690, 8855, 526, 11, 24, "Print",ExpressionUUID->"4e56c23a-0f45-4c6e-b98b-eb419a2e2013"],
Cell[302219, 8868, 534, 12, 24, "Print",ExpressionUUID->"9623f492-4e92-43bc-8d20-c58d12a7854a"],
Cell[302756, 8882, 368, 9, 24, "Print",ExpressionUUID->"c9b97b02-eafc-4c7a-ada8-aea504f09eed"],
Cell[303127, 8893, 400, 10, 24, "Print",ExpressionUUID->"26134890-d336-4eac-b33e-1347cdd7f22d"],
Cell[303530, 8905, 350, 9, 24, "Print",ExpressionUUID->"47953207-96dd-4d1a-9e9d-ce4b2f5f5a79"],
Cell[303883, 8916, 350, 9, 24, "Print",ExpressionUUID->"2e0a3249-73e7-48a0-9598-6b88d4e5de04"],
Cell[304236, 8927, 362, 9, 24, "Print",ExpressionUUID->"bb208f4d-cd6a-48e7-99ee-2cd0f197956c"],
Cell[304601, 8938, 366, 9, 24, "Print",ExpressionUUID->"24ef2105-addb-4376-848e-1477d3bb762c"],
Cell[304970, 8949, 524, 11, 24, "Print",ExpressionUUID->"60f16928-87fe-4c8e-bbe2-d2f064c2b681"],
Cell[305497, 8962, 536, 12, 24, "Print",ExpressionUUID->"53570a8e-3dd4-498a-93a4-51421c9772fe"],
Cell[306036, 8976, 534, 12, 24, "Print",ExpressionUUID->"a6bd3ad1-a92f-4f9f-91ce-bfb32127c375"],
Cell[306573, 8990, 526, 11, 24, "Print",ExpressionUUID->"b3835a59-19c6-4f2e-940f-1b3f8899fe17"],
Cell[307102, 9003, 534, 12, 24, "Print",ExpressionUUID->"31f72b85-93d0-4195-8b3f-3406f22a07df"],
Cell[307639, 9017, 368, 9, 24, "Print",ExpressionUUID->"af8c4656-7271-4821-ab4f-729f5b70ef1a"],
Cell[308010, 9028, 394, 10, 24, "Print",ExpressionUUID->"8f312120-459c-4ddb-9996-c2e12611a447"],
Cell[308407, 9040, 350, 9, 24, "Print",ExpressionUUID->"46619af1-8092-41b4-8222-4f9a16da5f1e"],
Cell[308760, 9051, 350, 9, 24, "Print",ExpressionUUID->"c3f0306a-5cc1-4b61-96d4-5f6022797114"],
Cell[309113, 9062, 360, 9, 24, "Print",ExpressionUUID->"ee6bae4d-e8ff-4599-b280-d4d5425c2287"],
Cell[309476, 9073, 364, 9, 24, "Print",ExpressionUUID->"35018b0f-5a88-4e03-8127-d1a57fbd3113"],
Cell[309843, 9084, 524, 11, 24, "Print",ExpressionUUID->"3821bd6e-0940-4432-9695-de3174b405e6"],
Cell[310370, 9097, 536, 12, 24, "Print",ExpressionUUID->"663c620a-46ae-4374-962c-fc4bc0c120c0"],
Cell[310909, 9111, 534, 12, 24, "Print",ExpressionUUID->"fee80596-f405-48a9-954a-b0674a4313af"],
Cell[311446, 9125, 524, 11, 24, "Print",ExpressionUUID->"e7a19f5c-9129-4d67-8932-150b1fbe525d"],
Cell[311973, 9138, 536, 12, 24, "Print",ExpressionUUID->"28b09bf6-aace-4e38-bde2-296d25fa1b6f"],
Cell[312512, 9152, 368, 9, 24, "Print",ExpressionUUID->"61e973b0-74c3-4ceb-827a-d48feebbdc72"],
Cell[312883, 9163, 396, 10, 24, "Print",ExpressionUUID->"d73cf4fa-e4e1-4e93-8a5a-674f8b9bf6cc"],
Cell[313282, 9175, 352, 9, 24, "Print",ExpressionUUID->"782d4e6b-6ad0-4dc2-b141-c4d27664b084"],
Cell[313637, 9186, 350, 9, 24, "Print",ExpressionUUID->"106e551a-c13b-42db-a428-6a615d5af780"],
Cell[313990, 9197, 360, 9, 24, "Print",ExpressionUUID->"fdcad515-afd5-4afd-be09-3add38ede6f6"],
Cell[314353, 9208, 366, 9, 24, "Print",ExpressionUUID->"a1805b4c-de53-496e-bea4-593c2d5ad32c"],
Cell[314722, 9219, 526, 11, 24, "Print",ExpressionUUID->"f94a6327-4a38-44d6-b839-7b709501c75d"],
Cell[315251, 9232, 538, 12, 24, "Print",ExpressionUUID->"1abcf482-2c52-4219-a329-2b97d4f01f80"],
Cell[315792, 9246, 536, 12, 24, "Print",ExpressionUUID->"a4a1b138-3007-40d8-9b5d-a6e80deb7626"],
Cell[316331, 9260, 524, 11, 24, "Print",ExpressionUUID->"b91d7d06-6806-4fea-ae8b-6f30ef173e07"],
Cell[316858, 9273, 534, 12, 24, "Print",ExpressionUUID->"900e1dc5-3dd1-4f5c-ab55-b598da0e051a"],
Cell[317395, 9287, 368, 9, 24, "Print",ExpressionUUID->"67017ae7-c1f0-479c-94c7-21108d8f550d"],
Cell[317766, 9298, 402, 10, 24, "Print",ExpressionUUID->"57fa5069-5933-4f11-870e-adec70e46d49"],
Cell[318171, 9310, 350, 9, 24, "Print",ExpressionUUID->"a1efbea4-cfc9-4535-ac04-7417424f9337"],
Cell[318524, 9321, 352, 9, 24, "Print",ExpressionUUID->"9dc08a99-59f4-4776-960c-78342903c969"],
Cell[318879, 9332, 360, 9, 24, "Print",ExpressionUUID->"ae30d9fe-bbce-46cd-803f-fa4eb51779f7"],
Cell[319242, 9343, 364, 9, 24, "Print",ExpressionUUID->"76f01dd2-7ac7-4353-8056-a6a20a25dfe1"],
Cell[319609, 9354, 524, 11, 24, "Print",ExpressionUUID->"154dbbc9-a8f9-4a51-b1fb-615105d58b93"],
Cell[320136, 9367, 536, 12, 24, "Print",ExpressionUUID->"d3b400e8-e24c-4362-9295-aa040a2bce79"],
Cell[320675, 9381, 536, 12, 24, "Print",ExpressionUUID->"8677cdd4-ba8b-499c-87cb-f3fcf747833a"],
Cell[321214, 9395, 522, 11, 24, "Print",ExpressionUUID->"dd84995d-bf59-4e5c-86e3-2965c73fd620"],
Cell[321739, 9408, 536, 12, 24, "Print",ExpressionUUID->"bd27b767-fb43-4544-b1b9-6d9b8a19bfa9"],
Cell[322278, 9422, 368, 9, 24, "Print",ExpressionUUID->"aff9f76b-f02e-4e0b-8e91-d8eb96cb1263"],
Cell[322649, 9433, 404, 10, 24, "Print",ExpressionUUID->"db42b7f2-007e-4bdd-a1a9-914bdcf9f319"],
Cell[323056, 9445, 350, 9, 24, "Print",ExpressionUUID->"73d0dfd1-103d-4858-92ac-92b5cbbc62a7"],
Cell[323409, 9456, 350, 9, 24, "Print",ExpressionUUID->"28c59beb-728d-4e14-9718-463b66305577"],
Cell[323762, 9467, 362, 9, 24, "Print",ExpressionUUID->"29ccfad2-d7d1-4a31-bdea-fd37e9ae150b"],
Cell[324127, 9478, 364, 9, 24, "Print",ExpressionUUID->"88b8033b-f283-4444-93b2-10019b98992d"],
Cell[324494, 9489, 524, 11, 24, "Print",ExpressionUUID->"c4edc251-8cdc-43d6-8404-8e0dee4a66b2"],
Cell[325021, 9502, 536, 12, 24, "Print",ExpressionUUID->"1ea2195b-2ad2-4016-930d-2318fa5f4dec"],
Cell[325560, 9516, 534, 12, 24, "Print",ExpressionUUID->"622bceee-cff4-49e9-8fbf-d48858d7f518"],
Cell[326097, 9530, 524, 11, 24, "Print",ExpressionUUID->"57a70b13-05f3-46b6-81ec-daae5be7e06b"],
Cell[326624, 9543, 534, 12, 24, "Print",ExpressionUUID->"bd566519-6648-437d-838b-fa17c131783b"],
Cell[327161, 9557, 368, 9, 24, "Print",ExpressionUUID->"f1938957-bdee-4a23-9e5d-eae0a5f46b9c"],
Cell[327532, 9568, 378, 9, 24, "Print",ExpressionUUID->"f8f03509-ecde-4224-8f80-1689dc0888e9"],
Cell[327913, 9579, 350, 9, 24, "Print",ExpressionUUID->"8ee7906d-65d1-4940-a13a-d35c64795b3b"],
Cell[328266, 9590, 350, 9, 24, "Print",ExpressionUUID->"3d6c44ec-b8a1-45cc-a6e8-5bb4e9f11148"],
Cell[328619, 9601, 362, 9, 24, "Print",ExpressionUUID->"2fde76e0-c89f-4fd2-a2b3-671ee4610749"],
Cell[328984, 9612, 366, 9, 24, "Print",ExpressionUUID->"d41ed009-4e8e-48ba-99e3-22786382d8ea"],
Cell[329353, 9623, 524, 11, 24, "Print",ExpressionUUID->"4e443bf7-bf97-40a0-9cb6-95617d8101db"],
Cell[329880, 9636, 536, 12, 24, "Print",ExpressionUUID->"c29e3b8f-cd4a-4f18-b91f-256b8da8dc79"],
Cell[330419, 9650, 534, 12, 24, "Print",ExpressionUUID->"c7fb733d-3098-40bd-bbd3-fe379a902531"],
Cell[330956, 9664, 526, 11, 24, "Print",ExpressionUUID->"87489cb7-a1eb-4491-a08f-ec7f96b8eca8"],
Cell[331485, 9677, 534, 12, 24, "Print",ExpressionUUID->"660c14a5-e350-4c91-9ea8-f126a86c2ade"],
Cell[332022, 9691, 368, 9, 24, "Print",ExpressionUUID->"e9d999a8-027c-4e18-b700-004d5afb1f6d"],
Cell[332393, 9702, 442, 10, 24, "Print",ExpressionUUID->"651fcec8-c08d-41b9-a948-6443d930f318"],
Cell[332838, 9714, 352, 9, 24, "Print",ExpressionUUID->"0916269e-2a70-453c-be8b-22cb87661f68"],
Cell[333193, 9725, 350, 9, 24, "Print",ExpressionUUID->"38056cca-2c54-4795-8ae3-6540260c22a5"],
Cell[333546, 9736, 360, 9, 24, "Print",ExpressionUUID->"f51ad694-e5ad-4813-a2c9-6100535fc34d"],
Cell[333909, 9747, 364, 9, 24, "Print",ExpressionUUID->"cc4f7c9d-fe64-4557-aedc-064e6c5ea714"],
Cell[334276, 9758, 526, 11, 24, "Print",ExpressionUUID->"1898716d-1cb2-463f-b85a-5b06f5294cd1"],
Cell[334805, 9771, 536, 12, 24, "Print",ExpressionUUID->"89b8637f-b6b0-4aba-9976-388fe12020b4"],
Cell[335344, 9785, 534, 12, 24, "Print",ExpressionUUID->"34b5f011-bd95-4d20-8312-a9c9b0c548c2"],
Cell[335881, 9799, 524, 11, 24, "Print",ExpressionUUID->"93fff589-80bb-4b6a-af16-e7fea38a7f05"],
Cell[336408, 9812, 534, 12, 24, "Print",ExpressionUUID->"53fd02a6-62d8-4e75-93ff-ceca56af79fd"],
Cell[336945, 9826, 370, 9, 24, "Print",ExpressionUUID->"65b2e5ca-006c-4833-a43c-854f105fab14"],
Cell[337318, 9837, 412, 10, 24, "Print",ExpressionUUID->"b233062b-9cce-4370-b7bd-93b3d2222674"],
Cell[337733, 9849, 350, 9, 24, "Print",ExpressionUUID->"edd4c519-5770-4fce-9188-7c49723485e6"],
Cell[338086, 9860, 352, 9, 24, "Print",ExpressionUUID->"7ec8838a-ebe4-4047-9a58-61578df66d31"],
Cell[338441, 9871, 360, 9, 24, "Print",ExpressionUUID->"f6b60a06-f8bd-44ef-8fd7-4c5e3619e403"],
Cell[338804, 9882, 364, 9, 24, "Print",ExpressionUUID->"bc124a33-46a7-464b-8927-0b010bb19c66"],
Cell[339171, 9893, 524, 11, 24, "Print",ExpressionUUID->"494b7c6b-c264-439d-98fc-9ff92866c8ea"],
Cell[339698, 9906, 538, 12, 24, "Print",ExpressionUUID->"b63c9498-9392-4a0c-a2e9-ce216e4a5af4"],
Cell[340239, 9920, 534, 12, 24, "Print",ExpressionUUID->"071b210e-771f-4f46-9052-7d2342c0fc38"],
Cell[340776, 9934, 524, 11, 24, "Print",ExpressionUUID->"c76adf51-3e43-4048-bfe7-daf343a8d176"],
Cell[341303, 9947, 536, 12, 24, "Print",ExpressionUUID->"9b156eb4-928d-4c36-a950-23ab6a00371d"],
Cell[341842, 9961, 368, 9, 24, "Print",ExpressionUUID->"96f8e069-d5d8-4407-8ec2-29fbf8088eab"],
Cell[342213, 9972, 414, 10, 24, "Print",ExpressionUUID->"5b1d2c7c-c421-4c2c-b837-7048fba2475c"],
Cell[342630, 9984, 352, 9, 24, "Print",ExpressionUUID->"296fe6d6-8c96-4faa-abcb-775dfbc65b78"],
Cell[342985, 9995, 350, 9, 24, "Print",ExpressionUUID->"58247322-e354-4b50-affe-d98214af5952"],
Cell[343338, 10006, 359, 9, 24, "Print",ExpressionUUID->"c05e1e5d-d89f-40db-aa99-c797a50c66f8"],
Cell[343700, 10017, 366, 9, 24, "Print",ExpressionUUID->"b735b037-c2e3-48a4-975a-fc8e733c35a3"],
Cell[344069, 10028, 524, 11, 24, "Print",ExpressionUUID->"b6477915-e885-48bc-a22a-effb4dc3ffc5"],
Cell[344596, 10041, 536, 12, 24, "Print",ExpressionUUID->"be36f617-fbdd-4e6b-9f2d-63b48a1e9f8b"],
Cell[345135, 10055, 534, 12, 24, "Print",ExpressionUUID->"f62f73cd-1d89-49cb-9190-36e44b7d884f"],
Cell[345672, 10069, 526, 11, 24, "Print",ExpressionUUID->"2d25cb4d-01b1-4ff6-bc28-c86286f4931c"],
Cell[346201, 10082, 533, 12, 24, "Print",ExpressionUUID->"f5b09a48-9d77-4153-a039-cbc0380e757b"],
Cell[346737, 10096, 368, 9, 24, "Print",ExpressionUUID->"e17e2252-045c-4064-a3a4-8eee2556fc17"],
Cell[347108, 10107, 414, 10, 24, "Print",ExpressionUUID->"5de125ab-bc29-4057-9687-ffa1048a66bd"],
Cell[347525, 10119, 352, 9, 24, "Print",ExpressionUUID->"e9be9383-d8c0-49cc-a2f0-053f31ad36ee"],
Cell[347880, 10130, 349, 9, 24, "Print",ExpressionUUID->"0baf8718-67d5-4bad-b945-b0483ddf4ce4"],
Cell[348232, 10141, 362, 9, 24, "Print",ExpressionUUID->"c72ab441-0ed1-4573-b809-fbd8f9df6b5b"],
Cell[348597, 10152, 364, 9, 24, "Print",ExpressionUUID->"c3a7ba20-4915-4b2f-b848-dcf366e0946e"],
Cell[348964, 10163, 524, 11, 24, "Print",ExpressionUUID->"672e470c-cdb7-405a-ae84-170f487405d9"],
Cell[349491, 10176, 536, 12, 24, "Print",ExpressionUUID->"addb5454-5967-41df-af86-f9661bd1a936"],
Cell[350030, 10190, 534, 12, 24, "Print",ExpressionUUID->"bdc07ad6-08ae-46e3-8e0f-7d1ea3dba5ce"],
Cell[350567, 10204, 524, 11, 24, "Print",ExpressionUUID->"1bc8429b-8e18-4e93-b73a-bc177a5cf86e"],
Cell[351094, 10217, 536, 12, 24, "Print",ExpressionUUID->"ad5bb9e0-4343-4faf-828f-f82a30b70783"],
Cell[351633, 10231, 368, 9, 24, "Print",ExpressionUUID->"2304a124-cb47-4f35-936c-7b1fb7d9c73f"],
Cell[352004, 10242, 410, 10, 24, "Print",ExpressionUUID->"6eab3614-9b5f-4e31-a829-df60ebeb01dd"],
Cell[352417, 10254, 350, 9, 24, "Print",ExpressionUUID->"3ebd7f30-693f-4189-be7e-5f322703d612"],
Cell[352770, 10265, 350, 9, 24, "Print",ExpressionUUID->"ced4b508-5745-402e-9c2a-258ab6274cf0"],
Cell[353123, 10276, 362, 9, 24, "Print",ExpressionUUID->"fff80452-f950-4f74-b051-6b43f41b9add"],
Cell[353488, 10287, 363, 9, 24, "Print",ExpressionUUID->"b1db4b5b-71a8-4e04-b42d-2c643743def0"],
Cell[353854, 10298, 524, 11, 24, "Print",ExpressionUUID->"bc5ebe81-24dd-44c4-a2e7-74e03a54e1e2"],
Cell[354381, 10311, 536, 12, 24, "Print",ExpressionUUID->"7051ca07-53fa-4c57-8a28-858310fde552"],
Cell[354920, 10325, 536, 12, 24, "Print",ExpressionUUID->"f198d977-227b-4779-995d-40548bdbb544"],
Cell[355459, 10339, 524, 11, 24, "Print",ExpressionUUID->"871d9142-e473-4a1c-a847-5f95276d7e03"],
Cell[355986, 10352, 534, 12, 24, "Print",ExpressionUUID->"eb917497-9479-4d76-970e-afa07b314470"],
Cell[356523, 10366, 368, 9, 24, "Print",ExpressionUUID->"3f206d02-9014-46af-b2e0-eb9e7a7e9b55"],
Cell[356894, 10377, 410, 10, 24, "Print",ExpressionUUID->"f74e5e08-6cd0-4fc9-b033-e22335d53b79"],
Cell[357307, 10389, 352, 9, 24, "Print",ExpressionUUID->"bf86322f-cdf1-4f71-94f4-53c5bd959ee9"],
Cell[357662, 10400, 350, 9, 24, "Print",ExpressionUUID->"f0f9b3ac-2c89-4f79-b8d5-7a63184492c3"],
Cell[358015, 10411, 360, 9, 24, "Print",ExpressionUUID->"de8389e2-1e54-44e3-a526-086472f68c32"],
Cell[358378, 10422, 364, 9, 24, "Print",ExpressionUUID->"a3674971-623a-47bc-8f9b-2c5fe96f5d6a"],
Cell[358745, 10433, 524, 11, 24, "Print",ExpressionUUID->"7e072d7a-e867-4103-83f4-d2224109a0c5"],
Cell[359272, 10446, 536, 12, 24, "Print",ExpressionUUID->"5227709d-0417-4241-b515-90e6b8d4017a"],
Cell[359811, 10460, 534, 12, 24, "Print",ExpressionUUID->"c9e316ff-fc86-4446-9f51-02141dea700c"],
Cell[360348, 10474, 523, 11, 24, "Print",ExpressionUUID->"d59358f9-f4a7-4d9b-991c-d6c4f2e9ce3a"],
Cell[360874, 10487, 536, 12, 24, "Print",ExpressionUUID->"ca5e7e70-2206-4837-b0a3-76c70f8e416f"],
Cell[361413, 10501, 368, 9, 24, "Print",ExpressionUUID->"7b20748b-80d6-457f-be2b-23839f3a1fc8"],
Cell[361784, 10512, 400, 10, 24, "Print",ExpressionUUID->"8c166bff-31ad-4e7d-a8de-72d1fc6784eb"],
Cell[362187, 10524, 350, 9, 24, "Print",ExpressionUUID->"26d88f46-1948-4a28-aa54-a785e3e1c08b"],
Cell[362540, 10535, 349, 9, 24, "Print",ExpressionUUID->"e2f8a269-5c82-4ef7-b4d9-409338ed77e5"],
Cell[362892, 10546, 360, 9, 24, "Print",ExpressionUUID->"6219fb21-7be1-4e5a-a8b3-39e2d4e36218"],
Cell[363255, 10557, 364, 9, 24, "Print",ExpressionUUID->"dca87842-e130-4353-89ff-b2b5670ee7d8"],
Cell[363622, 10568, 526, 11, 24, "Print",ExpressionUUID->"436aa17d-8852-456b-94b2-a36bb5c52fff"],
Cell[364151, 10581, 538, 12, 24, "Print",ExpressionUUID->"9803aad8-c55d-4b23-be35-320134d8c212"],
Cell[364692, 10595, 534, 12, 24, "Print",ExpressionUUID->"cac6126a-c79a-49c1-8b36-37f9df40ac64"],
Cell[365229, 10609, 524, 11, 24, "Print",ExpressionUUID->"4ba913b0-3a08-4844-b06c-f815783d353a"],
Cell[365756, 10622, 534, 12, 24, "Print",ExpressionUUID->"d106d332-7e48-4a97-a326-5d8b5ea2228e"],
Cell[366293, 10636, 368, 9, 24, "Print",ExpressionUUID->"af9a7f61-5ff0-4226-81d9-161259502696"],
Cell[366664, 10647, 411, 10, 24, "Print",ExpressionUUID->"013f6ae1-aa58-45bd-8009-9ac2905c9a64"],
Cell[367078, 10659, 352, 9, 24, "Print",ExpressionUUID->"6f2e1ee8-3c94-478c-996d-b3c8c8492411"],
Cell[367433, 10670, 352, 9, 24, "Print",ExpressionUUID->"ff0ec5cd-3384-486c-9737-e9d7d691a559"],
Cell[367788, 10681, 360, 9, 24, "Print",ExpressionUUID->"ad47ce65-3c34-4085-8579-fcf892547aaf"],
Cell[368151, 10692, 364, 9, 24, "Print",ExpressionUUID->"f7d000a5-fdb3-4b89-a261-bf25153bc5e3"],
Cell[368518, 10703, 524, 11, 24, "Print",ExpressionUUID->"60f0479c-409f-45fc-8052-e6c76d282af4"],
Cell[369045, 10716, 538, 12, 24, "Print",ExpressionUUID->"2fcdb3a6-5dd9-44ca-86a1-ac08804666c5"],
Cell[369586, 10730, 533, 12, 24, "Print",ExpressionUUID->"50948503-bd8f-400e-a2e6-8b43b57c55b0"],
Cell[370122, 10744, 523, 11, 24, "Print",ExpressionUUID->"041f4054-ea45-4007-91b1-986beb8018d9"],
Cell[370648, 10757, 534, 12, 24, "Print",ExpressionUUID->"e617e75a-81e6-462b-977f-73ac770eee8b"],
Cell[371185, 10771, 367, 9, 24, "Print",ExpressionUUID->"32c46a01-749c-4876-a840-472838b7ea0f"],
Cell[371555, 10782, 404, 10, 24, "Print",ExpressionUUID->"0bfe7bdf-d666-4e8d-a043-ccbb972bf32e"],
Cell[371962, 10794, 350, 9, 24, "Print",ExpressionUUID->"452a2470-aba9-4879-b21a-20330d80e55f"],
Cell[372315, 10805, 350, 9, 24, "Print",ExpressionUUID->"53c56f0c-956a-4217-9392-d421ad35ceaa"],
Cell[372668, 10816, 362, 9, 24, "Print",ExpressionUUID->"2f4f034b-9ac4-4f9e-abca-3f029086db0b"],
Cell[373033, 10827, 364, 9, 24, "Print",ExpressionUUID->"9a938391-c83c-40c4-9116-e3f85171c495"],
Cell[373400, 10838, 523, 11, 24, "Print",ExpressionUUID->"7ef80ed8-cb28-4c0f-b8e6-f5bfbd2b72c3"],
Cell[373926, 10851, 536, 12, 24, "Print",ExpressionUUID->"240ef66f-07ce-4125-855a-b1efd26723cf"],
Cell[374465, 10865, 534, 12, 24, "Print",ExpressionUUID->"42718ac8-02c3-4321-bb67-1dc619ad42fb"],
Cell[375002, 10879, 523, 11, 24, "Print",ExpressionUUID->"205616ee-a9ff-468a-8784-0a0616ec6293"],
Cell[375528, 10892, 536, 12, 24, "Print",ExpressionUUID->"15c34713-3030-443c-a07a-507842b80412"],
Cell[376067, 10906, 370, 9, 24, "Print",ExpressionUUID->"7dc7195c-0cbe-4899-abb0-647263e02021"],
Cell[376440, 10917, 398, 10, 24, "Print",ExpressionUUID->"aee4829e-a15f-40f3-9982-ef04fb361345"],
Cell[376841, 10929, 350, 9, 24, "Print",ExpressionUUID->"71d6b433-7433-4630-b0a5-1107627a38f6"],
Cell[377194, 10940, 350, 9, 24, "Print",ExpressionUUID->"3d8943a6-4a36-4ee8-9bc4-46a1a7cf6c08"],
Cell[377547, 10951, 362, 9, 24, "Print",ExpressionUUID->"5ab31e40-d036-4109-a4e3-6c270f5a814c"],
Cell[377912, 10962, 366, 9, 24, "Print",ExpressionUUID->"6e020ce3-1d0a-4e87-99b5-52777bd24ec8"],
Cell[378281, 10973, 526, 11, 24, "Print",ExpressionUUID->"7cb987b8-ad96-4334-961a-6294e0f468a5"],
Cell[378810, 10986, 536, 12, 24, "Print",ExpressionUUID->"e0e67b5b-4f7d-460c-8540-1c86427c064e"],
Cell[379349, 11000, 536, 12, 24, "Print",ExpressionUUID->"35808870-36ad-4275-9ae0-41bdc292f02a"],
Cell[379888, 11014, 524, 11, 24, "Print",ExpressionUUID->"5a834c58-b434-4a19-a9b9-75cc028cb0f6"],
Cell[380415, 11027, 534, 12, 24, "Print",ExpressionUUID->"14dfb074-8cd5-4949-a36b-3291ea62b185"],
Cell[380952, 11041, 368, 9, 24, "Print",ExpressionUUID->"d0f44a9e-7870-422a-81d6-75c8b677a86f"],
Cell[381323, 11052, 400, 10, 24, "Print",ExpressionUUID->"488b3311-1040-48b0-bb45-fef1306c7655"],
Cell[381726, 11064, 352, 9, 24, "Print",ExpressionUUID->"37809e15-3c1e-4976-8c3f-0109b19dc469"],
Cell[382081, 11075, 350, 9, 24, "Print",ExpressionUUID->"aed38044-45f6-45fb-856f-eb7c2d7aa7d2"],
Cell[382434, 11086, 362, 9, 24, "Print",ExpressionUUID->"f600d0a3-30db-4c9f-8833-8bfaa08cf902"],
Cell[382799, 11097, 364, 9, 24, "Print",ExpressionUUID->"e1a0a31b-45c4-46d7-b710-736407e59c71"],
Cell[383166, 11108, 526, 11, 24, "Print",ExpressionUUID->"14d91e4a-a1e9-435e-a0c0-a0971d198818"],
Cell[383695, 11121, 536, 12, 24, "Print",ExpressionUUID->"828b17ea-d983-4f8e-810a-3d8e54054a70"],
Cell[384234, 11135, 534, 12, 24, "Print",ExpressionUUID->"e1306c7b-7375-48af-a9b1-29201847adbd"],
Cell[384771, 11149, 524, 11, 24, "Print",ExpressionUUID->"5b770dd6-9433-4fe1-a813-248ca4d5ec82"],
Cell[385298, 11162, 534, 12, 24, "Print",ExpressionUUID->"2522d057-c75b-4a2f-9200-8db85fe64c6d"],
Cell[385835, 11176, 368, 9, 24, "Print",ExpressionUUID->"8210e558-e2e8-42f4-95d4-84d645792478"],
Cell[386206, 11187, 376, 9, 24, "Print",ExpressionUUID->"7beec9c3-96d9-4443-bf0d-f832849f5f49"],
Cell[386585, 11198, 350, 9, 24, "Print",ExpressionUUID->"4022eab6-1bad-46a5-a1a3-450c886acd9d"],
Cell[386938, 11209, 350, 9, 24, "Print",ExpressionUUID->"66eff67b-9350-442c-b7e1-0723638f1690"],
Cell[387291, 11220, 362, 9, 24, "Print",ExpressionUUID->"9fdd136f-35e0-47b6-b25c-6e5c4ddc97dd"],
Cell[387656, 11231, 364, 9, 24, "Print",ExpressionUUID->"258be43a-2dfe-4fdd-8e5b-e6b70023d70d"],
Cell[388023, 11242, 523, 11, 24, "Print",ExpressionUUID->"d88c33f4-8c2e-4e59-9116-5265808d88f7"],
Cell[388549, 11255, 536, 12, 24, "Print",ExpressionUUID->"9536ed40-38e8-4c15-9c3c-d123c614d21a"],
Cell[389088, 11269, 534, 12, 24, "Print",ExpressionUUID->"926c090a-b0c1-4c1f-9123-a5d190720581"],
Cell[389625, 11283, 526, 11, 24, "Print",ExpressionUUID->"68c30491-9d82-4803-8a83-3731074f2938"],
Cell[390154, 11296, 534, 12, 24, "Print",ExpressionUUID->"2496d30b-7736-44ca-88dc-4a2eeba64440"],
Cell[390691, 11310, 368, 9, 24, "Print",ExpressionUUID->"b710179f-212c-4c0e-b4d3-580c625bd042"],
Cell[391062, 11321, 376, 9, 24, "Print",ExpressionUUID->"ff31147e-78aa-437b-a157-edcdcb68ea77"],
Cell[391441, 11332, 350, 9, 24, "Print",ExpressionUUID->"6b00c73d-bafc-4e9e-af26-ac0abba2a62d"],
Cell[391794, 11343, 350, 9, 24, "Print",ExpressionUUID->"32595ea0-d3d7-4a6f-84a8-264c9e363814"],
Cell[392147, 11354, 360, 9, 24, "Print",ExpressionUUID->"4854f0c1-d690-4e08-be36-64f948907887"],
Cell[392510, 11365, 364, 9, 24, "Print",ExpressionUUID->"1d6dbdde-1c59-4a56-89b9-ed2e171799cc"],
Cell[392877, 11376, 524, 11, 24, "Print",ExpressionUUID->"68c5b7b3-5c2f-4581-a10f-215cebaa1d74"],
Cell[393404, 11389, 536, 12, 24, "Print",ExpressionUUID->"a506cb53-f7e2-4d4c-818b-3742e919f51d"],
Cell[393943, 11403, 534, 12, 24, "Print",ExpressionUUID->"aa97d7f5-feb4-4814-9b93-6209910121f5"],
Cell[394480, 11417, 524, 11, 24, "Print",ExpressionUUID->"41e322d4-8527-4d47-8c8e-0bc462967e12"],
Cell[395007, 11430, 534, 12, 24, "Print",ExpressionUUID->"b351f986-8da1-4996-8f78-2fa5b5c7028d"],
Cell[395544, 11444, 370, 9, 24, "Print",ExpressionUUID->"b4988dc9-4d29-4cb7-a744-74b729e34c31"],
Cell[395917, 11455, 443, 10, 24, "Print",ExpressionUUID->"d7b091fd-42c4-4625-8216-0499626210bf"],
Cell[396363, 11467, 350, 9, 24, "Print",ExpressionUUID->"24d70559-6607-43f7-8219-f0f7b7a654f3"],
Cell[396716, 11478, 352, 9, 24, "Print",ExpressionUUID->"2800d0c3-0220-41c5-8836-e9aab8881b46"],
Cell[397071, 11489, 360, 9, 24, "Print",ExpressionUUID->"fca7ec23-f3de-4a74-831d-5f373812f83f"],
Cell[397434, 11500, 364, 9, 24, "Print",ExpressionUUID->"94bee697-97d1-41ba-8b81-509bcc52aa4e"],
Cell[397801, 11511, 523, 11, 24, "Print",ExpressionUUID->"6e7216c3-775c-4505-9b53-cdb16402dc7c"],
Cell[398327, 11524, 536, 12, 24, "Print",ExpressionUUID->"f03760ba-5cbd-491c-8788-691345c5ae83"],
Cell[398866, 11538, 534, 12, 24, "Print",ExpressionUUID->"fb963cae-ca39-4142-aeef-62ae573931a2"],
Cell[399403, 11552, 526, 11, 24, "Print",ExpressionUUID->"a6836856-51dd-4d63-8505-aceb319bfc00"],
Cell[399932, 11565, 534, 12, 24, "Print",ExpressionUUID->"25faba90-6f7f-4934-8adf-2e67053c00b1"],
Cell[400469, 11579, 368, 9, 24, "Print",ExpressionUUID->"6d21bbfc-1c43-498a-9b12-8b7f182e53ab"],
Cell[400840, 11590, 376, 9, 24, "Print",ExpressionUUID->"7a970ca9-b862-47a0-b580-1e10375e7ec5"],
Cell[401219, 11601, 350, 9, 24, "Print",ExpressionUUID->"4e0654d6-78a6-4434-8df2-1cb70cc53983"],
Cell[401572, 11612, 352, 9, 24, "Print",ExpressionUUID->"07044cc5-f888-4734-a440-8501cc1a586f"],
Cell[401927, 11623, 360, 9, 24, "Print",ExpressionUUID->"b7fd8abe-09b8-40a8-8ecd-9b25359267b4"],
Cell[402290, 11634, 364, 9, 24, "Print",ExpressionUUID->"afaebaa6-544f-476c-8e5f-b684fc5d745a"],
Cell[402657, 11645, 526, 11, 24, "Print",ExpressionUUID->"1719c5e4-17cc-4381-a37e-c06e3cf0c488"],
Cell[403186, 11658, 536, 12, 24, "Print",ExpressionUUID->"4f8358ba-1765-4622-8538-fae2518bc3f2"],
Cell[403725, 11672, 534, 12, 24, "Print",ExpressionUUID->"23838210-91d4-4acf-887a-bb960cd57f8e"],
Cell[404262, 11686, 526, 11, 24, "Print",ExpressionUUID->"9635793e-a56d-4e24-b50a-5176da5f4338"],
Cell[404791, 11699, 534, 12, 24, "Print",ExpressionUUID->"3bae9c31-6637-4235-93e4-ff0349d56931"],
Cell[405328, 11713, 368, 9, 24, "Print",ExpressionUUID->"507050f6-a914-40dd-bc2e-2e370dbc2c31"],
Cell[405699, 11724, 376, 9, 24, "Print",ExpressionUUID->"d11a3965-fdba-453f-9682-c177bc4fbe9c"],
Cell[406078, 11735, 350, 9, 24, "Print",ExpressionUUID->"b5612c72-0769-4346-a937-9a8c7e46f5e9"],
Cell[406431, 11746, 350, 9, 24, "Print",ExpressionUUID->"6f4609df-2507-4a8e-9d21-ca7cd553b385"],
Cell[406784, 11757, 360, 9, 24, "Print",ExpressionUUID->"f2489cec-622c-41be-9337-188df7988a42"],
Cell[407147, 11768, 364, 9, 24, "Print",ExpressionUUID->"70d98cc7-18fb-4052-b10d-55ae214eeaab"],
Cell[407514, 11779, 526, 11, 24, "Print",ExpressionUUID->"c65a90e6-278d-4fcf-a5b6-6cce5b6345ae"],
Cell[408043, 11792, 536, 12, 24, "Print",ExpressionUUID->"7bc86fb0-8a0b-4b5f-af4d-76ae07d2c249"],
Cell[408582, 11806, 534, 12, 24, "Print",ExpressionUUID->"ac15ec5e-404b-4062-9677-d7a34a199f2a"],
Cell[409119, 11820, 526, 11, 24, "Print",ExpressionUUID->"08cd46b8-0546-4456-9bcb-1b6b508026a1"],
Cell[409648, 11833, 533, 12, 24, "Print",ExpressionUUID->"92f7fb75-52c9-49b1-b785-cb22d1e5d6ad"],
Cell[410184, 11847, 368, 9, 24, "Print",ExpressionUUID->"96feb088-6436-4e81-9b7f-a3f78865cd6f"],
Cell[410555, 11858, 378, 9, 24, "Print",ExpressionUUID->"58dddcf2-4a72-48c3-ab8e-ae5cec88737b"],
Cell[410936, 11869, 350, 9, 24, "Print",ExpressionUUID->"124a3eb2-a06e-44cc-a2a9-93888d2406f3"],
Cell[411289, 11880, 350, 9, 24, "Print",ExpressionUUID->"eba9b547-eede-4ab0-941f-83ae1eb49226"],
Cell[411642, 11891, 360, 9, 24, "Print",ExpressionUUID->"8c4c81b0-9f3a-4641-9969-b6a944252480"],
Cell[412005, 11902, 364, 9, 24, "Print",ExpressionUUID->"258912a5-04dc-4f69-a048-619e17a6d850"],
Cell[412372, 11913, 526, 11, 24, "Print",ExpressionUUID->"0d3bc3cd-6ddf-4c04-b01b-6426432158b1"],
Cell[412901, 11926, 535, 12, 24, "Print",ExpressionUUID->"9aa41591-def0-445e-ab71-15f1d2e21218"],
Cell[413439, 11940, 534, 12, 24, "Print",ExpressionUUID->"1a767907-d71d-4958-a7fc-0c1ca36d6c81"],
Cell[413976, 11954, 524, 11, 24, "Print",ExpressionUUID->"d024c396-12eb-4e11-8fe6-3eb2539f55be"],
Cell[414503, 11967, 536, 12, 24, "Print",ExpressionUUID->"24f13d4c-68c4-401b-a180-410d3c7356b4"],
Cell[415042, 11981, 370, 9, 24, "Print",ExpressionUUID->"3358f23a-dc16-4b97-901e-f915dd7fef79"],
Cell[415415, 11992, 376, 9, 24, "Print",ExpressionUUID->"7bde9d56-ef8f-4717-a89a-ee2de93c2099"],
Cell[415794, 12003, 350, 9, 24, "Print",ExpressionUUID->"a8992639-0443-4405-b477-c2903d561449"],
Cell[416147, 12014, 352, 9, 24, "Print",ExpressionUUID->"672b805e-e377-40f5-abe6-83be31a6787d"],
Cell[416502, 12025, 360, 9, 24, "Print",ExpressionUUID->"8c22ce1a-572c-403a-9cd5-15f9942310b5"],
Cell[416865, 12036, 364, 9, 24, "Print",ExpressionUUID->"7d0eff68-6295-477d-967f-e3523e1ce724"],
Cell[417232, 12047, 526, 11, 24, "Print",ExpressionUUID->"f3f41d58-d67f-486f-94db-0da6c031987e"],
Cell[417761, 12060, 538, 12, 24, "Print",ExpressionUUID->"4b429f7c-92d5-42b7-b128-4eee7cd57ae6"],
Cell[418302, 12074, 536, 12, 24, "Print",ExpressionUUID->"e9fe48d2-6eac-445e-ae67-bb049d8b2c45"],
Cell[418841, 12088, 524, 11, 24, "Print",ExpressionUUID->"859ab30e-53b1-42cd-91f5-7109bed9e4d5"],
Cell[419368, 12101, 534, 12, 24, "Print",ExpressionUUID->"ea5b2281-22d6-48f7-bf66-6da224eff8cc"],
Cell[419905, 12115, 370, 9, 24, "Print",ExpressionUUID->"d605f964-7f9f-4d2b-b5cc-e9f1174701d6"],
Cell[420278, 12126, 403, 10, 24, "Print",ExpressionUUID->"346e9c9a-e7f9-4059-a464-47246ddee634"],
Cell[420684, 12138, 352, 9, 24, "Print",ExpressionUUID->"7a9e0282-67fd-43db-add0-692c8013bda1"],
Cell[421039, 12149, 350, 9, 24, "Print",ExpressionUUID->"78346684-0b03-4dbb-8354-cfe3c8e3f139"],
Cell[421392, 12160, 362, 9, 24, "Print",ExpressionUUID->"3ced9a2a-da44-4b97-8184-8e3a445764b8"],
Cell[421757, 12171, 366, 9, 24, "Print",ExpressionUUID->"93c529c8-5d58-482e-adc3-3ac93af32276"],
Cell[422126, 12182, 526, 11, 24, "Print",ExpressionUUID->"3f92c077-3358-4501-a274-c70f727e3e57"],
Cell[422655, 12195, 536, 12, 24, "Print",ExpressionUUID->"9ff9915d-9713-40d5-acc8-b56ea7b8a2fa"],
Cell[423194, 12209, 534, 12, 24, "Print",ExpressionUUID->"0c7af62e-5680-40b0-9a70-5e633e726550"],
Cell[423731, 12223, 526, 11, 24, "Print",ExpressionUUID->"8a56944c-d0f6-45e1-9b21-8bb82fe97046"],
Cell[424260, 12236, 534, 12, 24, "Print",ExpressionUUID->"911fb292-2e19-41ec-af90-90816881d7ba"],
Cell[424797, 12250, 368, 9, 24, "Print",ExpressionUUID->"2e9279bf-8f78-4406-8fb4-e646506b9117"],
Cell[425168, 12261, 404, 10, 24, "Print",ExpressionUUID->"3976279b-22aa-4d20-9ab0-e3faa7a8194f"],
Cell[425575, 12273, 350, 9, 24, "Print",ExpressionUUID->"87b913ba-4f8c-42b2-9dd4-9187708df555"],
Cell[425928, 12284, 352, 9, 24, "Print",ExpressionUUID->"adfe97cf-9855-4468-82a4-49b9b0ab9c5c"],
Cell[426283, 12295, 362, 9, 24, "Print",ExpressionUUID->"01b8fad2-563d-46d7-a62d-eeedb6e0bf91"],
Cell[426648, 12306, 364, 9, 24, "Print",ExpressionUUID->"7b30751c-3552-4e1b-afcd-08eb35827a5f"],
Cell[427015, 12317, 524, 11, 24, "Print",ExpressionUUID->"e91ef356-03ce-48b5-b87a-2ff0ec1b6a83"],
Cell[427542, 12330, 538, 12, 24, "Print",ExpressionUUID->"3cd5603c-ebc8-4cbe-8f75-3078fbddfc83"],
Cell[428083, 12344, 534, 12, 24, "Print",ExpressionUUID->"9a1a24d3-f54a-486d-951a-1e7495afac96"],
Cell[428620, 12358, 524, 11, 24, "Print",ExpressionUUID->"14b0c91f-f795-4539-b732-429a71623298"],
Cell[429147, 12371, 534, 12, 24, "Print",ExpressionUUID->"136b8062-9d00-4503-ae5c-f4365857b066"],
Cell[429684, 12385, 368, 9, 24, "Print",ExpressionUUID->"150f9a8a-2869-4654-b5f5-8ef53800c779"],
Cell[430055, 12396, 376, 9, 24, "Print",ExpressionUUID->"fa938e77-a293-4b20-b8ac-9126a3f75716"],
Cell[430434, 12407, 352, 9, 24, "Print",ExpressionUUID->"15296b47-8897-4b0c-b5a6-6916294f2d39"],
Cell[430789, 12418, 350, 9, 24, "Print",ExpressionUUID->"8fe8f674-1e76-42a2-a7b6-4f200ee01cd9"],
Cell[431142, 12429, 360, 9, 24, "Print",ExpressionUUID->"f9dc5a7a-e237-4178-8a0f-fcf2419707d9"],
Cell[431505, 12440, 364, 9, 24, "Print",ExpressionUUID->"c7954fec-a356-4647-b836-f52c410dd8cf"],
Cell[431872, 12451, 526, 11, 24, "Print",ExpressionUUID->"72ae1724-f501-4bba-ae1f-365de9044c05"],
Cell[432401, 12464, 536, 12, 24, "Print",ExpressionUUID->"2e8f5c3b-1807-4fb9-8568-f82179f895be"],
Cell[432940, 12478, 533, 12, 24, "Print",ExpressionUUID->"093ae0ca-8d76-424e-959c-0410a61e42a2"],
Cell[433476, 12492, 524, 11, 24, "Print",ExpressionUUID->"874df1ed-9bbe-4cd3-bcd2-aba7df29dd7a"],
Cell[434003, 12505, 534, 12, 24, "Print",ExpressionUUID->"7090a5d2-af4f-4db1-8ed8-92035c8e5cf9"],
Cell[434540, 12519, 368, 9, 24, "Print",ExpressionUUID->"1875e9f3-275f-4c57-bf6d-aee76c747797"],
Cell[434911, 12530, 376, 9, 24, "Print",ExpressionUUID->"0666368b-36dc-434f-9bb5-7e69cd84d1a4"],
Cell[435290, 12541, 350, 9, 24, "Print",ExpressionUUID->"a92aadb1-9355-4547-a9b7-facda385312b"],
Cell[435643, 12552, 352, 9, 24, "Print",ExpressionUUID->"d11afdb8-d68b-43b4-a8aa-352ee955c755"],
Cell[435998, 12563, 360, 9, 24, "Print",ExpressionUUID->"0347873b-6701-4f27-9f78-d539e2740b22"],
Cell[436361, 12574, 364, 9, 24, "Print",ExpressionUUID->"6baf6fd5-ece0-4e4c-81a5-97ce6ce61ca1"],
Cell[436728, 12585, 524, 11, 24, "Print",ExpressionUUID->"22db72b6-4fcc-40e1-99ea-fa5c6a5e5bcd"],
Cell[437255, 12598, 538, 12, 24, "Print",ExpressionUUID->"2923cc89-d594-4e22-b820-850e6808473f"],
Cell[437796, 12612, 534, 12, 24, "Print",ExpressionUUID->"944ac936-3ed5-434d-a4b0-63dff53d147b"],
Cell[438333, 12626, 524, 11, 24, "Print",ExpressionUUID->"1e131cd8-315f-4aa0-b9ca-7fe26cdbc977"],
Cell[438860, 12639, 534, 12, 24, "Print",ExpressionUUID->"9198e292-7d1b-4d4f-aef8-77eac4990625"],
Cell[439397, 12653, 368, 9, 24, "Print",ExpressionUUID->"1511f490-0893-4f4c-8bc0-e688adccfff9"],
Cell[439768, 12664, 378, 9, 24, "Print",ExpressionUUID->"f3009ec7-c565-466d-8456-dd08756f3a50"],
Cell[440149, 12675, 352, 9, 24, "Print",ExpressionUUID->"37477112-af66-4cae-aba2-d1238b325e27"],
Cell[440504, 12686, 350, 9, 24, "Print",ExpressionUUID->"522495b3-998a-4925-8182-4e2a4f3389b5"],
Cell[440857, 12697, 360, 9, 24, "Print",ExpressionUUID->"7572031b-6d58-4a62-bd32-b7a6b37c8768"],
Cell[441220, 12708, 364, 9, 24, "Print",ExpressionUUID->"9955e781-5a5a-432b-b110-6e53b9f9a88f"],
Cell[441587, 12719, 524, 11, 24, "Print",ExpressionUUID->"2f461845-3090-461c-a65b-a6ce0eb3e58d"],
Cell[442114, 12732, 536, 12, 24, "Print",ExpressionUUID->"868274f1-ceb5-4ca8-aa22-ceb9174285d4"],
Cell[442653, 12746, 536, 12, 24, "Print",ExpressionUUID->"551e7a6d-a3ba-4db1-b608-18495a7d2011"],
Cell[443192, 12760, 524, 11, 24, "Print",ExpressionUUID->"f004fa77-c659-418c-9d4b-207585367998"],
Cell[443719, 12773, 534, 12, 24, "Print",ExpressionUUID->"448ae6b3-743b-4de6-b232-d22a45768a32"],
Cell[444256, 12787, 367, 9, 24, "Print",ExpressionUUID->"0ae27024-454e-454d-a6ea-a9e90106c89e"],
Cell[444626, 12798, 376, 9, 24, "Print",ExpressionUUID->"1bb8fd5d-844c-414a-8a0c-d7e37a7e3966"],
Cell[445005, 12809, 350, 9, 24, "Print",ExpressionUUID->"a36c1f7c-68f4-49d5-a09e-6e12334ce5ec"],
Cell[445358, 12820, 352, 9, 24, "Print",ExpressionUUID->"eb4257a8-f8a6-407a-b9ed-401dde9d0ef6"],
Cell[445713, 12831, 360, 9, 24, "Print",ExpressionUUID->"8c8a5983-945b-4521-8f7c-476d2f7cf809"],
Cell[446076, 12842, 364, 9, 24, "Print",ExpressionUUID->"e68fb0b6-8e2a-4797-aa1a-c02720b23234"],
Cell[446443, 12853, 524, 11, 24, "Print",ExpressionUUID->"855ee069-99f8-4ef3-a468-44566a240650"],
Cell[446970, 12866, 536, 12, 24, "Print",ExpressionUUID->"95ff4e3b-f546-4eda-a709-43c56f0adcb5"],
Cell[447509, 12880, 536, 12, 24, "Print",ExpressionUUID->"5a4a5c0e-d2fb-4e98-ae41-7c9a1d9443c1"],
Cell[448048, 12894, 524, 11, 24, "Print",ExpressionUUID->"3ad9f830-a259-4c3b-bd24-6c9d356f04fb"],
Cell[448575, 12907, 534, 12, 24, "Print",ExpressionUUID->"aced4ac2-edc3-4b39-9b2d-42844291a02a"],
Cell[449112, 12921, 370, 9, 24, "Print",ExpressionUUID->"dc1323ea-af57-4a47-ad08-d52430eb171b"],
Cell[449485, 12932, 376, 9, 24, "Print",ExpressionUUID->"a70a2181-9c34-48b4-b646-2777b4b2420f"],
Cell[449864, 12943, 350, 9, 24, "Print",ExpressionUUID->"5cf653a0-7f4a-4f79-812c-a0ec22350239"],
Cell[450217, 12954, 350, 9, 24, "Print",ExpressionUUID->"34ea84a6-a2d3-400c-a398-1d788dd54bbe"],
Cell[450570, 12965, 360, 9, 24, "Print",ExpressionUUID->"6ebd473a-f1c5-47cd-8309-9eabc199ba23"],
Cell[450933, 12976, 364, 9, 24, "Print",ExpressionUUID->"233fcb80-5f1e-40dc-8ad5-aedc93015459"],
Cell[451300, 12987, 524, 11, 24, "Print",ExpressionUUID->"1c918074-f9e3-4190-a871-d62168253641"],
Cell[451827, 13000, 536, 12, 24, "Print",ExpressionUUID->"a5287ea9-c27a-47dc-ac06-9ac45ac86c54"],
Cell[452366, 13014, 536, 12, 24, "Print",ExpressionUUID->"a21f6d64-b8f5-47b9-af5c-5dff164424ed"],
Cell[452905, 13028, 526, 11, 24, "Print",ExpressionUUID->"8d1c9fc9-e53d-4426-ac75-f3a0bd681a7d"],
Cell[453434, 13041, 534, 12, 24, "Print",ExpressionUUID->"1b43bc71-80c4-43f7-b0f6-a18b26c57343"],
Cell[453971, 13055, 370, 9, 24, "Print",ExpressionUUID->"31b367fd-a4a4-484d-bc7a-e6ee32291ea5"],
Cell[454344, 13066, 376, 9, 24, "Print",ExpressionUUID->"100feb4b-b453-44a2-a7f1-2d4a5205cecf"],
Cell[454723, 13077, 350, 9, 24, "Print",ExpressionUUID->"212f1387-34a2-4387-87ae-14568a95446b"],
Cell[455076, 13088, 350, 9, 24, "Print",ExpressionUUID->"79a4fe08-faee-4c63-9225-2e0e7a4bff30"],
Cell[455429, 13099, 362, 9, 24, "Print",ExpressionUUID->"7392d03b-9976-4bc5-bc7d-ba28176842e0"],
Cell[455794, 13110, 364, 9, 24, "Print",ExpressionUUID->"0b237c8b-ffe6-4c89-9a44-57447b95205e"],
Cell[456161, 13121, 524, 11, 24, "Print",ExpressionUUID->"4a92d001-e12a-4e87-bb52-caca928ee559"],
Cell[456688, 13134, 536, 12, 24, "Print",ExpressionUUID->"7b0a3e38-a751-4e9b-8ea2-3e95899306a1"],
Cell[457227, 13148, 534, 12, 24, "Print",ExpressionUUID->"c96cdfdb-9d7a-4eca-aa23-8d2c0a62004f"],
Cell[457764, 13162, 523, 11, 24, "Print",ExpressionUUID->"c08cd08a-a58c-48cd-a03f-c16a2145762e"],
Cell[458290, 13175, 534, 12, 24, "Print",ExpressionUUID->"36373791-c874-4b79-8626-ea97b66885e9"],
Cell[458827, 13189, 368, 9, 24, "Print",ExpressionUUID->"5b1571ef-254e-4257-9f43-1dbd679d46ad"],
Cell[459198, 13200, 408, 10, 24, "Print",ExpressionUUID->"907d4118-8243-4cc2-b951-e261a6ace5a0"],
Cell[459609, 13212, 352, 9, 24, "Print",ExpressionUUID->"799354cc-bb98-49aa-a15b-b95a821d695b"],
Cell[459964, 13223, 352, 9, 24, "Print",ExpressionUUID->"bc58c1b4-c79b-4f18-8e9f-0f42d8394010"],
Cell[460319, 13234, 360, 9, 24, "Print",ExpressionUUID->"b854f3bd-8b08-4f3e-935b-3116e99e7562"],
Cell[460682, 13245, 364, 9, 24, "Print",ExpressionUUID->"c8004efc-431a-4045-8b3e-313133d0bdd4"],
Cell[461049, 13256, 524, 11, 24, "Print",ExpressionUUID->"b125316b-ae6a-4022-9b8d-97d7025a2a0b"],
Cell[461576, 13269, 536, 12, 24, "Print",ExpressionUUID->"420188ac-bbe4-4b82-9092-cc535340f57c"],
Cell[462115, 13283, 534, 12, 24, "Print",ExpressionUUID->"44ff0029-03d0-49b6-baaf-4b525d122965"],
Cell[462652, 13297, 524, 11, 24, "Print",ExpressionUUID->"30a4df86-b3ee-4478-af87-59478de3338b"],
Cell[463179, 13310, 536, 12, 24, "Print",ExpressionUUID->"e28e5c28-4652-4e00-a9a5-ffdc26c8a2ae"],
Cell[463718, 13324, 368, 9, 24, "Print",ExpressionUUID->"a8f2042c-5a46-4ffb-a4fc-7955c75f0ddb"],
Cell[464089, 13335, 376, 9, 24, "Print",ExpressionUUID->"1a6118be-6d7a-4b36-a04e-104223464fa2"],
Cell[464468, 13346, 350, 9, 24, "Print",ExpressionUUID->"d2c8b3aa-955a-412e-80fc-b17a3401dfca"],
Cell[464821, 13357, 349, 9, 24, "Print",ExpressionUUID->"59616deb-97fc-4a34-b19c-82047fe3de58"],
Cell[465173, 13368, 360, 9, 24, "Print",ExpressionUUID->"312d4497-e12e-414a-a730-aa5355a66298"],
Cell[465536, 13379, 364, 9, 24, "Print",ExpressionUUID->"50ec1208-b234-4160-93ce-b34093e92e53"],
Cell[465903, 13390, 524, 11, 24, "Print",ExpressionUUID->"5c246103-1c84-4dba-9c8c-75b8a166a321"],
Cell[466430, 13403, 536, 12, 24, "Print",ExpressionUUID->"edfcd311-9d59-4e15-9cc8-6105c2d609d9"],
Cell[466969, 13417, 534, 12, 24, "Print",ExpressionUUID->"05ecc36d-55a8-49b8-987f-4a4e1b578b7b"],
Cell[467506, 13431, 524, 11, 24, "Print",ExpressionUUID->"d92b8f69-0a0d-47bd-8efb-e7a7a4568292"],
Cell[468033, 13444, 536, 12, 24, "Print",ExpressionUUID->"ac72be8c-fb91-4af2-95d0-478b4a48c7c2"],
Cell[468572, 13458, 368, 9, 24, "Print",ExpressionUUID->"f1bb1686-bd33-4b7c-9dae-5a05fed4a303"],
Cell[468943, 13469, 376, 9, 24, "Print",ExpressionUUID->"705f9c67-7b77-45c9-a37f-1f804e1ad3f9"],
Cell[469322, 13480, 352, 9, 24, "Print",ExpressionUUID->"5f8578d7-0b9f-4019-97a8-d6e83c92496b"],
Cell[469677, 13491, 352, 9, 24, "Print",ExpressionUUID->"ed7040fe-8e49-4ccf-b025-e79bd277cdcc"],
Cell[470032, 13502, 362, 9, 24, "Print",ExpressionUUID->"09ff4cbb-4bcd-4722-8f02-d3077d7d5161"],
Cell[470397, 13513, 363, 9, 24, "Print",ExpressionUUID->"7ad9916c-bbdf-4a5e-90f8-c76477d0f0fd"],
Cell[470763, 13524, 526, 11, 24, "Print",ExpressionUUID->"77808e15-cea3-4f25-8f39-47bdd0999b8f"],
Cell[471292, 13537, 536, 12, 24, "Print",ExpressionUUID->"4462f12d-d97f-4fbc-8916-42c331a2e927"],
Cell[471831, 13551, 534, 12, 24, "Print",ExpressionUUID->"cd68e8ea-fc08-4a8b-9912-e2f50e81e829"],
Cell[472368, 13565, 524, 11, 24, "Print",ExpressionUUID->"57188cf1-a941-4f40-8e0c-eba1b93ff007"],
Cell[472895, 13578, 534, 12, 24, "Print",ExpressionUUID->"513450dd-925a-4ad9-9e9f-751964cb22ff"],
Cell[473432, 13592, 368, 9, 24, "Print",ExpressionUUID->"564e1ab5-35c5-4386-b573-c866a513dc9d"],
Cell[473803, 13603, 378, 9, 24, "Print",ExpressionUUID->"3c60a577-1357-4014-96df-0a8611f34512"],
Cell[474184, 13614, 350, 9, 24, "Print",ExpressionUUID->"b107d48f-5063-43ba-8820-7343342afa46"],
Cell[474537, 13625, 352, 9, 24, "Print",ExpressionUUID->"5e779624-0523-4702-ae75-2539ea527dea"],
Cell[474892, 13636, 359, 9, 24, "Print",ExpressionUUID->"61c0ae7c-e549-4b94-95b9-169e1f305f08"],
Cell[475254, 13647, 364, 9, 24, "Print",ExpressionUUID->"92ba5cb5-e825-4b25-818d-593920696196"],
Cell[475621, 13658, 524, 11, 24, "Print",ExpressionUUID->"e12fc74f-fadc-4c87-97bb-d3988439b51b"],
Cell[476148, 13671, 538, 12, 24, "Print",ExpressionUUID->"a0214705-b6a6-4601-be6d-cb12759decd2"],
Cell[476689, 13685, 534, 12, 24, "Print",ExpressionUUID->"996b7165-0579-4410-b786-4a4c288e8a1d"],
Cell[477226, 13699, 524, 11, 24, "Print",ExpressionUUID->"5564ea93-2344-4416-8d77-d6fdb9b2a29d"],
Cell[477753, 13712, 534, 12, 24, "Print",ExpressionUUID->"047818c5-5692-41cd-9ad4-94fb20149dce"],
Cell[478290, 13726, 370, 9, 24, "Print",ExpressionUUID->"aaea8ae0-5592-4005-8782-357e09f8c38c"],
Cell[478663, 13737, 376, 9, 24, "Print",ExpressionUUID->"85e3b5c8-3aec-43f0-acb3-77ac4eaaaadc"],
Cell[479042, 13748, 350, 9, 24, "Print",ExpressionUUID->"dd62973c-1d51-41e0-86ee-1ceebc402d48"],
Cell[479395, 13759, 350, 9, 24, "Print",ExpressionUUID->"9770694a-6062-49d7-8da4-dcf0010b64ec"],
Cell[479748, 13770, 360, 9, 24, "Print",ExpressionUUID->"ff14ca64-fade-40a2-bdf0-65367080e3f6"],
Cell[480111, 13781, 364, 9, 24, "Print",ExpressionUUID->"915970ae-595c-4f2e-afc1-e3a8327104cb"],
Cell[480478, 13792, 524, 11, 24, "Print",ExpressionUUID->"705f82da-bc19-409c-bfc7-c9a185800592"],
Cell[481005, 13805, 536, 12, 24, "Print",ExpressionUUID->"5313ea2c-03fe-448e-b26a-c004669cad79"],
Cell[481544, 13819, 534, 12, 24, "Print",ExpressionUUID->"09b5e3ff-5e18-4a98-8972-952919c44657"],
Cell[482081, 13833, 524, 11, 24, "Print",ExpressionUUID->"5f10d869-6087-4c4f-a3a0-768596419ba2"],
Cell[482608, 13846, 534, 12, 24, "Print",ExpressionUUID->"26681f4a-22c2-4a7e-a880-cec9de7a880f"],
Cell[483145, 13860, 368, 9, 24, "Print",ExpressionUUID->"40418468-a5de-4c79-9862-f604c90268ae"],
Cell[483516, 13871, 376, 9, 24, "Print",ExpressionUUID->"3f338686-9aa9-4371-a4ac-068771417c09"],
Cell[483895, 13882, 350, 9, 24, "Print",ExpressionUUID->"b0060956-a38b-4566-8569-489dadb28464"],
Cell[484248, 13893, 352, 9, 24, "Print",ExpressionUUID->"026f050e-a29c-4c1a-a383-3cac3f8fef95"],
Cell[484603, 13904, 362, 9, 24, "Print",ExpressionUUID->"5b5f6e54-5b8b-44c6-b4ab-5a4bf000142f"],
Cell[484968, 13915, 364, 9, 24, "Print",ExpressionUUID->"586d9a26-59f2-409d-bf74-ae0d7d390177"],
Cell[485335, 13926, 526, 11, 24, "Print",ExpressionUUID->"3575acb9-3fc9-4368-8831-22c684c0824b"],
Cell[485864, 13939, 538, 12, 24, "Print",ExpressionUUID->"272fbef3-6460-474c-9a76-900bd76af200"],
Cell[486405, 13953, 534, 12, 24, "Print",ExpressionUUID->"ae7f2eb8-b92b-41cd-9a1a-54cc33129c1a"],
Cell[486942, 13967, 524, 11, 24, "Print",ExpressionUUID->"907f20b6-c237-4c31-a67f-7e2f78136eaa"],
Cell[487469, 13980, 534, 12, 24, "Print",ExpressionUUID->"21c00b10-619b-4e30-86fd-957bf12d5c77"],
Cell[488006, 13994, 368, 9, 24, "Print",ExpressionUUID->"f29917e9-c858-4507-b5f2-aab0524170fc"],
Cell[488377, 14005, 376, 9, 24, "Print",ExpressionUUID->"53c1485c-9084-498e-8f2b-d1ab8acf029e"],
Cell[488756, 14016, 350, 9, 24, "Print",ExpressionUUID->"eecc0689-60f6-4ff1-9580-4530a73866c8"],
Cell[489109, 14027, 352, 9, 24, "Print",ExpressionUUID->"c6f5c7bf-1552-4654-858c-de039f974a05"],
Cell[489464, 14038, 360, 9, 24, "Print",ExpressionUUID->"2779c2ab-4bbb-4938-90a5-fa2682a56d7a"],
Cell[489827, 14049, 364, 9, 24, "Print",ExpressionUUID->"8d425469-888e-4d2e-b0a0-9c9c58679edf"],
Cell[490194, 14060, 526, 11, 24, "Print",ExpressionUUID->"47ca9ed4-a326-43f1-913b-9dd4f9aebac2"],
Cell[490723, 14073, 538, 12, 24, "Print",ExpressionUUID->"1e975da8-a522-4fce-bde2-3e380cd7de35"],
Cell[491264, 14087, 534, 12, 24, "Print",ExpressionUUID->"9c00a80a-692a-4a0e-b4ef-ec974c090949"],
Cell[491801, 14101, 524, 11, 24, "Print",ExpressionUUID->"f5bcc23a-846e-417b-8399-3bae0d37a75d"],
Cell[492328, 14114, 534, 12, 24, "Print",ExpressionUUID->"477058aa-197a-4cdc-8787-50f1a552f689"],
Cell[492865, 14128, 368, 9, 24, "Print",ExpressionUUID->"8ffa2a30-c562-4ef1-9284-5d8d599ad13d"],
Cell[493236, 14139, 376, 9, 24, "Print",ExpressionUUID->"982d1b3f-f8e2-4499-98eb-63eaaebf24f7"],
Cell[493615, 14150, 352, 9, 24, "Print",ExpressionUUID->"0b1173ad-2e26-4cbf-bddc-579957118772"],
Cell[493970, 14161, 352, 9, 24, "Print",ExpressionUUID->"9f57bdb4-46e3-4f89-8ae4-83f13190829e"],
Cell[494325, 14172, 358, 9, 24, "Print",ExpressionUUID->"16cbcb61-7984-4130-91af-b27ade6f73a6"],
Cell[494686, 14183, 364, 9, 24, "Print",ExpressionUUID->"6b23db4e-8bda-4ad1-87c2-10f96f211e52"],
Cell[495053, 14194, 526, 11, 24, "Print",ExpressionUUID->"6c54d31a-3a52-48a2-ab53-8de083fa1671"],
Cell[495582, 14207, 536, 12, 24, "Print",ExpressionUUID->"680f1fca-4f03-4557-b9a7-2b55c08788b5"],
Cell[496121, 14221, 534, 12, 24, "Print",ExpressionUUID->"036b8010-c451-4974-bb0f-5ee9903ecf70"],
Cell[496658, 14235, 524, 11, 24, "Print",ExpressionUUID->"7ae4d2a8-3b0e-4b48-bc8e-b3f5aa5cad40"],
Cell[497185, 14248, 534, 12, 24, "Print",ExpressionUUID->"dd2b573d-244d-4643-a4e4-e93c0dd97d53"],
Cell[497722, 14262, 368, 9, 24, "Print",ExpressionUUID->"3175eaf5-0f3b-4a0c-8cae-6d2ccaeb4e76"],
Cell[498093, 14273, 376, 9, 24, "Print",ExpressionUUID->"a5a28597-c0e5-44bd-973f-60959d79b9d8"],
Cell[498472, 14284, 350, 9, 24, "Print",ExpressionUUID->"62547833-0217-45c4-a82b-6bbecf4211da"],
Cell[498825, 14295, 350, 9, 24, "Print",ExpressionUUID->"1aa17849-58bf-43d8-9b9a-20989a56aea5"],
Cell[499178, 14306, 360, 9, 24, "Print",ExpressionUUID->"e0875617-8c46-47b2-9fec-cb197764fd62"],
Cell[499541, 14317, 364, 9, 24, "Print",ExpressionUUID->"306f67fc-558f-498c-b02f-3a279e38a905"],
Cell[499908, 14328, 526, 11, 24, "Print",ExpressionUUID->"34f207de-ef66-4822-b8be-6a8765d1693f"],
Cell[500437, 14341, 535, 12, 24, "Print",ExpressionUUID->"f2ffcd1a-9edb-4616-8301-68b1531d0c4c"],
Cell[500975, 14355, 534, 12, 24, "Print",ExpressionUUID->"87acf3d5-58ed-4ebe-b5d7-4f4a591cfc56"],
Cell[501512, 14369, 526, 11, 24, "Print",ExpressionUUID->"4590bbe6-8b91-4731-bb42-f26232505408"],
Cell[502041, 14382, 536, 12, 24, "Print",ExpressionUUID->"5f1dab81-a40b-40b0-8389-6f41c9d2f3e8"],
Cell[502580, 14396, 367, 9, 24, "Print",ExpressionUUID->"001c7259-3629-467a-91e8-d584e450cb71"],
Cell[502950, 14407, 378, 9, 24, "Print",ExpressionUUID->"d1ccd562-4beb-4f31-85ce-479274c1a965"],
Cell[503331, 14418, 350, 9, 24, "Print",ExpressionUUID->"0edfd185-800c-4a13-a42e-857ee6c0bcdb"],
Cell[503684, 14429, 350, 9, 24, "Print",ExpressionUUID->"cecd58d2-b4e9-4083-89c2-9afc80e9a54e"],
Cell[504037, 14440, 360, 9, 24, "Print",ExpressionUUID->"0e7f930c-db53-49c1-8879-33920b60f8f4"],
Cell[504400, 14451, 366, 9, 24, "Print",ExpressionUUID->"12bb60ae-bd94-414e-b8bc-e3c0b64ae60a"],
Cell[504769, 14462, 526, 11, 24, "Print",ExpressionUUID->"cf904d39-718b-4beb-88d0-62cfd86b8325"],
Cell[505298, 14475, 536, 12, 24, "Print",ExpressionUUID->"0fa0e552-0fb8-407f-b675-33ccbacf562a"],
Cell[505837, 14489, 536, 12, 24, "Print",ExpressionUUID->"cb7c667c-46be-4bf5-af58-db63d4fd3e16"],
Cell[506376, 14503, 524, 11, 24, "Print",ExpressionUUID->"4986e1a0-2309-4f5b-a922-b164b966f892"],
Cell[506903, 14516, 536, 12, 24, "Print",ExpressionUUID->"300491c4-390e-4f9a-adde-89db51317c90"],
Cell[507442, 14530, 368, 9, 24, "Print",ExpressionUUID->"d238b4e1-5858-40f5-ba49-0a48f517fe26"],
Cell[507813, 14541, 376, 9, 24, "Print",ExpressionUUID->"7cac8c53-06dd-4101-8913-825ff1a34c4b"],
Cell[508192, 14552, 352, 9, 24, "Print",ExpressionUUID->"d7fff6fd-460b-4bda-9415-8206941310df"],
Cell[508547, 14563, 352, 9, 24, "Print",ExpressionUUID->"356a3b5b-3508-4fed-8375-c34be84cc357"],
Cell[508902, 14574, 360, 9, 24, "Print",ExpressionUUID->"376e1cbf-218a-4523-a338-e79ef02c10f1"],
Cell[509265, 14585, 364, 9, 24, "Print",ExpressionUUID->"07c43dfa-5d09-4669-bea4-5224678f8763"],
Cell[509632, 14596, 526, 11, 24, "Print",ExpressionUUID->"ef38924e-a807-41b9-ab99-a3d543cfb464"],
Cell[510161, 14609, 538, 12, 24, "Print",ExpressionUUID->"06454bf0-2145-4d63-8d67-eec0b4f3d237"],
Cell[510702, 14623, 534, 12, 24, "Print",ExpressionUUID->"1148301c-c53f-4118-8ee6-fb24722be909"],
Cell[511239, 14637, 524, 11, 24, "Print",ExpressionUUID->"ecb331b5-e26e-49fd-b50c-ce6bd44fce31"],
Cell[511766, 14650, 534, 12, 24, "Print",ExpressionUUID->"91d026c8-9c1e-4c1d-8715-bb7959e3092f"],
Cell[512303, 14664, 368, 9, 24, "Print",ExpressionUUID->"62d6b3fe-95a6-439d-8071-49cd7cfff22b"],
Cell[512674, 14675, 376, 9, 24, "Print",ExpressionUUID->"f0b76755-3953-414a-863c-e544942972be"],
Cell[513053, 14686, 352, 9, 24, "Print",ExpressionUUID->"ea4098a7-ff0d-4a0f-8d63-c882319fb1c2"],
Cell[513408, 14697, 350, 9, 24, "Print",ExpressionUUID->"f1c0ec96-cb77-4881-814d-255d9222d567"],
Cell[513761, 14708, 360, 9, 24, "Print",ExpressionUUID->"4039e9ff-156b-481e-8477-1edf55f60fb1"],
Cell[514124, 14719, 364, 9, 24, "Print",ExpressionUUID->"2aa99751-d31a-42be-a02c-4ffabf336fd9"],
Cell[514491, 14730, 524, 11, 24, "Print",ExpressionUUID->"baef3254-0603-47a9-b783-4ba2b37fd0dc"],
Cell[515018, 14743, 536, 12, 24, "Print",ExpressionUUID->"65c7a310-16b0-48b5-8ef7-5e6cb559fb20"],
Cell[515557, 14757, 534, 12, 24, "Print",ExpressionUUID->"c6be96a8-06df-4efd-9087-30ec83c1eb9b"],
Cell[516094, 14771, 524, 11, 24, "Print",ExpressionUUID->"11b666d0-11ae-4380-a9f2-25b8c6777514"],
Cell[516621, 14784, 536, 12, 24, "Print",ExpressionUUID->"f26da6a3-3e81-4dd0-936a-700966681e2c"],
Cell[517160, 14798, 368, 9, 24, "Print",ExpressionUUID->"8fc598db-c099-4f0f-a341-533b7ae928f3"],
Cell[517531, 14809, 428, 10, 24, "Print",ExpressionUUID->"a3015aa4-c53f-4c00-880c-633a1709dcad"],
Cell[517962, 14821, 350, 9, 24, "Print",ExpressionUUID->"6c478beb-ffe3-41c2-bd20-0a4c48d4b7f9"],
Cell[518315, 14832, 350, 9, 24, "Print",ExpressionUUID->"84cd8ebf-3625-4d42-9ffc-d8970573d63b"],
Cell[518668, 14843, 360, 9, 24, "Print",ExpressionUUID->"1367a6ae-3cbd-4cfc-9568-722ffa980bd0"],
Cell[519031, 14854, 364, 9, 24, "Print",ExpressionUUID->"46907dd9-539b-4b07-8b5c-2b8df457cf3b"],
Cell[519398, 14865, 524, 11, 24, "Print",ExpressionUUID->"63c47743-4100-4103-9c29-49925fb773c3"],
Cell[519925, 14878, 535, 12, 24, "Print",ExpressionUUID->"0c3e72c7-6e22-4509-8989-8cedd744d651"],
Cell[520463, 14892, 534, 12, 24, "Print",ExpressionUUID->"ba2f1972-4afb-4110-8918-ba53ef6ae5a8"],
Cell[521000, 14906, 524, 11, 24, "Print",ExpressionUUID->"83554954-08a0-4c40-90ba-12163b29955f"],
Cell[521527, 14919, 534, 12, 24, "Print",ExpressionUUID->"ccfc3bff-42f2-427b-b758-2704567a6254"],
Cell[522064, 14933, 368, 9, 24, "Print",ExpressionUUID->"2c59faf9-aa99-4bc5-b8a2-78e891779440"],
Cell[522435, 14944, 436, 10, 24, "Print",ExpressionUUID->"ed6b4813-7868-4163-9fe2-8672bb3705c3"],
Cell[522874, 14956, 349, 9, 24, "Print",ExpressionUUID->"c813c0b4-9bbc-4e4c-ac84-964b02d69607"],
Cell[523226, 14967, 350, 9, 24, "Print",ExpressionUUID->"0b143da1-57e1-4ca7-9e79-f1e79aae44d4"],
Cell[523579, 14978, 360, 9, 24, "Print",ExpressionUUID->"3ccc2d83-c953-4fe0-acfa-39a5378424b9"],
Cell[523942, 14989, 364, 9, 24, "Print",ExpressionUUID->"972910c7-5274-46ad-bf9a-3e5dee1f42aa"],
Cell[524309, 15000, 526, 11, 24, "Print",ExpressionUUID->"686ce801-dad0-4878-aee3-37fcf32e7780"],
Cell[524838, 15013, 536, 12, 24, "Print",ExpressionUUID->"b53f2398-0b03-48dc-ad16-f2fc29689106"],
Cell[525377, 15027, 534, 12, 24, "Print",ExpressionUUID->"26af4de5-e282-4115-b22d-3c7ed262fb3b"],
Cell[525914, 15041, 524, 11, 24, "Print",ExpressionUUID->"51982bfb-6bf0-42df-80ea-993fba229838"],
Cell[526441, 15054, 536, 12, 24, "Print",ExpressionUUID->"4ab49c04-c0c0-4a95-a036-78cb8cd2a1db"],
Cell[526980, 15068, 368, 9, 24, "Print",ExpressionUUID->"9266c6fa-dfd1-417a-bece-dbac97a1430b"],
Cell[527351, 15079, 444, 10, 24, "Print",ExpressionUUID->"73f879da-6004-4f39-af37-9c4fd326d60e"],
Cell[527798, 15091, 352, 9, 24, "Print",ExpressionUUID->"962904ff-4feb-4547-983e-7427b70ff537"],
Cell[528153, 15102, 350, 9, 24, "Print",ExpressionUUID->"3076186e-4b33-4444-917d-e276202d7421"],
Cell[528506, 15113, 362, 9, 24, "Print",ExpressionUUID->"38362787-536b-4707-8d35-e3a3e7147f6a"],
Cell[528871, 15124, 364, 9, 24, "Print",ExpressionUUID->"8f80d9e4-72de-4f03-b5d5-0ea73f8df724"],
Cell[529238, 15135, 524, 11, 24, "Print",ExpressionUUID->"f89ba98d-698b-4e77-bbd1-9cad8d63f450"],
Cell[529765, 15148, 536, 12, 24, "Print",ExpressionUUID->"2d16d478-dde4-4215-9519-90b48b91657b"],
Cell[530304, 15162, 534, 12, 24, "Print",ExpressionUUID->"839df755-a90f-4b51-a8e4-4e528a5e71fa"],
Cell[530841, 15176, 524, 11, 24, "Print",ExpressionUUID->"8f11c904-471f-42ae-919b-4587a07eabff"],
Cell[531368, 15189, 534, 12, 24, "Print",ExpressionUUID->"2f0bfc44-22d3-45e4-b785-63c347ebeae3"],
Cell[531905, 15203, 368, 9, 24, "Print",ExpressionUUID->"084a9865-afb0-4db7-9b55-9700b2edf30d"],
Cell[532276, 15214, 404, 10, 24, "Print",ExpressionUUID->"ded3a7e2-dacd-467a-92e0-f4b18ec642db"],
Cell[532683, 15226, 350, 9, 24, "Print",ExpressionUUID->"99b82019-c19b-4a0a-842b-01f13c7f5625"],
Cell[533036, 15237, 350, 9, 24, "Print",ExpressionUUID->"e2fdd7b9-0d3e-42b1-8fad-29d917d83d51"],
Cell[533389, 15248, 362, 9, 24, "Print",ExpressionUUID->"19de4f0a-892d-4f79-a1d4-69a8122b47ee"],
Cell[533754, 15259, 364, 9, 24, "Print",ExpressionUUID->"84fd71dc-5eed-4740-9854-da32b5eaff5a"],
Cell[534121, 15270, 524, 11, 24, "Print",ExpressionUUID->"ccbe258e-c811-4ced-9bf3-bf891b1bb756"],
Cell[534648, 15283, 535, 12, 24, "Print",ExpressionUUID->"99d2c2ea-750d-409c-8b08-97dcc412f775"],
Cell[535186, 15297, 536, 12, 24, "Print",ExpressionUUID->"cbd74b36-b896-4c98-8ba9-15d0a2928a8c"],
Cell[535725, 15311, 524, 11, 24, "Print",ExpressionUUID->"b6c97f62-1bdb-439d-9a2d-2031da8ff4e1"],
Cell[536252, 15324, 534, 12, 24, "Print",ExpressionUUID->"1dc9500c-b3e9-468c-adae-01d73c3f78df"],
Cell[536789, 15338, 368, 9, 24, "Print",ExpressionUUID->"60c6872a-2cb6-4870-a25d-b3c6bd60e8ba"],
Cell[537160, 15349, 398, 10, 24, "Print",ExpressionUUID->"17708b9e-671f-47ef-941f-3fa45037fc53"],
Cell[537561, 15361, 349, 9, 24, "Print",ExpressionUUID->"d017497f-2c1f-4350-aad9-36b49274eb37"],
Cell[537913, 15372, 350, 9, 24, "Print",ExpressionUUID->"2a013624-a9e3-4205-a11e-96629d3adec0"],
Cell[538266, 15383, 360, 9, 24, "Print",ExpressionUUID->"6e2fc6b4-9040-4015-b51d-9968730eb379"],
Cell[538629, 15394, 363, 9, 24, "Print",ExpressionUUID->"461b5d1b-926b-4ef4-abb7-9265274e8e18"],
Cell[538995, 15405, 523, 11, 24, "Print",ExpressionUUID->"e10d3ef8-68da-4301-8ea2-6c9bd09f7f08"],
Cell[539521, 15418, 536, 12, 24, "Print",ExpressionUUID->"a7feb013-10b6-455c-9510-5cc2c2c70f13"],
Cell[540060, 15432, 534, 12, 24, "Print",ExpressionUUID->"93d9d49f-33c6-46d0-80f2-7c87817c6a4f"],
Cell[540597, 15446, 523, 11, 24, "Print",ExpressionUUID->"03228898-7652-4fee-8cae-5c1d0c50e70e"],
Cell[541123, 15459, 536, 12, 24, "Print",ExpressionUUID->"c15fcf2b-dd9c-4431-957c-9fa44f7be2f6"],
Cell[541662, 15473, 366, 9, 24, "Print",ExpressionUUID->"60ce9b21-4729-45be-8e8f-0658f6d87c91"],
Cell[542031, 15484, 394, 10, 24, "Print",ExpressionUUID->"5021097d-6ce7-4b43-a146-a9a08575fa98"],
Cell[542428, 15496, 352, 9, 24, "Print",ExpressionUUID->"9264f53a-9206-4d2c-aa2f-9ea540cd1935"],
Cell[542783, 15507, 350, 9, 24, "Print",ExpressionUUID->"f2468978-1b97-4de3-aa56-c278555fcc49"],
Cell[543136, 15518, 360, 9, 24, "Print",ExpressionUUID->"54d62a1e-6d28-4612-9ed1-2f981ebcd6f6"],
Cell[543499, 15529, 364, 9, 24, "Print",ExpressionUUID->"31f13255-6208-408a-9288-2acc4c4a7d82"],
Cell[543866, 15540, 524, 11, 24, "Print",ExpressionUUID->"d87f8e50-fae8-47ea-9bf3-e482d98c60f1"],
Cell[544393, 15553, 536, 12, 24, "Print",ExpressionUUID->"d83ac48f-472b-47c5-912a-d5e452b7df5e"],
Cell[544932, 15567, 534, 12, 24, "Print",ExpressionUUID->"f43dc1dc-6a09-4901-a6a1-84e19ece1e98"],
Cell[545469, 15581, 524, 11, 24, "Print",ExpressionUUID->"db52242b-621c-4959-9588-e6b53b62c785"],
Cell[545996, 15594, 534, 12, 24, "Print",ExpressionUUID->"3109e2ff-7df0-46fd-a970-fb5dae48abfe"],
Cell[546533, 15608, 367, 9, 24, "Print",ExpressionUUID->"510b51e3-c7ca-49c1-9030-8b00decb3ac9"],
Cell[546903, 15619, 406, 10, 24, "Print",ExpressionUUID->"bd6eb850-f902-4987-97f6-bee6872f04c8"],
Cell[547312, 15631, 350, 9, 24, "Print",ExpressionUUID->"9cdb0f9e-c376-408b-937d-e8a649ff078d"],
Cell[547665, 15642, 349, 9, 24, "Print",ExpressionUUID->"5021cb04-c9e2-4445-8349-5ce8ff5611f3"],
Cell[548017, 15653, 360, 9, 24, "Print",ExpressionUUID->"2abc1f53-a278-42c0-95e7-bb0d9eae14c8"],
Cell[548380, 15664, 363, 9, 24, "Print",ExpressionUUID->"b06460d8-2172-4fc7-81dd-7629bd6f1fdc"],
Cell[548746, 15675, 526, 11, 24, "Print",ExpressionUUID->"9f0d34f4-7a84-4a29-923b-ad3d05a6e8b4"],
Cell[549275, 15688, 536, 12, 24, "Print",ExpressionUUID->"796d0af0-0f17-4981-ae17-f5be0a4a934b"],
Cell[549814, 15702, 534, 12, 24, "Print",ExpressionUUID->"7d1b3137-dcd3-4b20-b340-724b02a1488c"],
Cell[550351, 15716, 524, 11, 24, "Print",ExpressionUUID->"e3df6ef4-1697-46e6-b3f0-94c2dfa487bf"],
Cell[550878, 15729, 534, 12, 24, "Print",ExpressionUUID->"ac3edf8c-08d8-4806-b48c-d29335d30625"],
Cell[551415, 15743, 368, 9, 24, "Print",ExpressionUUID->"d47a30a1-966c-4d4c-8469-3cb245316085"],
Cell[551786, 15754, 396, 10, 24, "Print",ExpressionUUID->"f9e3b486-bd2c-4370-a46f-ccb4fd0f8bc9"],
Cell[552185, 15766, 350, 9, 24, "Print",ExpressionUUID->"e405fabd-7b93-4366-900a-f7b2b4f7e334"],
Cell[552538, 15777, 350, 9, 24, "Print",ExpressionUUID->"1ce4da8f-199c-411b-88e8-f73a3e741f9c"],
Cell[552891, 15788, 360, 9, 24, "Print",ExpressionUUID->"4da956a4-0c68-48bd-b1ef-f58f8f1f3ee7"],
Cell[553254, 15799, 364, 9, 24, "Print",ExpressionUUID->"527fee89-4eb2-43b9-af80-67d9376d43ac"],
Cell[553621, 15810, 524, 11, 24, "Print",ExpressionUUID->"89e7258a-031c-477e-8fcc-98349e34c0e6"],
Cell[554148, 15823, 535, 12, 24, "Print",ExpressionUUID->"824cbdd3-14ad-4368-b768-1eef4bf8050d"],
Cell[554686, 15837, 536, 12, 24, "Print",ExpressionUUID->"9717e9ec-90e6-4c1b-afff-87cc4d8668ef"],
Cell[555225, 15851, 526, 11, 24, "Print",ExpressionUUID->"5541a668-63df-4834-8c0a-97f9d0200f9c"],
Cell[555754, 15864, 534, 12, 24, "Print",ExpressionUUID->"057ba2ff-082f-46f2-a376-4715633be0e3"],
Cell[556291, 15878, 368, 9, 24, "Print",ExpressionUUID->"a165ee3a-8b4a-43e8-9744-5f34bde51a96"],
Cell[556662, 15889, 400, 10, 24, "Print",ExpressionUUID->"0e8df2ef-a572-4b92-b1ed-a70d6597a4d9"],
Cell[557065, 15901, 350, 9, 24, "Print",ExpressionUUID->"190ced92-65a6-4127-87cb-b10d15a608c9"],
Cell[557418, 15912, 350, 9, 24, "Print",ExpressionUUID->"9cac9028-43d6-4e26-aa6f-323ca953a377"],
Cell[557771, 15923, 362, 9, 24, "Print",ExpressionUUID->"be1f3ecb-9395-4b1f-a8b5-0c34114620a2"],
Cell[558136, 15934, 366, 9, 24, "Print",ExpressionUUID->"5f435084-7e4f-4a51-aa45-5a97cddc4130"],
Cell[558505, 15945, 526, 11, 24, "Print",ExpressionUUID->"156d51b9-463a-4cb5-9d97-ea5e3ea30ccd"],
Cell[559034, 15958, 536, 12, 24, "Print",ExpressionUUID->"3f9113b8-06f1-4d85-a7b0-e56199092dd0"],
Cell[559573, 15972, 534, 12, 24, "Print",ExpressionUUID->"5f249a88-7af8-4d90-97fe-dfc604b6ccaa"],
Cell[560110, 15986, 524, 11, 24, "Print",ExpressionUUID->"580e5436-04c1-4ddc-b68d-047304be235c"],
Cell[560637, 15999, 534, 12, 24, "Print",ExpressionUUID->"9ef747a6-859e-497b-bd07-9849b8f6884b"],
Cell[561174, 16013, 368, 9, 24, "Print",ExpressionUUID->"7cb516ce-eb76-4aec-b1d7-a19cbce8bba5"],
Cell[561545, 16024, 387, 10, 24, "Print",ExpressionUUID->"49a6f1f7-af08-46ae-b916-d244ffcaa483"],
Cell[561935, 16036, 352, 9, 24, "Print",ExpressionUUID->"a714de16-8911-4052-99f1-fd28aa0ab372"],
Cell[562290, 16047, 352, 9, 24, "Print",ExpressionUUID->"65d52426-a7df-463a-9a77-427a9d31d1b7"],
Cell[562645, 16058, 360, 9, 24, "Print",ExpressionUUID->"7fee4d42-7863-4b63-a892-f2134b45fd10"],
Cell[563008, 16069, 364, 9, 24, "Print",ExpressionUUID->"c836407f-ed87-4d4a-b21a-010ec553a36a"],
Cell[563375, 16080, 524, 11, 24, "Print",ExpressionUUID->"c1d8fd25-0d00-4399-83ac-81905da89833"],
Cell[563902, 16093, 536, 12, 24, "Print",ExpressionUUID->"72bab27f-975a-48e5-ac33-435922ed3cec"],
Cell[564441, 16107, 533, 12, 24, "Print",ExpressionUUID->"4df5fd86-e59e-4ef0-ab92-18ed1e1513a3"],
Cell[564977, 16121, 526, 11, 24, "Print",ExpressionUUID->"bc8bbc54-09f1-4011-a2fc-cee0fa2d4012"],
Cell[565506, 16134, 536, 12, 24, "Print",ExpressionUUID->"5d3194df-f016-47b4-b8d2-af522dc9ef7e"],
Cell[566045, 16148, 370, 9, 24, "Print",ExpressionUUID->"eb0b194a-0a27-4ff5-9360-9529999ef2b5"],
Cell[566418, 16159, 420, 10, 24, "Print",ExpressionUUID->"13eb7ceb-df5f-4f64-8ced-bb08441e1d9d"],
Cell[566841, 16171, 352, 9, 24, "Print",ExpressionUUID->"c125b112-7b83-4c3b-abb3-e838c3bc5c7c"],
Cell[567196, 16182, 348, 9, 24, "Print",ExpressionUUID->"d4b9c88a-4eba-4d72-808c-090903fb3d4b"],
Cell[567547, 16193, 362, 9, 24, "Print",ExpressionUUID->"5e10dc7d-b326-427c-8d9b-1e6f0ecee00e"],
Cell[567912, 16204, 364, 9, 24, "Print",ExpressionUUID->"5c76f0b6-b412-4764-a40c-845cedbe7555"],
Cell[568279, 16215, 526, 11, 24, "Print",ExpressionUUID->"2ce63301-4c6d-498a-bfab-c7eb7e67cc18"],
Cell[568808, 16228, 535, 12, 24, "Print",ExpressionUUID->"3f7929c3-f81d-4b18-a7a4-abacc00def27"],
Cell[569346, 16242, 534, 12, 24, "Print",ExpressionUUID->"6c29f6e4-d625-42cb-b3c8-025f6e030fdc"],
Cell[569883, 16256, 526, 11, 24, "Print",ExpressionUUID->"11e3e7f3-6cb4-4789-9241-b2ecb616f387"],
Cell[570412, 16269, 534, 12, 24, "Print",ExpressionUUID->"0d006e2a-87c3-4ed2-80ad-8406e49daf83"],
Cell[570949, 16283, 368, 9, 24, "Print",ExpressionUUID->"a5ed25bb-5a1b-4d8e-a74d-98d65745be8f"],
Cell[571320, 16294, 418, 10, 24, "Print",ExpressionUUID->"56e236da-7c08-4ef0-9ded-4b50104e264d"],
Cell[571741, 16306, 352, 9, 24, "Print",ExpressionUUID->"7542da36-d19c-4ce6-a424-89fa201a6713"],
Cell[572096, 16317, 350, 9, 24, "Print",ExpressionUUID->"5c668777-80c7-4ca3-8f79-d05e7fee084b"],
Cell[572449, 16328, 362, 9, 24, "Print",ExpressionUUID->"85132f6f-ab6d-464f-857f-9f1d4135ef82"],
Cell[572814, 16339, 364, 9, 24, "Print",ExpressionUUID->"ac54c17c-7536-4e70-93e1-067d1136aba3"],
Cell[573181, 16350, 524, 11, 24, "Print",ExpressionUUID->"2f844ace-6582-48f3-b7cb-605523fc4cb5"],
Cell[573708, 16363, 536, 12, 24, "Print",ExpressionUUID->"b290bb35-bdd7-4e23-bef5-fcccba8d4262"],
Cell[574247, 16377, 534, 12, 24, "Print",ExpressionUUID->"5b4bf419-633e-4d5d-8e2f-a635a0e82563"],
Cell[574784, 16391, 524, 11, 24, "Print",ExpressionUUID->"15b9c147-34e7-4e6d-b39e-14263e64c3dd"],
Cell[575311, 16404, 534, 12, 24, "Print",ExpressionUUID->"66ffb593-8bce-4721-9abc-ac4dbf855d1d"],
Cell[575848, 16418, 370, 9, 24, "Print",ExpressionUUID->"e95095f0-b37a-48e2-a237-c5dead3a382d"],
Cell[576221, 16429, 410, 10, 24, "Print",ExpressionUUID->"7e3f0bd5-8d79-4de0-b5b9-6231f82eaca1"],
Cell[576634, 16441, 350, 9, 24, "Print",ExpressionUUID->"0c469893-6e8d-4204-a454-b694fd3b3961"],
Cell[576987, 16452, 350, 9, 24, "Print",ExpressionUUID->"cc793d4a-d062-42d3-904b-95b623c35798"],
Cell[577340, 16463, 362, 9, 24, "Print",ExpressionUUID->"bcd65d94-c950-48df-87c7-d12ff868ae87"],
Cell[577705, 16474, 366, 9, 24, "Print",ExpressionUUID->"7aaed8bd-0c67-4de3-b37e-bcddc697083f"],
Cell[578074, 16485, 526, 11, 24, "Print",ExpressionUUID->"b9a2bee5-b6fa-463f-a0d4-43e6d16d3ddc"],
Cell[578603, 16498, 536, 12, 24, "Print",ExpressionUUID->"ee9bba0b-7995-4fde-aee4-c86269cf6256"],
Cell[579142, 16512, 534, 12, 24, "Print",ExpressionUUID->"33407204-02de-45a1-893f-bfc52eeed2fc"],
Cell[579679, 16526, 524, 11, 24, "Print",ExpressionUUID->"39cf9d55-1a1e-4be5-980a-cde33b4e0d6e"],
Cell[580206, 16539, 534, 12, 24, "Print",ExpressionUUID->"82ae7fdc-a687-4afa-bc76-28c716c8ac73"],
Cell[580743, 16553, 368, 9, 24, "Print",ExpressionUUID->"f57ed000-f366-45d8-b88e-cc5a558c34da"],
Cell[581114, 16564, 420, 10, 24, "Print",ExpressionUUID->"0c1f1dd5-e7bc-4407-a7d6-1d623c662394"],
Cell[581537, 16576, 352, 9, 24, "Print",ExpressionUUID->"1a8efbc0-9e83-4971-9ba9-eecf1c998163"],
Cell[581892, 16587, 349, 9, 24, "Print",ExpressionUUID->"b78495a4-9b68-460e-be7e-d00fbb3c8c4b"],
Cell[582244, 16598, 360, 9, 24, "Print",ExpressionUUID->"724a9159-c88d-43eb-bf78-6a1f32a89f1f"],
Cell[582607, 16609, 364, 9, 24, "Print",ExpressionUUID->"00bd9e50-69fc-4032-af90-d2bd0e85718d"],
Cell[582974, 16620, 524, 11, 24, "Print",ExpressionUUID->"c4efd2a6-204f-4e7e-8e82-083579f86857"],
Cell[583501, 16633, 536, 12, 24, "Print",ExpressionUUID->"dab2d69d-f244-4dfb-8985-2b4264523bf3"],
Cell[584040, 16647, 534, 12, 24, "Print",ExpressionUUID->"154e809f-beb5-4c4a-92e9-7fe5d049a30b"],
Cell[584577, 16661, 524, 11, 24, "Print",ExpressionUUID->"1a1e2bba-7e42-4f6c-902b-c3146046fa56"],
Cell[585104, 16674, 534, 12, 24, "Print",ExpressionUUID->"c1a06529-34b3-428d-8858-e2211b3b02ed"],
Cell[585641, 16688, 368, 9, 24, "Print",ExpressionUUID->"d06f6c7e-b720-4aa1-9832-316b932b76c6"],
Cell[586012, 16699, 412, 10, 24, "Print",ExpressionUUID->"496fbf61-a1db-431b-8a50-0d25631c439b"],
Cell[586427, 16711, 350, 9, 24, "Print",ExpressionUUID->"6c7350a1-4f00-4177-b009-64de98bcf932"],
Cell[586780, 16722, 349, 9, 24, "Print",ExpressionUUID->"7c3fe5fd-7150-428c-9370-d3ffe4ed58b7"],
Cell[587132, 16733, 360, 9, 24, "Print",ExpressionUUID->"b886553e-e887-4be5-bcdc-d3f03dcd2f41"],
Cell[587495, 16744, 364, 9, 24, "Print",ExpressionUUID->"e716ca43-95fd-49a2-95db-81fce4347b4d"],
Cell[587862, 16755, 524, 11, 24, "Print",ExpressionUUID->"ae85cd91-e1d6-410c-ad19-89ed447ba8d9"],
Cell[588389, 16768, 538, 12, 24, "Print",ExpressionUUID->"90d5d4fe-b1fc-4382-bb0d-a677bc072aa2"],
Cell[588930, 16782, 534, 12, 24, "Print",ExpressionUUID->"38f1b9e9-5345-4714-948c-35fd5679e108"],
Cell[589467, 16796, 524, 11, 24, "Print",ExpressionUUID->"a5ce8fd3-b862-41bc-8486-3e1d55698e06"],
Cell[589994, 16809, 534, 12, 24, "Print",ExpressionUUID->"5f983733-6110-4de0-a965-bbe7cf1c69e4"],
Cell[590531, 16823, 368, 9, 24, "Print",ExpressionUUID->"14bb2d51-1847-4073-8689-bb33c4ed3a7a"],
Cell[590902, 16834, 405, 10, 24, "Print",ExpressionUUID->"5ee48e10-7718-4701-8e32-d0160057bc73"],
Cell[591310, 16846, 350, 9, 24, "Print",ExpressionUUID->"3020038d-e388-4e55-89ec-260e08e55c0e"],
Cell[591663, 16857, 352, 9, 24, "Print",ExpressionUUID->"25d511ff-a160-41d0-89dd-a702326c62f1"],
Cell[592018, 16868, 360, 9, 24, "Print",ExpressionUUID->"42375368-37f3-4e49-b2e6-b9805fae0ddd"],
Cell[592381, 16879, 364, 9, 24, "Print",ExpressionUUID->"1ca92ba1-a9a5-40b6-bc54-2a8c44794d0d"],
Cell[592748, 16890, 523, 11, 24, "Print",ExpressionUUID->"9d279bf5-6494-4b5e-bf22-9a2aa9bf82d8"],
Cell[593274, 16903, 538, 12, 24, "Print",ExpressionUUID->"a720335d-1136-4001-8542-2b0efba0bb50"],
Cell[593815, 16917, 536, 12, 24, "Print",ExpressionUUID->"3a66e3c2-688c-48ad-b492-ec435a9ed0b1"],
Cell[594354, 16931, 524, 11, 24, "Print",ExpressionUUID->"eb065c8e-c9c5-409b-915e-6c10db5b8917"],
Cell[594881, 16944, 534, 12, 24, "Print",ExpressionUUID->"34a3766a-d930-4bba-b24c-e983c5f618b8"],
Cell[595418, 16958, 368, 9, 24, "Print",ExpressionUUID->"42de0c01-6a3b-49ca-b0e6-932b271ad506"],
Cell[595789, 16969, 408, 10, 24, "Print",ExpressionUUID->"4fbea527-cd69-4b46-89c3-688f3365cf60"],
Cell[596200, 16981, 350, 9, 24, "Print",ExpressionUUID->"bce92840-5fdd-4fe7-bc43-8f9bd018a6dd"],
Cell[596553, 16992, 352, 9, 24, "Print",ExpressionUUID->"cda119c1-50bf-4f53-8606-555733e7e9b9"],
Cell[596908, 17003, 360, 9, 24, "Print",ExpressionUUID->"4ce561a9-1093-426b-b3c1-52ce4c6643e5"],
Cell[597271, 17014, 364, 9, 24, "Print",ExpressionUUID->"0052c4c2-f7f8-4660-86bb-3c9dad54bb9c"],
Cell[597638, 17025, 524, 11, 24, "Print",ExpressionUUID->"8c07ec33-5546-4633-9858-f933f6cdd898"],
Cell[598165, 17038, 538, 12, 24, "Print",ExpressionUUID->"20de47db-a98e-4683-9ba1-b846bf799339"],
Cell[598706, 17052, 536, 12, 24, "Print",ExpressionUUID->"7b767578-6217-4b2d-9515-34358e852218"],
Cell[599245, 17066, 524, 11, 24, "Print",ExpressionUUID->"80e82847-1511-4b56-b06e-7945f5d6b7c4"],
Cell[599772, 17079, 536, 12, 24, "Print",ExpressionUUID->"c22782b2-86e7-4a29-9c09-f28a28cfd5cb"],
Cell[600311, 17093, 370, 9, 24, "Print",ExpressionUUID->"8a5a853c-d26d-4ac2-8768-6c2aeb6fa083"],
Cell[600684, 17104, 387, 10, 24, "Print",ExpressionUUID->"5ad305ac-fb9d-483c-9525-e08a1bcd2719"],
Cell[601074, 17116, 352, 9, 24, "Print",ExpressionUUID->"3f6966cd-4c79-44ab-b1b5-07cee8cd3105"],
Cell[601429, 17127, 350, 9, 24, "Print",ExpressionUUID->"1822f8ad-6123-44a7-8260-7e888da8a2dc"],
Cell[601782, 17138, 360, 9, 24, "Print",ExpressionUUID->"4a6d4bb3-dd77-492d-b799-ceb6385e431e"],
Cell[602145, 17149, 363, 9, 24, "Print",ExpressionUUID->"0fe9c1a4-6474-4460-9353-1d0e61ac05d5"],
Cell[602511, 17160, 524, 11, 24, "Print",ExpressionUUID->"49ec317c-d226-46d2-8d83-1e397a9ad358"],
Cell[603038, 17173, 536, 12, 24, "Print",ExpressionUUID->"912bd336-0fda-4778-a866-9c42692db59b"],
Cell[603577, 17187, 536, 12, 24, "Print",ExpressionUUID->"7a125ed5-98a9-4322-8dfb-c11185a19873"],
Cell[604116, 17201, 524, 11, 24, "Print",ExpressionUUID->"9cf0b999-83ec-45f6-9689-48e1c8bcd283"],
Cell[604643, 17214, 534, 12, 24, "Print",ExpressionUUID->"16742a6b-59ce-464c-bc09-03af97985c2f"],
Cell[605180, 17228, 370, 9, 24, "Print",ExpressionUUID->"d644a3f7-dba2-4c86-ab91-68f3f1e1a801"],
Cell[605553, 17239, 387, 10, 24, "Print",ExpressionUUID->"ed82db16-0712-4e5c-ad86-bf5c93defc87"],
Cell[605943, 17251, 350, 9, 24, "Print",ExpressionUUID->"f63aa5bf-4a92-4f5b-bed1-f4fccd795a0f"],
Cell[606296, 17262, 352, 9, 24, "Print",ExpressionUUID->"8d86bd13-ca87-4641-9efa-951d989a6818"],
Cell[606651, 17273, 360, 9, 24, "Print",ExpressionUUID->"b6d60a1e-83b3-45a9-bee5-5b3546bde709"],
Cell[607014, 17284, 364, 9, 24, "Print",ExpressionUUID->"798f0b7c-cc23-4657-b9e7-b3580b1fbdf1"],
Cell[607381, 17295, 524, 11, 24, "Print",ExpressionUUID->"44f2e905-d8ae-4ea5-8b0d-92fc8adab585"],
Cell[607908, 17308, 538, 12, 24, "Print",ExpressionUUID->"a61f13d6-4fc9-4381-9ecb-4f4a11e83e74"],
Cell[608449, 17322, 536, 12, 24, "Print",ExpressionUUID->"9a81115f-377b-44f3-a30f-be48435d5c2f"],
Cell[608988, 17336, 524, 11, 24, "Print",ExpressionUUID->"fdecc38c-d644-4329-8d9c-a077acfcc139"],
Cell[609515, 17349, 536, 12, 24, "Print",ExpressionUUID->"86bb1d82-fd53-441b-badb-91a7aa4d1042"],
Cell[610054, 17363, 368, 9, 24, "Print",ExpressionUUID->"81fd692c-008a-4c12-af20-36d9d9bf7dfa"],
Cell[610425, 17374, 452, 10, 24, "Print",ExpressionUUID->"48af94c7-67d1-41ce-8b58-dd8a8ae2ead6"],
Cell[610880, 17386, 350, 9, 24, "Print",ExpressionUUID->"57bd2fe0-c7d5-49a7-9fd9-6bf6f64a689e"],
Cell[611233, 17397, 350, 9, 24, "Print",ExpressionUUID->"9051bbf7-086b-43c0-891a-2c32c12d3a0c"],
Cell[611586, 17408, 362, 9, 24, "Print",ExpressionUUID->"6969b230-00ca-4fc2-823d-63774bb4f115"],
Cell[611951, 17419, 364, 9, 24, "Print",ExpressionUUID->"cdab25d9-6af3-4426-854a-3756ffd2b3b4"],
Cell[612318, 17430, 524, 11, 24, "Print",ExpressionUUID->"b7820de1-71ec-461b-b9f8-73a9f3f9ab21"],
Cell[612845, 17443, 536, 12, 24, "Print",ExpressionUUID->"bc2e2802-91b6-4a4c-80d0-0628b4eabd2f"],
Cell[613384, 17457, 534, 12, 24, "Print",ExpressionUUID->"458c6ca0-eea7-4c1e-b782-1cc3b0b90f07"],
Cell[613921, 17471, 526, 11, 24, "Print",ExpressionUUID->"82bfad9a-08db-46b2-b87a-6f401031996a"],
Cell[614450, 17484, 534, 12, 24, "Print",ExpressionUUID->"7a941fa0-0653-4d7f-8ace-c894a5253d67"],
Cell[614987, 17498, 368, 9, 24, "Print",ExpressionUUID->"9528988b-104e-48ec-976f-6d2070abfb40"],
Cell[615358, 17509, 387, 10, 24, "Print",ExpressionUUID->"469f8015-c8bf-41db-a3cd-157e5d6b9159"],
Cell[615748, 17521, 350, 9, 24, "Print",ExpressionUUID->"feafced0-53a7-42d6-8f81-64c2d821fe21"],
Cell[616101, 17532, 352, 9, 24, "Print",ExpressionUUID->"ffa15388-d9a9-4685-8e5e-6bf775fd846b"],
Cell[616456, 17543, 359, 9, 24, "Print",ExpressionUUID->"cf6b1759-da3c-4cc6-8184-717d85a6b300"],
Cell[616818, 17554, 364, 9, 24, "Print",ExpressionUUID->"99346a4d-0aef-43ad-9097-63cea0424e42"],
Cell[617185, 17565, 524, 11, 24, "Print",ExpressionUUID->"aed56b60-8ea1-4007-91fd-b846f37d7177"],
Cell[617712, 17578, 536, 12, 24, "Print",ExpressionUUID->"c0ca5f3b-2c34-45fa-bdfe-e442e6a3fba5"],
Cell[618251, 17592, 534, 12, 24, "Print",ExpressionUUID->"8cee17d5-9dcf-462a-8acd-f4488b0b7130"],
Cell[618788, 17606, 526, 11, 24, "Print",ExpressionUUID->"c4c215d2-1202-4489-a951-4d912ff3c799"],
Cell[619317, 17619, 534, 12, 24, "Print",ExpressionUUID->"41236779-29c2-4f7f-8150-16c8e8938127"],
Cell[619854, 17633, 368, 9, 24, "Print",ExpressionUUID->"bb0e6f00-a26b-4db8-ad8e-73886e3b04bb"],
Cell[620225, 17644, 387, 10, 24, "Print",ExpressionUUID->"d5025a15-a4f4-49e3-8e6a-bc22c36640d5"],
Cell[620615, 17656, 350, 9, 24, "Print",ExpressionUUID->"ade16b60-e18c-4724-83b8-4a812436cee5"],
Cell[620968, 17667, 350, 9, 24, "Print",ExpressionUUID->"0163b20c-31c2-48e7-b338-13cc35b8203d"],
Cell[621321, 17678, 360, 9, 24, "Print",ExpressionUUID->"2581746a-a307-4856-83bb-cff5486b2fe4"],
Cell[621684, 17689, 366, 9, 24, "Print",ExpressionUUID->"731a6473-d9bf-471a-a7a0-499893585bf4"],
Cell[622053, 17700, 524, 11, 24, "Print",ExpressionUUID->"043da7fc-45b3-4fea-836e-7a72ecafd8ea"],
Cell[622580, 17713, 538, 12, 24, "Print",ExpressionUUID->"647c8f93-4920-411a-bde2-e4963cdbcfa3"],
Cell[623121, 17727, 534, 12, 24, "Print",ExpressionUUID->"9f6feff8-d3af-4b82-80b0-6d8add9e7a15"],
Cell[623658, 17741, 524, 11, 24, "Print",ExpressionUUID->"4f8391c5-3b40-4491-ac12-d1030f760b44"],
Cell[624185, 17754, 534, 12, 24, "Print",ExpressionUUID->"0c152b8b-5e45-43cd-89f1-786931a9c87d"],
Cell[624722, 17768, 370, 9, 24, "Print",ExpressionUUID->"27086a65-d814-4ecb-a582-92b1e9dadf34"],
Cell[625095, 17779, 386, 10, 24, "Print",ExpressionUUID->"2f132f97-a6f4-49ce-bc97-1f71d0e5d2a2"],
Cell[625484, 17791, 350, 9, 24, "Print",ExpressionUUID->"6007df29-e526-4ee7-82c1-d3933012a507"],
Cell[625837, 17802, 350, 9, 24, "Print",ExpressionUUID->"e9dbd29e-7c93-41e2-b01e-a63f31a863ac"],
Cell[626190, 17813, 362, 9, 24, "Print",ExpressionUUID->"d4a99421-6dd9-480c-ad66-fd4cf2097d22"],
Cell[626555, 17824, 364, 9, 24, "Print",ExpressionUUID->"3cdf3dc8-ff53-4d61-8be7-c5aa987c3c8f"],
Cell[626922, 17835, 526, 11, 24, "Print",ExpressionUUID->"5be4c50e-b515-4105-8593-cba367be0fa3"],
Cell[627451, 17848, 538, 12, 24, "Print",ExpressionUUID->"e3ce028e-a07f-4910-91b7-d3a627221d85"],
Cell[627992, 17862, 533, 12, 24, "Print",ExpressionUUID->"c71791ab-cdab-4d3e-afa5-cd185204ee6c"],
Cell[628528, 17876, 524, 11, 24, "Print",ExpressionUUID->"76e37a75-7dfe-49ce-954d-14b2c6ff16d2"],
Cell[629055, 17889, 534, 12, 24, "Print",ExpressionUUID->"8e8e5b83-0d1b-40ce-8031-3dd7e6e59899"],
Cell[629592, 17903, 368, 9, 24, "Print",ExpressionUUID->"f6e27386-cbf8-4d10-a60c-b4ee80886463"],
Cell[629963, 17914, 387, 10, 24, "Print",ExpressionUUID->"f4173989-1e32-4e97-8d00-830eac65c0bb"],
Cell[630353, 17926, 352, 9, 24, "Print",ExpressionUUID->"245dc1ed-3fdb-42a2-b76a-88c44c26b1ce"],
Cell[630708, 17937, 349, 9, 24, "Print",ExpressionUUID->"3cabb41b-c660-4bef-9a91-0556bb5eea78"],
Cell[631060, 17948, 362, 9, 24, "Print",ExpressionUUID->"8b753f08-0f42-4947-83a1-d29bae0b537b"],
Cell[631425, 17959, 364, 9, 24, "Print",ExpressionUUID->"aa1e47bc-5490-43fe-8f3e-c14c01b3a916"],
Cell[631792, 17970, 523, 11, 24, "Print",ExpressionUUID->"c4bcab39-8e95-4b02-9994-02c6f4348ae0"],
Cell[632318, 17983, 535, 12, 24, "Print",ExpressionUUID->"310b0e14-1222-469c-afb5-082e0f15820f"],
Cell[632856, 17997, 534, 12, 24, "Print",ExpressionUUID->"e9a3b7b8-19ca-4ae7-a53c-6e1f137c4d77"],
Cell[633393, 18011, 524, 11, 24, "Print",ExpressionUUID->"1c31e3cd-7079-4bb4-aadd-5f1b57deb0f8"],
Cell[633920, 18024, 536, 12, 24, "Print",ExpressionUUID->"919b0cff-684f-4784-991f-c0eafa7282a1"],
Cell[634459, 18038, 368, 9, 24, "Print",ExpressionUUID->"ab905b63-9865-4145-82f9-ba6e3e4feeab"],
Cell[634830, 18049, 411, 10, 24, "Print",ExpressionUUID->"95e3a3ff-08de-4b6c-a111-b6610ead61cb"],
Cell[635244, 18061, 350, 9, 24, "Print",ExpressionUUID->"6b564b3f-a934-4234-97fb-7621884b188e"],
Cell[635597, 18072, 352, 9, 24, "Print",ExpressionUUID->"46439eaa-6e34-43a1-a70d-868d847f1640"],
Cell[635952, 18083, 360, 9, 24, "Print",ExpressionUUID->"e57026a2-8929-41ee-8f6c-3ded49356d9a"],
Cell[636315, 18094, 364, 9, 24, "Print",ExpressionUUID->"5a8f1d21-b5c1-4759-a913-38eca7aa364d"],
Cell[636682, 18105, 524, 11, 24, "Print",ExpressionUUID->"6e35dffa-8c73-47ea-b167-96f9832b1bdd"],
Cell[637209, 18118, 536, 12, 24, "Print",ExpressionUUID->"44c9636a-6a79-4d78-9e71-e1fc9d72518c"],
Cell[637748, 18132, 536, 12, 24, "Print",ExpressionUUID->"12407a9c-cbdd-46d6-9bed-4c8f38d49fb1"],
Cell[638287, 18146, 524, 11, 24, "Print",ExpressionUUID->"42ebd32e-bbb6-46f5-9b4d-a986143f90a4"],
Cell[638814, 18159, 536, 12, 24, "Print",ExpressionUUID->"abe39f07-b367-46ae-bd04-b58095e646c5"],
Cell[639353, 18173, 368, 9, 24, "Print",ExpressionUUID->"56e0b3b8-e7f4-412d-9319-3dcaace96e33"],
Cell[639724, 18184, 412, 10, 24, "Print",ExpressionUUID->"d75784d1-6a4d-4dd5-b834-f6de05b2d715"],
Cell[640139, 18196, 352, 9, 24, "Print",ExpressionUUID->"30dcd6a4-4695-4f54-b59f-28b26ad618ab"],
Cell[640494, 18207, 350, 9, 24, "Print",ExpressionUUID->"215dbd0c-ef29-46df-8535-3f7c13d77cfe"],
Cell[640847, 18218, 360, 9, 24, "Print",ExpressionUUID->"1c2e9a4a-5ea6-4c57-901f-367a66642980"],
Cell[641210, 18229, 364, 9, 24, "Print",ExpressionUUID->"0da9b74d-257e-4d14-bddd-6010f629699f"],
Cell[641577, 18240, 524, 11, 24, "Print",ExpressionUUID->"a17acfa9-1f0f-44c6-97ab-082c3de225fd"],
Cell[642104, 18253, 538, 12, 24, "Print",ExpressionUUID->"777a1d87-dd73-42ed-a5e4-38da5efd6165"],
Cell[642645, 18267, 534, 12, 24, "Print",ExpressionUUID->"19361e27-d36e-442e-9e2a-cb226b4331fb"],
Cell[643182, 18281, 524, 11, 24, "Print",ExpressionUUID->"5c4acc4a-8900-4039-8528-860476030d49"],
Cell[643709, 18294, 534, 12, 24, "Print",ExpressionUUID->"3ce4bc54-9af3-4984-9aed-7b1cd32421fb"],
Cell[644246, 18308, 370, 9, 24, "Print",ExpressionUUID->"62ea6e66-2c02-49ce-a0c2-7c56253fd37c"],
Cell[644619, 18319, 389, 10, 24, "Print",ExpressionUUID->"e5afc769-1583-4afa-9dbb-00568cd9c002"],
Cell[645011, 18331, 350, 9, 24, "Print",ExpressionUUID->"2feb2213-bd21-457e-a484-2fa66999bd21"],
Cell[645364, 18342, 350, 9, 24, "Print",ExpressionUUID->"d2ee647f-a242-4ae1-a26b-cf8a65ff15ba"],
Cell[645717, 18353, 360, 9, 24, "Print",ExpressionUUID->"5a696970-73d6-472d-8211-ae180568b2a0"],
Cell[646080, 18364, 364, 9, 24, "Print",ExpressionUUID->"fdd6b5e9-e304-43d9-b9f1-5c254decd113"],
Cell[646447, 18375, 524, 11, 24, "Print",ExpressionUUID->"e9f99483-1599-4f47-bf27-69460798f638"],
Cell[646974, 18388, 536, 12, 24, "Print",ExpressionUUID->"55c0b5e6-8c07-4983-b9d4-40b25ee8f26e"],
Cell[647513, 18402, 534, 12, 24, "Print",ExpressionUUID->"00845af4-aa5d-4d07-8678-0b515b309d28"],
Cell[648050, 18416, 524, 11, 24, "Print",ExpressionUUID->"b5f6add8-2b96-47b4-97f1-803695f9180b"],
Cell[648577, 18429, 534, 12, 24, "Print",ExpressionUUID->"26dc75d6-5efe-438f-971c-87a7990371e7"],
Cell[649114, 18443, 368, 9, 24, "Print",ExpressionUUID->"703aff96-2804-43e8-a66e-19646dc1e447"],
Cell[649485, 18454, 389, 10, 24, "Print",ExpressionUUID->"b2192f81-0ea4-43d0-ac40-a81d5a452401"],
Cell[649877, 18466, 352, 9, 24, "Print",ExpressionUUID->"f37a8b48-025e-44a3-80dd-162b5253623c"],
Cell[650232, 18477, 350, 9, 24, "Print",ExpressionUUID->"941d0a1a-1261-4876-b51e-84aa0beb3bc4"],
Cell[650585, 18488, 360, 9, 24, "Print",ExpressionUUID->"cff7b693-517d-4e6a-a6ae-27a044913274"],
Cell[650948, 18499, 364, 9, 24, "Print",ExpressionUUID->"6fe1bdb2-a607-4ab6-9ba6-c6896eedafb5"],
Cell[651315, 18510, 524, 11, 24, "Print",ExpressionUUID->"2038857e-9572-41bf-bd3c-af92d19c49de"],
Cell[651842, 18523, 536, 12, 24, "Print",ExpressionUUID->"cc7fd701-9eac-4600-bf04-b18f85932b41"],
Cell[652381, 18537, 534, 12, 24, "Print",ExpressionUUID->"a6b4586b-dd70-466c-ab65-a4f90f9995d3"],
Cell[652918, 18551, 523, 11, 24, "Print",ExpressionUUID->"7d9775d9-5fac-4a9a-ba5a-e7d61f0f2cdb"],
Cell[653444, 18564, 534, 12, 24, "Print",ExpressionUUID->"f2b888a1-254e-4257-9c45-f76db95a244e"],
Cell[653981, 18578, 368, 9, 24, "Print",ExpressionUUID->"1e851cdf-07e2-48a1-954a-439dca021800"],
Cell[654352, 18589, 387, 10, 24, "Print",ExpressionUUID->"7a102755-f438-4e12-9750-a4c04b050936"],
Cell[654742, 18601, 352, 9, 24, "Print",ExpressionUUID->"ab7dc79b-74c0-4e08-bc58-4a5eb2cf0aa6"],
Cell[655097, 18612, 352, 9, 24, "Print",ExpressionUUID->"68a6e567-cebc-4175-8b3b-618003a6e895"],
Cell[655452, 18623, 360, 9, 24, "Print",ExpressionUUID->"6cab4117-a097-456f-9754-a2d5f9c9d286"],
Cell[655815, 18634, 364, 9, 24, "Print",ExpressionUUID->"505e5ab1-dbe8-4648-ae68-12bd71849387"],
Cell[656182, 18645, 524, 11, 24, "Print",ExpressionUUID->"078dc381-4454-4154-b6c4-1b2342e3ac5c"],
Cell[656709, 18658, 536, 12, 24, "Print",ExpressionUUID->"94542b77-4520-4863-8db3-bc366071f392"],
Cell[657248, 18672, 534, 12, 24, "Print",ExpressionUUID->"8ac7efa4-8a4b-4d94-94c9-d82ba5410680"],
Cell[657785, 18686, 524, 11, 24, "Print",ExpressionUUID->"7e60d4ca-e51a-4471-86d5-0956e3807c0a"],
Cell[658312, 18699, 534, 12, 24, "Print",ExpressionUUID->"00471eb9-9848-4715-acb5-60e676149c47"],
Cell[658849, 18713, 368, 9, 24, "Print",ExpressionUUID->"74adbf8a-88da-4be4-a344-83f8da5e7375"],
Cell[659220, 18724, 389, 10, 24, "Print",ExpressionUUID->"22d94de2-7b70-4572-9241-f48c23738761"],
Cell[659612, 18736, 350, 9, 24, "Print",ExpressionUUID->"b31dd1b8-e454-40a6-b4ef-2c9f5b7f3836"],
Cell[659965, 18747, 349, 9, 24, "Print",ExpressionUUID->"e928b32d-caa7-468c-b400-8be336259ec8"],
Cell[660317, 18758, 360, 9, 24, "Print",ExpressionUUID->"48ecd8f4-3b6b-405e-9dcd-4d4af8a5280d"],
Cell[660680, 18769, 364, 9, 24, "Print",ExpressionUUID->"0df1bc27-1aec-409d-a965-71df9ce2326b"],
Cell[661047, 18780, 524, 11, 24, "Print",ExpressionUUID->"00cc97f1-134b-4536-bdab-eb6f797550d9"],
Cell[661574, 18793, 536, 12, 24, "Print",ExpressionUUID->"268c63f7-a0e7-410f-9b24-f6bab43551a2"],
Cell[662113, 18807, 534, 12, 24, "Print",ExpressionUUID->"a9cb1348-a168-4a56-a951-ad1e93bb43bf"],
Cell[662650, 18821, 524, 11, 24, "Print",ExpressionUUID->"88bb90d8-e3ca-4b4d-ae9d-91a343a032d8"],
Cell[663177, 18834, 534, 12, 24, "Print",ExpressionUUID->"f8c111cb-3186-4bd3-ab35-45715610be11"],
Cell[663714, 18848, 367, 9, 24, "Print",ExpressionUUID->"d15179db-cb9f-419e-b047-764ac88ae5ed"],
Cell[664084, 18859, 387, 10, 24, "Print",ExpressionUUID->"766e4b83-9936-48d9-ad4c-0870fc0c2b17"],
Cell[664474, 18871, 350, 9, 24, "Print",ExpressionUUID->"c059f770-18e2-4633-99ad-e3f030f58e47"],
Cell[664827, 18882, 350, 9, 24, "Print",ExpressionUUID->"ab9778d7-41e0-4b48-b396-84e5f13e98c4"],
Cell[665180, 18893, 360, 9, 24, "Print",ExpressionUUID->"7f1dc74c-acb2-410d-b3d7-74df7eb68c3d"],
Cell[665543, 18904, 364, 9, 24, "Print",ExpressionUUID->"3b1747f2-91c0-409c-9237-94ea8d4b3887"],
Cell[665910, 18915, 524, 11, 24, "Print",ExpressionUUID->"bef3aaf9-8bc2-4586-914b-bcf8c9976ef9"],
Cell[666437, 18928, 538, 12, 24, "Print",ExpressionUUID->"428b121d-cbc2-49a5-b206-24ff5f201b1e"],
Cell[666978, 18942, 534, 12, 24, "Print",ExpressionUUID->"bd7c40ac-b7d6-4c50-ba95-5e5824e64c8d"],
Cell[667515, 18956, 524, 11, 24, "Print",ExpressionUUID->"d976be09-4323-480c-a4b0-1875aca5fe5f"],
Cell[668042, 18969, 534, 12, 24, "Print",ExpressionUUID->"0b09f208-29cf-4bee-bf93-699e2c7ee1d7"],
Cell[668579, 18983, 370, 9, 24, "Print",ExpressionUUID->"e9d29831-da6c-4f4f-95e7-2826b867ec4c"],
Cell[668952, 18994, 387, 10, 24, "Print",ExpressionUUID->"19fa6e32-e17f-4a77-ae12-961d87fd9524"],
Cell[669342, 19006, 350, 9, 24, "Print",ExpressionUUID->"a36b9841-eb9b-4660-90f0-594186b2266e"],
Cell[669695, 19017, 350, 9, 24, "Print",ExpressionUUID->"33ba10e3-b152-4e81-a059-47f3752c4d10"],
Cell[670048, 19028, 362, 9, 24, "Print",ExpressionUUID->"764a900f-5d23-4a8c-9c15-47219adf524e"],
Cell[670413, 19039, 364, 9, 24, "Print",ExpressionUUID->"9fdda33f-e43d-473b-9709-8fb4b0f67573"],
Cell[670780, 19050, 524, 11, 24, "Print",ExpressionUUID->"a3b41c5d-9123-4bea-8183-0460a739a5fa"],
Cell[671307, 19063, 535, 12, 24, "Print",ExpressionUUID->"916452db-60aa-4f0d-b4c4-95c9655815a3"],
Cell[671845, 19077, 536, 12, 24, "Print",ExpressionUUID->"69c20218-7ac5-4298-b47d-77846669469c"],
Cell[672384, 19091, 524, 11, 24, "Print",ExpressionUUID->"cc49bf7f-5ca5-40b8-a6ba-c3c34e9758e7"],
Cell[672911, 19104, 534, 12, 24, "Print",ExpressionUUID->"cbb34b4a-89ea-47e7-af3f-1ddf75533ec4"],
Cell[673448, 19118, 368, 9, 24, "Print",ExpressionUUID->"f08e6b15-e3fa-488c-a0cc-06d4b8e0f221"],
Cell[673819, 19129, 414, 10, 24, "Print",ExpressionUUID->"1c13a405-eb41-4631-ad44-4ca297ae465f"],
Cell[674236, 19141, 350, 9, 24, "Print",ExpressionUUID->"ad4c2a66-79a9-4c3b-84d8-6e9b61272d06"],
Cell[674589, 19152, 350, 9, 24, "Print",ExpressionUUID->"fc39530e-e830-48b5-9aaa-f54a0bbd35a4"],
Cell[674942, 19163, 360, 9, 24, "Print",ExpressionUUID->"28bedbeb-fb40-454e-9db0-f20cec6681cc"],
Cell[675305, 19174, 364, 9, 24, "Print",ExpressionUUID->"38ad129f-3d00-41d9-991b-acf9a86e59ca"],
Cell[675672, 19185, 526, 11, 24, "Print",ExpressionUUID->"4a12f0ba-2721-408d-92fa-001d93d4b128"],
Cell[676201, 19198, 536, 12, 24, "Print",ExpressionUUID->"a5c4f569-c47f-47c6-8e2a-65de2a4a4930"],
Cell[676740, 19212, 534, 12, 24, "Print",ExpressionUUID->"b68414ca-52d5-45f6-962e-c276f7b4a92e"],
Cell[677277, 19226, 524, 11, 24, "Print",ExpressionUUID->"35916964-303a-49d8-a4ec-1b94a2a764e8"],
Cell[677804, 19239, 534, 12, 24, "Print",ExpressionUUID->"8c44e2bd-3910-42dd-94d4-59480729d8a3"],
Cell[678341, 19253, 368, 9, 24, "Print",ExpressionUUID->"26b15f97-9c0a-4cd4-bf8b-cb77194e517e"],
Cell[678712, 19264, 389, 10, 24, "Print",ExpressionUUID->"16991a8d-31d6-4552-839f-fdb7a627ffa5"],
Cell[679104, 19276, 350, 9, 24, "Print",ExpressionUUID->"759cc1ce-01fb-4703-b73c-9e096dfab5c9"],
Cell[679457, 19287, 350, 9, 24, "Print",ExpressionUUID->"260a997c-3a20-4346-8877-23127bbccc11"],
Cell[679810, 19298, 362, 9, 24, "Print",ExpressionUUID->"e9eb6e51-61a6-4e35-94ca-d5921c0f64e6"],
Cell[680175, 19309, 364, 9, 24, "Print",ExpressionUUID->"c235ac88-8f62-4619-8205-240632363f2c"],
Cell[680542, 19320, 524, 11, 24, "Print",ExpressionUUID->"ce67b005-884e-4062-8346-ea8cc6652817"],
Cell[681069, 19333, 536, 12, 24, "Print",ExpressionUUID->"a41f116b-43f7-42c4-bc66-33501ef78591"],
Cell[681608, 19347, 533, 12, 24, "Print",ExpressionUUID->"f312716d-279f-47c3-9d67-5f94bf6f17c0"],
Cell[682144, 19361, 523, 11, 24, "Print",ExpressionUUID->"b69c1ccb-870e-4b12-97b3-c00c25ebdec3"],
Cell[682670, 19374, 536, 12, 24, "Print",ExpressionUUID->"b5638691-a4ef-4932-95c2-3261c7214572"],
Cell[683209, 19388, 370, 9, 24, "Print",ExpressionUUID->"e89bb508-df73-4a65-a54a-abc953001f3e"],
Cell[683582, 19399, 389, 10, 24, "Print",ExpressionUUID->"5b2b557c-29c8-4472-be9d-d993c32d0e68"],
Cell[683974, 19411, 350, 9, 24, "Print",ExpressionUUID->"d1429880-ab29-4ab6-9efc-524429462338"],
Cell[684327, 19422, 350, 9, 24, "Print",ExpressionUUID->"ed05e7d6-bb51-4ec4-a2f8-d858f3020427"],
Cell[684680, 19433, 360, 9, 24, "Print",ExpressionUUID->"511de702-98b3-473d-a52f-3e6557d9717e"],
Cell[685043, 19444, 364, 9, 24, "Print",ExpressionUUID->"39913ddd-6a36-4ee2-af5a-c29965ea5251"],
Cell[685410, 19455, 523, 11, 24, "Print",ExpressionUUID->"4c7d1629-7229-4fcf-9672-22165ada2bfa"],
Cell[685936, 19468, 536, 12, 24, "Print",ExpressionUUID->"99a66c9f-77d3-4315-a1a2-1f250a6dfea1"],
Cell[686475, 19482, 534, 12, 24, "Print",ExpressionUUID->"799715d4-8e22-41c6-a871-375db267fde8"],
Cell[687012, 19496, 524, 11, 24, "Print",ExpressionUUID->"39208020-cc08-45e6-92c6-29edcd91d394"],
Cell[687539, 19509, 536, 12, 24, "Print",ExpressionUUID->"cfbaeb24-b10d-4c37-ae55-9c1db8dda6ad"],
Cell[688078, 19523, 368, 9, 24, "Print",ExpressionUUID->"77a2c49e-4a06-48f8-a12d-fe6f86c86af0"],
Cell[688449, 19534, 387, 10, 24, "Print",ExpressionUUID->"3fdaf1e6-8ff3-45a1-a96d-1e868e1d3083"],
Cell[688839, 19546, 350, 9, 24, "Print",ExpressionUUID->"637968ff-15a0-4076-9f03-7ae756a43f45"],
Cell[689192, 19557, 350, 9, 24, "Print",ExpressionUUID->"281fcad1-78c9-4a34-82f4-19699d3c6c59"],
Cell[689545, 19568, 360, 9, 24, "Print",ExpressionUUID->"38048d1f-f64b-4021-8c7a-13e4472c3c85"],
Cell[689908, 19579, 364, 9, 24, "Print",ExpressionUUID->"f078be1a-9ec7-420a-bbe7-26c910f1b58a"],
Cell[690275, 19590, 526, 11, 24, "Print",ExpressionUUID->"d336b906-3172-4c6e-90ef-9eff07fa48f6"],
Cell[690804, 19603, 535, 12, 24, "Print",ExpressionUUID->"b47319bc-676d-45f8-b42c-ab4362cc1966"],
Cell[691342, 19617, 534, 12, 24, "Print",ExpressionUUID->"97fe14cf-276b-4b84-b14e-3db9b9f8e2f7"],
Cell[691879, 19631, 523, 11, 24, "Print",ExpressionUUID->"a40ec768-fca6-478a-b946-2d0c2a511af0"],
Cell[692405, 19644, 536, 12, 24, "Print",ExpressionUUID->"50f6da40-dab9-47ea-b32f-876689142276"],
Cell[692944, 19658, 368, 9, 24, "Print",ExpressionUUID->"b4078653-b5cb-46f6-8e1f-812e796f3005"],
Cell[693315, 19669, 387, 10, 24, "Print",ExpressionUUID->"f8fe0902-a8f0-42b6-91e4-d37ee4c1c5b1"],
Cell[693705, 19681, 350, 9, 24, "Print",ExpressionUUID->"1654e0f5-f8a6-4d2a-a41a-0638b260f42d"],
Cell[694058, 19692, 350, 9, 24, "Print",ExpressionUUID->"0775debf-8eca-41cf-90ae-c4d855d75e6d"],
Cell[694411, 19703, 360, 9, 24, "Print",ExpressionUUID->"e8435812-b740-4b90-8aad-a7a7856d3217"],
Cell[694774, 19714, 366, 9, 24, "Print",ExpressionUUID->"79793263-7f93-465a-8ac3-847aad671dc3"],
Cell[695143, 19725, 524, 11, 24, "Print",ExpressionUUID->"ea774c4c-f227-4a6a-ab69-12f728085ea7"],
Cell[695670, 19738, 535, 12, 24, "Print",ExpressionUUID->"22e10c6b-e1d2-4c95-8a83-2aee7995930c"],
Cell[696208, 19752, 534, 12, 24, "Print",ExpressionUUID->"49a42963-a3bb-4f70-9752-d39ded501f06"],
Cell[696745, 19766, 523, 11, 24, "Print",ExpressionUUID->"028ac416-ce40-45f0-983d-d0c3a4317904"],
Cell[697271, 19779, 534, 12, 24, "Print",ExpressionUUID->"4b63b765-bc7d-4570-b949-dbcb0d74aefc"],
Cell[697808, 19793, 366, 9, 24, "Print",ExpressionUUID->"d86d92f7-c759-49ef-bad0-b15afa6a516d"],
Cell[698177, 19804, 387, 10, 24, "Print",ExpressionUUID->"85cba44b-b037-458d-bae4-8ef0f7fb6907"],
Cell[698567, 19816, 352, 9, 24, "Print",ExpressionUUID->"5b2d39d6-cd14-44ac-8e5a-b8dd300c46e6"],
Cell[698922, 19827, 350, 9, 24, "Print",ExpressionUUID->"8bd48d93-b398-4d98-a2c8-7876381459fc"],
Cell[699275, 19838, 360, 9, 24, "Print",ExpressionUUID->"2bf40628-83f4-4eed-b379-a8d14e6262c4"],
Cell[699638, 19849, 364, 9, 24, "Print",ExpressionUUID->"6fc98df7-1e5f-4193-a358-1ef514f72c4c"],
Cell[700005, 19860, 524, 11, 24, "Print",ExpressionUUID->"39b6fb7c-efbf-4326-add0-f23fa9a332ad"],
Cell[700532, 19873, 536, 12, 24, "Print",ExpressionUUID->"7e4a9413-ba07-4a2a-b753-298c4f3b4d23"],
Cell[701071, 19887, 533, 12, 24, "Print",ExpressionUUID->"47472507-2b03-4490-ab68-7f82ab732fbe"],
Cell[701607, 19901, 524, 11, 24, "Print",ExpressionUUID->"1eae20b6-008d-4fb8-a490-4098656ad43f"],
Cell[702134, 19914, 534, 12, 24, "Print",ExpressionUUID->"de5e8293-26a8-4589-8ce8-58fa8e10593f"],
Cell[702671, 19928, 368, 9, 24, "Print",ExpressionUUID->"60da430f-5415-40c4-b05f-766942691446"],
Cell[703042, 19939, 387, 10, 24, "Print",ExpressionUUID->"974a1061-0c7a-4775-b66f-4cb0f89e03ad"],
Cell[703432, 19951, 349, 9, 24, "Print",ExpressionUUID->"c7b11516-c123-46fe-8275-d086a0cfd676"],
Cell[703784, 19962, 350, 9, 24, "Print",ExpressionUUID->"112e1f03-6601-4e01-9596-f91a2e60dea1"],
Cell[704137, 19973, 359, 9, 24, "Print",ExpressionUUID->"449c623f-0e74-425e-9d57-9c834fdf3e00"],
Cell[704499, 19984, 364, 9, 24, "Print",ExpressionUUID->"5877f09b-497c-4aeb-9130-b4ad954e4892"],
Cell[704866, 19995, 526, 11, 24, "Print",ExpressionUUID->"13d36ae1-d525-42cb-8b18-92f0820bbe2c"],
Cell[705395, 20008, 538, 12, 24, "Print",ExpressionUUID->"fe3bcbc9-2df1-4c4f-aa97-7c571f14e2b6"],
Cell[705936, 20022, 533, 12, 24, "Print",ExpressionUUID->"d48d42e4-0eaa-48c4-a5dd-e5cb63518442"],
Cell[706472, 20036, 524, 11, 24, "Print",ExpressionUUID->"85bf95ba-90a8-4454-9ec9-87f9c9cb6830"],
Cell[706999, 20049, 534, 12, 24, "Print",ExpressionUUID->"b7b2be23-07d0-43b1-b251-6052d4e3410d"],
Cell[707536, 20063, 368, 9, 24, "Print",ExpressionUUID->"06ecd63e-f5c8-42a6-8095-44191760ce9b"],
Cell[707907, 20074, 387, 10, 24, "Print",ExpressionUUID->"35041033-a0ba-4bd4-9110-6ce9bde78ca1"],
Cell[708297, 20086, 350, 9, 24, "Print",ExpressionUUID->"91ad3239-3dfb-450c-bebc-d827f0820e63"],
Cell[708650, 20097, 350, 9, 24, "Print",ExpressionUUID->"98ce1f50-9386-45b4-aaf4-480250fe5adc"],
Cell[709003, 20108, 360, 9, 24, "Print",ExpressionUUID->"bdd9d6b8-b4a4-4598-982d-bb8f3e3b4bf1"],
Cell[709366, 20119, 364, 9, 24, "Print",ExpressionUUID->"5101c081-fee7-4ed1-ac98-31169acdb012"],
Cell[709733, 20130, 526, 11, 24, "Print",ExpressionUUID->"86622360-e948-4a02-8ad7-ae34a3809030"],
Cell[710262, 20143, 536, 12, 24, "Print",ExpressionUUID->"aafc60fd-c4fd-4675-ad1c-173ed8f4f197"],
Cell[710801, 20157, 536, 12, 24, "Print",ExpressionUUID->"93d75944-bf53-43db-a05e-82d0edb45760"],
Cell[711340, 20171, 526, 11, 24, "Print",ExpressionUUID->"44818169-fd92-4638-bc13-b131346bc32f"],
Cell[711869, 20184, 533, 12, 24, "Print",ExpressionUUID->"9acfc522-b47f-4471-b5fc-c31db313befa"],
Cell[712405, 20198, 368, 9, 24, "Print",ExpressionUUID->"f681b43e-ce1c-4aad-8e78-38b0c420d49a"],
Cell[712776, 20209, 387, 10, 24, "Print",ExpressionUUID->"781bcb77-1572-4a84-9e79-52bb3fe38ae5"],
Cell[713166, 20221, 350, 9, 24, "Print",ExpressionUUID->"c95a0421-2b7b-4ad2-a107-e0c3bc93444e"],
Cell[713519, 20232, 350, 9, 24, "Print",ExpressionUUID->"c68d4fab-f2dd-451f-883b-f68b1c3cffeb"],
Cell[713872, 20243, 362, 9, 24, "Print",ExpressionUUID->"cc4ddef2-4c6b-437a-857e-7d64fce42251"],
Cell[714237, 20254, 366, 9, 24, "Print",ExpressionUUID->"ad9611d9-7f9d-4d9e-a600-fd65f066c7e7"],
Cell[714606, 20265, 526, 11, 24, "Print",ExpressionUUID->"87159d15-4ab4-426e-93ec-9f4ddd51a081"],
Cell[715135, 20278, 536, 12, 24, "Print",ExpressionUUID->"aa430cf9-3192-435c-9c3f-b2053f185e09"],
Cell[715674, 20292, 534, 12, 24, "Print",ExpressionUUID->"d5778655-0eac-4a1d-8915-ffc2a97ba78c"],
Cell[716211, 20306, 524, 11, 24, "Print",ExpressionUUID->"05610a40-6591-4f70-be3c-d688748d7cd1"],
Cell[716738, 20319, 536, 12, 24, "Print",ExpressionUUID->"e1ef173a-ef03-4314-a4cc-3f68e16da7f3"],
Cell[717277, 20333, 368, 9, 24, "Print",ExpressionUUID->"d6fc85af-197c-45c2-8c90-0c6a9c0ab471"],
Cell[717648, 20344, 386, 10, 24, "Print",ExpressionUUID->"68baad1c-619a-4da2-a99f-f1496d0b255d"],
Cell[718037, 20356, 350, 9, 24, "Print",ExpressionUUID->"252bcc2f-ef92-4a1e-96fd-afbbb50b311a"],
Cell[718390, 20367, 350, 9, 24, "Print",ExpressionUUID->"ab0b432d-2d19-4195-b83c-552553567f6c"],
Cell[718743, 20378, 360, 9, 24, "Print",ExpressionUUID->"328fb18a-789c-4379-8d1e-a6f32a92c5dc"],
Cell[719106, 20389, 364, 9, 24, "Print",ExpressionUUID->"27f73465-4905-471a-9a1e-0b78e553893b"],
Cell[719473, 20400, 524, 11, 24, "Print",ExpressionUUID->"8a90652b-6525-4050-856d-a65b6938e4c0"],
Cell[720000, 20413, 536, 12, 24, "Print",ExpressionUUID->"81971bac-41de-44bf-a306-cd0882289ad4"],
Cell[720539, 20427, 534, 12, 24, "Print",ExpressionUUID->"d6d0e9e5-439d-421e-8a7d-559f598c059b"],
Cell[721076, 20441, 526, 11, 24, "Print",ExpressionUUID->"23e1a66f-1880-48a4-b827-81a2a061603e"],
Cell[721605, 20454, 534, 12, 24, "Print",ExpressionUUID->"c80fa4fe-5a32-463e-9187-d8994e3bed3c"],
Cell[722142, 20468, 368, 9, 24, "Print",ExpressionUUID->"7ccf35f3-45f8-4708-8e42-22eb32af7459"],
Cell[722513, 20479, 387, 10, 24, "Print",ExpressionUUID->"a3bf47b6-78c1-4be8-8587-644f9c20c3f4"],
Cell[722903, 20491, 350, 9, 24, "Print",ExpressionUUID->"46cdd806-d6b0-4637-a9f5-287c56656f3b"],
Cell[723256, 20502, 350, 9, 24, "Print",ExpressionUUID->"d4d00da7-e845-4097-8b54-6bb853006369"],
Cell[723609, 20513, 360, 9, 24, "Print",ExpressionUUID->"ff675fdc-e56c-47ec-ae03-69be72e05ccc"],
Cell[723972, 20524, 366, 9, 24, "Print",ExpressionUUID->"9b3b42a0-007e-4d74-a843-a4f851c070c3"],
Cell[724341, 20535, 524, 11, 24, "Print",ExpressionUUID->"8155af98-d0f0-4497-9674-95a9721414fa"],
Cell[724868, 20548, 535, 12, 24, "Print",ExpressionUUID->"dcb14ac4-b325-4977-a150-e7882c073c71"],
Cell[725406, 20562, 534, 12, 24, "Print",ExpressionUUID->"aeaadb81-b109-44c2-a035-b5a69cc9ec52"],
Cell[725943, 20576, 526, 11, 24, "Print",ExpressionUUID->"e00fa4aa-6870-435e-8500-e35e107c335d"],
Cell[726472, 20589, 534, 12, 24, "Print",ExpressionUUID->"210952b6-62ac-4ef0-9039-59455e2a324a"],
Cell[727009, 20603, 368, 9, 24, "Print",ExpressionUUID->"63c4b4d2-c204-4172-8b6d-6fe87753a795"],
Cell[727380, 20614, 387, 10, 24, "Print",ExpressionUUID->"ee3d5e4e-2040-4c96-937b-ac28e14a6a85"],
Cell[727770, 20626, 350, 9, 24, "Print",ExpressionUUID->"499bba34-375d-4e12-85ad-b10d91ae7a85"],
Cell[728123, 20637, 352, 9, 24, "Print",ExpressionUUID->"c481075d-3e2e-40fd-9584-ddd78a12172b"],
Cell[728478, 20648, 362, 9, 24, "Print",ExpressionUUID->"1bcbb7f2-54f5-4ac5-be2e-a1085f958198"],
Cell[728843, 20659, 364, 9, 24, "Print",ExpressionUUID->"b0a0adfd-f854-41fa-a07f-3b7d8510fee0"],
Cell[729210, 20670, 524, 11, 24, "Print",ExpressionUUID->"69015c9a-ec57-438f-97d1-83558d693761"],
Cell[729737, 20683, 536, 12, 24, "Print",ExpressionUUID->"f2430e70-6c46-4862-afbf-89e635b1b5ba"],
Cell[730276, 20697, 534, 12, 24, "Print",ExpressionUUID->"4a8c316e-2cc1-4ed6-b9bd-3a2e2215bf4f"],
Cell[730813, 20711, 524, 11, 24, "Print",ExpressionUUID->"82720f83-cf0c-4947-9545-2d1889890dc8"],
Cell[731340, 20724, 534, 12, 24, "Print",ExpressionUUID->"aa2d12c1-1404-4712-8418-f38d8ce68f59"],
Cell[731877, 20738, 368, 9, 24, "Print",ExpressionUUID->"620785a4-52fa-4dc8-904c-af79da36c601"],
Cell[732248, 20749, 436, 10, 24, "Print",ExpressionUUID->"86176a1c-fc9b-4b3a-9064-d957eaf502f5"],
Cell[732687, 20761, 350, 9, 24, "Print",ExpressionUUID->"d3c2e3b0-e0a6-4165-93e7-09994814af0f"],
Cell[733040, 20772, 350, 9, 24, "Print",ExpressionUUID->"633830b1-a9f1-4d93-b8c8-ba65b1e9ae11"],
Cell[733393, 20783, 360, 9, 24, "Print",ExpressionUUID->"923b7a8b-46e7-4e4a-a338-4ca858222fe8"],
Cell[733756, 20794, 363, 9, 24, "Print",ExpressionUUID->"e40ad8e8-c23a-47f8-b7e3-7c50308fc19e"],
Cell[734122, 20805, 524, 11, 24, "Print",ExpressionUUID->"da23d74e-dc9c-4a10-b1c4-764cb12cfc98"],
Cell[734649, 20818, 536, 12, 24, "Print",ExpressionUUID->"c5da540a-5a0f-4b3b-ad00-6b53bb826d89"],
Cell[735188, 20832, 534, 12, 24, "Print",ExpressionUUID->"be2d3d00-c040-44c3-a5e0-63140a4cb0fb"],
Cell[735725, 20846, 524, 11, 24, "Print",ExpressionUUID->"c3a879fc-021f-4a2f-af37-c7cd8898f3d6"],
Cell[736252, 20859, 534, 12, 24, "Print",ExpressionUUID->"0c223b41-efa6-422c-9cbc-d691e6dfad47"],
Cell[736789, 20873, 368, 9, 24, "Print",ExpressionUUID->"08890745-fd1b-4931-9ee4-e213897a42e2"],
Cell[737160, 20884, 442, 10, 24, "Print",ExpressionUUID->"2f440f2e-1982-4d81-98ab-4bd0ce269784"],
Cell[737605, 20896, 352, 9, 24, "Print",ExpressionUUID->"8e9d37e3-06bc-4d48-b65c-756ba78f582e"],
Cell[737960, 20907, 350, 9, 24, "Print",ExpressionUUID->"c6501a05-ce61-49c0-8059-3393dc654d93"],
Cell[738313, 20918, 360, 9, 24, "Print",ExpressionUUID->"7826bab9-2ff5-4b1a-b3da-f1a0ec76795e"],
Cell[738676, 20929, 364, 9, 24, "Print",ExpressionUUID->"a1d80e08-77ad-4381-a669-36defe235e95"],
Cell[739043, 20940, 524, 11, 24, "Print",ExpressionUUID->"e72bc371-6fcc-4662-8f1f-6b4c439ca478"],
Cell[739570, 20953, 536, 12, 24, "Print",ExpressionUUID->"a8826971-c8bb-4d5a-abe6-6c30166fc0bd"],
Cell[740109, 20967, 536, 12, 24, "Print",ExpressionUUID->"8dc34edc-2374-46c8-a2da-b85021fd6e90"],
Cell[740648, 20981, 524, 11, 24, "Print",ExpressionUUID->"ff45bf08-6176-4e0e-ab0a-52cbbbbbe374"],
Cell[741175, 20994, 534, 12, 24, "Print",ExpressionUUID->"fa18e637-7c19-404a-af42-fbb85a8a7768"],
Cell[741712, 21008, 370, 9, 24, "Print",ExpressionUUID->"ce52f194-f67c-4b52-99a0-909322176e4d"],
Cell[742085, 21019, 450, 10, 24, "Print",ExpressionUUID->"6fdcfd01-11cd-4764-b857-81f7bcc83377"],
Cell[742538, 21031, 350, 9, 24, "Print",ExpressionUUID->"c21d5e7f-7eef-4431-b22e-f32dce93db7e"],
Cell[742891, 21042, 350, 9, 24, "Print",ExpressionUUID->"ce8dab0e-9014-4878-a862-93825ff82187"],
Cell[743244, 21053, 360, 9, 24, "Print",ExpressionUUID->"5771b2cd-f43f-414a-be0b-da114d4c4bb8"],
Cell[743607, 21064, 364, 9, 24, "Print",ExpressionUUID->"d3f9eb64-8a57-4e07-93f3-081ee46c7df6"],
Cell[743974, 21075, 524, 11, 24, "Print",ExpressionUUID->"2d665c21-0f09-4b11-8d68-4a1dadd9e5df"],
Cell[744501, 21088, 536, 12, 24, "Print",ExpressionUUID->"84139d67-8b7e-4458-afc2-fea0cdc2778d"],
Cell[745040, 21102, 534, 12, 24, "Print",ExpressionUUID->"21bbe291-9b20-4028-bf0a-5bdec02e0d91"],
Cell[745577, 21116, 523, 11, 24, "Print",ExpressionUUID->"74b40bf4-46e5-441b-aa2f-fe1c28cb7847"],
Cell[746103, 21129, 534, 12, 24, "Print",ExpressionUUID->"f2fdbecd-57c1-4224-9ff8-3b3fb31fe3d0"],
Cell[746640, 21143, 368, 9, 24, "Print",ExpressionUUID->"bc4ebfa4-4909-47ed-804e-ba08e026a5f3"],
Cell[747011, 21154, 398, 10, 24, "Print",ExpressionUUID->"718002cd-0a81-4dee-aecf-3531df5d3597"],
Cell[747412, 21166, 350, 9, 24, "Print",ExpressionUUID->"bb03b764-ebb3-4f71-8996-5c50a271bef1"],
Cell[747765, 21177, 350, 9, 24, "Print",ExpressionUUID->"9c0f8f95-0403-48cf-a9e5-3a842a95c389"],
Cell[748118, 21188, 360, 9, 24, "Print",ExpressionUUID->"e5eb65db-2be5-4873-b4af-1afefa2915a5"],
Cell[748481, 21199, 364, 9, 24, "Print",ExpressionUUID->"7b8b4b82-f3db-49db-9109-a4c48787721e"],
Cell[748848, 21210, 524, 11, 24, "Print",ExpressionUUID->"d48ffba4-0bdd-4e08-8edc-1871f5e489e7"],
Cell[749375, 21223, 536, 12, 24, "Print",ExpressionUUID->"2431b5d9-170a-477c-a1c8-ae1d08dbe885"],
Cell[749914, 21237, 536, 12, 24, "Print",ExpressionUUID->"c8436e48-d167-40ea-b066-dd82f654fa48"],
Cell[750453, 21251, 524, 11, 24, "Print",ExpressionUUID->"4d215391-cb11-485d-b53b-b969c2bf0ef7"],
Cell[750980, 21264, 534, 12, 24, "Print",ExpressionUUID->"b1bf3c5a-a2a6-4fbc-86a9-4bb5a2323945"],
Cell[751517, 21278, 370, 9, 24, "Print",ExpressionUUID->"460f3031-0e9e-432b-bf96-012833b0a7bd"],
Cell[751890, 21289, 402, 10, 24, "Print",ExpressionUUID->"d144fe47-a0f9-4ef5-a785-1e4412549ee1"],
Cell[752295, 21301, 350, 9, 24, "Print",ExpressionUUID->"51d29457-5ed3-45ef-81fb-9c867080485b"],
Cell[752648, 21312, 350, 9, 24, "Print",ExpressionUUID->"9bc1ce6e-ded5-4c71-a172-1f98d44a451e"],
Cell[753001, 21323, 360, 9, 24, "Print",ExpressionUUID->"4e64fcdd-0a9f-457e-96a8-15dda8015312"],
Cell[753364, 21334, 364, 9, 24, "Print",ExpressionUUID->"05eced32-dd6c-4205-950c-43695a9945a9"],
Cell[753731, 21345, 526, 11, 24, "Print",ExpressionUUID->"63010cac-87bf-4504-9834-ea5730a8176e"],
Cell[754260, 21358, 538, 12, 24, "Print",ExpressionUUID->"55fe33a1-c515-4311-a289-dac14e361067"],
Cell[754801, 21372, 533, 12, 24, "Print",ExpressionUUID->"428ec412-e621-4a86-bdab-119e76caeb87"],
Cell[755337, 21386, 524, 11, 24, "Print",ExpressionUUID->"679dc1f1-70f4-46f7-a3c7-1ebd6e0e64e3"],
Cell[755864, 21399, 534, 12, 24, "Print",ExpressionUUID->"8123fdc5-1da1-49fd-84c8-40f73978c428"],
Cell[756401, 21413, 368, 9, 24, "Print",ExpressionUUID->"3fab3c21-3c42-47b5-aa17-0e5a430f558e"],
Cell[756772, 21424, 380, 9, 24, "Print",ExpressionUUID->"cc8c6de0-59ca-4584-8bae-073cad1e9282"],
Cell[757155, 21435, 350, 9, 24, "Print",ExpressionUUID->"3ad72497-4287-47de-a466-f34937ed3c24"],
Cell[757508, 21446, 352, 9, 24, "Print",ExpressionUUID->"6b70562b-6bb4-4bd4-9538-7f4c59ef9cbd"],
Cell[757863, 21457, 362, 9, 24, "Print",ExpressionUUID->"8693a2a2-14d7-4c83-a40e-184a7967b482"],
Cell[758228, 21468, 364, 9, 24, "Print",ExpressionUUID->"f6bf1959-85a3-4a62-b25a-1bec91047fc6"],
Cell[758595, 21479, 524, 11, 24, "Print",ExpressionUUID->"7c00e5d3-1f74-4d12-b932-def911e3b2c5"],
Cell[759122, 21492, 536, 12, 24, "Print",ExpressionUUID->"9ad1add3-85ac-4ac9-9468-309144c5ce9a"],
Cell[759661, 21506, 534, 12, 24, "Print",ExpressionUUID->"a6470d6e-6ddd-480b-973e-2fc2fcca142a"],
Cell[760198, 21520, 524, 11, 24, "Print",ExpressionUUID->"6919c49b-9a89-4ff1-b5c3-05239b7d5b29"],
Cell[760725, 21533, 534, 12, 24, "Print",ExpressionUUID->"34951311-9cf0-40f8-84fc-9eb9890a1463"],
Cell[761262, 21547, 368, 9, 24, "Print",ExpressionUUID->"d312149e-07ce-4046-ba95-f7a8f81d90e1"],
Cell[761633, 21558, 379, 9, 24, "Print",ExpressionUUID->"c1d00faf-5eb6-4550-b691-68347e73ec9d"],
Cell[762015, 21569, 350, 9, 24, "Print",ExpressionUUID->"6d018dd0-431f-4e76-ac8d-874cc11552d5"],
Cell[762368, 21580, 350, 9, 24, "Print",ExpressionUUID->"5a5c738e-2785-4561-bf83-5f8a0ad43a30"],
Cell[762721, 21591, 360, 9, 24, "Print",ExpressionUUID->"a1d8f965-79c5-4f74-a13c-a619514376e9"],
Cell[763084, 21602, 364, 9, 24, "Print",ExpressionUUID->"065cf3dc-5c3a-4b07-8e14-5be338708f28"],
Cell[763451, 21613, 524, 11, 24, "Print",ExpressionUUID->"119ca0fe-7afd-40b3-bb7e-f1cf8de0972a"],
Cell[763978, 21626, 538, 12, 24, "Print",ExpressionUUID->"470d0365-5551-4e5a-a4e3-804b80f4c7e4"],
Cell[764519, 21640, 534, 12, 24, "Print",ExpressionUUID->"f371bee2-a3db-4258-ad79-7cbd8e3fe01e"],
Cell[765056, 21654, 524, 11, 24, "Print",ExpressionUUID->"8633ee75-eceb-4e2e-be5f-de44aa103073"],
Cell[765583, 21667, 534, 12, 24, "Print",ExpressionUUID->"43700818-f0a7-41d2-aef8-18607eb41c48"],
Cell[766120, 21681, 368, 9, 24, "Print",ExpressionUUID->"1e76b130-5d5b-42ee-aa41-2d5b1d59f85b"],
Cell[766491, 21692, 380, 9, 24, "Print",ExpressionUUID->"83d55935-993d-475e-9fb7-ae1b7606feb1"],
Cell[766874, 21703, 352, 9, 24, "Print",ExpressionUUID->"749e611d-3e5e-4d85-b72d-c54a0cf3257e"],
Cell[767229, 21714, 352, 9, 24, "Print",ExpressionUUID->"18e7120c-1fc1-4bd4-811f-e83941479830"],
Cell[767584, 21725, 362, 9, 24, "Print",ExpressionUUID->"03f4e0b1-89b5-4ed1-8e6c-2b5e38c7c614"],
Cell[767949, 21736, 364, 9, 24, "Print",ExpressionUUID->"580a15cc-ff34-4278-a454-33dbd1d097b5"],
Cell[768316, 21747, 526, 11, 24, "Print",ExpressionUUID->"375b56a5-c171-4394-91dc-325721765876"],
Cell[768845, 21760, 536, 12, 24, "Print",ExpressionUUID->"5f4f18ae-506b-422a-9133-43528eb54ae6"],
Cell[769384, 21774, 534, 12, 24, "Print",ExpressionUUID->"23ebf6b0-4265-45a7-b0d9-bbed8e5a80f7"],
Cell[769921, 21788, 526, 11, 24, "Print",ExpressionUUID->"65562cbc-1f29-4db4-b101-288f82fbec73"],
Cell[770450, 21801, 534, 12, 24, "Print",ExpressionUUID->"31206230-5166-44a6-9a61-85eded64bfe8"],
Cell[770987, 21815, 368, 9, 24, "Print",ExpressionUUID->"71f278c8-79ba-47d9-83ea-f8cb6f54326b"],
Cell[771358, 21826, 380, 9, 24, "Print",ExpressionUUID->"49c1a502-f5c0-45ef-af40-1a39aa09dc5c"],
Cell[771741, 21837, 350, 9, 24, "Print",ExpressionUUID->"21dfd499-4f6c-46e6-aeb2-7e3b517e8fcb"],
Cell[772094, 21848, 350, 9, 24, "Print",ExpressionUUID->"e2910b61-a669-48ab-b6c4-bd552e236fc7"],
Cell[772447, 21859, 364, 9, 24, "Print",ExpressionUUID->"d1ca0dad-c12a-4e99-a53e-6fdb0720e0f8"],
Cell[772814, 21870, 380, 9, 24, "Print",ExpressionUUID->"93accc89-58c9-4845-adb2-b2788d808872"],
Cell[773197, 21881, 352, 9, 24, "Print",ExpressionUUID->"ce1d06e6-4806-437a-ba36-dcd299a41a00"],
Cell[773552, 21892, 350, 9, 24, "Print",ExpressionUUID->"985e0bb5-5b52-45bc-8633-9914e80d26fe"],
Cell[773905, 21903, 366, 9, 24, "Print",ExpressionUUID->"96c5e61c-b13f-4376-8b1d-a68d78a13caa"],
Cell[774274, 21914, 380, 9, 24, "Print",ExpressionUUID->"0428ab11-dcc6-40c5-bd86-9c1541285a15"],
Cell[774657, 21925, 352, 9, 24, "Print",ExpressionUUID->"a5e33a94-4318-43ac-8f95-d6332e59c123"],
Cell[775012, 21936, 350, 9, 24, "Print",ExpressionUUID->"4cd12470-0589-4e5d-a874-c45d037c0e71"],
Cell[775365, 21947, 362, 9, 24, "Print",ExpressionUUID->"1e015110-406b-4271-a29d-e1f8b92937dd"],
Cell[775730, 21958, 364, 9, 24, "Print",ExpressionUUID->"7013e45a-95b8-4d1e-9f43-58cff89309de"],
Cell[776097, 21969, 524, 11, 24, "Print",ExpressionUUID->"d32bd064-7405-4435-8b6b-4af67cec1d84"],
Cell[776624, 21982, 536, 12, 24, "Print",ExpressionUUID->"36b8ef4d-8e54-4dd7-aa5d-39913fd8cff5"],
Cell[777163, 21996, 534, 12, 24, "Print",ExpressionUUID->"b67d20e1-7b80-4f8e-8539-943376248080"],
Cell[777700, 22010, 523, 11, 24, "Print",ExpressionUUID->"f17d778a-44d9-47d4-addf-27b5f5df78e3"],
Cell[778226, 22023, 536, 12, 24, "Print",ExpressionUUID->"dcf95c2d-57bd-4fcb-90fc-b0b6cb35e03e"],
Cell[778765, 22037, 368, 9, 24, "Print",ExpressionUUID->"f5d1c0a7-0e44-4541-9880-2ed8c557f0d6"],
Cell[779136, 22048, 380, 9, 24, "Print",ExpressionUUID->"f792e555-ed0e-40e0-a504-c8450ccc3559"],
Cell[779519, 22059, 350, 9, 24, "Print",ExpressionUUID->"d13e9ff2-60cd-4890-9263-b90170009678"],
Cell[779872, 22070, 350, 9, 24, "Print",ExpressionUUID->"abd03448-949d-432d-a56f-3ca94f04ad91"],
Cell[780225, 22081, 360, 9, 24, "Print",ExpressionUUID->"9959bbb6-abda-4ab6-9c1a-b946cd0ccf77"],
Cell[780588, 22092, 364, 9, 24, "Print",ExpressionUUID->"73f33646-84ce-48e5-ab7f-d35f2e926976"],
Cell[780955, 22103, 526, 11, 24, "Print",ExpressionUUID->"b8dc7dd1-1f87-4227-adbd-95551232b66c"],
Cell[781484, 22116, 536, 12, 24, "Print",ExpressionUUID->"d1411664-d2d2-4c90-b2b7-cf53f502d488"],
Cell[782023, 22130, 534, 12, 24, "Print",ExpressionUUID->"6ce792f7-607d-481a-a35e-646033027752"],
Cell[782560, 22144, 526, 11, 24, "Print",ExpressionUUID->"3e55c5e5-9623-462c-971a-aa162cabc114"],
Cell[783089, 22157, 536, 12, 24, "Print",ExpressionUUID->"57e73ffb-3b81-4d3f-b92d-503051f5a4b7"],
Cell[783628, 22171, 370, 9, 24, "Print",ExpressionUUID->"0ff7a324-5c01-4629-9067-6a7f9504862f"],
Cell[784001, 22182, 382, 9, 24, "Print",ExpressionUUID->"72ac7eb3-5e6e-46f0-9810-bda41bc928e1"],
Cell[784386, 22193, 350, 9, 24, "Print",ExpressionUUID->"a7cd7785-5397-4d04-8c1a-25d278962aef"],
Cell[784739, 22204, 350, 9, 24, "Print",ExpressionUUID->"b9d06ce9-12a4-408b-ad6a-45f9206309c3"],
Cell[785092, 22215, 362, 9, 24, "Print",ExpressionUUID->"155efae8-537b-4e32-bee0-3d279b0a8493"],
Cell[785457, 22226, 364, 9, 24, "Print",ExpressionUUID->"910fd06a-4ee7-4ae7-8b9a-0971828eb219"],
Cell[785824, 22237, 524, 11, 24, "Print",ExpressionUUID->"53c2fdc8-7474-4fb0-b79d-c9238150be1a"],
Cell[786351, 22250, 538, 12, 24, "Print",ExpressionUUID->"dfc45157-d20b-42a3-9d24-17cfded0e5b7"],
Cell[786892, 22264, 534, 12, 24, "Print",ExpressionUUID->"2dff74cb-572d-4405-9551-7de3632ee3d4"],
Cell[787429, 22278, 524, 11, 24, "Print",ExpressionUUID->"45915433-e165-4ff4-8ff2-e709482e562a"],
Cell[787956, 22291, 534, 12, 24, "Print",ExpressionUUID->"7926dbc3-6860-42e7-9333-fa5ec5764ccb"],
Cell[788493, 22305, 370, 9, 24, "Print",ExpressionUUID->"9aa5ea74-aaaa-4eb4-b8b3-74935afc7665"],
Cell[788866, 22316, 380, 9, 24, "Print",ExpressionUUID->"eb31b200-e5bc-4b10-918d-7e80a3a2ea70"],
Cell[789249, 22327, 350, 9, 24, "Print",ExpressionUUID->"589b4faa-6d92-49e4-b172-ff52af469d5f"],
Cell[789602, 22338, 350, 9, 24, "Print",ExpressionUUID->"918dc6e4-b010-4085-ab14-e2ce79234231"],
Cell[789955, 22349, 360, 9, 24, "Print",ExpressionUUID->"7505a596-0379-4adb-a5a7-cce2bd617600"],
Cell[790318, 22360, 364, 9, 24, "Print",ExpressionUUID->"796cb553-edbd-42c0-a8fa-5a3130ab344b"],
Cell[790685, 22371, 524, 11, 24, "Print",ExpressionUUID->"3576db1b-cd51-45df-99e9-6c2b5a1a186e"],
Cell[791212, 22384, 538, 12, 24, "Print",ExpressionUUID->"d8fa753d-f1b6-4430-97dc-324fab5319ec"],
Cell[791753, 22398, 536, 12, 24, "Print",ExpressionUUID->"6af08a70-b681-45c4-a369-0e6d9ff92bac"],
Cell[792292, 22412, 523, 11, 24, "Print",ExpressionUUID->"3cc396fa-4acb-4551-92ea-4853ea93ddc4"],
Cell[792818, 22425, 534, 12, 24, "Print",ExpressionUUID->"89eb18fc-7a0d-436e-ac5c-7d2af0f0192c"],
Cell[793355, 22439, 368, 9, 24, "Print",ExpressionUUID->"3a50c2f6-6ece-4b6d-88d9-4d697702676c"],
Cell[793726, 22450, 380, 9, 24, "Print",ExpressionUUID->"c943630b-ba77-4757-a557-aed0ad7edc07"],
Cell[794109, 22461, 350, 9, 24, "Print",ExpressionUUID->"d2b6a188-be43-4b61-8d35-8ca2887b0fc4"],
Cell[794462, 22472, 350, 9, 24, "Print",ExpressionUUID->"023c0aba-e629-496c-b6e1-045ae9506caa"],
Cell[794815, 22483, 362, 9, 24, "Print",ExpressionUUID->"80522b84-95c3-4344-90fe-7772646ff746"],
Cell[795180, 22494, 363, 9, 24, "Print",ExpressionUUID->"b3ff59af-381f-4992-b095-7af3059c4d48"],
Cell[795546, 22505, 524, 11, 24, "Print",ExpressionUUID->"c2837711-f5cc-41f4-93cb-1137315910d4"],
Cell[796073, 22518, 538, 12, 24, "Print",ExpressionUUID->"66bc4f27-4c04-484f-8494-84fb477087a8"],
Cell[796614, 22532, 533, 12, 24, "Print",ExpressionUUID->"e086eb32-4725-4076-a421-e541a1c79ca3"],
Cell[797150, 22546, 524, 11, 24, "Print",ExpressionUUID->"faca5caf-01bc-4f2d-8ad7-e7307a55a36a"],
Cell[797677, 22559, 536, 12, 24, "Print",ExpressionUUID->"321b4441-405a-4a06-b0eb-0580d148dd60"],
Cell[798216, 22573, 368, 9, 24, "Print",ExpressionUUID->"e9569878-17b7-42f6-94c5-23110a361c0f"],
Cell[798587, 22584, 380, 9, 24, "Print",ExpressionUUID->"4394d3ec-1461-40b7-8fff-7e47fd2ef7ad"],
Cell[798970, 22595, 350, 9, 24, "Print",ExpressionUUID->"1da2e110-b43f-43e2-8ade-d57bc2217c0b"],
Cell[799323, 22606, 350, 9, 24, "Print",ExpressionUUID->"493fecae-47ad-4409-a756-51f84dd6774a"],
Cell[799676, 22617, 360, 9, 24, "Print",ExpressionUUID->"2bb64cf4-288b-40d4-bb56-04bc68879b20"],
Cell[800039, 22628, 364, 9, 24, "Print",ExpressionUUID->"6e3e75d9-1981-465f-af48-1fe89cd3ab48"],
Cell[800406, 22639, 524, 11, 24, "Print",ExpressionUUID->"3034a1ad-1b17-4c8b-8965-2d7705efe0ae"],
Cell[800933, 22652, 536, 12, 24, "Print",ExpressionUUID->"2e397743-d4b2-454b-9803-7834398b8cb5"],
Cell[801472, 22666, 534, 12, 24, "Print",ExpressionUUID->"e0d5144c-8316-4752-a0f2-6815bcfdbd59"],
Cell[802009, 22680, 524, 11, 24, "Print",ExpressionUUID->"124db792-8316-40be-88be-e19c7a8eb6ee"],
Cell[802536, 22693, 536, 12, 24, "Print",ExpressionUUID->"61673fdd-bdc0-4109-8871-1195df785ca8"],
Cell[803075, 22707, 370, 9, 24, "Print",ExpressionUUID->"3f5bb9dc-a579-4361-992e-e6252719778c"],
Cell[803448, 22718, 382, 9, 24, "Print",ExpressionUUID->"2048f28f-7c50-4ab5-b209-214c7133a126"],
Cell[803833, 22729, 350, 9, 24, "Print",ExpressionUUID->"aaa39ec4-a76f-40e1-9787-40398fc00a40"],
Cell[804186, 22740, 350, 9, 24, "Print",ExpressionUUID->"7f496a89-82bb-481c-b382-7361bfb9ca94"],
Cell[804539, 22751, 360, 9, 24, "Print",ExpressionUUID->"3c9a92e0-fd91-43fa-bfeb-122bdae1f0b9"],
Cell[804902, 22762, 364, 9, 24, "Print",ExpressionUUID->"40e1193f-2b3b-401c-857d-39dc7cc0f927"],
Cell[805269, 22773, 524, 11, 24, "Print",ExpressionUUID->"febbdc95-1405-415f-98a8-2c2a3642d61c"],
Cell[805796, 22786, 536, 12, 24, "Print",ExpressionUUID->"59603731-29a4-4358-bc57-ffa7b695e970"],
Cell[806335, 22800, 534, 12, 24, "Print",ExpressionUUID->"8f4e3a97-0b78-4f85-acf4-0a0d9335aee0"],
Cell[806872, 22814, 524, 11, 24, "Print",ExpressionUUID->"c5d3ce29-b2a6-4ac0-985d-7b1902cf9d31"],
Cell[807399, 22827, 534, 12, 24, "Print",ExpressionUUID->"fa85e670-f186-438c-9cf4-948e37868d43"],
Cell[807936, 22841, 368, 9, 24, "Print",ExpressionUUID->"9064ae31-cc58-46ae-92ae-0d84663197cf"],
Cell[808307, 22852, 380, 9, 24, "Print",ExpressionUUID->"d9ed5940-49ee-44b4-8d65-e219aa69b1e5"],
Cell[808690, 22863, 350, 9, 24, "Print",ExpressionUUID->"e7612753-30ab-4760-9169-2f9f9cb914fa"],
Cell[809043, 22874, 350, 9, 24, "Print",ExpressionUUID->"65a6245c-c754-4cd8-9903-6d620956c936"],
Cell[809396, 22885, 362, 9, 24, "Print",ExpressionUUID->"fa31bfee-e6ee-41fe-b447-8365aa55c5fe"],
Cell[809761, 22896, 364, 9, 24, "Print",ExpressionUUID->"5a2ed7aa-6f57-4245-bb46-20722bb81e76"],
Cell[810128, 22907, 524, 11, 24, "Print",ExpressionUUID->"5754648f-f7c2-428e-9a3b-f604b519914c"],
Cell[810655, 22920, 538, 12, 24, "Print",ExpressionUUID->"1ecf4c1a-e71d-4661-ab57-37e0187ffe2f"],
Cell[811196, 22934, 534, 12, 24, "Print",ExpressionUUID->"ca071234-1cb5-469f-99b9-e04197b6a73c"],
Cell[811733, 22948, 524, 11, 24, "Print",ExpressionUUID->"c20ccb3a-670c-4ce4-990b-449c57aea3c2"],
Cell[812260, 22961, 536, 12, 24, "Print",ExpressionUUID->"491fe8d2-00af-433e-a806-6518396176d3"],
Cell[812799, 22975, 370, 9, 24, "Print",ExpressionUUID->"7ca54427-9377-46a4-b809-106112e49dfa"],
Cell[813172, 22986, 380, 9, 24, "Print",ExpressionUUID->"cc648baa-a5b8-4a78-8e78-36c40101c6a0"],
Cell[813555, 22997, 350, 9, 24, "Print",ExpressionUUID->"d1fbc793-a8ca-4b29-922a-952b3e780df8"],
Cell[813908, 23008, 350, 9, 24, "Print",ExpressionUUID->"c3013dfb-32c4-4087-8945-07ff3ad09a7a"],
Cell[814261, 23019, 360, 9, 24, "Print",ExpressionUUID->"bcdc08b2-bede-415e-b186-8b3c9ed99850"],
Cell[814624, 23030, 366, 9, 24, "Print",ExpressionUUID->"f23ba476-2f3a-4e81-9346-6ac64401bdef"],
Cell[814993, 23041, 524, 11, 24, "Print",ExpressionUUID->"e5f98148-e5a9-4f8c-91fb-641ddd750256"],
Cell[815520, 23054, 536, 12, 24, "Print",ExpressionUUID->"e12cddc9-c193-4d97-a517-51645ec505f4"],
Cell[816059, 23068, 534, 12, 24, "Print",ExpressionUUID->"47288549-0a10-42ca-8b98-77f803a1168f"],
Cell[816596, 23082, 524, 11, 24, "Print",ExpressionUUID->"ae1cc3a7-a86a-4aae-91aa-4c23e58b0384"],
Cell[817123, 23095, 534, 12, 24, "Print",ExpressionUUID->"7cc60a22-9df8-42fd-a8de-e22109da077f"],
Cell[817660, 23109, 368, 9, 24, "Print",ExpressionUUID->"26bd35b0-6dfc-47d2-b87b-f932f1e3ee5e"],
Cell[818031, 23120, 382, 9, 24, "Print",ExpressionUUID->"60a55f3c-9260-4993-aa49-87d587a9f961"],
Cell[818416, 23131, 350, 9, 24, "Print",ExpressionUUID->"f24084e3-49ae-426a-8b5e-25d58bf5d42b"],
Cell[818769, 23142, 350, 9, 24, "Print",ExpressionUUID->"2c31801d-4d7c-4655-966a-b7d33bf3c85c"],
Cell[819122, 23153, 360, 9, 24, "Print",ExpressionUUID->"c4d132d1-7822-4a37-9a1d-25d8791d6dfb"],
Cell[819485, 23164, 364, 9, 24, "Print",ExpressionUUID->"bab13e1c-f3b5-4229-b451-2f9faa85fe6c"],
Cell[819852, 23175, 524, 11, 24, "Print",ExpressionUUID->"993512c6-83dc-446c-9402-4bf98a426cf2"],
Cell[820379, 23188, 536, 12, 24, "Print",ExpressionUUID->"54ab88a1-b9a7-4405-8b8c-44ad0882f31a"],
Cell[820918, 23202, 536, 12, 24, "Print",ExpressionUUID->"44585be2-0502-4363-b609-4c46473ec175"],
Cell[821457, 23216, 526, 11, 24, "Print",ExpressionUUID->"34c73d22-a267-4a06-a48a-293e75a9553e"],
Cell[821986, 23229, 534, 12, 24, "Print",ExpressionUUID->"c21d6c3d-2430-401b-820b-3a0400615f8a"],
Cell[822523, 23243, 368, 9, 24, "Print",ExpressionUUID->"86d772a1-636e-482b-833e-3bace08e9d72"],
Cell[822894, 23254, 380, 9, 24, "Print",ExpressionUUID->"736e1b39-6030-4722-a9b6-86de5bc19af3"],
Cell[823277, 23265, 350, 9, 24, "Print",ExpressionUUID->"59bbc67c-3b51-4df0-b2c9-8ac7a0dd9f44"],
Cell[823630, 23276, 349, 9, 24, "Print",ExpressionUUID->"1c82892a-262e-4566-8046-ec201b4a53db"],
Cell[823982, 23287, 362, 9, 24, "Print",ExpressionUUID->"e03f9dca-af86-4efa-a06e-7d550fa4ba1c"],
Cell[824347, 23298, 363, 9, 24, "Print",ExpressionUUID->"ddc41765-b4bf-4a76-a4d9-3ff987abb2ce"],
Cell[824713, 23309, 523, 11, 24, "Print",ExpressionUUID->"dc6f056a-5c32-441c-910c-143151e06d19"],
Cell[825239, 23322, 538, 12, 24, "Print",ExpressionUUID->"58e768ee-8c44-4816-b497-5061c68df17f"],
Cell[825780, 23336, 534, 12, 24, "Print",ExpressionUUID->"e8f3b29e-d4c8-4679-8baa-dec6ae665403"],
Cell[826317, 23350, 524, 11, 24, "Print",ExpressionUUID->"77cc82b7-b801-416c-b3ec-1e3fea1cf1c7"],
Cell[826844, 23363, 533, 12, 24, "Print",ExpressionUUID->"fdb27c1e-a4e6-4bfb-ab26-b0c8d63f3223"],
Cell[827380, 23377, 368, 9, 24, "Print",ExpressionUUID->"91fd69bd-87fc-4a35-a88c-fc65aefc65c3"],
Cell[827751, 23388, 382, 9, 24, "Print",ExpressionUUID->"ca065135-a6dd-4dd6-baf7-6773743195e0"],
Cell[828136, 23399, 350, 9, 24, "Print",ExpressionUUID->"e4722b6c-3b1e-4250-8f88-d91dbf1382c1"],
Cell[828489, 23410, 349, 9, 24, "Print",ExpressionUUID->"38c7b55d-2698-4328-8aeb-45b37f6fc570"],
Cell[828841, 23421, 360, 9, 24, "Print",ExpressionUUID->"6bcf4b5c-5b0a-4e0e-8c82-e99bbd5f4fe9"],
Cell[829204, 23432, 364, 9, 24, "Print",ExpressionUUID->"5d2f3680-2e71-486f-a722-98d070ce1896"],
Cell[829571, 23443, 526, 11, 24, "Print",ExpressionUUID->"771aae08-341a-4232-bcf0-215174ec9500"],
Cell[830100, 23456, 536, 12, 24, "Print",ExpressionUUID->"89ae89d7-5222-444e-ae9f-5f076cf38b58"],
Cell[830639, 23470, 534, 12, 24, "Print",ExpressionUUID->"f1bf5e34-27b5-4e19-b4d3-e57742650c3b"],
Cell[831176, 23484, 524, 11, 24, "Print",ExpressionUUID->"b1770cd5-2c4b-4b09-80dd-021b8256947c"],
Cell[831703, 23497, 536, 12, 24, "Print",ExpressionUUID->"60fbd4d3-4b0d-4f4b-9f78-b77bb1f721c7"],
Cell[832242, 23511, 368, 9, 24, "Print",ExpressionUUID->"97c8a54a-8380-4a4c-8c5d-7a57a5a28fa8"],
Cell[832613, 23522, 380, 9, 24, "Print",ExpressionUUID->"0719923f-603a-4a6d-817f-b6527baef1a6"],
Cell[832996, 23533, 350, 9, 24, "Print",ExpressionUUID->"6ba99ab2-6e61-42ac-827e-c0c49364e7bf"],
Cell[833349, 23544, 350, 9, 24, "Print",ExpressionUUID->"9dd0a185-9b32-4e5f-84df-6bc206bf60a9"],
Cell[833702, 23555, 362, 9, 24, "Print",ExpressionUUID->"75001f2b-e10a-4206-84bd-0bb200027fd1"],
Cell[834067, 23566, 362, 9, 24, "Print",ExpressionUUID->"65394dd7-ca8b-4605-b7fe-7720ac01e0da"],
Cell[834432, 23577, 524, 11, 24, "Print",ExpressionUUID->"d20a662d-e77f-49c7-8fdc-413bd6062f95"],
Cell[834959, 23590, 538, 12, 24, "Print",ExpressionUUID->"a8e9888f-c324-47dc-8c30-5ab9b9f314f5"],
Cell[835500, 23604, 534, 12, 24, "Print",ExpressionUUID->"cb9e8839-4a5b-4603-82f0-e9ebdcbcf99f"],
Cell[836037, 23618, 526, 11, 24, "Print",ExpressionUUID->"9f9cc15c-c448-4d99-b101-1508b60db549"],
Cell[836566, 23631, 534, 12, 24, "Print",ExpressionUUID->"72479690-3170-4ae7-aeda-cac881545412"],
Cell[837103, 23645, 368, 9, 24, "Print",ExpressionUUID->"b4ade13b-5c31-494d-93e0-5a74aa151e15"],
Cell[837474, 23656, 404, 10, 24, "Print",ExpressionUUID->"4fe8c8fe-d37b-42d6-9dc9-9e06409f0e93"],
Cell[837881, 23668, 350, 9, 24, "Print",ExpressionUUID->"ec9945bc-2a9d-46df-b44f-21d252ae6753"],
Cell[838234, 23679, 349, 9, 24, "Print",ExpressionUUID->"1566cf9a-44f5-47bf-9f93-5aac17820ab1"],
Cell[838586, 23690, 360, 9, 24, "Print",ExpressionUUID->"125c349d-ce1c-4e04-af01-d11ac6824102"],
Cell[838949, 23701, 364, 9, 24, "Print",ExpressionUUID->"c1ee45fd-ec49-4d3b-ab0f-c990c35f8424"],
Cell[839316, 23712, 524, 11, 24, "Print",ExpressionUUID->"040ecd72-76a4-462e-b3c5-0a8ca9d82663"],
Cell[839843, 23725, 536, 12, 24, "Print",ExpressionUUID->"fe7139f5-a172-4c46-9b98-37db9db7e803"],
Cell[840382, 23739, 534, 12, 24, "Print",ExpressionUUID->"8b3c49cb-bcc3-4306-b573-998b27fdcff3"],
Cell[840919, 23753, 524, 11, 24, "Print",ExpressionUUID->"b04d1a40-7ec3-4397-803c-05e3a97a445b"],
Cell[841446, 23766, 534, 12, 24, "Print",ExpressionUUID->"54e4ae40-fd29-4d8a-93f5-53eeeff5012a"],
Cell[841983, 23780, 368, 9, 24, "Print",ExpressionUUID->"6d847572-0c91-4ff1-8928-e64e8cbaae93"],
Cell[842354, 23791, 404, 10, 24, "Print",ExpressionUUID->"3fd01582-840f-4eae-9ce3-e9f4f59b0463"],
Cell[842761, 23803, 352, 9, 24, "Print",ExpressionUUID->"e444219b-554f-4f25-9524-1860c4964a86"],
Cell[843116, 23814, 350, 9, 24, "Print",ExpressionUUID->"bb92253d-df9e-41b0-bd83-8833bef06462"],
Cell[843469, 23825, 360, 9, 24, "Print",ExpressionUUID->"35a78c81-dd5c-4f6c-a9f8-2808d52b6edc"],
Cell[843832, 23836, 364, 9, 24, "Print",ExpressionUUID->"452a4124-cc32-4f93-9fd7-baff3bd8ec9e"],
Cell[844199, 23847, 524, 11, 24, "Print",ExpressionUUID->"9450d2f0-f581-486e-a37a-d48881c8f646"],
Cell[844726, 23860, 538, 12, 24, "Print",ExpressionUUID->"1e958a41-1c40-4acc-8067-b9f96bcbfbf7"],
Cell[845267, 23874, 534, 12, 24, "Print",ExpressionUUID->"a568faba-ac77-4c85-b053-76feafee33ec"],
Cell[845804, 23888, 524, 11, 24, "Print",ExpressionUUID->"d6dd1df6-a6db-4055-be6a-c807574d404f"],
Cell[846331, 23901, 534, 12, 24, "Print",ExpressionUUID->"08e6fa33-9d30-4304-9e05-121c9069d069"],
Cell[846868, 23915, 368, 9, 24, "Print",ExpressionUUID->"5ced5c45-7f11-4fcc-a64e-a8f15b2f984b"],
Cell[847239, 23926, 406, 10, 24, "Print",ExpressionUUID->"2557c1db-3808-4ae5-b590-9200825c66cb"],
Cell[847648, 23938, 350, 9, 24, "Print",ExpressionUUID->"d565a389-6d60-41e9-8139-8f9d1be6c939"],
Cell[848001, 23949, 350, 9, 24, "Print",ExpressionUUID->"d8845c8a-af2d-4af4-b01f-43ef1e365de3"],
Cell[848354, 23960, 360, 9, 24, "Print",ExpressionUUID->"b041e938-6926-4f1e-9bae-9eae5609c44b"],
Cell[848717, 23971, 366, 9, 24, "Print",ExpressionUUID->"edaad52a-608f-4063-9f61-92dee1d942cc"],
Cell[849086, 23982, 524, 11, 24, "Print",ExpressionUUID->"d0a3a2e5-f9b3-410b-8b94-cf70bfab6ac4"],
Cell[849613, 23995, 536, 12, 24, "Print",ExpressionUUID->"d8c581ee-b382-4d99-b158-bebe104ffa9b"],
Cell[850152, 24009, 536, 12, 24, "Print",ExpressionUUID->"f5366072-7d51-431a-b301-635e8907cbbd"],
Cell[850691, 24023, 523, 11, 24, "Print",ExpressionUUID->"7cacb2f1-2c38-4cf7-9573-fbc19a331188"],
Cell[851217, 24036, 534, 12, 24, "Print",ExpressionUUID->"be0f27c4-800b-457a-af31-18222bba4218"],
Cell[851754, 24050, 367, 9, 24, "Print",ExpressionUUID->"b210bb70-dc93-49c6-ab7e-247876f53c03"],
Cell[852124, 24061, 376, 9, 24, "Print",ExpressionUUID->"e3d61bf8-3027-4014-b2aa-193d4519f9f7"],
Cell[852503, 24072, 349, 9, 24, "Print",ExpressionUUID->"6c6daf3f-de4d-4361-ab12-65101804d263"],
Cell[852855, 24083, 352, 9, 24, "Print",ExpressionUUID->"1b30ec86-329d-4f40-8a82-48ff2647827a"],
Cell[853210, 24094, 360, 9, 24, "Print",ExpressionUUID->"ff051ea8-827a-43ae-982c-0253b7493813"],
Cell[853573, 24105, 364, 9, 24, "Print",ExpressionUUID->"fa0f36e0-bd36-4b88-94f0-3971b5f5eceb"],
Cell[853940, 24116, 524, 11, 24, "Print",ExpressionUUID->"7890d7bf-488e-4eee-93e7-8b98f07089d4"],
Cell[854467, 24129, 536, 12, 24, "Print",ExpressionUUID->"e9bd37c8-75d5-4af0-8aae-59a5f4289642"],
Cell[855006, 24143, 534, 12, 24, "Print",ExpressionUUID->"5a158d69-daaa-4c2e-9460-c0e8ec4d0292"],
Cell[855543, 24157, 524, 11, 24, "Print",ExpressionUUID->"3ec0dbf4-8649-48b3-870e-0c7661644ea6"],
Cell[856070, 24170, 536, 12, 24, "Print",ExpressionUUID->"0f2f3c3d-d714-4b5c-b0c7-58ee520fda3a"],
Cell[856609, 24184, 370, 9, 24, "Print",ExpressionUUID->"ab3960f5-c08a-4714-80fd-2e37d7041401"],
Cell[856982, 24195, 378, 9, 24, "Print",ExpressionUUID->"25b8d354-378c-40c2-aece-ac16cb747032"],
Cell[857363, 24206, 350, 9, 24, "Print",ExpressionUUID->"a403e412-6638-49b4-8bd8-d146e78440cf"],
Cell[857716, 24217, 352, 9, 24, "Print",ExpressionUUID->"7172cee9-3e08-48a4-b7d0-94d07abd8ae0"],
Cell[858071, 24228, 359, 9, 24, "Print",ExpressionUUID->"8a4ae953-96c1-49be-8249-3422646c8197"],
Cell[858433, 24239, 366, 9, 24, "Print",ExpressionUUID->"4dbcd1d9-3770-4e35-b147-730b19fecae4"],
Cell[858802, 24250, 526, 11, 24, "Print",ExpressionUUID->"72c948ec-2966-4487-9d1b-3e6d035e088c"],
Cell[859331, 24263, 536, 12, 24, "Print",ExpressionUUID->"56173482-a2a5-4ff1-b214-e5421b0656ec"],
Cell[859870, 24277, 534, 12, 24, "Print",ExpressionUUID->"81963513-6472-47a7-82a4-0d7e3b6b81fe"],
Cell[860407, 24291, 526, 11, 24, "Print",ExpressionUUID->"51c45308-6cf9-478c-96fc-8dc844b9f96e"],
Cell[860936, 24304, 534, 12, 24, "Print",ExpressionUUID->"6708a4d6-d1d3-43e5-8bf4-764eac95136b"],
Cell[861473, 24318, 368, 9, 24, "Print",ExpressionUUID->"f31df282-4e2b-4fbd-81a9-ed95d4c46d74"],
Cell[861844, 24329, 376, 9, 24, "Print",ExpressionUUID->"513c7edd-a11c-42fc-bb4f-c0495a282254"],
Cell[862223, 24340, 350, 9, 24, "Print",ExpressionUUID->"220d9962-6b42-4e33-a1d6-6aca8ee6c1e5"],
Cell[862576, 24351, 350, 9, 24, "Print",ExpressionUUID->"1acf072b-c914-47e3-b8ac-9fcca7f7392a"],
Cell[862929, 24362, 360, 9, 24, "Print",ExpressionUUID->"c4447b87-6b85-4ef3-b965-cd432a7c04fb"],
Cell[863292, 24373, 364, 9, 24, "Print",ExpressionUUID->"b64c9fa3-faf7-46df-af37-5692206472a8"],
Cell[863659, 24384, 526, 11, 24, "Print",ExpressionUUID->"67eda690-a0e8-4d4c-aca8-b2cee0cdfbac"],
Cell[864188, 24397, 536, 12, 24, "Print",ExpressionUUID->"fccc59a0-aed7-40a1-bce7-f7a9eb0a3cff"],
Cell[864727, 24411, 534, 12, 24, "Print",ExpressionUUID->"77e1d41f-baca-4f93-bb62-f6df44626c70"],
Cell[865264, 24425, 524, 11, 24, "Print",ExpressionUUID->"325abeb0-bbbd-4efe-9cb5-a350d73b03c2"],
Cell[865791, 24438, 534, 12, 24, "Print",ExpressionUUID->"281ffb8c-d1c1-48ae-bb1b-1fc3cf684946"],
Cell[866328, 24452, 368, 9, 24, "Print",ExpressionUUID->"283d5036-3829-4f0e-a9cf-282089450b12"],
Cell[866699, 24463, 378, 9, 24, "Print",ExpressionUUID->"930d7acf-adcf-47dc-b0fa-894270f234b8"],
Cell[867080, 24474, 350, 9, 24, "Print",ExpressionUUID->"ba9a063b-1950-410e-90ff-a9d31453cf58"],
Cell[867433, 24485, 352, 9, 24, "Print",ExpressionUUID->"6519900b-7a4c-4429-ab0b-c63ecce7bb73"],
Cell[867788, 24496, 360, 9, 24, "Print",ExpressionUUID->"62353a82-899b-4cdc-ba1e-f711d9e24097"],
Cell[868151, 24507, 364, 9, 24, "Print",ExpressionUUID->"cc590536-532b-4930-bbdd-a1c2248833d9"],
Cell[868518, 24518, 524, 11, 24, "Print",ExpressionUUID->"c44dbaa3-a4e5-48d7-82cc-923c9e401ba2"],
Cell[869045, 24531, 535, 12, 24, "Print",ExpressionUUID->"e3420604-58e8-4c5e-b80b-ec72b180c881"],
Cell[869583, 24545, 533, 12, 24, "Print",ExpressionUUID->"6cf9194e-a913-4a31-8ef7-e41f15c2e5eb"],
Cell[870119, 24559, 524, 11, 24, "Print",ExpressionUUID->"1009359b-514b-4613-8dc6-561850b04402"],
Cell[870646, 24572, 536, 12, 24, "Print",ExpressionUUID->"ac535f8d-97ad-4508-842c-16b2becb8b0e"],
Cell[871185, 24586, 368, 9, 24, "Print",ExpressionUUID->"9d9f9ad7-6ba5-4ceb-b7e5-b361298cb322"],
Cell[871556, 24597, 378, 9, 24, "Print",ExpressionUUID->"09edc52b-4915-42ab-869f-3e1bff1680f7"],
Cell[871937, 24608, 352, 9, 24, "Print",ExpressionUUID->"0161c84f-b2dc-498a-a9ed-f7ee7bd6f317"],
Cell[872292, 24619, 350, 9, 24, "Print",ExpressionUUID->"f1b7a88d-4e6c-4f03-ba27-333fc26556c7"],
Cell[872645, 24630, 360, 9, 24, "Print",ExpressionUUID->"f324f809-2038-4724-adf2-fde0fac737d0"],
Cell[873008, 24641, 366, 9, 24, "Print",ExpressionUUID->"6a7eab23-296e-454e-8f52-de07cd8eca3a"],
Cell[873377, 24652, 524, 11, 24, "Print",ExpressionUUID->"d182fc8f-fe62-4e3f-becd-4b66fbb68029"],
Cell[873904, 24665, 536, 12, 24, "Print",ExpressionUUID->"015e7445-3c3f-461c-913a-b04466152234"],
Cell[874443, 24679, 534, 12, 24, "Print",ExpressionUUID->"493aa411-ccbd-4fc3-9001-977cb5b2200c"],
Cell[874980, 24693, 526, 11, 24, "Print",ExpressionUUID->"52b7ccba-93b4-4fa9-8954-9d5c3d79c617"],
Cell[875509, 24706, 534, 12, 24, "Print",ExpressionUUID->"915d60ea-0e67-4414-b9ab-ab6e5a2cdbea"],
Cell[876046, 24720, 368, 9, 24, "Print",ExpressionUUID->"e12bca27-6501-40c0-8ff0-c92909420352"],
Cell[876417, 24731, 375, 9, 24, "Print",ExpressionUUID->"96f2c59a-6d4c-407c-b535-ac3ef049d530"],
Cell[876795, 24742, 350, 9, 24, "Print",ExpressionUUID->"90951315-fa53-41a4-94d7-5926503dde49"],
Cell[877148, 24753, 350, 9, 24, "Print",ExpressionUUID->"ed72a2b2-7e20-4762-9a2e-8d6736522c78"],
Cell[877501, 24764, 360, 9, 24, "Print",ExpressionUUID->"9c41f503-8f88-4d7d-b510-67582d86453d"],
Cell[877864, 24775, 362, 9, 24, "Print",ExpressionUUID->"35853a0d-cb0e-401d-b771-999c94164cc0"],
Cell[878229, 24786, 524, 11, 24, "Print",ExpressionUUID->"0b580d5f-e9ef-465f-9fe3-baaa13a7eb25"],
Cell[878756, 24799, 536, 12, 24, "Print",ExpressionUUID->"5f1b23b3-9bfc-4f21-a73c-774038ffd628"],
Cell[879295, 24813, 534, 12, 24, "Print",ExpressionUUID->"bd4ab72a-d052-43f0-bbd7-0e649973964d"],
Cell[879832, 24827, 524, 11, 24, "Print",ExpressionUUID->"2ac062c6-b25b-490e-9439-56953fe2e0e3"],
Cell[880359, 24840, 534, 12, 24, "Print",ExpressionUUID->"d58a8088-89fb-425f-be01-8902bf52411e"],
Cell[880896, 24854, 368, 9, 24, "Print",ExpressionUUID->"9fd5dda5-de63-4419-b1dc-b3d10766e23e"],
Cell[881267, 24865, 376, 9, 24, "Print",ExpressionUUID->"54f81747-9d61-48f2-9452-928a0583b3bb"],
Cell[881646, 24876, 350, 9, 24, "Print",ExpressionUUID->"05db837b-a9a2-478e-a553-bdf550327b42"],
Cell[881999, 24887, 350, 9, 24, "Print",ExpressionUUID->"74e3d6b6-1a30-4033-bc5d-52ed92fa5767"],
Cell[882352, 24898, 360, 9, 24, "Print",ExpressionUUID->"30a8c295-f5b2-4dd8-b3be-c34ce0df1757"],
Cell[882715, 24909, 364, 9, 24, "Print",ExpressionUUID->"6d7cbc79-60eb-4197-8f9e-528921a1d995"],
Cell[883082, 24920, 526, 11, 24, "Print",ExpressionUUID->"27fefd3e-0b10-400a-954f-46bd80df85d0"],
Cell[883611, 24933, 536, 12, 24, "Print",ExpressionUUID->"d7a63dbe-071a-476a-8fd8-1a1554a95933"],
Cell[884150, 24947, 536, 12, 24, "Print",ExpressionUUID->"1c8329bc-1597-4e36-ada3-a44ba190c089"],
Cell[884689, 24961, 524, 11, 24, "Print",ExpressionUUID->"62571fb4-6a49-427f-aa13-22b9adff274d"],
Cell[885216, 24974, 536, 12, 24, "Print",ExpressionUUID->"cd168c8d-34a7-47df-959d-ada3e86f4537"],
Cell[885755, 24988, 368, 9, 24, "Print",ExpressionUUID->"68f999fa-8219-421c-97d4-d5bd2c59b448"],
Cell[886126, 24999, 376, 9, 24, "Print",ExpressionUUID->"f4d45aa5-d5c7-47ac-ae37-0dc926b2becc"],
Cell[886505, 25010, 350, 9, 24, "Print",ExpressionUUID->"71c87f8e-5294-4f8d-88f3-e79aec532f15"],
Cell[886858, 25021, 350, 9, 24, "Print",ExpressionUUID->"03706821-33b1-4a2b-98c6-18c18d863f2e"],
Cell[887211, 25032, 360, 9, 24, "Print",ExpressionUUID->"98b6685a-fde3-4640-b192-a0fcdf7a715d"],
Cell[887574, 25043, 366, 9, 24, "Print",ExpressionUUID->"1354b225-3310-49ca-a313-7a9d8f7da43b"],
Cell[887943, 25054, 524, 11, 24, "Print",ExpressionUUID->"7684b20e-3ba5-453d-aa20-d38626e6041c"],
Cell[888470, 25067, 538, 12, 24, "Print",ExpressionUUID->"d6e790e1-07d1-4efd-980a-96ef088f3aec"],
Cell[889011, 25081, 531, 12, 24, "Print",ExpressionUUID->"8da6c432-9b12-445b-b7ce-29858e341957"],
Cell[889545, 25095, 523, 11, 24, "Print",ExpressionUUID->"47c9266d-6317-4ef4-bb0e-0d6e2fcaa4cc"],
Cell[890071, 25108, 534, 12, 24, "Print",ExpressionUUID->"3672cb7c-09e1-4024-8dfe-ad05b7dcf92f"],
Cell[890608, 25122, 368, 9, 24, "Print",ExpressionUUID->"bd668d7e-6ae5-43fb-ba83-9028f2ee2c15"],
Cell[890979, 25133, 404, 10, 24, "Print",ExpressionUUID->"fc6980b1-872f-4d30-a621-765daf9c518e"],
Cell[891386, 25145, 350, 9, 24, "Print",ExpressionUUID->"79896ae4-834a-4782-9234-8360f4d13639"],
Cell[891739, 25156, 350, 9, 24, "Print",ExpressionUUID->"f634fa7b-dbaa-4ac8-9e5f-3a802db2d91f"],
Cell[892092, 25167, 360, 9, 24, "Print",ExpressionUUID->"02c89f2e-0956-4517-8a2a-5853ab4b36b4"],
Cell[892455, 25178, 366, 9, 24, "Print",ExpressionUUID->"f8db0ce9-70f5-4feb-a4aa-576bf484ae9c"],
Cell[892824, 25189, 524, 11, 24, "Print",ExpressionUUID->"3c198efc-97df-40e1-be68-485b96b947e8"],
Cell[893351, 25202, 538, 12, 24, "Print",ExpressionUUID->"2185d607-ce77-47d2-882b-6f2191adca0a"],
Cell[893892, 25216, 534, 12, 24, "Print",ExpressionUUID->"55340318-5c84-46cb-9ca6-93b94b187753"],
Cell[894429, 25230, 526, 11, 24, "Print",ExpressionUUID->"5acd01fc-f20d-479f-84da-45660685cb40"],
Cell[894958, 25243, 534, 12, 24, "Print",ExpressionUUID->"a6d0c616-b6a7-42bd-8650-e69989c3d8b7"],
Cell[895495, 25257, 368, 9, 24, "Print",ExpressionUUID->"bc3aca19-2f91-490b-92ad-17fcbc84fc59"],
Cell[895866, 25268, 408, 10, 24, "Print",ExpressionUUID->"905da045-6c66-4d25-a434-c25dd89e0749"],
Cell[896277, 25280, 350, 9, 24, "Print",ExpressionUUID->"46c7709c-8cd1-489d-9fdf-023bbd4a685c"],
Cell[896630, 25291, 352, 9, 24, "Print",ExpressionUUID->"a7724190-b44b-4688-8b78-5add3a531a4d"],
Cell[896985, 25302, 362, 9, 24, "Print",ExpressionUUID->"563cdc1c-2756-47f7-976c-3a7cbf69873e"],
Cell[897350, 25313, 364, 9, 24, "Print",ExpressionUUID->"9557ec89-3c23-4414-a911-54f5194f3fa6"],
Cell[897717, 25324, 526, 11, 24, "Print",ExpressionUUID->"3f9f2030-ef6e-4450-9494-bff56058bca2"],
Cell[898246, 25337, 536, 12, 24, "Print",ExpressionUUID->"b7fbfddb-3690-45ea-921a-7955a4fd6d72"],
Cell[898785, 25351, 533, 12, 24, "Print",ExpressionUUID->"60252bf7-f3b9-40ad-b192-cb256ea3ed8e"],
Cell[899321, 25365, 524, 11, 24, "Print",ExpressionUUID->"cc3e1326-4a9f-4b89-a580-10352d069a61"],
Cell[899848, 25378, 534, 12, 24, "Print",ExpressionUUID->"7cd3ee50-2f1b-446d-8988-0028fb170af2"],
Cell[900385, 25392, 368, 9, 24, "Print",ExpressionUUID->"1d0baef0-b18d-4d12-a614-f3cc005f96ab"],
Cell[900756, 25403, 402, 10, 24, "Print",ExpressionUUID->"49a30ae1-b772-49ec-949e-7de8717bd369"],
Cell[901161, 25415, 225, 4, 24, "Print",ExpressionUUID->"bb0930d2-8923-4c29-b2fd-5012b0071a9d"],
Cell[901389, 25421, 183, 4, 24, "Print",ExpressionUUID->"af548061-54f7-425a-8a4f-0fd0346de6f6"],
Cell[901575, 25427, 436, 10, 24, "Print",ExpressionUUID->"50c2b5f6-c3bf-41b8-adec-26eddd5811a4"],
Cell[902014, 25439, 188, 4, 24, "Print",ExpressionUUID->"10220929-13d8-4a8e-8d5e-02914b3792a5"],
Cell[902205, 25445, 384, 9, 24, "Print",ExpressionUUID->"6e9b8ccc-6ed6-420f-84c1-d8dbef720a5a"],
Cell[902592, 25456, 364, 9, 24, "Print",ExpressionUUID->"40539411-b449-4804-985a-b90c8a20b5d9"],
Cell[902959, 25467, 233, 5, 24, "Print",ExpressionUUID->"c663b24e-f629-4431-939c-8dbfa5885060"],
Cell[903195, 25474, 2249, 56, 49, "Print",ExpressionUUID->"23255cf0-8720-4a09-8591-a6d787a9802a"],
Cell[905447, 25532, 328, 8, 24, "Print",ExpressionUUID->"824cc23d-3ee8-495a-b841-90aaa464da75"],
Cell[905778, 25542, 384, 9, 24, "Print",ExpressionUUID->"abaa31c8-bee6-43a1-8101-42b109843c26"],
Cell[906165, 25553, 334, 8, 24, "Print",ExpressionUUID->"f192fb97-25d1-4262-b41e-7ca217792f7d"],
Cell[906502, 25563, 448, 11, 24, "Print",ExpressionUUID->"e73595cf-a615-4c67-a524-f22277cef1a6"],
Cell[906953, 25576, 435, 10, 24, "Print",ExpressionUUID->"2e3c2399-9332-4f7b-a3c1-aa41fef2dafc"],
Cell[907391, 25588, 522, 11, 24, "Print",ExpressionUUID->"45bdce21-c03c-4e9a-ac36-f1f03beafe6f"],
Cell[907916, 25601, 328, 8, 24, "Print",ExpressionUUID->"c252256d-c36c-468f-9a86-48810c849def"],
Cell[908247, 25611, 364, 9, 24, "Print",ExpressionUUID->"c637e46e-eaf8-4c6e-8692-f399eb86d7d8"],
Cell[908614, 25622, 360, 9, 24, "Print",ExpressionUUID->"a3742c0d-8be8-4e03-af27-9d7616baf887"],
Cell[908977, 25633, 366, 9, 24, "Print",ExpressionUUID->"bdc9977b-602e-45b7-8943-02de3fbd5c6e"],
Cell[909346, 25644, 346, 9, 24, "Print",ExpressionUUID->"e382c03f-2137-4b92-a992-196d3ffe1fbb"],
Cell[909695, 25655, 524, 11, 24, "Print",ExpressionUUID->"31ffb113-890b-4b27-ba07-5bcc76893b60"],
Cell[910222, 25668, 546, 13, 24, "Print",ExpressionUUID->"f8e1ed72-ceab-49d0-b9ae-61a4f2a51c09"],
Cell[910771, 25683, 563, 13, 40, "Print",ExpressionUUID->"f371eb5a-8434-4c3b-8b5d-2ad1a8a74954"],
Cell[911337, 25698, 563, 13, 40, "Print",ExpressionUUID->"dcdb85ec-0b3d-454a-a683-026782b65418"],
Cell[911903, 25713, 534, 13, 24, "Print",ExpressionUUID->"a1e5e457-c34d-4691-a75b-6f2bff910f81"],
Cell[912440, 25728, 554, 14, 24, "Print",ExpressionUUID->"1aee4ac6-7151-400f-a10c-84f601966fb0"],
Cell[912997, 25744, 368, 9, 24, "Print",ExpressionUUID->"5488016e-dd95-4ef1-8f65-395cd1613d78"],
Cell[913368, 25755, 396, 10, 24, "Print",ExpressionUUID->"85fbea3e-fb7f-4200-89d6-77fd5e3f7633"],
Cell[913767, 25767, 446, 11, 24, "Print",ExpressionUUID->"73934049-73fc-4ec5-a913-85927aa1e2e7"],
Cell[914216, 25780, 522, 11, 24, "Print",ExpressionUUID->"b3b84a81-4ec7-4349-b5ce-b4163e9d03ff"],
Cell[914741, 25793, 231, 5, 24, "Print",ExpressionUUID->"7fac583e-c24b-4c53-8e2c-4b0ffbe638f5"],
Cell[914975, 25800, 3352, 89, 66, "Print",ExpressionUUID->"c4535632-738d-42c0-8217-138f2b853ab6"],
Cell[918330, 25891, 326, 8, 24, "Print",ExpressionUUID->"77bfb34f-5db8-47b4-8b55-571c3a914f14"],
Cell[918659, 25901, 394, 10, 24, "Print",ExpressionUUID->"91778b61-710d-43be-bc32-6aa190060eaf"],
Cell[919056, 25913, 406, 10, 24, "Print",ExpressionUUID->"6775c7f1-4a13-4c46-9a8a-14edb0481b01"],
Cell[919465, 25925, 402, 10, 24, "Print",ExpressionUUID->"c2bfb837-115e-4ae1-8c99-90b00dc12e04"],
Cell[919870, 25937, 364, 9, 24, "Print",ExpressionUUID->"199c1c9d-e7fd-4682-ac21-2cb377d10ea6"],
Cell[920237, 25948, 402, 10, 24, "Print",ExpressionUUID->"710822d7-b581-4e3b-8c10-7cb8d32da00b"],
Cell[920642, 25960, 2247, 54, 63, "Print",ExpressionUUID->"2b4dbd3d-a5f0-4e62-88d7-8437dccbda91"],
Cell[922892, 26016, 326, 8, 24, "Print",ExpressionUUID->"e913b4d8-51a6-4fa4-bea2-2c4772a9ad81"],
Cell[923221, 26026, 364, 9, 24, "Print",ExpressionUUID->"039b6ad9-1f2b-464c-bb85-908c0393cff9"],
Cell[923588, 26037, 393, 10, 24, "Print",ExpressionUUID->"db654629-69ac-4b52-8e87-c15a10e65534"],
Cell[923984, 26049, 857, 20, 24, "Print",ExpressionUUID->"a6b3129e-7c45-4671-8a32-047e34397081"],
Cell[924844, 26071, 328, 8, 24, "Print",ExpressionUUID->"f0e6815f-4650-47a4-9e87-49d34effb054"],
Cell[925175, 26081, 366, 9, 24, "Print",ExpressionUUID->"93399ba4-9072-45c7-b7d5-950eaad5aae8"],
Cell[925544, 26092, 394, 10, 24, "Print",ExpressionUUID->"094949ce-57b5-4dc0-90a3-12e4047f6522"],
Cell[925941, 26104, 366, 9, 24, "Print",ExpressionUUID->"b0c63927-83c1-4d00-af08-fd30352bca5f"],
Cell[926310, 26115, 404, 10, 24, "Print",ExpressionUUID->"80b7180a-e456-4a33-88cf-412d45d14b08"],
Cell[926717, 26127, 406, 10, 24, "Print",ExpressionUUID->"9b8cb6a8-9dc2-4b64-964a-1802d38c06b2"],
Cell[927126, 26139, 341, 9, 24, "Print",ExpressionUUID->"b0971e74-dc48-4436-b193-911810f94ec6"],
Cell[927470, 26150, 227, 4, 24, "Print",ExpressionUUID->"58ad8f9c-f4bc-48f3-97b8-e9eb91ae26ae"],
Cell[927700, 26156, 364, 9, 24, "Print",ExpressionUUID->"d9bcff50-eb1c-4691-a11e-069a4a3a7cc0"],
Cell[928067, 26167, 376, 9, 24, "Print",ExpressionUUID->"572e1714-c711-4eae-b1c6-abd12314f3da"],
Cell[928446, 26178, 442, 10, 24, "Print",ExpressionUUID->"a05fb4ad-a786-4385-99f1-2a59fff47e0d"],
Cell[928891, 26190, 412, 10, 24, "Print",ExpressionUUID->"093d86f1-178c-4602-aa8c-609be560e761"],
Cell[929306, 26202, 414, 10, 24, "Print",ExpressionUUID->"02a8a471-2bb3-46dc-a104-93d589e70221"],
Cell[929723, 26214, 414, 10, 24, "Print",ExpressionUUID->"2ad4346d-3b96-4548-92e0-b048d701b3e8"],
Cell[930140, 26226, 410, 10, 24, "Print",ExpressionUUID->"1b9ce7f4-c7f0-47c8-b469-340cf5f13be3"],
Cell[930553, 26238, 410, 10, 24, "Print",ExpressionUUID->"a64febd9-9a07-4216-8bd5-2b88f67d0735"],
Cell[930966, 26250, 400, 10, 24, "Print",ExpressionUUID->"cbc7a76d-97c9-4e73-a378-02ccf4784341"],
Cell[931369, 26262, 414, 10, 24, "Print",ExpressionUUID->"2c3e25cf-921f-4ba2-aaa7-11d1fae02823"],
Cell[931786, 26274, 404, 10, 24, "Print",ExpressionUUID->"f7e341cc-feb2-40b2-9985-c0dec491bb62"],
Cell[932193, 26286, 398, 10, 24, "Print",ExpressionUUID->"2d740f81-102f-44b6-8783-82362f0b4b8c"],
Cell[932594, 26298, 400, 10, 24, "Print",ExpressionUUID->"5d928892-6876-4ef9-81e6-7d7d772267b8"],
Cell[932997, 26310, 378, 9, 24, "Print",ExpressionUUID->"abb73491-ba14-4d97-a81c-daa25465ca44"],
Cell[933378, 26321, 376, 9, 24, "Print",ExpressionUUID->"799f0dfe-9bc6-4535-bb5f-138631403c55"],
Cell[933757, 26332, 446, 10, 24, "Print",ExpressionUUID->"899c38a0-5874-4fae-a98d-b8152bfddfc0"],
Cell[934206, 26344, 376, 9, 24, "Print",ExpressionUUID->"4b58861d-ea07-40db-811c-927ab53f114b"],
Cell[934585, 26355, 376, 9, 24, "Print",ExpressionUUID->"672aab8a-ba5e-4615-a9e6-8d8cc283c510"],
Cell[934964, 26366, 376, 9, 24, "Print",ExpressionUUID->"894c7c69-eee7-4d61-b6c0-30323724979f"],
Cell[935343, 26377, 376, 9, 24, "Print",ExpressionUUID->"93b27b07-6a7a-43d1-88d4-6e4faff017b9"],
Cell[935722, 26388, 360, 9, 24, "Print",ExpressionUUID->"ac84bb2a-ea2d-40dd-ba10-34da8b351a08"],
Cell[936085, 26399, 526, 11, 24, "Print",ExpressionUUID->"1c59e883-23ce-4dff-9619-641ad24b3d33"],
Cell[936614, 26412, 368, 9, 24, "Print",ExpressionUUID->"ec014d3b-9b23-4742-ab21-a4c7ccf9b24c"],
Cell[936985, 26423, 404, 10, 24, "Print",ExpressionUUID->"312e659e-e920-43e7-9f2c-3347f69976a7"],
Cell[937392, 26435, 366, 9, 24, "Print",ExpressionUUID->"e03d8b12-771a-444e-808f-30dc0a6f9e1e"],
Cell[937761, 26446, 406, 10, 24, "Print",ExpressionUUID->"9d9c795c-61d6-40b0-8a8e-d34109b66f27"],
Cell[938170, 26458, 364, 9, 24, "Print",ExpressionUUID->"aac1f939-c780-431f-9ea0-ffc18d4763eb"],
Cell[938537, 26469, 376, 9, 24, "Print",ExpressionUUID->"c4932297-851b-4d5d-b89b-dd859937a24a"],
Cell[938916, 26480, 376, 9, 24, "Print",ExpressionUUID->"d6f3a01d-0e0a-4dee-b83b-dec7b693dc20"],
Cell[939295, 26491, 378, 9, 24, "Print",ExpressionUUID->"b8c6ef4f-a557-4dae-8a3c-324cd1e40ba2"],
Cell[939676, 26502, 495, 11, 24, "Print",ExpressionUUID->"e16e56e9-efb8-449c-bc48-b3d30bf3fd49"],
Cell[940174, 26515, 376, 9, 24, "Print",ExpressionUUID->"964b82b1-9ec8-4e1b-949a-4f10f7bdc190"],
Cell[940553, 26526, 493, 11, 24, "Print",ExpressionUUID->"81184445-3405-42f8-97a5-286bacbfa7e4"],
Cell[941049, 26539, 376, 9, 24, "Print",ExpressionUUID->"2f10f616-cb33-4ae3-91e5-bc0f2baad1aa"],
Cell[941428, 26550, 376, 9, 24, "Print",ExpressionUUID->"5d3e865b-fdd6-4c9f-9c02-07f6d4018cf3"],
Cell[941807, 26561, 408, 10, 24, "Print",ExpressionUUID->"61f353e9-2d13-4b03-a83f-8ea3228de6a2"],
Cell[942218, 26573, 376, 9, 24, "Print",ExpressionUUID->"759c3be8-c141-4a68-9236-7368aec67418"],
Cell[942597, 26584, 231, 5, 24, "Print",ExpressionUUID->"6b43a04c-4247-411d-8048-264624be20a5"],
Cell[942831, 26591, 6582, 164, 106, "Print",ExpressionUUID->"5b0b3e2d-2bd5-4bac-89e0-1d449e6f8063"],
Cell[949416, 26757, 326, 8, 24, "Print",ExpressionUUID->"580978a5-23e3-45aa-b57a-2f3495baa666"],
Cell[949745, 26767, 376, 9, 24, "Print",ExpressionUUID->"64a85afa-2973-4301-a66e-184447bc5d95"],
Cell[950124, 26778, 364, 9, 24, "Print",ExpressionUUID->"3b620d53-f6ac-470e-a695-11271d0bd024"],
Cell[950491, 26789, 376, 9, 24, "Print",ExpressionUUID->"84aee96d-0f41-4249-bc0b-82f5b91020a5"],
Cell[950870, 26800, 378, 9, 24, "Print",ExpressionUUID->"336ea870-7bf9-45c6-952a-83a27fb43d78"],
Cell[951251, 26811, 378, 9, 24, "Print",ExpressionUUID->"289b27b8-9724-4845-8811-6fd884e2c584"],
Cell[951632, 26822, 378, 9, 24, "Print",ExpressionUUID->"5afb92ff-7515-4914-930d-54fbdf4a4983"],
Cell[952013, 26833, 376, 9, 24, "Print",ExpressionUUID->"e63de566-fd17-415c-a1ce-35294149abb0"],
Cell[952392, 26844, 495, 11, 24, "Print",ExpressionUUID->"589de357-9ec1-49da-a09b-b9ce68f80aee"],
Cell[952890, 26857, 376, 9, 24, "Print",ExpressionUUID->"a6f6551b-c2bc-4183-b016-b05580515c83"],
Cell[953269, 26868, 378, 9, 24, "Print",ExpressionUUID->"cd6fe7b7-d72d-44e2-8434-2fe1f9fcc16b"],
Cell[953650, 26879, 378, 9, 24, "Print",ExpressionUUID->"c6bab34c-e993-4ea2-aaac-c77fbec1862c"],
Cell[954031, 26890, 376, 9, 24, "Print",ExpressionUUID->"3a0bc06f-98d2-4603-a0d4-358936f9a1e6"],
Cell[954410, 26901, 428, 10, 24, "Print",ExpressionUUID->"21f2efad-5c3c-491b-a259-104eb580f476"],
Cell[954841, 26913, 434, 10, 24, "Print",ExpressionUUID->"347dc0b2-dc9b-4b01-9f93-05ebbf005e47"],
Cell[955278, 26925, 442, 10, 24, "Print",ExpressionUUID->"7ac56204-a562-4090-b9d8-d7d13ba7277d"],
Cell[955723, 26937, 402, 10, 24, "Print",ExpressionUUID->"0c36f72c-f241-44c9-81bf-bec84020ee54"],
Cell[956128, 26949, 398, 10, 24, "Print",ExpressionUUID->"0539d524-b261-444b-adb2-b2e00909cf8a"],
Cell[956529, 26961, 364, 9, 24, "Print",ExpressionUUID->"b4f16152-a8dc-4fd1-ace1-80f262eabec4"],
Cell[956896, 26972, 492, 11, 24, "Print",ExpressionUUID->"bd1c8b07-1bff-4a19-91fb-ab4b2f3e22f3"],
Cell[957391, 26985, 391, 10, 24, "Print",ExpressionUUID->"9824ed21-e967-4776-9322-0089666e622b"],
Cell[957785, 26997, 364, 9, 24, "Print",ExpressionUUID->"1acd5cad-1a46-463a-858f-1bf2b6f0cf46"],
Cell[958152, 27008, 495, 11, 24, "Print",ExpressionUUID->"a845b694-e117-4217-832f-abc950e1ac92"],
Cell[958650, 27021, 404, 10, 24, "Print",ExpressionUUID->"c877fb61-0400-4215-add6-f22bc4051608"],
Cell[959057, 27033, 364, 9, 24, "Print",ExpressionUUID->"8632eb06-6a2f-49ac-aceb-7075427d9e30"],
Cell[959424, 27044, 495, 11, 24, "Print",ExpressionUUID->"8f8b6f0a-c0cc-4e02-bba3-eac9367bd60e"],
Cell[959922, 27057, 396, 10, 24, "Print",ExpressionUUID->"0b3b9c7f-79c9-480f-8f9e-e6981d930243"],
Cell[960321, 27069, 400, 10, 24, "Print",ExpressionUUID->"443354ab-5b9f-4010-9738-18acdc23abf4"],
Cell[960724, 27081, 364, 9, 24, "Print",ExpressionUUID->"db7c44dd-92cb-493d-82d3-63336574eaa5"],
Cell[961091, 27092, 387, 10, 24, "Print",ExpressionUUID->"f4caed17-940d-47cd-9cf0-cf9bca50a28f"],
Cell[961481, 27104, 420, 10, 24, "Print",ExpressionUUID->"590a8cb2-ff33-4fd9-9c22-8325cd624897"],
Cell[961904, 27116, 418, 10, 24, "Print",ExpressionUUID->"7d89116d-640d-4019-a20e-65bed72cea3a"],
Cell[962325, 27128, 408, 10, 24, "Print",ExpressionUUID->"9c205daa-cc06-41fa-9e34-c7990f20769f"],
Cell[962736, 27140, 419, 10, 24, "Print",ExpressionUUID->"f1c1f1a1-392b-4924-8d3b-add3b3e5265a"],
Cell[963158, 27152, 414, 10, 24, "Print",ExpressionUUID->"0eb70a86-bcd9-4242-afa3-81bf25344d66"],
Cell[963575, 27164, 493, 11, 24, "Print",ExpressionUUID->"722f14ec-3e7f-46d0-be92-32243a2d02b9"],
Cell[964071, 27177, 408, 10, 24, "Print",ExpressionUUID->"0439cfff-627a-4f9c-882d-cfc7605f3cc7"],
Cell[964482, 27189, 410, 10, 24, "Print",ExpressionUUID->"13c1094f-b8db-400e-a432-742e6e7cb479"],
Cell[964895, 27201, 387, 10, 24, "Print",ExpressionUUID->"45d9d331-7799-4d4f-ac50-22dff6dc140a"],
Cell[965285, 27213, 387, 10, 24, "Print",ExpressionUUID->"ecdd4227-1969-451d-ad35-12530d671a1f"],
Cell[965675, 27225, 452, 10, 24, "Print",ExpressionUUID->"e46df4a6-a241-4cc9-87b1-a57df066eac8"],
Cell[966130, 27237, 387, 10, 24, "Print",ExpressionUUID->"4271adaf-d09f-458d-b148-c7da1009eba6"],
Cell[966520, 27249, 387, 10, 24, "Print",ExpressionUUID->"44da8bea-34fd-4a3e-bc66-bb5be15e2a1c"],
Cell[966910, 27261, 389, 10, 24, "Print",ExpressionUUID->"a1706af9-12b4-4f95-8aae-5e852e217376"],
Cell[967302, 27273, 387, 10, 24, "Print",ExpressionUUID->"eb4b05ea-964d-4772-aabf-6600325c9de3"],
Cell[967692, 27285, 412, 10, 24, "Print",ExpressionUUID->"b7c76995-cb94-429c-9485-0976f2beaedc"],
Cell[968107, 27297, 364, 9, 24, "Print",ExpressionUUID->"d6a9fa5a-fc17-492f-acb1-b50e74f7e46f"],
Cell[968474, 27308, 412, 10, 24, "Print",ExpressionUUID->"34453a0e-a328-4f40-a50a-6203466f996c"],
Cell[968889, 27320, 363, 9, 24, "Print",ExpressionUUID->"7e392964-3d3b-4726-bcab-8c66548487ef"],
Cell[969255, 27331, 387, 10, 24, "Print",ExpressionUUID->"7b6f4d01-15a8-4efd-a8d0-d1ce13f313e5"],
Cell[969645, 27343, 387, 10, 24, "Print",ExpressionUUID->"7a043a46-68d9-4e98-ae3d-9b229fce3d46"],
Cell[970035, 27355, 387, 10, 24, "Print",ExpressionUUID->"d49a7ed0-8f2d-41b0-b912-5f15c0dfc218"],
Cell[970425, 27367, 387, 10, 24, "Print",ExpressionUUID->"b394b7cc-62bc-4f95-a68d-d333321d4b36"],
Cell[970815, 27379, 387, 10, 24, "Print",ExpressionUUID->"e3d4e99b-c86a-4adc-aaef-fc4b19938c70"],
Cell[971205, 27391, 387, 10, 24, "Print",ExpressionUUID->"8e679355-71fb-425b-a4d4-f60593c9f75b"],
Cell[971595, 27403, 414, 10, 24, "Print",ExpressionUUID->"79ff6ae6-4029-4a36-8ca6-c9d61d0bcdad"],
Cell[972012, 27415, 387, 10, 24, "Print",ExpressionUUID->"9f046a07-10fa-40db-b9d0-4483a234cd78"],
Cell[972402, 27427, 387, 10, 24, "Print",ExpressionUUID->"6d6228c8-e3ad-420e-b045-b062fd126a72"],
Cell[972792, 27439, 364, 9, 24, "Print",ExpressionUUID->"5fcdb67c-e11a-4440-ab9c-42c967666934"],
Cell[973159, 27450, 387, 10, 24, "Print",ExpressionUUID->"a22e6a5d-12ff-465d-abd5-3cddad1592a8"],
Cell[973549, 27462, 387, 10, 24, "Print",ExpressionUUID->"4d30c886-3800-452d-9016-03f1b1b058c6"],
Cell[973939, 27474, 387, 10, 24, "Print",ExpressionUUID->"08709555-da0e-49bd-8604-6338a42730ca"],
Cell[974329, 27486, 387, 10, 24, "Print",ExpressionUUID->"e1052810-b7ba-4276-b278-13a32b92c513"],
Cell[974719, 27498, 387, 10, 24, "Print",ExpressionUUID->"65483eb6-1aab-4791-9c1b-5b98f576d46a"],
Cell[975109, 27510, 387, 10, 24, "Print",ExpressionUUID->"3660cedf-caf7-406d-ac6f-8188b7e184d8"],
Cell[975499, 27522, 387, 10, 24, "Print",ExpressionUUID->"870320dd-ceb2-4b24-9c06-9a326c646031"],
Cell[975889, 27534, 389, 10, 24, "Print",ExpressionUUID->"2351bf37-29a8-4398-a485-cf08a89d7249"],
Cell[976281, 27546, 389, 10, 24, "Print",ExpressionUUID->"dbce596a-4136-40d8-b6a5-6b280b1da3c9"],
Cell[976673, 27558, 436, 10, 24, "Print",ExpressionUUID->"851e63d5-0431-420e-b2e3-de20cb359fef"],
Cell[977112, 27570, 442, 10, 24, "Print",ExpressionUUID->"45530a8c-19f6-4824-85a2-1d73670a2eab"],
Cell[977557, 27582, 450, 10, 24, "Print",ExpressionUUID->"f3e36d59-0d29-40b9-b7fe-d716dee2b4ef"],
Cell[978010, 27594, 396, 10, 24, "Print",ExpressionUUID->"95b2a8cb-6ea8-4707-96f1-3bd0c8029bfa"],
Cell[978409, 27606, 400, 10, 24, "Print",ExpressionUUID->"9649ea6a-e933-4df2-aa65-586e039f6dfc"],
Cell[978812, 27618, 380, 9, 24, "Print",ExpressionUUID->"a5147702-1062-4205-93f7-ccaf5e7b908f"],
Cell[979195, 27629, 222, 4, 24, "Print",ExpressionUUID->"99425815-a1a7-4dc1-9e84-a1baa24fba8e"],
Cell[979420, 27635, 380, 9, 24, "Print",ExpressionUUID->"93e281f7-50d8-4fe7-98c0-fc16f4e6924a"],
Cell[979803, 27646, 380, 9, 24, "Print",ExpressionUUID->"9b7a3915-b5a4-4912-bf2c-6f4c4f01c3d7"],
Cell[980186, 27657, 382, 9, 24, "Print",ExpressionUUID->"4f30e02d-428a-4982-8d85-cc1606c46d46"],
Cell[980571, 27668, 380, 9, 24, "Print",ExpressionUUID->"77db6406-e088-4a72-ba38-fa235d61d46f"],
Cell[980954, 27679, 379, 9, 24, "Print",ExpressionUUID->"8697c825-5aa1-4d47-a96f-9f878cc8ebbe"],
Cell[981336, 27690, 379, 9, 24, "Print",ExpressionUUID->"c82befcc-7aca-4397-88a1-e932b20cb8eb"],
Cell[981718, 27701, 380, 9, 24, "Print",ExpressionUUID->"300a26a3-0ba2-422f-a24a-9e34fd3b58de"],
Cell[982101, 27712, 380, 9, 24, "Print",ExpressionUUID->"b85c4269-d1fe-4832-83c0-31bfbfcdc493"],
Cell[982484, 27723, 380, 9, 24, "Print",ExpressionUUID->"7e050477-9044-4ff6-a130-129a5504a8f3"],
Cell[982867, 27734, 380, 9, 24, "Print",ExpressionUUID->"358c95b6-a36e-4f61-b252-023c9bccdcd4"],
Cell[983250, 27745, 382, 9, 24, "Print",ExpressionUUID->"1b1207c7-6dd1-44a3-ac61-b7e3700f48af"],
Cell[983635, 27756, 380, 9, 24, "Print",ExpressionUUID->"a9f32ef1-55a9-4fee-a331-736294e677bf"],
Cell[984018, 27767, 382, 9, 24, "Print",ExpressionUUID->"f41a28c8-e4a6-4cb5-a852-0abb4ee0ff60"],
Cell[984403, 27778, 379, 9, 24, "Print",ExpressionUUID->"cc7e2850-6585-4310-9de3-d66c57d3797b"],
Cell[984785, 27789, 380, 9, 24, "Print",ExpressionUUID->"a786b6dd-6f9c-4b2d-ad28-eeaa611ea37a"],
Cell[985168, 27800, 382, 9, 24, "Print",ExpressionUUID->"ae42ecdb-d7cd-4b42-b4aa-c82a5f606840"],
Cell[985553, 27811, 380, 9, 24, "Print",ExpressionUUID->"b4ee6e8c-a8bc-414b-b53a-23e6e9e01a99"],
Cell[985936, 27822, 404, 10, 24, "Print",ExpressionUUID->"046303e0-fd23-4a57-8039-3941c9b1701f"],
Cell[986343, 27834, 364, 9, 24, "Print",ExpressionUUID->"0f3314eb-bac6-430b-9e65-01a0a6062eaf"],
Cell[986710, 27845, 404, 10, 24, "Print",ExpressionUUID->"ff7a3613-7f63-42a5-af19-580daa472360"],
Cell[987117, 27857, 403, 10, 24, "Print",ExpressionUUID->"024d774b-c6af-4082-845a-152cd712bd8e"],
Cell[987523, 27869, 376, 9, 24, "Print",ExpressionUUID->"2a1a24fb-8838-4c96-a731-c4b623b0561d"],
Cell[987902, 27880, 376, 9, 24, "Print",ExpressionUUID->"ac967315-932e-4465-99dd-be21c357e701"],
Cell[988281, 27891, 376, 9, 24, "Print",ExpressionUUID->"c5b09e50-a122-4fde-a80c-3965da633798"],
Cell[988660, 27902, 363, 9, 24, "Print",ExpressionUUID->"bf336c9f-fd66-4939-bd1a-b8c87b155dcb"],
Cell[989026, 27913, 378, 9, 24, "Print",ExpressionUUID->"a97e196c-40b7-4d6c-9e26-d47717137589"],
Cell[989407, 27924, 375, 9, 24, "Print",ExpressionUUID->"2cadf0b4-22a0-4bfb-b673-043160d84a54"],
Cell[989785, 27935, 376, 9, 24, "Print",ExpressionUUID->"4c49ffac-44ca-4237-8570-e08ba6830d75"],
Cell[990164, 27946, 376, 9, 24, "Print",ExpressionUUID->"ab55da03-d16d-4ac4-9ca9-f881e435081b"],
Cell[990543, 27957, 376, 9, 24, "Print",ExpressionUUID->"8b9f76b0-e3b1-4ef5-91bc-05d34335eef1"],
Cell[990922, 27968, 404, 10, 24, "Print",ExpressionUUID->"25740787-1860-462f-842d-6e35e54a3ebf"],
Cell[991329, 27980, 360, 9, 24, "Print",ExpressionUUID->"a127f724-7a6d-4dfe-9ced-ff812899737f"],
Cell[991692, 27991, 524, 11, 24, "Print",ExpressionUUID->"f00b77cd-206f-4995-9caa-32688729405e"],
Cell[992219, 28004, 368, 9, 24, "Print",ExpressionUUID->"930c0e1b-0c86-41dc-a8f5-1e45e222febe"],
Cell[992590, 28015, 408, 10, 24, "Print",ExpressionUUID->"308f8ee3-50a9-49d0-86ee-7e71049a02d7"],
Cell[993001, 28027, 400, 10, 24, "Print",ExpressionUUID->"acbfb327-cf09-4a0e-b5e4-78ec1f84687f"],
Cell[993404, 28039, 183, 4, 24, "Print",ExpressionUUID->"1455ff7d-1291-4c8d-851a-f11e5326b329"],
Cell[993590, 28045, 426, 10, 24, "Print",ExpressionUUID->"aa574963-d9da-486f-b382-b7cb14fe587e"],
Cell[994019, 28057, 188, 4, 24, "Print",ExpressionUUID->"e937d4d4-125c-43aa-894c-385b6ffc12c0"],
Cell[994210, 28063, 384, 9, 24, "Print",ExpressionUUID->"8c2d7371-4bbf-410b-9878-0b001ee96f45"],
Cell[994597, 28074, 686, 18, 24, "Print",ExpressionUUID->"d6714415-f699-4b8d-9441-df3192941e9b"],
Cell[995286, 28094, 326, 8, 24, "Print",ExpressionUUID->"1a3c89d1-758c-4774-8842-bcde49e8b5f0"],
Cell[995615, 28104, 364, 9, 24, "Print",ExpressionUUID->"6d901acf-1fee-4f7c-98f4-7824c7c05c45"],
Cell[995982, 28115, 384, 9, 24, "Print",ExpressionUUID->"4406555b-2eb4-446c-be4f-d8e987be74c4"],
Cell[996369, 28126, 336, 8, 24, "Print",ExpressionUUID->"6676e934-5cfb-444d-83e7-28b04629a8da"],
Cell[996708, 28136, 448, 11, 24, "Print",ExpressionUUID->"6ae7110d-5de6-4d36-8d9f-1392f48550a3"],
Cell[997159, 28149, 435, 10, 24, "Print",ExpressionUUID->"18135d76-542d-4a54-ba5b-d34bc1140295"],
Cell[997597, 28161, 524, 11, 24, "Print",ExpressionUUID->"63a41945-b3c0-4352-921a-6e71c35ab3ab"],
Cell[998124, 28174, 325, 8, 24, "Print",ExpressionUUID->"1fda6d6b-9c0c-4e35-8846-e98de5f646e9"],
Cell[998452, 28184, 354, 9, 24, "Print",ExpressionUUID->"f635b5e2-65aa-4feb-a5bf-1fd469166409"],
Cell[998809, 28195, 362, 9, 24, "Print",ExpressionUUID->"f5c83972-e598-4630-b0c9-1b8df2882628"],
Cell[999174, 28206, 364, 9, 24, "Print",ExpressionUUID->"74ccf150-3d5e-44cf-9360-410d56b4cf20"],
Cell[999541, 28217, 346, 9, 24, "Print",ExpressionUUID->"2029b766-daf0-4446-bf19-169548d0dee8"],
Cell[999890, 28228, 526, 11, 24, "Print",ExpressionUUID->"54207251-be88-4d09-9420-fedea06a9bfe"],
Cell[1000419, 28241, 546, 13, 24, "Print",ExpressionUUID->"57be43f7-a746-46ec-8aca-d4c7afa9966b"],
Cell[1000968, 28256, 565, 13, 40, "Print",ExpressionUUID->"bcbc918f-aa7e-4c70-8ab4-1b3330ddce9d"],
Cell[1001536, 28271, 565, 13, 40, "Print",ExpressionUUID->"59f7470a-d25d-4881-9bfd-6d44a8d35abd"],
Cell[1002104, 28286, 534, 13, 24, "Print",ExpressionUUID->"62fe37dd-ed53-464f-b94a-e9ba4ee0f529"],
Cell[1002641, 28301, 552, 14, 24, "Print",ExpressionUUID->"266a1e90-481e-49f7-b590-7bb1ad0d26b5"],
Cell[1003196, 28317, 368, 9, 24, "Print",ExpressionUUID->"59b96ad1-df23-4cb0-b3b4-2f8985a182dc"],
Cell[1003567, 28328, 396, 10, 24, "Print",ExpressionUUID->"70802b57-7920-4285-9dbf-7df1bfd637d3"],
Cell[1003966, 28340, 446, 11, 24, "Print",ExpressionUUID->"a0512586-51bb-4880-9cb0-c3ef9741624d"],
Cell[1004415, 28353, 522, 11, 24, "Print",ExpressionUUID->"feeaea25-7dc4-4956-aced-ce69c027974f"],
Cell[1004940, 28366, 231, 5, 24, "Print",ExpressionUUID->"30a2d48b-18e0-4856-81e1-39c349a67649"],
Cell[1005174, 28373, 1016, 29, 27, "Print",ExpressionUUID->"a154508c-49ba-4154-aff3-5ba887e4a27a"],
Cell[1006193, 28404, 326, 8, 24, "Print",ExpressionUUID->"1f02b1e3-36c6-4ede-a1d6-c0cc67d0f3a9"],
Cell[1006522, 28414, 396, 10, 24, "Print",ExpressionUUID->"de01cd3c-b380-4599-a05a-e1d8d72f2cbf"],
Cell[1006921, 28426, 406, 10, 24, "Print",ExpressionUUID->"e2527b12-4fe3-4886-af37-78d1e0ac4800"],
Cell[1007330, 28438, 402, 10, 24, "Print",ExpressionUUID->"1631eb76-980e-4e45-9b35-7cfc08066e95"],
Cell[1007735, 28450, 880, 25, 27, "Print",ExpressionUUID->"5e10d3ef-522b-4871-b24f-42b46cf3ef66"],
Cell[1008618, 28477, 326, 8, 24, "Print",ExpressionUUID->"0964ed8b-d867-48e9-82b5-fe80635fa792"],
Cell[1008947, 28487, 366, 9, 24, "Print",ExpressionUUID->"22f9d2ef-344c-4e79-8ef9-d820e4ed9331"],
Cell[1009316, 28498, 400, 10, 24, "Print",ExpressionUUID->"4472ff8c-2de6-46f9-bc08-eb9872167a41"],
Cell[1009719, 28510, 396, 10, 24, "Print",ExpressionUUID->"efa3054c-d141-45c0-9856-b70d9f88b906"],
Cell[1010118, 28522, 394, 10, 24, "Print",ExpressionUUID->"b4bdae1e-537e-4096-a345-18e63bc0ee50"],
Cell[1010515, 28534, 401, 10, 24, "Print",ExpressionUUID->"5a8631c6-660c-466f-a563-1e3942d99018"],
Cell[1010919, 28546, 364, 9, 24, "Print",ExpressionUUID->"ea8d971a-ed15-4188-b2a7-7d636b118b8e"],
Cell[1011286, 28557, 404, 10, 24, "Print",ExpressionUUID->"cfa913e8-d226-4b60-abc0-a6ec08275c07"],
Cell[1011693, 28569, 339, 9, 24, "Print",ExpressionUUID->"e17964d0-6ac0-4661-8223-d90282475526"],
Cell[1012035, 28580, 376, 9, 24, "Print",ExpressionUUID->"ed9f08b8-27c2-47a4-9281-320eaec0897c"],
Cell[1012414, 28591, 442, 10, 24, "Print",ExpressionUUID->"281e53ee-cc29-402c-831f-fe969628350e"],
Cell[1012859, 28603, 412, 10, 24, "Print",ExpressionUUID->"639d795b-b530-4228-8274-d72b6e587c84"],
Cell[1013274, 28615, 414, 10, 24, "Print",ExpressionUUID->"3cb8670f-88e2-437f-a693-f35d965b3fae"],
Cell[1013691, 28627, 414, 10, 24, "Print",ExpressionUUID->"eb616269-095f-4f0f-8c51-519255427fa8"],
Cell[1014108, 28639, 410, 10, 24, "Print",ExpressionUUID->"cbabcd34-785a-496d-862c-499263a4c691"],
Cell[1014521, 28651, 410, 10, 24, "Print",ExpressionUUID->"dc4466a2-6409-4e43-bc7f-d5c432d41896"],
Cell[1014934, 28663, 400, 10, 24, "Print",ExpressionUUID->"d3c2edc8-d99c-488a-81e0-cabf62d48680"],
Cell[1015337, 28675, 412, 10, 24, "Print",ExpressionUUID->"8d8a3a52-bb27-4731-a775-e7cf39f83fa1"],
Cell[1015752, 28687, 404, 10, 24, "Print",ExpressionUUID->"a923d036-c0f2-4547-afcc-7fe0fdf87588"],
Cell[1016159, 28699, 400, 10, 24, "Print",ExpressionUUID->"b08b96b3-b796-4da9-bff8-510560f9b8fa"],
Cell[1016562, 28711, 400, 10, 24, "Print",ExpressionUUID->"8322b90c-4498-43c0-84ad-0fceea0e8cb1"],
Cell[1016965, 28723, 376, 9, 24, "Print",ExpressionUUID->"c86549c2-ae53-4432-8d6a-9ff2eaf418c4"],
Cell[1017344, 28734, 376, 9, 24, "Print",ExpressionUUID->"71cbaacd-77b5-4967-bc68-26c84b05710e"],
Cell[1017723, 28745, 444, 10, 24, "Print",ExpressionUUID->"044c2ba7-6d37-471e-a3d6-3c60a91e531f"],
Cell[1018170, 28757, 376, 9, 24, "Print",ExpressionUUID->"1f56ccf4-8004-406d-9c95-a49a1be704f2"],
Cell[1018549, 28768, 378, 9, 24, "Print",ExpressionUUID->"076cb4b3-050c-47ce-b011-3a9500cddcce"],
Cell[1018930, 28779, 376, 9, 24, "Print",ExpressionUUID->"dc73bcee-6ce7-4f2a-aed1-4571f5f1c554"],
Cell[1019309, 28790, 376, 9, 24, "Print",ExpressionUUID->"2ad9ec68-55de-4276-af27-6a85b976f420"],
Cell[1019688, 28801, 360, 9, 24, "Print",ExpressionUUID->"926a02bb-3fb0-4494-b4c9-8cd3e0de2c49"],
Cell[1020051, 28812, 524, 11, 24, "Print",ExpressionUUID->"9e3eb083-0d47-400c-9793-dfb324a361c9"],
Cell[1020578, 28825, 370, 9, 24, "Print",ExpressionUUID->"823a6740-1fe5-4fb7-b6cf-1c0a10dbd2af"],
Cell[1020951, 28836, 404, 10, 24, "Print",ExpressionUUID->"ed811706-9d5a-4162-a5fb-2f25a3e793c2"],
Cell[1021358, 28848, 894, 25, 27, "Print",ExpressionUUID->"023892a5-5808-4283-9524-2803de5023a6"],
Cell[1022255, 28875, 326, 8, 24, "Print",ExpressionUUID->"bc10996d-a8f3-4e3a-af2f-66dc23ddb19a"],
Cell[1022584, 28885, 366, 9, 24, "Print",ExpressionUUID->"a56a8143-2372-4d0b-b015-0359db1296b6"],
Cell[1022953, 28896, 406, 10, 24, "Print",ExpressionUUID->"80af0fbc-91a5-4210-a01c-2586fe744c63"],
Cell[1023362, 28908, 904, 25, 27, "Print",ExpressionUUID->"fd66e8ec-17a4-4be5-b90f-6e9dea0cdffa"],
Cell[1024269, 28935, 326, 8, 24, "Print",ExpressionUUID->"8ec7a40d-2a9c-4544-89fa-a90277d7752e"],
Cell[1024598, 28945, 364, 9, 24, "Print",ExpressionUUID->"c115c927-2123-4da5-8e9d-7161139da925"],
Cell[1024965, 28956, 378, 9, 24, "Print",ExpressionUUID->"d49f4c0b-e1b1-4e4a-b5a1-611e354cb04d"],
Cell[1025346, 28967, 376, 9, 24, "Print",ExpressionUUID->"a996bbba-0508-4c41-b276-5ce8108a1645"],
Cell[1025725, 28978, 378, 9, 24, "Print",ExpressionUUID->"a6345deb-5b0f-4e0b-ac90-7f01688f4ec8"],
Cell[1026106, 28989, 376, 9, 24, "Print",ExpressionUUID->"2e249d5b-956b-4efc-ad2f-da9c22563b97"],
Cell[1026485, 29000, 376, 9, 24, "Print",ExpressionUUID->"a38e8406-18e5-48e1-ba4a-9a15df1b984e"],
Cell[1026864, 29011, 366, 9, 24, "Print",ExpressionUUID->"27c69bd7-2d0b-4386-8fe3-b1e989b5318f"],
Cell[1027233, 29022, 376, 9, 24, "Print",ExpressionUUID->"726eb77a-3740-453e-ab59-9ec16b9501b4"],
Cell[1027612, 29033, 366, 9, 24, "Print",ExpressionUUID->"6a87e381-c7e7-44e0-a89b-d382df3e9fe3"],
Cell[1027981, 29044, 408, 10, 24, "Print",ExpressionUUID->"2d2e8b4d-616f-4ccf-a87e-e6b9c7535ea1"],
Cell[1028392, 29056, 364, 9, 24, "Print",ExpressionUUID->"8675a82c-96b0-4352-b23c-7da35faa9db9"],
Cell[1028759, 29067, 376, 9, 24, "Print",ExpressionUUID->"32626644-211d-4791-a27b-7d25f88677ed"],
Cell[1029138, 29078, 376, 9, 24, "Print",ExpressionUUID->"686f0185-5ab2-4c0d-8f78-1ee04defbdd0"],
Cell[1029517, 29089, 376, 9, 24, "Print",ExpressionUUID->"a2ea0a6a-20a0-44db-982f-ea722aef502d"],
Cell[1029896, 29100, 364, 9, 24, "Print",ExpressionUUID->"221ee0e7-c322-4607-9d68-05c7a32784af"],
Cell[1030263, 29111, 376, 9, 24, "Print",ExpressionUUID->"b4c8e027-710f-45a5-ac2b-8fe2549a856d"],
Cell[1030642, 29122, 376, 9, 24, "Print",ExpressionUUID->"f10c3341-60b9-4b4c-8402-34dc895a6e62"],
Cell[1031021, 29133, 341, 9, 24, "Print",ExpressionUUID->"b95d83c7-cd1d-4c5c-b057-57ee95c7d5de"],
Cell[1031365, 29144, 376, 9, 24, "Print",ExpressionUUID->"f82f88c6-6679-478e-813c-46df35338868"],
Cell[1031744, 29155, 376, 9, 24, "Print",ExpressionUUID->"d72e8832-d7ae-48c4-adbb-ea06f1604347"],
Cell[1032123, 29166, 376, 9, 24, "Print",ExpressionUUID->"4ffbbca8-bee7-426e-9494-e97d89e1d9b9"],
Cell[1032502, 29177, 378, 9, 24, "Print",ExpressionUUID->"04bf3467-ef3f-4914-bbe8-a88e492d5281"],
Cell[1032883, 29188, 376, 9, 24, "Print",ExpressionUUID->"8532417c-ce64-4477-b503-05c1ff204b78"],
Cell[1033262, 29199, 376, 9, 24, "Print",ExpressionUUID->"e1732bc4-3452-4910-b016-a5c8dd54dbae"],
Cell[1033641, 29210, 430, 10, 24, "Print",ExpressionUUID->"e644be14-b1f2-4b22-9090-944b4475dbe9"],
Cell[1034074, 29222, 434, 10, 24, "Print",ExpressionUUID->"72618fe0-e1b3-4fb5-ab55-0454e6d98235"],
Cell[1034511, 29234, 442, 10, 24, "Print",ExpressionUUID->"61c3542c-6a8c-471c-a23e-b87a5828331c"],
Cell[1034956, 29246, 404, 10, 24, "Print",ExpressionUUID->"d547c924-b49f-46fd-976d-fbb873c851b2"],
Cell[1035363, 29258, 398, 10, 24, "Print",ExpressionUUID->"fe9959c5-fac8-413e-81b8-f35ae2a8c4d4"],
Cell[1035764, 29270, 394, 10, 24, "Print",ExpressionUUID->"4103b642-7ec2-401c-ba19-053faf45fa55"],
Cell[1036161, 29282, 406, 10, 24, "Print",ExpressionUUID->"ecf610ee-a3a1-4527-99a4-259f92b615cf"],
Cell[1036570, 29294, 396, 10, 24, "Print",ExpressionUUID->"9aa5e729-ea88-4fe7-8c96-38e77b468fda"],
Cell[1036969, 29306, 364, 9, 24, "Print",ExpressionUUID->"b77e3ae8-d024-4e89-a068-1e7ba3547df0"],
Cell[1037336, 29317, 400, 10, 24, "Print",ExpressionUUID->"504dace4-dd1e-4057-b461-a895e4eb2e69"],
Cell[1037739, 29329, 387, 10, 24, "Print",ExpressionUUID->"2c41018b-3eb3-4a41-9f6e-899485b3a924"],
Cell[1038129, 29341, 418, 10, 24, "Print",ExpressionUUID->"201c721b-e057-4249-95ef-1f3c769ccd43"],
Cell[1038550, 29353, 418, 10, 24, "Print",ExpressionUUID->"7d35c835-bf9f-43a9-80f8-2526a14b875e"],
Cell[1038971, 29365, 408, 10, 24, "Print",ExpressionUUID->"1e21a8a9-9e4e-43cf-bd8e-19e3dbe23c11"],
Cell[1039382, 29377, 422, 10, 24, "Print",ExpressionUUID->"c8f4fa3e-c219-414a-9a31-2beee928df98"],
Cell[1039807, 29389, 412, 10, 24, "Print",ExpressionUUID->"7b2719af-a2b1-474c-b4f1-0701f1ccc8bf"],
Cell[1040222, 29401, 405, 10, 24, "Print",ExpressionUUID->"352f681d-9838-48de-86b5-bbd6e46ef5ec"],
Cell[1040630, 29413, 408, 10, 24, "Print",ExpressionUUID->"b3636c75-d9f8-4cd4-8f8a-e86f3e9b7da8"],
Cell[1041041, 29425, 387, 10, 24, "Print",ExpressionUUID->"78f1773d-94e2-4f86-81de-bc50b58c9a40"],
Cell[1041431, 29437, 387, 10, 24, "Print",ExpressionUUID->"7800459c-7f65-402a-a6ba-ac2d961c101c"],
Cell[1041821, 29449, 452, 10, 24, "Print",ExpressionUUID->"d7537a8d-d0d4-4006-ba04-8fed89263e2d"],
Cell[1042276, 29461, 389, 10, 24, "Print",ExpressionUUID->"d49482ed-a7b1-4132-99a9-db669050973f"],
Cell[1042668, 29473, 387, 10, 24, "Print",ExpressionUUID->"1f58ff9b-3701-479b-a5eb-413e182c1c4b"],
Cell[1043058, 29485, 387, 10, 24, "Print",ExpressionUUID->"8a7e2dab-748d-43b6-b334-330db3ff4982"],
Cell[1043448, 29497, 387, 10, 24, "Print",ExpressionUUID->"8c631ba4-adc6-4101-92b4-64f2467635b3"],
Cell[1043838, 29509, 412, 10, 24, "Print",ExpressionUUID->"a369ae15-8408-4ba3-8cfc-625fd225017f"],
Cell[1044253, 29521, 633, 17, 24, "Print",ExpressionUUID->"aaf5ca31-f70a-4785-8aa7-444ce6bd4770"],
Cell[1044889, 29540, 326, 8, 24, "Print",ExpressionUUID->"0fae3041-b9a5-4b2d-a3f7-2270cf730a79"],
Cell[1045218, 29550, 364, 9, 24, "Print",ExpressionUUID->"403b7c6e-136c-4dd2-b6f6-1a3f9430ba0d"],
Cell[1045585, 29561, 414, 10, 24, "Print",ExpressionUUID->"13c6205f-5ac7-4c79-bd00-50ca11be1c10"],
Cell[1046002, 29573, 819, 23, 27, "Print",ExpressionUUID->"1cea9922-42df-44d1-ab8e-a7f117509166"],
Cell[1046824, 29598, 328, 8, 24, "Print",ExpressionUUID->"35b84d55-5832-4906-bb63-e5bb6f5c11ce"],
Cell[1047155, 29608, 364, 9, 24, "Print",ExpressionUUID->"d0adbaab-cef9-4aa8-9ba7-aadc67456fbb"],
Cell[1047522, 29619, 387, 10, 24, "Print",ExpressionUUID->"f2c1962f-b09e-4311-83de-a2ff559e8040"],
Cell[1047912, 29631, 387, 10, 24, "Print",ExpressionUUID->"72bb595a-de37-4111-a994-7fc183486def"],
Cell[1048302, 29643, 387, 10, 24, "Print",ExpressionUUID->"bd7d9508-c263-4660-a61f-51caab60388d"],
Cell[1048692, 29655, 387, 10, 24, "Print",ExpressionUUID->"0d3f7765-7b59-4c65-82af-f7fb2e308ad8"],
Cell[1049082, 29667, 387, 10, 24, "Print",ExpressionUUID->"2e5f21ee-6b01-4215-bcf7-06b99ad4f8b4"],
Cell[1049472, 29679, 364, 9, 24, "Print",ExpressionUUID->"b44535dc-a0ee-4633-ba22-fa855d2e46fe"],
Cell[1049839, 29690, 389, 10, 24, "Print",ExpressionUUID->"eddb9581-0104-4790-b0f1-974389c0483d"],
Cell[1050231, 29702, 366, 9, 24, "Print",ExpressionUUID->"3bf6dfb8-f21e-4eb9-b160-ea5515e47e50"],
Cell[1050600, 29713, 414, 10, 24, "Print",ExpressionUUID->"824b448a-2950-4a5c-86e8-9397179e1947"],
Cell[1051017, 29725, 364, 9, 24, "Print",ExpressionUUID->"63f6e50e-3c0c-4c70-a534-3e7ab60931e9"],
Cell[1051384, 29736, 387, 10, 24, "Print",ExpressionUUID->"8603e821-419e-4275-b329-760501385e55"],
Cell[1051774, 29748, 387, 10, 24, "Print",ExpressionUUID->"6095e45e-33ce-4390-8e75-1d2e653cf422"],
Cell[1052164, 29760, 387, 10, 24, "Print",ExpressionUUID->"fc900a4c-394c-46f4-a3fd-bfe5dade150f"],
Cell[1052554, 29772, 364, 9, 24, "Print",ExpressionUUID->"5150d744-e330-4ae4-9be0-66d57428b245"],
Cell[1052921, 29783, 387, 10, 24, "Print",ExpressionUUID->"6c21f9aa-a321-44a7-ba48-8592f6cac070"],
Cell[1053311, 29795, 387, 10, 24, "Print",ExpressionUUID->"b2a6fd35-3362-47d4-9da7-eb34f0163007"],
Cell[1053701, 29807, 387, 10, 24, "Print",ExpressionUUID->"b22dfe2f-be31-4ff0-8cf7-81f63ddcc92e"],
Cell[1054091, 29819, 386, 10, 24, "Print",ExpressionUUID->"5fd8de5b-d8e9-4ed9-9b1d-5e38a448659b"],
Cell[1054480, 29831, 389, 10, 24, "Print",ExpressionUUID->"62d46eab-4c6c-49ce-a13d-0c50b256143f"],
Cell[1054872, 29843, 387, 10, 24, "Print",ExpressionUUID->"7139943e-03cf-4396-9bc0-93641a54bfbc"],
Cell[1055262, 29855, 387, 10, 24, "Print",ExpressionUUID->"2f1168c8-ba8a-4e4e-8751-80f8a5a4a547"],
Cell[1055652, 29867, 387, 10, 24, "Print",ExpressionUUID->"c26436f4-4bee-461f-bfcf-0774946660b4"],
Cell[1056042, 29879, 436, 10, 24, "Print",ExpressionUUID->"30e81482-e0e6-4c06-aa47-93c6b1b92c66"],
Cell[1056481, 29891, 444, 10, 24, "Print",ExpressionUUID->"527eb7da-624e-43cc-9314-5409cdfec899"],
Cell[1056928, 29903, 452, 10, 24, "Print",ExpressionUUID->"bc82468b-1cad-4a91-9212-17fe9d83a809"],
Cell[1057383, 29915, 395, 10, 24, "Print",ExpressionUUID->"ea4cbd76-f7fa-463d-abe5-09477a72b49c"],
Cell[1057781, 29927, 402, 10, 24, "Print",ExpressionUUID->"c812b522-f599-4578-a147-de83f1c3e669"],
Cell[1058186, 29939, 354, 9, 24, "Print",ExpressionUUID->"984b881e-2084-491b-988d-40b01a7a2d61"],
Cell[1058543, 29950, 380, 9, 24, "Print",ExpressionUUID->"a88f6a5a-be5d-461f-b535-e2bccba38d99"],
Cell[1058926, 29961, 352, 9, 24, "Print",ExpressionUUID->"75f14997-2dab-48e2-ade5-2c4695833c7a"],
Cell[1059281, 29972, 380, 9, 24, "Print",ExpressionUUID->"c0d04cc7-cb63-4ced-812f-41da8c680963"],
Cell[1059664, 29983, 354, 9, 24, "Print",ExpressionUUID->"0b7f1966-a54c-408e-aeec-06e35cca1327"],
Cell[1060021, 29994, 382, 9, 24, "Print",ExpressionUUID->"617520a0-6bb9-4e9b-ac80-750b8740f54a"],
Cell[1060406, 30005, 380, 9, 24, "Print",ExpressionUUID->"14b2931d-3325-4186-9087-0edc6f5a5404"],
Cell[1060789, 30016, 352, 9, 24, "Print",ExpressionUUID->"ee2f288d-d28a-4341-b978-043086a41dae"],
Cell[1061144, 30027, 380, 9, 24, "Print",ExpressionUUID->"f920dc9a-d03b-48da-9022-cda8071c98cd"],
Cell[1061527, 30038, 339, 9, 24, "Print",ExpressionUUID->"838c150c-74b2-4068-baae-5a6938913eb5"],
Cell[1061869, 30049, 336, 8, 24, "Print",ExpressionUUID->"f2f3d785-4fa1-438f-8c1f-1d5a63c14b3d"],
Cell[1062208, 30059, 340, 8, 24, "Print",ExpressionUUID->"cb033198-5e25-444f-947b-10c23bf96291"],
Cell[1062551, 30069, 380, 9, 24, "Print",ExpressionUUID->"142ca76f-ded7-4b83-a88e-7702f2390c98"],
Cell[1062934, 30080, 341, 9, 24, "Print",ExpressionUUID->"27b4531c-dc06-40af-9bd7-eb4639e9a5fb"],
Cell[1063278, 30091, 494, 12, 24, "Print",ExpressionUUID->"9002a613-1bc7-4460-a836-1d23286ab270"],
Cell[1063775, 30105, 338, 8, 24, "Print",ExpressionUUID->"b776c008-b020-4f78-8a9f-1862d3c6b533"],
Cell[1064116, 30115, 380, 9, 24, "Print",ExpressionUUID->"86a7f233-d210-4cb6-bd89-50fb5cb8b76c"],
Cell[1064499, 30126, 364, 9, 24, "Print",ExpressionUUID->"4a684565-5ca2-46a7-9615-4aaac77d2230"],
Cell[1064866, 30137, 380, 9, 24, "Print",ExpressionUUID->"9d3e918b-baad-41bb-8de5-8f64b4edba30"],
Cell[1065249, 30148, 364, 9, 24, "Print",ExpressionUUID->"095776e1-608b-4afd-9e47-4f7dd49ff300"],
Cell[1065616, 30159, 380, 9, 24, "Print",ExpressionUUID->"d95ccfd7-513f-472c-aa6a-3b8226b03805"],
Cell[1065999, 30170, 366, 9, 24, "Print",ExpressionUUID->"d3d9aed6-3151-49b1-bd8e-508de522dee4"],
Cell[1066368, 30181, 382, 9, 24, "Print",ExpressionUUID->"9e11e0f2-e656-4b3c-8db7-fabca53d1a44"],
Cell[1066753, 30192, 364, 9, 24, "Print",ExpressionUUID->"b724fe70-5b5d-49f7-9429-367297f69416"],
Cell[1067120, 30203, 382, 9, 24, "Print",ExpressionUUID->"deee769b-a39b-4745-b897-c8fe2ba31c64"],
Cell[1067505, 30214, 366, 9, 24, "Print",ExpressionUUID->"7fc2de09-b6db-4ea7-a233-298a8a2eeff8"],
Cell[1067874, 30225, 380, 9, 24, "Print",ExpressionUUID->"116cec83-db96-4124-a9bd-c77ca65ebee9"],
Cell[1068257, 30236, 364, 9, 24, "Print",ExpressionUUID->"688ae2d4-22ab-4998-b71f-3abd87367177"],
Cell[1068624, 30247, 379, 9, 24, "Print",ExpressionUUID->"12e0168e-25be-4e6c-9673-44e8d07a9834"],
Cell[1069006, 30258, 341, 9, 24, "Print",ExpressionUUID->"fa348472-f0fd-4ff3-8890-4c3acadc5330"],
Cell[1069350, 30269, 382, 9, 24, "Print",ExpressionUUID->"0531d051-4562-494b-863e-13307571985c"],
Cell[1069735, 30280, 382, 9, 24, "Print",ExpressionUUID->"b3d23517-fa70-42e7-b81a-1252d54e5df6"],
Cell[1070120, 30291, 380, 9, 24, "Print",ExpressionUUID->"0c141f55-a9ee-4414-af79-5bc649a23df9"],
Cell[1070503, 30302, 338, 9, 24, "Print",ExpressionUUID->"234f8965-eeac-4dde-9476-d58bb8abbd2a"],
Cell[1070844, 30313, 379, 9, 24, "Print",ExpressionUUID->"d275302a-b770-4411-8abe-6e615a37e4e3"],
Cell[1071226, 30324, 382, 9, 24, "Print",ExpressionUUID->"e24f6d48-71df-4223-8c7c-b1cffbcc9d33"],
Cell[1071611, 30335, 402, 10, 24, "Print",ExpressionUUID->"f5c543e5-a9b5-485a-9fda-6b94f5c4c044"],
Cell[1072016, 30347, 5209, 142, 113, "Print",ExpressionUUID->"e92db17e-3dcf-4c93-9989-5bc6c0fd03d1"],
Cell[1077228, 30491, 328, 8, 24, "Print",ExpressionUUID->"5f1b4351-4e63-42b8-ae94-e4eb8031b1f0"],
Cell[1077559, 30501, 364, 9, 24, "Print",ExpressionUUID->"7e2f8c49-f747-46fb-be2c-55896bce95a7"],
Cell[1077926, 30512, 406, 10, 24, "Print",ExpressionUUID->"61a6cdc2-6778-4b81-b189-0d40191ad893"],
Cell[1078335, 30524, 493, 11, 24, "Print",ExpressionUUID->"305338f5-f11c-47a3-bc4b-165ec440c8ef"],
Cell[1078831, 30537, 404, 10, 24, "Print",ExpressionUUID->"72027916-0577-4d2b-a6eb-f01969d088fa"],
Cell[1079238, 30549, 376, 9, 24, "Print",ExpressionUUID->"d37ea465-c756-437b-8c55-d9dcf305a393"],
Cell[1079617, 30560, 364, 9, 24, "Print",ExpressionUUID->"4f2d3b65-fa4d-4a11-a28c-6e73026a2e8d"],
Cell[1079984, 30571, 378, 9, 24, "Print",ExpressionUUID->"5168758c-ad11-4af4-b36b-a576892ea08a"],
Cell[1080365, 30582, 366, 9, 24, "Print",ExpressionUUID->"3d4ee03b-d7fd-4539-ba41-c82879a47c64"],
Cell[1080734, 30593, 378, 9, 24, "Print",ExpressionUUID->"68003a3a-6371-4ca3-b1c5-2df4bbb6ef2f"],
Cell[1081115, 30604, 378, 9, 24, "Print",ExpressionUUID->"1f572f1d-7ba5-4fa0-b63f-0f015657f15b"],
Cell[1081496, 30615, 493, 12, 24, "Print",ExpressionUUID->"fd75d9a1-d563-445e-9296-9c1981effe4d"],
Cell[1081992, 30629, 376, 9, 24, "Print",ExpressionUUID->"20c590ec-8188-4805-8cad-446421850dda"],
Cell[1082371, 30640, 376, 9, 24, "Print",ExpressionUUID->"273ab226-9981-4866-bcc1-2730f2434e9b"],
Cell[1082750, 30651, 364, 9, 24, "Print",ExpressionUUID->"ac808836-7c71-47b0-9dae-a259fb350d25"],
Cell[1083117, 30662, 376, 9, 24, "Print",ExpressionUUID->"b4f2cda2-4274-474d-8960-76c37750f81e"],
Cell[1083496, 30673, 364, 9, 24, "Print",ExpressionUUID->"d00f8dd3-ed02-4825-bde7-deec47faa058"],
Cell[1083863, 30684, 375, 9, 24, "Print",ExpressionUUID->"3918eed8-12f5-487a-ae4c-b404e2352305"],
Cell[1084241, 30695, 493, 11, 24, "Print",ExpressionUUID->"fd40be86-5261-4ae1-bbda-2455206ffadc"],
Cell[1084737, 30708, 404, 10, 24, "Print",ExpressionUUID->"dc9cc577-7d2d-46bf-adf7-166d31ba6223"],
Cell[1085144, 30720, 360, 9, 24, "Print",ExpressionUUID->"96bbac10-dca6-4aae-a640-1725ea3459c3"],
Cell[1085507, 30731, 524, 11, 24, "Print",ExpressionUUID->"e644bf3a-025a-4d9a-9e5f-ef773c45fb60"],
Cell[1086034, 30744, 368, 9, 24, "Print",ExpressionUUID->"96343f9a-b3b7-4db3-b680-0695d6ff7245"],
Cell[1086405, 30755, 408, 10, 24, "Print",ExpressionUUID->"5056f0b0-068e-45ef-9f02-3e609f47eebd"],
Cell[1086816, 30767, 400, 10, 24, "Print",ExpressionUUID->"82dc4e6a-4d43-49d5-af0e-e8c6f5759d8b"],
Cell[1087219, 30779, 183, 4, 24, "Print",ExpressionUUID->"f3d0b258-e02a-4846-b909-cc17249d613c"],
Cell[1087405, 30785, 427, 10, 24, "Print",ExpressionUUID->"964ca50f-67de-40f6-be50-b33835b19c25"],
Cell[1087835, 30797, 188, 4, 24, "Print",ExpressionUUID->"34a2bddb-5bbc-4ada-8743-41d2e9578002"],
Cell[1088026, 30803, 386, 9, 24, "Print",ExpressionUUID->"7a77c985-4f95-4aa7-8a01-61a024053954"],
Cell[1088415, 30814, 364, 9, 24, "Print",ExpressionUUID->"aa423383-8558-464d-8df9-fad21c54960f"],
Cell[1088782, 30825, 384, 9, 24, "Print",ExpressionUUID->"3570e7d7-2d21-4a50-aeeb-3ec289c0c56e"],
Cell[1089169, 30836, 334, 8, 24, "Print",ExpressionUUID->"5730c153-6aa7-4732-be31-87b3d5280091"],
Cell[1089506, 30846, 450, 11, 24, "Print",ExpressionUUID->"fc2aeb22-8943-4acd-ae99-2ef97dca5d25"],
Cell[1089959, 30859, 435, 10, 24, "Print",ExpressionUUID->"c44aab57-2276-4d37-aead-c6c6d776ed11"],
Cell[1090397, 30871, 522, 11, 24, "Print",ExpressionUUID->"b17c5c81-dbf6-467a-a357-03bef6d0172c"],
Cell[1090922, 30884, 326, 8, 24, "Print",ExpressionUUID->"4c5d4c0d-225c-4a17-8d7f-4ab55b0535ff"],
Cell[1091251, 30894, 356, 9, 24, "Print",ExpressionUUID->"3e0e7037-b622-44dd-aecd-82a288699bf6"],
Cell[1091610, 30905, 360, 9, 24, "Print",ExpressionUUID->"6ae9da75-91ff-414d-a1b7-3453a648caf4"],
Cell[1091973, 30916, 364, 9, 24, "Print",ExpressionUUID->"7314fc0c-aa90-4052-af7c-627670d3d64e"],
Cell[1092340, 30927, 348, 9, 24, "Print",ExpressionUUID->"3c04eb6d-ed19-4a09-ac3d-9c935029ce96"],
Cell[1092691, 30938, 563, 13, 40, "Print",ExpressionUUID->"d8441627-40ff-4b67-8df0-81217b9623df"],
Cell[1093257, 30953, 231, 5, 24, "Print",ExpressionUUID->"ee6a6efe-09a4-477a-a215-67ce81992d6a"],
Cell[1093491, 30960, 1099, 29, 27, "Print",ExpressionUUID->"76929c19-8212-4f59-8ce4-2436853722b3"],
Cell[1094593, 30991, 328, 8, 24, "Print",ExpressionUUID->"4c3a2549-8831-4228-970b-a376aa417a13"],
Cell[1094924, 31001, 526, 11, 24, "Print",ExpressionUUID->"8d9c5d93-6d4e-42e9-8893-f2b33a1157cb"],
Cell[1095453, 31014, 546, 13, 24, "Print",ExpressionUUID->"58375448-183e-4fa9-b704-d89f60ebdaba"],
Cell[1096002, 31029, 565, 13, 40, "Print",ExpressionUUID->"6d2c01f6-6111-4f99-b65c-ef9f4e6d255f"],
Cell[1096570, 31044, 565, 13, 40, "Print",ExpressionUUID->"e8186ddc-3316-42d3-a110-6ca94962200d"],
Cell[1097138, 31059, 534, 13, 24, "Print",ExpressionUUID->"fe22df7b-7716-4398-9786-16a80b928d6c"],
Cell[1097675, 31074, 552, 14, 24, "Print",ExpressionUUID->"cf596b93-3351-48fe-b257-4f68742b180e"],
Cell[1098230, 31090, 368, 9, 24, "Print",ExpressionUUID->"c3d36803-36ff-4096-b015-fae2119b4172"],
Cell[1098601, 31101, 398, 10, 24, "Print",ExpressionUUID->"a20142ac-3b26-4f1c-be91-01b1ae681dd2"],
Cell[1099002, 31113, 366, 9, 24, "Print",ExpressionUUID->"ab5a60db-9309-49ab-8e8f-060653df3277"],
Cell[1099371, 31124, 445, 11, 24, "Print",ExpressionUUID->"8bfe85ec-9c6b-44a2-8c19-8b424df353e0"],
Cell[1099819, 31137, 524, 11, 24, "Print",ExpressionUUID->"49b81949-ac32-4084-88fa-d0f86984aed8"],
Cell[1100346, 31150, 230, 5, 24, "Print",ExpressionUUID->"d5e2efc2-3d34-4c53-ac94-f89590458e1c"],
Cell[1100579, 31157, 2171, 60, 46, "Print",ExpressionUUID->"9bcc75f6-6a6d-4b96-9751-98a4d93dda9b"],
Cell[1102753, 31219, 326, 8, 24, "Print",ExpressionUUID->"04953537-7955-4d12-baea-407dac8828ae"],
Cell[1103082, 31229, 393, 10, 24, "Print",ExpressionUUID->"5aed6fd5-fd42-4d97-a75a-5519597e171f"],
Cell[1103478, 31241, 3412, 93, 69, "Print",ExpressionUUID->"9524dfe9-b20a-4147-8f24-edbac6bd619f"],
Cell[1106893, 31336, 441, 10, 24, "Print",ExpressionUUID->"58a29a32-ffbe-473b-81fc-e0a620194321"],
Cell[1107337, 31348, 524, 11, 24, "Print",ExpressionUUID->"96201719-086a-4152-95af-4355230905d8"],
Cell[1107864, 31361, 328, 8, 24, "Print",ExpressionUUID->"27cd492e-54fc-4f8f-94b2-f03537c5a792"],
Cell[1108195, 31371, 364, 9, 24, "Print",ExpressionUUID->"158bd75e-8297-4003-a69f-d4e4e76a714f"],
Cell[1108562, 31382, 441, 10, 24, "Print",ExpressionUUID->"f51e08f8-39b2-461d-8693-a8a693c482d6"],
Cell[1109006, 31394, 522, 11, 24, "Print",ExpressionUUID->"a88b3041-a102-4753-9142-c8218b1b4b59"],
Cell[1109531, 31407, 231, 5, 24, "Print",ExpressionUUID->"abeeb904-e3e6-48ee-8e1f-8ec6b53092b6"],
Cell[1109765, 31414, 954, 27, 27, "Print",ExpressionUUID->"72ff10fa-8541-4efa-b3d7-fd390b3bf251"],
Cell[1110722, 31443, 328, 8, 24, "Print",ExpressionUUID->"7053149d-22b1-4429-ad59-3d766db3fbca"],
Cell[1111053, 31453, 406, 10, 24, "Print",ExpressionUUID->"a79f0e5c-dc1b-48ff-8211-a9a59907377f"],
Cell[1111462, 31465, 360, 9, 24, "Print",ExpressionUUID->"8b4a126e-00a3-457e-a89b-5de8ccfdfda8"],
Cell[1111825, 31476, 435, 10, 24, "Print",ExpressionUUID->"b757f18f-a8b1-4aa4-a376-8ef274aa48ec"],
Cell[1112263, 31488, 524, 11, 24, "Print",ExpressionUUID->"f4870087-5327-43da-a15b-131f32a606f7"],
Cell[1112790, 31501, 231, 5, 24, "Print",ExpressionUUID->"31f5d0cb-5499-4700-9112-829e40dba9af"],
Cell[1113024, 31508, 292, 8, 24, "Print",ExpressionUUID->"8ae1b327-29c0-4de8-b21e-b8b750d66fdc"],
Cell[1113319, 31518, 326, 8, 24, "Print",ExpressionUUID->"d2b98130-7b1c-4639-91c7-f7ecdfe73caf"],
Cell[1113648, 31528, 523, 11, 24, "Print",ExpressionUUID->"20d440cb-a0bc-441d-85f0-8dee73020cee"],
Cell[1114174, 31541, 368, 9, 24, "Print",ExpressionUUID->"60f14c4d-9dce-4191-b053-fc0b03c3f135"],
Cell[1114545, 31552, 402, 10, 24, "Print",ExpressionUUID->"c161d676-d055-495d-82a1-799e2cad6e89"],
Cell[1114950, 31564, 364, 9, 24, "Print",ExpressionUUID->"35afd273-452f-4131-8b29-3c2366ebed6d"],
Cell[1115317, 31575, 400, 10, 24, "Print",ExpressionUUID->"60ea5e48-14c1-43a2-878a-ef0113f15ed2"],
Cell[1115720, 31587, 396, 10, 24, "Print",ExpressionUUID->"c41771be-830a-4258-8816-ea153c4a80c1"],
Cell[1116119, 31599, 394, 10, 24, "Print",ExpressionUUID->"48907d7b-771f-4dad-a5f7-abbf9d2e3f8e"],
Cell[1116516, 31611, 402, 10, 24, "Print",ExpressionUUID->"999ead4a-b95e-4194-8380-baaf491bf36e"],
Cell[1116921, 31623, 404, 10, 24, "Print",ExpressionUUID->"5d2804bc-7ea6-4bef-87d8-07194b6a9af1"],
Cell[1117328, 31635, 376, 9, 24, "Print",ExpressionUUID->"8bdf63b6-f598-409e-a106-ca98abb848dc"],
Cell[1117707, 31646, 442, 10, 24, "Print",ExpressionUUID->"413fd56e-917e-43ae-8b12-c0477f30261b"],
Cell[1118152, 31658, 412, 10, 24, "Print",ExpressionUUID->"2d7ce944-33f0-4f34-9aef-25f8dcb59624"],
Cell[1118567, 31670, 416, 10, 24, "Print",ExpressionUUID->"2d2af2b1-dedf-4505-95be-9348d79686a2"],
Cell[1118986, 31682, 414, 10, 24, "Print",ExpressionUUID->"b4888be2-d833-4158-9fc1-542a7e463320"],
Cell[1119403, 31694, 410, 10, 24, "Print",ExpressionUUID->"ffb887a0-d875-4133-9d26-e42262ea6cb1"],
Cell[1119816, 31706, 412, 10, 24, "Print",ExpressionUUID->"3e3e8155-6845-4c2d-b886-9742f28062dc"],
Cell[1120231, 31718, 400, 10, 24, "Print",ExpressionUUID->"cdfb4adf-5285-4ece-8103-8ac5436bca03"],
Cell[1120634, 31730, 364, 9, 24, "Print",ExpressionUUID->"01650861-ba6d-46ed-9a72-e6b0fbbf360a"],
Cell[1121001, 31741, 412, 10, 24, "Print",ExpressionUUID->"0b047718-4a1b-4545-ac0f-07d18dc5d3fd"],
Cell[1121416, 31753, 546, 13, 24, "Print",ExpressionUUID->"104bc433-4278-4798-a197-a9dbf83d3ca7"],
Cell[1121965, 31768, 231, 5, 24, "Print",ExpressionUUID->"c41ce66d-9aca-4a2d-98f8-42026f7a5e1a"],
Cell[1122199, 31775, 2334, 63, 46, "Print",ExpressionUUID->"178eef16-7dc7-4b23-9eda-1c410457e434"],
Cell[1124536, 31840, 326, 8, 24, "Print",ExpressionUUID->"2ab79d06-8b6c-4d38-b0a3-1ce36471ffe6"],
Cell[1124865, 31850, 406, 10, 24, "Print",ExpressionUUID->"cf6be7b6-ced5-400a-b242-093b87590f54"],
Cell[1125274, 31862, 398, 10, 24, "Print",ExpressionUUID->"abab0b31-7def-4b6c-941d-eabaa456ece4"],
Cell[1125675, 31874, 402, 10, 24, "Print",ExpressionUUID->"b0be5f5a-0f91-4556-8630-375bd7969dc1"],
Cell[1126080, 31886, 376, 9, 24, "Print",ExpressionUUID->"b359e90b-11f4-484f-955b-5c822273ecec"],
Cell[1126459, 31897, 376, 9, 24, "Print",ExpressionUUID->"b1d16b0a-cd9b-4377-aa23-cc37afe0e30a"],
Cell[1126838, 31908, 364, 9, 24, "Print",ExpressionUUID->"959ae247-5adc-49d7-a669-2ff22dfffaa5"],
Cell[1127205, 31919, 446, 10, 24, "Print",ExpressionUUID->"da9975d8-451b-48d6-90a2-d0f234a4be63"],
Cell[1127654, 31931, 378, 9, 24, "Print",ExpressionUUID->"768dd976-688c-4e8a-ba34-aa359555087d"],
Cell[1128035, 31942, 378, 9, 24, "Print",ExpressionUUID->"ec23616a-340b-4af4-80ff-d93f93fa7437"],
Cell[1128416, 31953, 376, 9, 24, "Print",ExpressionUUID->"d5442893-7251-4ddc-993d-d7259845f157"],
Cell[1128795, 31964, 375, 9, 24, "Print",ExpressionUUID->"f06cbf74-dd1a-47c2-bfe0-6321eb2710c2"],
Cell[1129173, 31975, 360, 9, 24, "Print",ExpressionUUID->"45c2c477-d8ff-4142-9d6b-c0c1b27c6c92"],
Cell[1129536, 31986, 524, 11, 24, "Print",ExpressionUUID->"8b46c42f-f824-4e4d-bfbf-4342ec76c88a"],
Cell[1130063, 31999, 368, 9, 24, "Print",ExpressionUUID->"b841aced-29f6-44a4-8afd-c2e3781ee192"],
Cell[1130434, 32010, 404, 10, 24, "Print",ExpressionUUID->"d4580fa2-cf94-42b5-b081-9dc26076ad51"],
Cell[1130841, 32022, 366, 9, 24, "Print",ExpressionUUID->"d2cd773a-edea-4c70-b580-ac509339c781"],
Cell[1131210, 32033, 404, 10, 24, "Print",ExpressionUUID->"2f3c1c1e-03f7-442f-a84f-d9e56b019ed8"],
Cell[1131617, 32045, 364, 9, 24, "Print",ExpressionUUID->"86bec850-24b8-4d57-bbb8-27e47e3c9014"],
Cell[1131984, 32056, 376, 9, 24, "Print",ExpressionUUID->"cd68b4ce-47f0-44ff-8e75-fe94139efc5f"],
Cell[1132363, 32067, 378, 9, 24, "Print",ExpressionUUID->"4577027d-2608-4a84-b368-22ee5440026f"],
Cell[1132744, 32078, 376, 9, 24, "Print",ExpressionUUID->"4f870942-41bc-4f1e-8229-701f6109fac6"],
Cell[1133123, 32089, 376, 9, 24, "Print",ExpressionUUID->"6107776f-ce66-455e-b85f-c1aac5a88de5"],
Cell[1133502, 32100, 376, 9, 24, "Print",ExpressionUUID->"cba9160f-ec7d-4c66-9c87-71fa7b3e90f3"],
Cell[1133881, 32111, 376, 9, 24, "Print",ExpressionUUID->"89e724df-a5cf-4508-9d6a-e0c78ed0ad0d"],
Cell[1134260, 32122, 406, 10, 24, "Print",ExpressionUUID->"9bc0c547-0fa7-457b-b429-023b862ee132"],
Cell[1134669, 32134, 376, 9, 24, "Print",ExpressionUUID->"1ba2031f-08f6-4f43-a49c-98946c505afb"],
Cell[1135048, 32145, 378, 9, 24, "Print",ExpressionUUID->"46d46662-af0d-4321-84d2-35416f17a31e"],
Cell[1135429, 32156, 376, 9, 24, "Print",ExpressionUUID->"8fd7a38a-9bec-4cbe-b00d-c9478ced337a"],
Cell[1135808, 32167, 378, 9, 24, "Print",ExpressionUUID->"9a89ce35-f1ed-43e7-8ab1-27eec13fba3e"],
Cell[1136189, 32178, 378, 9, 24, "Print",ExpressionUUID->"b80a1eee-3ffd-448f-b2cd-ca5a38099df3"],
Cell[1136570, 32189, 378, 9, 24, "Print",ExpressionUUID->"2af8c60f-7e17-4d20-853e-1e4385ebc162"],
Cell[1136951, 32200, 378, 9, 24, "Print",ExpressionUUID->"77ced8c3-b1d3-4afa-b075-d73491ec01d5"],
Cell[1137332, 32211, 376, 9, 24, "Print",ExpressionUUID->"56b932f8-8c2d-47e2-be31-8433138ee956"],
Cell[1137711, 32222, 376, 9, 24, "Print",ExpressionUUID->"7e394ba3-7b5a-4da9-bd17-13d2ee26bcc8"],
Cell[1138090, 32233, 366, 9, 24, "Print",ExpressionUUID->"6d1fecd6-6caa-45cc-b6ee-87a9d5ae1d88"],
Cell[1138459, 32244, 378, 9, 24, "Print",ExpressionUUID->"f4e7b76b-2a62-4f47-8717-3b245c159ce7"],
Cell[1138840, 32255, 376, 9, 24, "Print",ExpressionUUID->"20c145ad-bea1-4988-b6c3-afcc2e909028"],
Cell[1139219, 32266, 428, 10, 24, "Print",ExpressionUUID->"32abbb80-c17b-4b59-b090-ed9876c37854"],
Cell[1139650, 32278, 434, 10, 24, "Print",ExpressionUUID->"9d8c0a65-2ab8-4567-a255-13a3cbf51c06"],
Cell[1140087, 32290, 442, 10, 24, "Print",ExpressionUUID->"24c62086-c25f-4c7c-8285-465207aa33c6"],
Cell[1140532, 32302, 402, 10, 24, "Print",ExpressionUUID->"8540a26c-b3d1-46a5-add0-3cf1a23d6e84"],
Cell[1140937, 32314, 398, 10, 24, "Print",ExpressionUUID->"545fd4e3-f5b4-4a00-9202-6758533f78ad"],
Cell[1141338, 32326, 394, 10, 24, "Print",ExpressionUUID->"77a909e2-f587-4672-9f8a-694dcfee0dcc"],
Cell[1141735, 32338, 406, 10, 24, "Print",ExpressionUUID->"f8894b8c-d9a7-477c-95f8-4bfd8234b120"],
Cell[1142144, 32350, 396, 10, 24, "Print",ExpressionUUID->"c8ad8044-1e75-4d79-95ff-ffb075aaf7d5"],
Cell[1142543, 32362, 402, 10, 24, "Print",ExpressionUUID->"0148d006-1a47-4728-9c67-0b731f6964ae"],
Cell[1142948, 32374, 386, 10, 24, "Print",ExpressionUUID->"f3aff589-377e-4f7d-be40-5cc156cb16fb"],
Cell[1143337, 32386, 418, 10, 24, "Print",ExpressionUUID->"8eae0525-750b-475f-9038-06bde46f6571"],
Cell[1143758, 32398, 420, 10, 24, "Print",ExpressionUUID->"0691477b-ef16-4cf3-a960-7b6c6c73423e"],
Cell[1144181, 32410, 408, 10, 24, "Print",ExpressionUUID->"b9a8a3bc-8647-4f2c-afa3-53ef2dd84b35"],
Cell[1144592, 32422, 366, 9, 24, "Print",ExpressionUUID->"a098f875-8c79-44aa-a952-4f5da9c2a8da"],
Cell[1144961, 32433, 422, 10, 24, "Print",ExpressionUUID->"b2d30cc2-9f6b-4b98-bbdd-f437d2072153"],
Cell[1145386, 32445, 412, 10, 24, "Print",ExpressionUUID->"1f89a913-14c7-4396-b5a7-e09c1433b198"],
Cell[1145801, 32457, 406, 10, 24, "Print",ExpressionUUID->"d965d9c4-119c-4a02-8d39-5d6c015d1495"],
Cell[1146210, 32469, 408, 10, 24, "Print",ExpressionUUID->"15cae825-8a3e-49ef-a7dd-dbf041434d90"],
Cell[1146621, 32481, 387, 10, 24, "Print",ExpressionUUID->"a4085b34-670e-4125-8ab1-d423ad378f1a"],
Cell[1147011, 32493, 387, 10, 24, "Print",ExpressionUUID->"003199e2-c3fc-4ad1-9608-a05c52840b19"],
Cell[1147401, 32505, 1216, 32, 27, "Print",ExpressionUUID->"452f16fa-e631-4b9b-938f-8ff34d9334a4"],
Cell[1148620, 32539, 328, 8, 24, "Print",ExpressionUUID->"293a4d20-4b18-4cc7-8363-80eedb3a1903"],
Cell[1148951, 32549, 366, 9, 24, "Print",ExpressionUUID->"f8f75591-9862-4607-b73e-605b6f88721e"],
Cell[1149320, 32560, 451, 10, 24, "Print",ExpressionUUID->"1883a0f0-9e77-49f8-8c25-5580336f953e"],
Cell[1149774, 32572, 387, 10, 24, "Print",ExpressionUUID->"f4c3342b-55b3-499e-9182-92c50731dcc8"],
Cell[1150164, 32584, 387, 10, 24, "Print",ExpressionUUID->"80161d09-2a68-42b4-a8d6-d2efe045e313"],
Cell[1150554, 32596, 389, 10, 24, "Print",ExpressionUUID->"89b1f154-cabc-41bc-9a15-c7c549628c1d"],
Cell[1150946, 32608, 387, 10, 24, "Print",ExpressionUUID->"d4fcd7a6-2cc3-421a-9fee-36c03ef801e1"],
Cell[1151336, 32620, 412, 10, 24, "Print",ExpressionUUID->"e6854e97-d3f7-458d-b2b4-81fb26d1a674"],
Cell[1151751, 32632, 364, 9, 24, "Print",ExpressionUUID->"5340cb0a-c0d2-4536-82a3-584fc12fc85b"],
Cell[1152118, 32643, 412, 10, 24, "Print",ExpressionUUID->"7543d066-77ba-4231-b6f9-f1ccf0611a60"],
Cell[1152533, 32655, 364, 9, 24, "Print",ExpressionUUID->"5e9b3200-5adf-4bbd-8ce1-ada23a9e53d7"],
Cell[1152900, 32666, 387, 10, 24, "Print",ExpressionUUID->"aa57b8da-c73e-4e6b-801a-d93630cae315"],
Cell[1153290, 32678, 387, 10, 24, "Print",ExpressionUUID->"d26da36c-75ad-4266-8bea-b5f560fd7681"],
Cell[1153680, 32690, 389, 10, 24, "Print",ExpressionUUID->"30922086-4c5c-46fe-bb1a-60eb324f0d6b"],
Cell[1154072, 32702, 387, 10, 24, "Print",ExpressionUUID->"ca3ab680-7f01-49c3-9e4d-d1e8cdfaecd9"],
Cell[1154462, 32714, 386, 10, 24, "Print",ExpressionUUID->"1d976504-8cab-4154-a3c9-08d2c6d03cff"],
Cell[1154851, 32726, 387, 10, 24, "Print",ExpressionUUID->"8e240f3d-d7f5-432b-b6ef-c579764a2574"],
Cell[1155241, 32738, 416, 10, 24, "Print",ExpressionUUID->"3ca5da2c-a010-4808-8f3f-d2505f6091c9"],
Cell[1155660, 32750, 387, 10, 24, "Print",ExpressionUUID->"bd0f9678-7924-4ad7-86d1-61a7985b6768"],
Cell[1156050, 32762, 387, 10, 24, "Print",ExpressionUUID->"a6a5bfb2-7448-463c-89f5-c1b568c665b2"],
Cell[1156440, 32774, 389, 10, 24, "Print",ExpressionUUID->"98715a66-963a-415a-bca3-6345c35c53ee"],
Cell[1156832, 32786, 389, 10, 24, "Print",ExpressionUUID->"5b7a2988-9d20-442c-92b2-3aab2be60372"],
Cell[1157224, 32798, 387, 10, 24, "Print",ExpressionUUID->"ab166388-4757-4995-9897-61f1c4069752"],
Cell[1157614, 32810, 389, 10, 24, "Print",ExpressionUUID->"6dd40f00-d84c-4784-9b37-d4a9d92ddf7e"],
Cell[1158006, 32822, 387, 10, 24, "Print",ExpressionUUID->"664a48ab-2aa9-4d0e-bbf7-fa5a522ef193"],
Cell[1158396, 32834, 387, 10, 24, "Print",ExpressionUUID->"727e54c7-2a00-4cfe-a4cd-d4b4fb3dead2"],
Cell[1158786, 32846, 387, 10, 24, "Print",ExpressionUUID->"b2d4134e-422a-432e-9ac0-9e02a92037a2"],
Cell[1159176, 32858, 364, 9, 24, "Print",ExpressionUUID->"810f2e77-af80-410e-a97f-c6bf47db5350"],
Cell[1159543, 32869, 387, 10, 24, "Print",ExpressionUUID->"724a100e-a49e-4a50-905d-62c865853539"],
Cell[1159933, 32881, 389, 10, 24, "Print",ExpressionUUID->"0f14722b-9100-4874-91ed-800871c34a41"],
Cell[1160325, 32893, 436, 10, 24, "Print",ExpressionUUID->"f9d3e993-5d40-4e82-8524-90911715ae1c"],
Cell[1160764, 32905, 444, 10, 24, "Print",ExpressionUUID->"e2a68d47-3e18-4891-853d-224185b0e6f9"],
Cell[1161211, 32917, 450, 10, 24, "Print",ExpressionUUID->"a53b5a7f-b035-4492-96e3-ff1f8f7d9c9b"],
Cell[1161664, 32929, 396, 10, 24, "Print",ExpressionUUID->"91ac83ef-e1cf-486f-b438-10ce1ee3abec"],
Cell[1162063, 32941, 400, 10, 24, "Print",ExpressionUUID->"09519fb4-25ee-488f-b6c2-3f7f3adbc108"],
Cell[1162466, 32953, 382, 9, 24, "Print",ExpressionUUID->"cfe7f495-3125-4934-bc27-3935d9cc29e1"],
Cell[1162851, 32964, 379, 9, 24, "Print",ExpressionUUID->"863933a8-0582-4635-bb26-936757bfea2b"],
Cell[1163233, 32975, 378, 9, 24, "Print",ExpressionUUID->"7593f05c-eb8f-440b-bb5a-a630a2c332cb"],
Cell[1163614, 32986, 380, 9, 24, "Print",ExpressionUUID->"a6c39efd-59d5-4edc-8dd5-b5d1be827d5c"],
Cell[1163997, 32997, 382, 9, 24, "Print",ExpressionUUID->"90ffaf3e-fad4-42d4-a0eb-9d5ddbbb5a0c"],
Cell[1164382, 33008, 380, 9, 24, "Print",ExpressionUUID->"da4675ed-ab8b-4e9f-ad41-46a8137da123"],
Cell[1164765, 33019, 380, 9, 24, "Print",ExpressionUUID->"2be41da4-ed02-4e93-ab67-92b2e495551b"],
Cell[1165148, 33030, 382, 9, 24, "Print",ExpressionUUID->"d8fa39de-4a87-450b-a44c-d7cd970537bc"],
Cell[1165533, 33041, 379, 9, 24, "Print",ExpressionUUID->"bd852adc-3c58-4964-b9d5-eb53e3382021"],
Cell[1165915, 33052, 380, 9, 24, "Print",ExpressionUUID->"182d82e4-cfc7-4585-9199-994ed1061ec9"],
Cell[1166298, 33063, 380, 9, 24, "Print",ExpressionUUID->"aa958ff5-655a-4def-b57a-cd28324aec82"],
Cell[1166681, 33074, 382, 9, 24, "Print",ExpressionUUID->"1a774bc7-6728-4adc-9c61-97e6788e7a4e"],
Cell[1167066, 33085, 380, 9, 24, "Print",ExpressionUUID->"7b1b3e57-0f3f-42c8-978f-c63fb863113f"],
Cell[1167449, 33096, 379, 9, 24, "Print",ExpressionUUID->"3964ec17-8078-46e3-a383-690b4c1919f9"],
Cell[1167831, 33107, 379, 9, 24, "Print",ExpressionUUID->"7de8f3f6-febb-4fcb-96a2-adbf186e727f"],
Cell[1168213, 33118, 380, 9, 24, "Print",ExpressionUUID->"a881710a-a32a-4b61-8b3f-99e6540647e0"],
Cell[1168596, 33129, 380, 9, 24, "Print",ExpressionUUID->"010e58e0-b5bc-44e8-841d-f9d0801b52be"],
Cell[1168979, 33140, 380, 9, 24, "Print",ExpressionUUID->"25ce3fe2-c81b-4ddb-a916-d1a4844fb6e7"],
Cell[1169362, 33151, 402, 10, 24, "Print",ExpressionUUID->"b2d17eda-c221-4f3c-9f4d-bb4bade74484"],
Cell[1169767, 33163, 364, 9, 24, "Print",ExpressionUUID->"18789632-3932-47ad-b5a4-4fd12e7ca570"],
Cell[1170134, 33174, 404, 10, 24, "Print",ExpressionUUID->"260ede7c-8414-491d-83df-f59f9146d57e"],
Cell[1170541, 33186, 406, 10, 24, "Print",ExpressionUUID->"33e96e48-bbf5-4b90-89a0-8e6c965de93b"],
Cell[1170950, 33198, 376, 9, 24, "Print",ExpressionUUID->"062e0fad-ecc3-4dee-9af8-2644acbeb207"],
Cell[1171329, 33209, 376, 9, 24, "Print",ExpressionUUID->"29d00775-1312-4296-933a-13d7ff9540db"],
Cell[1171708, 33220, 378, 9, 24, "Print",ExpressionUUID->"fc3dd73a-d1f3-47a5-a625-2490b1fcee1a"],
Cell[1172089, 33231, 375, 9, 24, "Print",ExpressionUUID->"8d50b7f1-9d86-4676-8301-959a6622b280"],
Cell[1172467, 33242, 376, 9, 24, "Print",ExpressionUUID->"34d252ad-a8c7-40a1-913b-c4035635932a"],
Cell[1172846, 33253, 364, 9, 24, "Print",ExpressionUUID->"116219e1-5da8-4160-8278-8d334b1f735e"],
Cell[1173213, 33264, 376, 9, 24, "Print",ExpressionUUID->"4238a5a1-7711-4e22-a93a-7869a6fdf8f8"],
Cell[1173592, 33275, 376, 9, 24, "Print",ExpressionUUID->"e4b4f167-cffb-4111-891f-f3f9ec4aecfc"],
Cell[1173971, 33286, 376, 9, 24, "Print",ExpressionUUID->"39dcc0a7-3229-4821-adfa-6c95f6b57f97"],
Cell[1174350, 33297, 404, 10, 24, "Print",ExpressionUUID->"fb5d8bf4-aa18-4bd1-a283-ae921d8b403c"],
Cell[1174757, 33309, 360, 9, 24, "Print",ExpressionUUID->"6a904fcd-cebd-4cb3-a262-8e724bb774c9"],
Cell[1175120, 33320, 524, 11, 24, "Print",ExpressionUUID->"9a124662-12c7-4112-9b2f-96397cb0a6cf"],
Cell[1175647, 33333, 368, 9, 24, "Print",ExpressionUUID->"6a71da21-a48d-447d-b0fa-8531cf2b36af"],
Cell[1176018, 33344, 408, 10, 24, "Print",ExpressionUUID->"2502e9c0-877d-429b-9ae0-67f6c6964391"],
Cell[1176429, 33356, 400, 10, 24, "Print",ExpressionUUID->"83953672-e6ff-429a-a44d-7abd694deeba"],
Cell[1176832, 33368, 183, 4, 24, "Print",ExpressionUUID->"2bd520e2-02d6-473a-a6a2-4dafcf44a950"],
Cell[1177018, 33374, 420, 10, 24, "Print",ExpressionUUID->"6d86b41e-acd6-406e-9497-542b36dc82f3"],
Cell[1177441, 33386, 188, 4, 24, "Print",ExpressionUUID->"819a125b-87df-460d-a8d8-f8871a1ffe17"],
Cell[1177632, 33392, 384, 9, 24, "Print",ExpressionUUID->"dd1986db-8469-4004-809c-5376ec2b96a3"],
Cell[1178019, 33403, 364, 9, 24, "Print",ExpressionUUID->"fd05c962-4190-4d7f-9edb-8ca79091f7ec"],
Cell[1178386, 33414, 384, 9, 24, "Print",ExpressionUUID->"959754a9-bfea-428a-9c78-cc196c25edc0"],
Cell[1178773, 33425, 334, 8, 24, "Print",ExpressionUUID->"87e8d24e-eafe-4541-a1b0-bdd3e7982a2b"],
Cell[1179110, 33435, 448, 11, 24, "Print",ExpressionUUID->"681dc22e-5327-47b5-8edf-0236e0e6ac26"],
Cell[1179561, 33448, 435, 10, 24, "Print",ExpressionUUID->"9808d2b9-2b4b-4617-a7ef-545a159283dd"],
Cell[1179999, 33460, 522, 11, 24, "Print",ExpressionUUID->"ea62ea5e-1305-481a-9764-ed4253c626be"],
Cell[1180524, 33473, 326, 8, 24, "Print",ExpressionUUID->"d065eb6c-d8e0-4014-beba-a986561fe60f"],
Cell[1180853, 33483, 362, 9, 24, "Print",ExpressionUUID->"587af666-4853-47e4-a863-84f6bb28e351"],
Cell[1181218, 33494, 364, 9, 24, "Print",ExpressionUUID->"50886b82-879f-4086-a54e-f45fe2f759d3"],
Cell[1181585, 33505, 346, 9, 24, "Print",ExpressionUUID->"ee6cc113-7ed3-4107-b6df-4baa84d64305"],
Cell[1181934, 33516, 524, 11, 24, "Print",ExpressionUUID->"d4dcf169-0bb5-4fa3-9a00-18b00c949f77"],
Cell[1182461, 33529, 546, 13, 24, "Print",ExpressionUUID->"9c144a14-74f8-4e2d-a5d9-8573f16d4845"],
Cell[1183010, 33544, 565, 13, 40, "Print",ExpressionUUID->"a1dba588-ef75-4fa5-951f-30504c83747f"],
Cell[1183578, 33559, 565, 13, 40, "Print",ExpressionUUID->"704605b2-a7ba-428d-adb7-797ee0cdc147"],
Cell[1184146, 33574, 534, 13, 24, "Print",ExpressionUUID->"2438ef2b-80dd-472a-a7e2-8f45a4e5b2fd"],
Cell[1184683, 33589, 551, 14, 24, "Print",ExpressionUUID->"61db5cd0-0076-4a92-9670-3b567f6bf296"],
Cell[1185237, 33605, 368, 9, 24, "Print",ExpressionUUID->"c33a8e97-060e-41fb-95e0-6ab449af4e62"],
Cell[1185608, 33616, 396, 10, 24, "Print",ExpressionUUID->"94eae01e-9513-48d0-b215-8b39d64d8c46"],
Cell[1186007, 33628, 446, 11, 24, "Print",ExpressionUUID->"757074f9-9efa-4c91-8efa-aaa755c13627"],
Cell[1186456, 33641, 522, 11, 24, "Print",ExpressionUUID->"58fd54ff-feea-435d-8273-cdccc2802e99"],
Cell[1186981, 33654, 233, 5, 24, "Print",ExpressionUUID->"5a8f1369-072f-42b5-95d8-b15f3bec3be5"],
Cell[1187217, 33661, 14716, 343, 268, "Print",ExpressionUUID->"a5957cdf-9162-4007-880e-97720821759b"],
Cell[1201936, 34006, 326, 8, 24, "Print",ExpressionUUID->"67099b6d-3f9f-4e9f-8c70-7fe45d6d28c8"],
Cell[1202265, 34016, 394, 10, 24, "Print",ExpressionUUID->"8d7d31b5-d01a-4fd0-b0fc-3a2a20592526"],
Cell[1202662, 34028, 406, 10, 24, "Print",ExpressionUUID->"19d5d27a-7b27-4c2d-b18a-1810d80a8152"],
Cell[1203071, 34040, 404, 10, 24, "Print",ExpressionUUID->"c74056d0-71bd-41dd-b76a-d920033ff166"],
Cell[1203478, 34052, 364, 9, 24, "Print",ExpressionUUID->"ad12bb74-a5dc-484b-8483-cfcd09f53342"],
Cell[1203845, 34063, 400, 10, 24, "Print",ExpressionUUID->"b851fa30-2102-4f5d-971f-710eb8625ecf"],
Cell[1204248, 34075, 394, 10, 24, "Print",ExpressionUUID->"42b9f8c7-848a-473e-b3f0-7f13c3e8ca88"],
Cell[1204645, 34087, 394, 10, 24, "Print",ExpressionUUID->"bac9e26c-6a2f-4821-a5f9-b8822ec2cfe8"],
Cell[1205042, 34099, 404, 10, 24, "Print",ExpressionUUID->"20ec0805-cec5-47e6-be1a-29f7b9f1b3aa"],
Cell[1205449, 34111, 404, 10, 24, "Print",ExpressionUUID->"6eca1651-2ccc-4ac0-8da5-15a8671baebb"],
Cell[1205856, 34123, 338, 9, 24, "Print",ExpressionUUID->"6af036ca-eb7d-4512-8114-dfe7a3fec40e"],
Cell[1206197, 34134, 378, 9, 24, "Print",ExpressionUUID->"a3bbea34-2d46-4413-963a-ea4c7ede3dd5"],
Cell[1206578, 34145, 442, 10, 24, "Print",ExpressionUUID->"20169c0a-0949-4bb7-b066-4336c7a59ad3"],
Cell[1207023, 34157, 414, 10, 24, "Print",ExpressionUUID->"75eeb638-e984-4aa5-9633-87e022896de3"],
Cell[1207440, 34169, 413, 10, 24, "Print",ExpressionUUID->"22a5f006-8f09-4fc6-a0d2-13c4a962c818"],
Cell[1207856, 34181, 414, 10, 24, "Print",ExpressionUUID->"8013984a-5c39-4395-9e3a-108e2b804609"],
Cell[1208273, 34193, 410, 10, 24, "Print",ExpressionUUID->"c3a57ae3-5dfe-41b5-b1c7-ce5d7e3eaad2"],
Cell[1208686, 34205, 410, 10, 24, "Print",ExpressionUUID->"684003af-e2ac-4d0e-97da-bace875c9034"],
Cell[1209099, 34217, 400, 10, 24, "Print",ExpressionUUID->"6f344841-57b0-430a-b1f9-39614c046631"],
Cell[1209502, 34229, 412, 10, 24, "Print",ExpressionUUID->"8088bd4a-2f79-4ed4-bedd-b32d38360c38"],
Cell[1209917, 34241, 404, 10, 24, "Print",ExpressionUUID->"937e35e5-3cef-460a-9130-2ce7c04124a8"],
Cell[1210324, 34253, 398, 10, 24, "Print",ExpressionUUID->"6d01d6e0-b215-4cc5-acff-de9d75cb3b7b"],
Cell[1210725, 34265, 402, 10, 24, "Print",ExpressionUUID->"3612a20e-6a15-4f93-9bef-d19ad1df5351"],
Cell[1211130, 34277, 378, 9, 24, "Print",ExpressionUUID->"e7ce8aee-df9c-4429-9419-aa7dba490776"],
Cell[1211511, 34288, 376, 9, 24, "Print",ExpressionUUID->"98ecb6d9-4127-4276-810f-c9b7289316d7"],
Cell[1211890, 34299, 446, 10, 24, "Print",ExpressionUUID->"3227f53e-432b-4987-a1c8-64aec8ac78d3"],
Cell[1212339, 34311, 376, 9, 24, "Print",ExpressionUUID->"104e98fa-c6e3-4e44-a051-e3f916865b58"],
Cell[1212718, 34322, 375, 9, 24, "Print",ExpressionUUID->"bed622ff-29c8-4111-a1ce-c0765c31262d"],
Cell[1213096, 34333, 376, 9, 24, "Print",ExpressionUUID->"5a244631-28b8-4c93-9aa3-9a37234d39e5"],
Cell[1213475, 34344, 378, 9, 24, "Print",ExpressionUUID->"33e717c2-defa-4f60-a63a-0b631df6a872"],
Cell[1213856, 34355, 360, 9, 24, "Print",ExpressionUUID->"91c4dc18-9311-418e-9db3-29067f4a6a51"],
Cell[1214219, 34366, 523, 11, 24, "Print",ExpressionUUID->"35cab28f-a8c1-4050-bdf5-e089e64c6135"],
Cell[1214745, 34379, 370, 9, 24, "Print",ExpressionUUID->"27a9a4b3-f53e-43ba-a6c0-f4486c6a29f0"],
Cell[1215118, 34390, 403, 10, 24, "Print",ExpressionUUID->"2c00f0a0-924c-4722-be85-c8259a247a3a"],
Cell[1215524, 34402, 364, 9, 24, "Print",ExpressionUUID->"390ad224-9a86-4565-b24f-415cf3a0d2db"],
Cell[1215891, 34413, 404, 10, 24, "Print",ExpressionUUID->"c5f48879-aac0-453b-9ecd-8d31ad336a07"],
Cell[1216298, 34425, 364, 9, 24, "Print",ExpressionUUID->"5eb89828-5c34-413a-9a15-b7d848c65e37"],
Cell[1216665, 34436, 376, 9, 24, "Print",ExpressionUUID->"8db65027-dca2-4748-b6ee-2b47c9a0d9dd"],
Cell[1217044, 34447, 376, 9, 24, "Print",ExpressionUUID->"14c6e5bc-f793-4b37-9932-46abc0daa919"],
Cell[1217423, 34458, 378, 9, 24, "Print",ExpressionUUID->"34b0eb42-8851-4640-b889-dcb05128cb8e"],
Cell[1217804, 34469, 376, 9, 24, "Print",ExpressionUUID->"69824359-fa4f-4e42-b33c-670a41797db3"],
Cell[1218183, 34480, 376, 9, 24, "Print",ExpressionUUID->"73af87a7-6b89-445e-b033-874c93ef0484"],
Cell[1218562, 34491, 378, 9, 24, "Print",ExpressionUUID->"009818a4-cfd2-4848-9763-153198ec82eb"],
Cell[1218943, 34502, 408, 10, 24, "Print",ExpressionUUID->"0ff6f2b3-9955-4e3d-8685-b9831914e6cb"],
Cell[1219354, 34514, 376, 9, 24, "Print",ExpressionUUID->"67b0aeb8-3000-4c3a-bdf9-bba477f07785"],
Cell[1219733, 34525, 378, 9, 24, "Print",ExpressionUUID->"39158c36-d65f-4247-8aab-0740538d4bca"],
Cell[1220114, 34536, 378, 9, 24, "Print",ExpressionUUID->"4a9618ac-63eb-4cb5-81db-4b993e63e966"],
Cell[1220495, 34547, 376, 9, 24, "Print",ExpressionUUID->"415ee5f0-d24e-44b9-ace5-0ad64aefe55b"],
Cell[1220874, 34558, 366, 9, 24, "Print",ExpressionUUID->"22fa5a2b-db5f-4485-b579-f1ee2fdd6550"],
Cell[1221243, 34569, 376, 9, 24, "Print",ExpressionUUID->"cfafd1f1-d2cf-4b87-a5a4-0f2e609b0f9c"],
Cell[1221622, 34580, 376, 9, 24, "Print",ExpressionUUID->"79bd6759-8531-4875-9535-c1f992f741a4"],
Cell[1222001, 34591, 376, 9, 24, "Print",ExpressionUUID->"44b187e0-1b46-42f8-bb82-2bf7b02d7b0b"],
Cell[1222380, 34602, 376, 9, 24, "Print",ExpressionUUID->"d6e473b5-408c-4671-81ca-2d15961687d1"],
Cell[1222759, 34613, 376, 9, 24, "Print",ExpressionUUID->"efecf301-2193-4811-ad40-ac159d381e9a"],
Cell[1223138, 34624, 376, 9, 24, "Print",ExpressionUUID->"7c1086f0-afc8-4d15-b205-8b232509da74"],
Cell[1223517, 34635, 378, 9, 24, "Print",ExpressionUUID->"c6dfe17b-474d-4893-bb01-02efec922dc8"],
Cell[1223898, 34646, 430, 10, 24, "Print",ExpressionUUID->"453ead8f-a61d-4a08-bc18-560a9098cb31"],
Cell[1224331, 34658, 434, 10, 24, "Print",ExpressionUUID->"a8e755e2-0bb0-4383-80fa-0086cdc3b3c6"],
Cell[1224768, 34670, 442, 10, 24, "Print",ExpressionUUID->"51f0bfba-d47a-4c27-b74e-2cb85f98e1cb"],
Cell[1225213, 34682, 404, 10, 24, "Print",ExpressionUUID->"dc3505b2-e9ee-4774-8c2e-269835a6e6d3"],
Cell[1225620, 34694, 398, 10, 24, "Print",ExpressionUUID->"38521d6f-53a1-4e35-9d13-73b4793669f0"],
Cell[1226021, 34706, 392, 10, 24, "Print",ExpressionUUID->"b7d698ae-31e3-42b8-ab0f-04faffc605f5"],
Cell[1226416, 34718, 404, 10, 24, "Print",ExpressionUUID->"236ac498-1e3a-4975-9d90-e72eedd7c224"],
Cell[1226823, 34730, 394, 10, 24, "Print",ExpressionUUID->"a0fb6ceb-2485-4e0b-a558-55fe719c49a5"],
Cell[1227220, 34742, 400, 10, 24, "Print",ExpressionUUID->"c58bd6ea-4160-402e-9a49-ecdbd2ec48ab"],
Cell[1227623, 34754, 387, 10, 24, "Print",ExpressionUUID->"fd42e18c-8925-4120-8ed3-a3d5610c0d54"],
Cell[1228013, 34766, 418, 10, 24, "Print",ExpressionUUID->"2de60ee6-c050-4842-8b0f-ffae22f90623"],
Cell[1228434, 34778, 420, 10, 24, "Print",ExpressionUUID->"240ac400-1228-49e7-99e0-f2a529adc820"],
Cell[1228857, 34790, 408, 10, 24, "Print",ExpressionUUID->"c24950b4-db6a-40e1-a787-65a28949505c"],
Cell[1229268, 34802, 422, 10, 24, "Print",ExpressionUUID->"4c170645-6c91-42ee-83cd-0477f909e9d6"],
Cell[1229693, 34814, 414, 10, 24, "Print",ExpressionUUID->"b252d646-b2a4-43b0-b5ce-653f6e2013a7"],
Cell[1230110, 34826, 408, 10, 24, "Print",ExpressionUUID->"ef9cf6de-005e-4bd8-99fc-78d857709489"],
Cell[1230521, 34838, 408, 10, 24, "Print",ExpressionUUID->"fd1e726f-48a8-4cef-b03a-2f2d0bdc91e2"],
Cell[1230932, 34850, 389, 10, 24, "Print",ExpressionUUID->"2f7254f7-cefd-4fa7-bbe7-0badf2487c22"],
Cell[1231324, 34862, 387, 10, 24, "Print",ExpressionUUID->"ab5b8f38-e65f-4fa2-a3be-bb9326376cd0"],
Cell[1231714, 34874, 452, 10, 24, "Print",ExpressionUUID->"48b2ac41-fa58-4e5f-a60b-2d410ed07b8a"],
Cell[1232169, 34886, 387, 10, 24, "Print",ExpressionUUID->"a650ded3-6fa8-48f9-bd4c-a39fa3df1f72"],
Cell[1232559, 34898, 387, 10, 24, "Print",ExpressionUUID->"ed30dbfc-d784-43a5-baab-11c1b9c0cffa"],
Cell[1232949, 34910, 389, 10, 24, "Print",ExpressionUUID->"5ff72c83-99ef-447e-a025-8edd47659c51"],
Cell[1233341, 34922, 387, 10, 24, "Print",ExpressionUUID->"a726ab17-5627-4007-8d43-197fb1dbd187"],
Cell[1233731, 34934, 412, 10, 24, "Print",ExpressionUUID->"972c8911-febb-4762-91c7-80cfa82022ba"],
Cell[1234146, 34946, 364, 9, 24, "Print",ExpressionUUID->"47372527-1848-4f90-bce8-6ed02e650757"],
Cell[1234513, 34957, 414, 10, 24, "Print",ExpressionUUID->"15916a91-486d-4bf2-86b0-ef7c29ca2b27"],
Cell[1234930, 34969, 366, 9, 24, "Print",ExpressionUUID->"4637f2aa-eb89-4170-912f-bee7f3530d00"],
Cell[1235299, 34980, 387, 10, 24, "Print",ExpressionUUID->"84547ec9-3eae-48ba-bf59-7d88b350497e"],
Cell[1235689, 34992, 387, 10, 24, "Print",ExpressionUUID->"40665dce-be30-4267-aae0-3c50f54a2f8d"],
Cell[1236079, 35004, 387, 10, 24, "Print",ExpressionUUID->"4dcba5ee-247e-4f50-9530-df5d7523b425"],
Cell[1236469, 35016, 387, 10, 24, "Print",ExpressionUUID->"5b696564-00e6-4984-ade1-ee80f423a268"],
Cell[1236859, 35028, 387, 10, 24, "Print",ExpressionUUID->"e3d56359-fd3c-4d5f-a180-3b01af90ab8d"],
Cell[1237249, 35040, 387, 10, 24, "Print",ExpressionUUID->"314dcb19-d65c-4b82-b93a-4c481eff5fc6"],
Cell[1237639, 35052, 412, 10, 24, "Print",ExpressionUUID->"5dc73a8a-f6d7-46f3-8f05-8223853bc410"],
Cell[1238054, 35064, 387, 10, 24, "Print",ExpressionUUID->"29bc4254-fc71-4241-a8b0-ac6728c8027d"],
Cell[1238444, 35076, 389, 10, 24, "Print",ExpressionUUID->"b753665b-f4cd-45e1-bde4-bebb43bad8c5"],
Cell[1238836, 35088, 387, 10, 24, "Print",ExpressionUUID->"38be557f-f962-4979-855d-e9ade09aa0a1"],
Cell[1239226, 35100, 387, 10, 24, "Print",ExpressionUUID->"92ecdd4d-1141-4a24-a72c-2e5bc1f6c5a1"],
Cell[1239616, 35112, 364, 9, 24, "Print",ExpressionUUID->"5b39203b-3b41-44ed-a838-1e349da3cf94"],
Cell[1239983, 35123, 389, 10, 24, "Print",ExpressionUUID->"4c4f9722-0fed-497a-8899-6edb543913e5"],
Cell[1240375, 35135, 386, 10, 24, "Print",ExpressionUUID->"f1f2a0fa-89f7-4ac5-8428-4425e0c5a16b"],
Cell[1240764, 35147, 387, 10, 24, "Print",ExpressionUUID->"d62f8c90-867c-4924-bd87-4a705ad277f9"],
Cell[1241154, 35159, 389, 10, 24, "Print",ExpressionUUID->"df0cde3f-cdc7-4e58-aaa2-de002620570a"],
Cell[1241546, 35171, 387, 10, 24, "Print",ExpressionUUID->"9321da27-90ad-4f67-8116-5df02ffaf0f4"],
Cell[1241936, 35183, 387, 10, 24, "Print",ExpressionUUID->"bd4459a4-4aa6-41ae-a587-2e71723911e2"],
Cell[1242326, 35195, 387, 10, 24, "Print",ExpressionUUID->"d7bc06c3-25ba-4636-9d68-ea9f49499985"],
Cell[1242716, 35207, 436, 10, 24, "Print",ExpressionUUID->"88cefb63-736b-402e-99d7-8bf2406612ea"],
Cell[1243155, 35219, 442, 10, 24, "Print",ExpressionUUID->"1bce28f8-d994-4176-8cbb-dcdd1f64ba20"],
Cell[1243600, 35231, 450, 10, 24, "Print",ExpressionUUID->"658e1a73-942f-4d09-b22b-2e14ec51f7a4"],
Cell[1244053, 35243, 396, 10, 24, "Print",ExpressionUUID->"bc68ea02-eed5-436b-aeb0-78fbbd167529"],
Cell[1244452, 35255, 400, 10, 24, "Print",ExpressionUUID->"b778a36c-d7e1-4021-831e-f0da0835e4e4"],
Cell[1244855, 35267, 382, 9, 24, "Print",ExpressionUUID->"f23b73ab-cb75-452c-b5be-0cbd7a73a276"],
Cell[1245240, 35278, 380, 9, 24, "Print",ExpressionUUID->"205a72c3-08ce-4938-8b92-58e9dfaab067"],
Cell[1245623, 35289, 382, 9, 24, "Print",ExpressionUUID->"833b20e4-1124-4789-a614-e9d01ee8b331"],
Cell[1246008, 35300, 4225, 106, 101, "Print",ExpressionUUID->"74b65311-efe6-4f3e-9f42-27dbf61f6a2a"],
Cell[1250236, 35408, 328, 8, 24, "Print",ExpressionUUID->"fe68ac05-1aa4-4bee-89c3-c9f2bef7dfe8"],
Cell[1250567, 35418, 363, 9, 24, "Print",ExpressionUUID->"e86386dc-2c18-4493-ba6f-934f593235d9"],
Cell[1250933, 35429, 382, 9, 24, "Print",ExpressionUUID->"34157b5b-cf7b-4389-b3e4-34f6cf673d79"],
Cell[1251318, 35440, 382, 9, 24, "Print",ExpressionUUID->"f37a1592-259e-41af-996d-ee580d5e81a2"],
Cell[1251703, 35451, 382, 9, 24, "Print",ExpressionUUID->"70566f0c-a501-4746-ab39-26842bb99048"],
Cell[1252088, 35462, 380, 9, 24, "Print",ExpressionUUID->"ba495407-7c47-4f29-b956-8bcc02d35054"],
Cell[1252471, 35473, 380, 9, 24, "Print",ExpressionUUID->"5ab85b62-50d9-4a95-92e8-0e05611bfefa"],
Cell[1252854, 35484, 380, 9, 24, "Print",ExpressionUUID->"9884949e-d1ac-4be2-9388-46f5d55dbe3f"],
Cell[1253237, 35495, 382, 9, 24, "Print",ExpressionUUID->"4a757db4-d2c8-4b83-9ae6-521033d06eb3"],
Cell[1253622, 35506, 382, 9, 24, "Print",ExpressionUUID->"9cf9eeb8-eb2d-4db2-a591-52e6ca61468f"],
Cell[1254007, 35517, 380, 9, 24, "Print",ExpressionUUID->"97c664e1-be42-440c-bb26-a44f2222e3f4"],
Cell[1254390, 35528, 380, 9, 24, "Print",ExpressionUUID->"94eafeb4-7604-4f71-8933-6c87ee850f62"],
Cell[1254773, 35539, 380, 9, 24, "Print",ExpressionUUID->"4b685a8c-b94e-49bd-a3fc-d012490831a8"],
Cell[1255156, 35550, 382, 9, 24, "Print",ExpressionUUID->"a16b4c27-e7f7-403d-94e3-16b5d84ebe97"],
Cell[1255541, 35561, 380, 9, 24, "Print",ExpressionUUID->"190864e7-381e-43d7-ba57-2ee95c901bcd"],
Cell[1255924, 35572, 380, 9, 24, "Print",ExpressionUUID->"400d9209-11a4-407a-ac6b-a2c65a34d4b2"],
Cell[1256307, 35583, 380, 9, 24, "Print",ExpressionUUID->"fde6a5e8-9c3a-44a3-b72a-b44bf35ec944"],
Cell[1256690, 35594, 1516, 38, 44, "Print",ExpressionUUID->"b121f0f0-bc59-416b-841c-0495934cfde9"],
Cell[1258209, 35634, 326, 8, 24, "Print",ExpressionUUID->"a7754ec9-e724-467b-ab8a-6fb4487809e4"],
Cell[1258538, 35644, 366, 9, 24, "Print",ExpressionUUID->"e51ade34-61be-42b7-94ee-72820daea340"],
Cell[1258907, 35655, 402, 10, 24, "Print",ExpressionUUID->"50660b20-72e7-476a-b59e-2ffc75454145"],
Cell[1259312, 35667, 364, 9, 24, "Print",ExpressionUUID->"c6b5442b-763c-4d55-b875-0acd55ac7224"],
Cell[1259679, 35678, 404, 10, 24, "Print",ExpressionUUID->"4566fd87-5332-4f44-a329-a6b2fe25cc9f"],
Cell[1260086, 35690, 404, 10, 24, "Print",ExpressionUUID->"7398d87a-df2d-4676-896e-d7595cf3344b"],
Cell[1260493, 35702, 378, 9, 24, "Print",ExpressionUUID->"c6cddb1a-500b-4235-81ae-0ba8dcc26c28"],
Cell[1260874, 35713, 378, 9, 24, "Print",ExpressionUUID->"20b62377-fa87-412f-8b61-3fa115192db9"],
Cell[1261255, 35724, 376, 9, 24, "Print",ExpressionUUID->"e637838d-365c-4747-90ae-f239dd5d49c9"],
Cell[1261634, 35735, 376, 9, 24, "Print",ExpressionUUID->"e9530aad-08b3-4d25-a428-e9c9a1bceedc"],
Cell[1262013, 35746, 376, 9, 24, "Print",ExpressionUUID->"c350c24f-8af3-41f0-8952-ff0bff1e81af"],
Cell[1262392, 35757, 376, 9, 24, "Print",ExpressionUUID->"80719f87-cdf6-4964-93b4-2f3d6817388e"],
Cell[1262771, 35768, 378, 9, 24, "Print",ExpressionUUID->"2d3fb804-b465-43ef-8d63-670541c9f48c"],
Cell[1263152, 35779, 376, 9, 24, "Print",ExpressionUUID->"75d88415-02b2-461f-bedf-9e943d031476"],
Cell[1263531, 35790, 404, 10, 24, "Print",ExpressionUUID->"b885a4d8-f54c-4500-aed5-9ad387d8f714"],
Cell[1263938, 35802, 360, 9, 24, "Print",ExpressionUUID->"1f174a7f-20f9-407c-bd48-c13a246c36ee"],
Cell[1264301, 35813, 526, 11, 24, "Print",ExpressionUUID->"ca40c952-9f62-49fb-a8d0-7952abe5432a"],
Cell[1264830, 35826, 162, 3, 34, "Output",ExpressionUUID->"c17f15b9-d7ee-47d9-8924-5d7d6db66c5a"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

